import { __assign, __extends, __decorate } from 'tslib';
import React from 'react';
import { BuilderBlock, BuilderBlocks, Builder, BuilderComponent } from '@builder.io/react';

var BG_START_TAG = 'bg-image-start';
var BG_END_TAG = 'bg-image-end';
var sizes = {
    xsmall: {
        min: 0,
        default: 0,
        max: 0,
    },
    small: {
        min: 0,
        default: 321,
        max: 639,
    },
    medium: {
        min: 640,
        default: 641,
        max: 999,
    },
    large: {
        min: 1000,
        default: 1001,
        max: 1200,
    },
    getWidthForSize: function (size) {
        return this[size].default;
    },
    getSizeForWidth: function (width) {
        for (var _i = 0, sizeNames_1 = sizeNames; _i < sizeNames_1.length; _i++) {
            var size = sizeNames_1[_i];
            var value = this[size];
            if (width <= value.max) {
                return size;
            }
        }
        return 'large';
    },
};
var sizeNames = ['xsmall', 'small', 'medium', 'large'];
var camelCaseToKebabCase = function (str) {
    return str ? str.replace(/([A-Z])/g, function (g) { return "-" + g[0].toLowerCase(); }) : '';
};
var cssCase = function (property) {
    if (!property) {
        return property;
    }
    var str = camelCaseToKebabCase(property);
    if (property[0] === property[0].toUpperCase()) {
        str = '-' + str;
    }
    return str;
};
function mapToCss(map, spaces, important) {
    if (spaces === void 0) { spaces = 2; }
    if (important === void 0) { important = false; }
    return Object.keys(map).reduce(function (memo, key) {
        var value = map[key];
        if (typeof value !== 'string') {
            return memo;
        }
        return (memo +
            (value && value.trim()
                ? "\n" + ' '.repeat(spaces) + cssCase(key) + ": " + (value + (important ? ' !important' : '')) + ";"
                : ''));
    }, '');
}
var Block = /** @class */ (function (_super) {
    __extends(Block, _super);
    function Block() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.outerTable = null;
        return _this;
    }
    Block.prototype.getAlign = function (size) {
        var _a;
        var block = this.props.builderBlock;
        var sizeStyles = ((_a = block.responsiveStyles) === null || _a === void 0 ? void 0 : _a[size]) || {};
        var align = sizeStyles.marginRight === 'auto' && sizeStyles.marginLeft === 'auto'
            ? 'center'
            : sizeStyles.marginLeft === 'auto'
                ? 'right'
                : 'left';
        return align;
    };
    Block.prototype.getVAlign = function (size) {
        var block = this.props.builderBlock;
        var sizeStyles = block.responsiveStyles[size] || {};
        var vAlign = sizeStyles.marginBottom === 'auto' && sizeStyles.marginTop === 'auto'
            ? 'middle'
            : sizeStyles.marginTop === 'auto'
                ? 'bottom'
                : 'top';
        return vAlign;
    };
    Block.prototype.getOuterStyles = function (size) {
        var block = this.props.builderBlock;
        var sizeStyles = block.responsiveStyles[size] || {};
        var outerDisplay = sizeStyles.display;
        var outerVerticalAlign = sizeStyles.verticalAlign;
        var outerStyles = {
            width: '100%',
            border: '0',
            display: outerDisplay,
            verticalAlign: outerVerticalAlign,
        };
        return outerStyles;
    };
    Block.prototype.getMidStyles = function (size) {
        var block = this.props.builderBlock;
        var sizeStyles = block.responsiveStyles[size] || {};
        var align = this.getAlign(size);
        var vAlign = this.getVAlign(size);
        var midStyles = {
            paddingTop: sizeStyles.marginTop,
            paddingRight: sizeStyles.marginRight,
            paddingBottom: sizeStyles.marginBottom,
            paddingLeft: sizeStyles.marginLeft,
            verticalAlign: vAlign,
            width: (align === 'left' && sizeStyles.marginRight !== 'auto' && '100%') || undefined,
        };
        return midStyles;
    };
    Block.prototype.getInnerStyles = function (size) {
        var block = this.props.builderBlock;
        var align = this.getAlign(size);
        var sizeStyles = block.responsiveStyles[size] || {};
        var innerStyles = __assign(__assign(__assign({ verticalAlign: 'top' }, sizeStyles), { marginTop: undefined, marginBottom: undefined, marginLeft: undefined, marginRight: undefined, width: (align === 'left' && sizeStyles.marginRight !== 'auto' && '100%') || undefined, display: undefined }), this.props.innerStyleOverrides);
        return innerStyles;
    };
    Block.prototype.getInnerTableStyles = function (size) {
        var block = this.props.builderBlock;
        var sizeStyles = block.responsiveStyles[size] || {};
        var hasPxWidth = sizeStyles.width && sizeStyles.width.trim().endsWith('px');
        var align = this.getAlign(size);
        return {
            // TODO: hasPercent use that also
            width: hasPxWidth
                ? sizeStyles.width
                : (align === 'left' && sizeStyles.marginRight !== 'auto' && '100%') || undefined,
        };
    };
    Block.prototype.getLeftTdStyle = function (size) {
        var align = this.getAlign(size);
        return {
            // width: align === 'center' ? '45%' : '90%',
            display: align === 'right' || align === 'center' ? undefined : 'none',
        };
    };
    Block.prototype.getRightTdStyle = function (size) {
        var align = this.getAlign(size);
        return {
            // width: align === 'center' ? '45%' : '90%',
            display: align === 'left' || align === 'center' ? undefined : 'none',
        };
    };
    Object.defineProperty(Block.prototype, "css", {
        get: function () {
            var css = '';
            var block = this.props.builderBlock;
            if (!block) {
                return '';
            }
            var reversedNames = sizeNames.slice().reverse();
            if (block.responsiveStyles) {
                for (var _i = 0, reversedNames_1 = reversedNames; _i < reversedNames_1.length; _i++) {
                    var size = reversedNames_1[_i];
                    if (size !== 'large' &&
                        size !== 'xsmall' &&
                        block.responsiveStyles[size] &&
                        Object.keys(block.responsiveStyles[size]).length) {
                        // TODO: use emotion
                        css += "\n@media only screen and (max-width: " + sizes[size].max + "px) {\n  ." + block.id + " { " + mapToCss(this.getOuterStyles(size), 4, true) + " }\n  ." + block.id + "-inner { " + mapToCss(this.getInnerTableStyles(size), 4, true) + " }\n  ." + block.id + "-subject { " + mapToCss(this.getInnerStyles(size), 4, true) + " }\n  ." + block.id + "-middle { " + mapToCss(this.getMidStyles(size), 4, true) + " }\n}";
                    }
                }
            }
            return css;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Block.prototype, "bgImageUrl", {
        get: function () {
            var backgroundImage = this.props.builderBlock.responsiveStyles.large.backgroundImage;
            return backgroundImage && backgroundImage.replace(/.*?url\(['"]?(.*?)['"]?\).*?/, '$1');
        },
        enumerable: true,
        configurable: true
    });
    Block.prototype.render = function () {
        var _this = this;
        var block = this.props.builderBlock;
        var align = this.getAlign('large');
        var vAlign = this.getVAlign('large');
        var midStyles = this.getMidStyles('large');
        var attributes = this.props.attributes || {};
        var hasLink = attributes.href;
        var InnerTag = hasLink ? 'a' : 'span';
        var innerStyles = this.getInnerStyles('large');
        var bgImageUrl = this.bgImageUrl;
        var pxHeight = innerStyles.height && innerStyles.height.includes('px') && parseFloat(innerStyles.height);
        // TODO: only double wrap if hasMargin
        return (React.createElement(React.Fragment, null,
            React.createElement("style", { className: "builder-style" }, this.css),
            React.createElement("table", { role: "presentation", ref: function (ref) { return (_this.outerTable = ref); }, cellPadding: "0", cellSpacing: "0", "builder-id": attributes['builder-id'], className: attributes.class || attributes.className, style: this.getOuterStyles('large') },
                React.createElement("tbody", { style: { width: '100%' } },
                    React.createElement("tr", null,
                        React.createElement("td", null),
                        React.createElement("td", __assign({}, { align: align, vAlign: vAlign }, { style: midStyles, className: block.id + "-middle" }),
                            React.createElement(InnerTag, __assign({}, (hasLink
                                ? {
                                    href: attributes.href,
                                    target: '_blank',
                                    style: {
                                        textDecoration: 'none',
                                        // TODO: outlook this not always working
                                        color: 'inherit',
                                    },
                                }
                                : null)),
                                React.createElement("table", __assign({ role: "presentation", cellPadding: "0", cellSpacing: "0", className: block.id + "-inner", style: __assign(__assign({}, this.getInnerTableStyles('large')), { height: '100%' }) }, {
                                    border: '0',
                                }),
                                    React.createElement("tbody", { style: { width: '100%' } },
                                        React.createElement("tr", null,
                                            React.createElement("td", __assign({ className: "builder-block-subject " + this.props.builderBlock.id + "-subject", style: innerStyles }, (typeof pxHeight === 'number' &&
                                                !isNaN(pxHeight) && {
                                                height: pxHeight,
                                            })),
                                                bgImageUrl && (React.createElement(BG_START_TAG, { url: this.bgImageUrl, color: innerStyles.backgroundColor, height: innerStyles.height })),
                                                this.props.children,
                                                bgImageUrl && React.createElement(BG_END_TAG, null))))))),
                        React.createElement("td", null))))));
    };
    return Block;
}(React.Component));

// TODO: acceptsChildren option?
var Box = /** @class */ (function (_super) {
    __extends(Box, _super);
    function Box() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Box.prototype.render = function () {
        return (React.createElement(Block, { attributes: this.props.attributes, builderBlock: this.props.builderBlock, innerStyleOverrides: { verticalAlign: this.props.verticalAlignContent } },
            React.createElement(BuilderBlocks, { blocks: this.props.children, dataPath: "children", emailMode: true })));
    };
    Box = __decorate([
        BuilderBlock({
            name: 'Email:Box',
            inputs: [
                {
                    name: 'children',
                    type: 'uiBlocks',
                    defaultValue: [],
                    // showNoBlocks: false
                    hideFromUI: true,
                },
                {
                    name: 'verticalAlignContent',
                    type: 'string',
                    enum: ['top', 'bottom', 'middle'],
                    defaultValue: 'top',
                },
            ],
            defaultStyles: {
                height: '200px',
            },
        })
    ], Box);
    return Box;
}(React.Component));

var defaultBlocks = [
    {
        '@type': '@builder.io/sdk:Element',
        responsiveStyles: {
            large: {
                marginTop: '20px',
                minWidth: '20px',
                overflow: 'hidden',
                fontSize: '0px',
            },
        },
        component: {
            name: 'Email:Image',
            options: {
                image: 'https://builder.io/api/v1/image/assets%2Fpwgjf0RoYWbdnJSbpBAjXNRMe9F2%2Ffb27a7c790324294af8be1c35fe30f4d',
            },
        },
    },
    {
        '@type': '@builder.io/sdk:Element',
        responsiveStyles: {
            large: {
                marginTop: '20px',
                textAlign: 'center',
            },
        },
        component: {
            name: 'Email:Text',
            options: {
                text: '<span>Enter some text...</span>',
            },
        },
    },
];
var Columns = /** @class */ (function (_super) {
    __extends(Columns, _super);
    function Columns() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Columns.prototype.render = function () {
        var _this = this;
        return (React.createElement(Block, { attributes: this.props.attributes, builderBlock: this.props.builderBlock },
            this.props.stackColumnsAt && this.props.stackColumnsAt !== 'never' && (React.createElement("style", null, "\n          @media only screen and (max-width:" + (this.props.stackColumnsAt === 'mobile' ? 639 : 999) + "px) {\n            ." + this.props.builderBlock.id + "-separator-td {\n              display: none !important;\n            }\n\n            ." + this.props.builderBlock.id + "-subject-td {\n              display: block !important;\n              width: 100% !important;\n            }\n          }\n        ")),
            React.createElement("table", { style: { width: '100%' }, cellPadding: "0", cellSpacing: "0" },
                React.createElement("tbody", null,
                    React.createElement("tr", null, this.props.columns.map(function (col, index) { return (
                    // TODO: width
                    React.createElement(React.Fragment, { key: index },
                        index !== 0 && (React.createElement("td", { className: _this.props.builderBlock.id + "-separator-td", style: {
                                width: _this.props.space,
                                minWidth: _this.props.space,
                            } })),
                        React.createElement("td", { className: _this.props.builderBlock.id + "-subject-td", style: {
                                width: col.width,
                                verticalAlign: _this.props.verticalAlignContent || 'top',
                            } },
                            React.createElement(BuilderBlocks, { blocks: col.blocks, dataPath: "columns." + index + ".blocks", emailMode: true })))); }))))));
    };
    Columns = __decorate([
        BuilderBlock({
            name: 'Email:Columns',
            inputs: [
                {
                    name: 'columns',
                    type: 'array',
                    subFields: [
                        {
                            name: 'blocks',
                            type: 'uiBlocks',
                            hideFromUI: true,
                            defaultValue: defaultBlocks,
                        },
                        {
                            name: 'width',
                            type: 'string',
                            // defaultValue: 'auto',
                            // advanced: true,
                            helperText: 'Width, e.g. set to "100px" to always be 100 pixels wide, or "50%" to always fill 50% of the entire space',
                        },
                        {
                            name: 'verticalAlignContent',
                            type: 'string',
                            enum: ['top', 'bottom', 'middle'],
                            defaultValue: 'top',
                        },
                    ],
                    defaultValue: [
                        { blocks: defaultBlocks, width: '50%' },
                        { blocks: defaultBlocks, width: '50%' },
                    ],
                    onChange: function (options) {
                        var columns = options.get('columns');
                        var colsWithoutPx = columns.filter(function (col) {
                            var width = col.get('width') || '';
                            return !width.includes('px');
                        });
                        function round(num) {
                            return Math.round(num * 1000) / 1000;
                        }
                        function clearWidths() {
                            colsWithoutPx.forEach(function (col) {
                                // TODO: round
                                col.set('width', round(100 / colsWithoutPx.length) + '%');
                            });
                        }
                        if (Array.isArray(columns)) {
                            var containsColumnWithWidth = !!colsWithoutPx.find(function (col) { return col.get('width'); });
                            if (containsColumnWithWidth) {
                                var containsColumnWithoutWidth = !!colsWithoutPx.find(function (col) { return !col.get('width'); });
                                if (containsColumnWithoutWidth) {
                                    clearWidths();
                                }
                                else {
                                    var sumWidths = colsWithoutPx.reduce(function (memo, col) {
                                        return memo + col.get('width');
                                    }, 0);
                                    var widthsDontAddUp = sumWidths !== 100;
                                    if (widthsDontAddUp) {
                                        clearWidths();
                                    }
                                }
                            }
                        }
                    },
                },
                {
                    name: 'space',
                    friendlyName: 'Gap size',
                    type: 'number',
                    defaultValue: 20,
                    helperText: 'Size of gap between columns',
                },
                {
                    name: 'stackColumnsAt',
                    type: 'string',
                    defaultValue: 'mobile',
                    helperText: 'Convert horizontal columns to vertical at what device size',
                    enum: ['tablet', 'mobile', 'never'],
                },
            ],
        })
    ], Columns);
    return Columns;
}(React.Component));

var CustomCode = /** @class */ (function (_super) {
    __extends(CustomCode, _super);
    function CustomCode() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CustomCode.prototype.render = function () {
        return (React.createElement(Block, { attributes: this.props.attributes, builderBlock: this.props.builderBlock },
            React.createElement("span", { dangerouslySetInnerHTML: { __html: this.props.code } })));
    };
    CustomCode = __decorate([
        BuilderBlock({
            name: 'Email:CustomCode',
            inputs: [
                {
                    name: 'code',
                    type: 'html',
                    required: true,
                    defaultValue: 'I am custom html',
                },
            ],
        })
    ], CustomCode);
    return CustomCode;
}(React.Component));

function getStyles(block) {
    // TODO: responsive
    var styles = block && block.responsiveStyles && block.responsiveStyles.large;
    return styles;
}

function updateQueryParam(uri, key, value) {
    if (uri === void 0) { uri = ''; }
    var re = new RegExp('([?&])' + key + '=.*?(&|$)', 'i');
    var separator = uri.indexOf('?') !== -1 ? '&' : '?';
    if (uri.match(re)) {
        return uri.replace(re, '$1' + key + '=' + encodeURIComponent(value) + '$2');
    }
    return uri + separator + key + '=' + encodeURIComponent(value);
}
var DEFAULT_ASPECT_RATIO = 0.7041;
var Image = /** @class */ (function (_super) {
    __extends(Image, _super);
    function Image() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Image.prototype.getSrcSet = function () {
        var url = this.props.image;
        if (!url) {
            return url;
        }
        var sizes = [100, 200, 400, 800, 1200, 1600, 2000];
        return sizes
            .map(function (size) { return updateQueryParam(url, 'width', String(size)) + " " + size + "w"; })
            .concat([url])
            .join(', ');
    };
    Image.prototype.render = function () {
        var allStyles = getStyles(this.props.builderBlock) || {};
        var srcset = this.props.srcset;
        var image = this.props.image;
        if (srcset && image && image.includes('/api/v1/image')) {
            if (!srcset.includes(image.split('?')[0])) {
                console.debug('Removed given srcset');
                srcset = this.getSrcSet();
            }
        }
        else if (image) {
            srcset = this.getSrcSet();
        }
        return (React.createElement(Block, { attributes: this.props.attributes, builderBlock: this.props.builderBlock },
            React.createElement("img", { key: Builder.isEditing
                    ? (typeof this.props.image === 'string' && this.props.image.split('?')[0]) ||
                        undefined
                    : undefined, alt: this.props.altText, height: this.props.height, width: this.props.width, role: !this.props.altText ? 'presentation' : undefined, style: {
                    height: allStyles.height || 'auto',
                    // maxWidth: '100%',
                    width: '100%',
                }, className: "builder-image", src: this.props.image, sizes: this.props.sizes, srcSet: srcset })));
    };
    Image = __decorate([
        BuilderBlock({
            name: 'Email:Image',
            image: 'https://firebasestorage.googleapis.com/v0/b/builder-3b0a2.appspot.com/o/images%2Fbaseline-insert_photo-24px.svg?alt=media&token=4e5d0ef4-f5e8-4e57-b3a9-38d63a9b9dc4',
            defaultStyles: {
                minHeight: '20px',
                minWidth: '20px',
                overflow: 'hidden',
                fontSize: '0px',
                textAlign: 'center',
            },
            inputs: [
                {
                    name: 'image',
                    type: 'file',
                    // TODO: gif!
                    allowedFileTypes: ['jpeg', 'jpg', 'png', 'svg'],
                    required: true,
                    // TODO: something better
                    defaultValue: 'https://builder.io/api/v1/image/assets%2Fpwgjf0RoYWbdnJSbpBAjXNRMe9F2%2Ffb27a7c790324294af8be1c35fe30f4d',
                    onChange: function (options) {
                        var DEFAULT_ASPECT_RATIO = 0.7041;
                        function loadImage(url, timeout) {
                            if (timeout === void 0) { timeout = 60000; }
                            return new Promise(function (resolve, reject) {
                                var img = document.createElement('img');
                                var loaded = false;
                                img.onload = function () {
                                    loaded = true;
                                    resolve(img);
                                };
                                img.addEventListener('error', function (event) {
                                    console.warn('Image load failed', event.error);
                                    reject(event.error);
                                });
                                img.src = url;
                                setTimeout(function () {
                                    if (!loaded) {
                                        reject(new Error('Image load timed out'));
                                    }
                                }, timeout);
                            });
                        }
                        // // TODO
                        var value = options.get('image');
                        var aspectRatio = options.get('aspectRatio');
                        if (value && (!aspectRatio || aspectRatio === DEFAULT_ASPECT_RATIO)) {
                            return loadImage(value).then(function (img) {
                                var possiblyUpdatedAspectRatio = options.get('aspectRatio');
                                if (options.get('image') === value &&
                                    (!possiblyUpdatedAspectRatio || possiblyUpdatedAspectRatio === DEFAULT_ASPECT_RATIO)) {
                                    if (img.width && img.height) {
                                        // options.set('aspectRatio', round(img.height / img.width));
                                        options.set('height', img.height);
                                        options.set('width', img.width);
                                    }
                                }
                            });
                        }
                    },
                },
                {
                    name: 'altText',
                    type: 'string',
                    helperText: 'Text to display when the user has images off',
                },
                {
                    name: 'height',
                    type: 'number',
                    hideFromUI: true,
                },
                {
                    name: 'width',
                    type: 'number',
                    hideFromUI: true,
                },
                {
                    name: 'aspectRatio',
                    type: 'number',
                    helperText: "This is the ratio of height/width, e.g. set to 1.5 for a 300px wide and 200px tall photo. Set to 0 to not force the image to maintain it's aspect ratio",
                    advanced: true,
                    defaultValue: DEFAULT_ASPECT_RATIO,
                },
            ],
        })
    ], Image);
    return Image;
}(React.Component));

var Text = /** @class */ (function (_super) {
    __extends(Text, _super);
    function Text() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Text.prototype.render = function () {
        return (React.createElement(Block, { attributes: this.props.attributes, builderBlock: this.props.builderBlock },
            React.createElement("span", { dangerouslySetInnerHTML: { __html: this.props.text } })));
    };
    Text = __decorate([
        BuilderBlock({
            name: 'Email:Text',
            inputs: [
                {
                    name: 'text',
                    type: 'html',
                    required: true,
                    defaultValue: '<span>Enter some text...</span>',
                },
            ],
            defaultStyles: {
                lineHeight: 'normal',
                height: 'auto',
                textAlign: 'center',
            },
        })
    ], Text);
    return Text;
}(React.Component));

// TODO: acceptsChildren option?
var Section = /** @class */ (function (_super) {
    __extends(Section, _super);
    function Section() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Section.prototype.render = function () {
        return (React.createElement(Block, { attributes: this.props.attributes, builderBlock: this.props.builderBlock, innerStyleOverrides: { verticalAlign: this.props.verticalAlignContent } },
            React.createElement("table", __assign({ cellPadding: "0", cellSpacing: "0" }, {
                width: '100%',
                border: '0',
            }),
                React.createElement("tbody", null,
                    React.createElement("tr", null,
                        React.createElement("td", null),
                        React.createElement("td", __assign({}, { align: 'center', width: this.props.maxWidth }, { style: { maxWidth: '100%' } }),
                            React.createElement("div", { style: { margin: 'auto', maxWidth: this.props.maxWidth } },
                                React.createElement(BuilderBlocks, { blocks: this.props.children, dataPath: "children", emailMode: true }))),
                        React.createElement("td", null))))));
    };
    Section = __decorate([
        BuilderBlock({
            name: 'Email:Section',
            inputs: [
                {
                    name: 'children',
                    type: 'uiBlocks',
                    defaultValue: [
                        {
                            '@type': '@builder.io/sdk:Element',
                            responsiveStyles: {
                                large: {
                                    // marginTop: '20px',
                                    textAlign: 'center',
                                },
                            },
                            component: {
                                name: 'Email:Text',
                                options: {
                                    text: "<span>I am a section! My content keeps from getting too wide, so that it's easy to read even on big screens. Lorem ipsum dolor kismet etc etc :)</span>",
                                },
                            },
                        },
                    ],
                    // showNoBlocks: false
                    hideFromUI: true,
                },
                {
                    name: 'maxWidth',
                    type: 'number',
                    defaultValue: 800,
                },
                {
                    name: 'verticalAlignContent',
                    type: 'string',
                    enum: ['top', 'bottom', 'middle'],
                    defaultValue: 'top',
                },
            ],
            defaultStyles: {
                // height: '200px',
                paddingLeft: '20px',
                paddingRight: '20px',
                paddingTop: '50px',
                paddingBottom: '50px',
                marginTop: '0px',
            },
        })
    ], Section);
    return Section;
}(React.Component));

var resetStyles = "\n/* Based on The MailChimp Reset INLINE: Yes. */\n\n/* Client-specific Styles */\n/* Force Outlook to provide a \"view in browser\" menu link. */\n#outlook a {\n    padding:0;\n}\n\na {\n    text-decoration: none;\n    color: inherit;\n}\n\nbody {\n    width:100% !important;\n    -webkit-text-size-adjust:100%;\n    -ms-text-size-adjust:100%;\n    margin:0;\n    padding:0;\n}\n\n/* Prevent Webkit and Windows Mobile platforms from changing default font sizes.*/\n/* Force Hotmail to display emails at full width */\n.ExternalClass {\n    width:100%;\n}\n.ExternalClass,\n.ExternalClass p,\n.ExternalClass span,\n.ExternalClass font,\n.ExternalClass td,\n.ExternalClass div {\n    line-height: 100%;\n}\n\n/* Forces Hotmail to display normal line spacing.  More on that: http://www.emailonacid.com/forum/viewthread/43/ */\n#backgroundTable {\n    margin:0;\n    padding:0;\n    width:100% !important;\n    line-height: 100% !important;\n}\n\n/* End reset */\n\n/* Some sensible defaults for images Bring inline: Yes. */\nimg {\n    outline:none;\n    text-decoration:none;\n    -ms-interpolation-mode: bicubic;\n}\n\na img {\n    border:none;\n}\n\n.image_fix {\n    display:block;\n}\n\n/* Yahoo paragraph fix Bring inline: Yes. */\np {\n    /* margin: 1em 0;*/\n    margin: 0;\n}\n\n/* Hotmail header color reset Bring inline: Yes. */\nh1, h2, h3, h4, h5, h6 {\n    color: black !important;\n}\n\nh1 a, h2 a, h3 a, h4 a, h5 a, h6 a {\n    color: blue !important;\n}\n\n/* Preferably not the same color as the normal header link color.  There is limited support for psuedo classes in email clients, this was added just for good measure. */\nh1 a:active,\nh2 a:active,\nh3 a:active,\nh4 a:active,\nh5 a:active,\nh6 a:active {\n    color: red !important;\n}\n\n/* Preferably not the same color as the normal header link color. There is limited support for psuedo classes in email clients, this was added just for good measure. */\nh1 a:visited,\nh2 a:visited,\nh3 a:visited,\nh4 a:visited,\nh5 a:visited,\nh6 a:visited {\n    color: purple !important;\n}\n\n/* Outlook 07, 10 Padding issue fix Bring inline: No.*/\ntable td {\n    border-collapse: collapse;\n}\n\n/* Remove spacing around Outlook 07, 10 tables Bring inline: Yes */\ntable {\n    border-collapse:collapse; mso-table-lspace:0pt; mso-table-rspace:0pt;\n}\n\n/* Styling your links has become much simpler with the new Yahoo.  In fact, it falls in line with the main credo of styling in email and make sure to bring your styles inline.  Your link colors will be uniform across clients when brought inline. Bring inline: Yes. */\na {\n    color: orange;\n}\n\n\n/***************************************************\n ****************************************************\n MOBILE TARGETING\n ****************************************************\n ***************************************************/\n @media only screen and (max-device-width: 480px) {\n     /* Part one of controlling phone number linking for mobile. */\n a[href^=\"tel\"], a[href^=\"sms\"] {\n     text-decoration: none;\n     color: blue; /* or whatever your want */\n     pointer-events: none;\n     cursor: default;\n }\n\n .mobile_link a[href^=\"tel\"], .mobile_link a[href^=\"sms\"] {\n     text-decoration: default;\n     color: orange !important;\n     pointer-events: auto;\n     cursor: default;\n }\n\n }\n\n /* More Specific Targeting */\n\n @media only screen and (min-device-width: 768px) and (max-device-width: 1024px) {\n /* You guessed it, ipad (tablets, smaller screens, etc) */\n     /* repeating for the ipad */\n     a[href^=\"tel\"], a[href^=\"sms\"] {\n                 text-decoration: none;\n                 color: blue; /* or whatever your want */\n                 pointer-events: none;\n                 cursor: default;\n             }\n\n .mobile_link a[href^=\"tel\"], .mobile_link a[href^=\"sms\"] {\n             text-decoration: default;\n             color: orange !important;\n             pointer-events: auto;\n             cursor: default;\n         }\n }\n\n @media only screen and (-webkit-min-device-pixel-ratio: 2) {\n /* iPhone 4g styles in here */\n }\n\n /* Android targeting */\n @media only screen and (-webkit-device-pixel-ratio:.75){\n /* CSS for low density (ldpi) Android layouts in here */\n }\n @media only screen and (-webkit-device-pixel-ratio:1){\n /* CSS for medium density (mdpi) Android layouts in here */\n }\n @media only screen and (-webkit-device-pixel-ratio:1.5){\n /* CSS for high density (hdpi) Android layouts in here */\n }\n /* end Android targeting */\n\n";

var Email = /** @class */ (function (_super) {
    __extends(Email, _super);
    function Email() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Email.prototype.render = function () {
        return (React.createElement(React.Fragment, null,
            React.createElement("html", null,
                React.createElement("head", null,
                    React.createElement("meta", { "http-equiv": "Content-Type", content: "text/html; charset=utf-8" }),
                    React.createElement("meta", { name: "viewport", content: "width=device-width, initial-scale=1.0" }),
                    React.createElement("title", null, this.props.title),
                    React.createElement("style", { type: "text/css" }, resetStyles)),
                React.createElement("body", null, this.props.children))));
    };
    Email = __decorate([
        BuilderBlock({
            name: 'Email:Email',
            inputs: [
                {
                    name: 'title',
                    type: 'text',
                    required: true,
                    defaultValue: 'Email title',
                },
            ],
        })
    ], Email);
    return Email;
}(React.Component));

var EmailPreview = /** @class */ (function (_super) {
    __extends(EmailPreview, _super);
    function EmailPreview() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    EmailPreview.prototype.render = function () {
        return (React.createElement("div", null,
            React.createElement("style", { type: "text/css" }, resetStyles),
            this.props.children));
    };
    return EmailPreview;
}(React.Component));

var EmailPreviewComponent = /** @class */ (function (_super) {
    __extends(EmailPreviewComponent, _super);
    function EmailPreviewComponent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    EmailPreviewComponent.prototype.render = function () {
        return (React.createElement(EmailPreview, null,
            React.createElement(BuilderComponent, __assign({ emailMode: true }, this.props))));
    };
    return EmailPreviewComponent;
}(React.Component));

export { Box, Columns, CustomCode, Image, Text, Section, Email, EmailPreview, EmailPreviewComponent };
//# sourceMappingURL=builder-email.esm.js.map
