"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var react_1 = require("react");
var BG_START_TAG = 'bg-image-start';
var BG_END_TAG = 'bg-image-end';
var sizes = {
    xsmall: {
        min: 0,
        default: 0,
        max: 0,
    },
    small: {
        min: 0,
        default: 321,
        max: 639,
    },
    medium: {
        min: 640,
        default: 641,
        max: 999,
    },
    large: {
        min: 1000,
        default: 1001,
        max: 1200,
    },
    getWidthForSize: function (size) {
        return this[size].default;
    },
    getSizeForWidth: function (width) {
        for (var _i = 0, sizeNames_1 = sizeNames; _i < sizeNames_1.length; _i++) {
            var size = sizeNames_1[_i];
            var value = this[size];
            if (width <= value.max) {
                return size;
            }
        }
        return 'large';
    },
};
var sizeNames = ['xsmall', 'small', 'medium', 'large'];
var camelCaseToKebabCase = function (str) {
    return str ? str.replace(/([A-Z])/g, function (g) { return "-" + g[0].toLowerCase(); }) : '';
};
var cssCase = function (property) {
    if (!property) {
        return property;
    }
    var str = camelCaseToKebabCase(property);
    if (property[0] === property[0].toUpperCase()) {
        str = '-' + str;
    }
    return str;
};
function mapToCss(map, spaces, important) {
    if (spaces === void 0) { spaces = 2; }
    if (important === void 0) { important = false; }
    return Object.keys(map).reduce(function (memo, key) {
        var value = map[key];
        if (typeof value !== 'string') {
            return memo;
        }
        return (memo +
            (value && value.trim()
                ? "\n" + ' '.repeat(spaces) + cssCase(key) + ": " + (value + (important ? ' !important' : '')) + ";"
                : ''));
    }, '');
}
var Block = /** @class */ (function (_super) {
    __extends(Block, _super);
    function Block() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.outerTable = null;
        return _this;
    }
    Block.prototype.getAlign = function (size) {
        var _a;
        var block = this.props.builderBlock;
        var sizeStyles = ((_a = block.responsiveStyles) === null || _a === void 0 ? void 0 : _a[size]) || {};
        var align = sizeStyles.marginRight === 'auto' && sizeStyles.marginLeft === 'auto'
            ? 'center'
            : sizeStyles.marginLeft === 'auto'
                ? 'right'
                : 'left';
        return align;
    };
    Block.prototype.getVAlign = function (size) {
        var block = this.props.builderBlock;
        var sizeStyles = block.responsiveStyles[size] || {};
        var vAlign = sizeStyles.marginBottom === 'auto' && sizeStyles.marginTop === 'auto'
            ? 'middle'
            : sizeStyles.marginTop === 'auto'
                ? 'bottom'
                : 'top';
        return vAlign;
    };
    Block.prototype.getOuterStyles = function (size) {
        var block = this.props.builderBlock;
        var sizeStyles = block.responsiveStyles[size] || {};
        var outerDisplay = sizeStyles.display;
        var outerVerticalAlign = sizeStyles.verticalAlign;
        var outerStyles = {
            width: '100%',
            border: '0',
            display: outerDisplay,
            verticalAlign: outerVerticalAlign,
        };
        return outerStyles;
    };
    Block.prototype.getMidStyles = function (size) {
        var block = this.props.builderBlock;
        var sizeStyles = block.responsiveStyles[size] || {};
        var align = this.getAlign(size);
        var vAlign = this.getVAlign(size);
        var midStyles = {
            paddingTop: sizeStyles.marginTop,
            paddingRight: sizeStyles.marginRight,
            paddingBottom: sizeStyles.marginBottom,
            paddingLeft: sizeStyles.marginLeft,
            verticalAlign: vAlign,
            width: (align === 'left' && sizeStyles.marginRight !== 'auto' && '100%') || undefined,
        };
        return midStyles;
    };
    Block.prototype.getInnerStyles = function (size) {
        var block = this.props.builderBlock;
        var align = this.getAlign(size);
        var sizeStyles = block.responsiveStyles[size] || {};
        var innerStyles = __assign(__assign(__assign({ verticalAlign: 'top' }, sizeStyles), { marginTop: undefined, marginBottom: undefined, marginLeft: undefined, marginRight: undefined, width: (align === 'left' && sizeStyles.marginRight !== 'auto' && '100%') || undefined, display: undefined }), this.props.innerStyleOverrides);
        return innerStyles;
    };
    Block.prototype.getInnerTableStyles = function (size) {
        var block = this.props.builderBlock;
        var sizeStyles = block.responsiveStyles[size] || {};
        var hasPxWidth = sizeStyles.width && sizeStyles.width.trim().endsWith('px');
        var align = this.getAlign(size);
        return {
            // TODO: hasPercent use that also
            width: hasPxWidth
                ? sizeStyles.width
                : (align === 'left' && sizeStyles.marginRight !== 'auto' && '100%') || undefined,
        };
    };
    Block.prototype.getLeftTdStyle = function (size) {
        var align = this.getAlign(size);
        return {
            // width: align === 'center' ? '45%' : '90%',
            display: align === 'right' || align === 'center' ? undefined : 'none',
        };
    };
    Block.prototype.getRightTdStyle = function (size) {
        var align = this.getAlign(size);
        return {
            // width: align === 'center' ? '45%' : '90%',
            display: align === 'left' || align === 'center' ? undefined : 'none',
        };
    };
    Object.defineProperty(Block.prototype, "css", {
        get: function () {
            var css = '';
            var block = this.props.builderBlock;
            if (!block) {
                return '';
            }
            var reversedNames = sizeNames.slice().reverse();
            if (block.responsiveStyles) {
                for (var _i = 0, reversedNames_1 = reversedNames; _i < reversedNames_1.length; _i++) {
                    var size = reversedNames_1[_i];
                    if (size !== 'large' &&
                        size !== 'xsmall' &&
                        block.responsiveStyles[size] &&
                        Object.keys(block.responsiveStyles[size]).length) {
                        // TODO: use emotion
                        css += "\n@media only screen and (max-width: " + sizes[size].max + "px) {\n  ." + block.id + " { " + mapToCss(this.getOuterStyles(size), 4, true) + " }\n  ." + block.id + "-inner { " + mapToCss(this.getInnerTableStyles(size), 4, true) + " }\n  ." + block.id + "-subject { " + mapToCss(this.getInnerStyles(size), 4, true) + " }\n  ." + block.id + "-middle { " + mapToCss(this.getMidStyles(size), 4, true) + " }\n}";
                    }
                }
            }
            return css;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(Block.prototype, "bgImageUrl", {
        get: function () {
            var backgroundImage = this.props.builderBlock.responsiveStyles.large.backgroundImage;
            return backgroundImage && backgroundImage.replace(/.*?url\(['"]?(.*?)['"]?\).*?/, '$1');
        },
        enumerable: true,
        configurable: true
    });
    Block.prototype.render = function () {
        var _this = this;
        var block = this.props.builderBlock;
        var align = this.getAlign('large');
        var vAlign = this.getVAlign('large');
        var midStyles = this.getMidStyles('large');
        var attributes = this.props.attributes || {};
        var hasLink = attributes.href;
        var InnerTag = hasLink ? 'a' : 'span';
        var innerStyles = this.getInnerStyles('large');
        var bgImageUrl = this.bgImageUrl;
        var pxHeight = innerStyles.height && innerStyles.height.includes('px') && parseFloat(innerStyles.height);
        // TODO: only double wrap if hasMargin
        return (react_1.default.createElement(react_1.default.Fragment, null,
            react_1.default.createElement("style", { className: "builder-style" }, this.css),
            react_1.default.createElement("table", { role: "presentation", ref: function (ref) { return (_this.outerTable = ref); }, cellPadding: "0", cellSpacing: "0", "builder-id": attributes['builder-id'], className: attributes.class || attributes.className, style: this.getOuterStyles('large') },
                react_1.default.createElement("tbody", { style: { width: '100%' } },
                    react_1.default.createElement("tr", null,
                        react_1.default.createElement("td", null),
                        react_1.default.createElement("td", __assign({}, { align: align, vAlign: vAlign }, { style: midStyles, className: block.id + "-middle" }),
                            react_1.default.createElement(InnerTag, __assign({}, (hasLink
                                ? {
                                    href: attributes.href,
                                    target: '_blank',
                                    style: {
                                        textDecoration: 'none',
                                        // TODO: outlook this not always working
                                        color: 'inherit',
                                    },
                                }
                                : null)),
                                react_1.default.createElement("table", __assign({ role: "presentation", cellPadding: "0", cellSpacing: "0", className: block.id + "-inner", style: __assign(__assign({}, this.getInnerTableStyles('large')), { height: '100%' }) }, {
                                    border: '0',
                                }),
                                    react_1.default.createElement("tbody", { style: { width: '100%' } },
                                        react_1.default.createElement("tr", null,
                                            react_1.default.createElement("td", __assign({ className: "builder-block-subject " + this.props.builderBlock.id + "-subject", style: innerStyles }, (typeof pxHeight === 'number' &&
                                                !isNaN(pxHeight) && {
                                                height: pxHeight,
                                            })),
                                                bgImageUrl && (react_1.default.createElement(BG_START_TAG, { url: this.bgImageUrl, color: innerStyles.backgroundColor, height: innerStyles.height })),
                                                this.props.children,
                                                bgImageUrl && react_1.default.createElement(BG_END_TAG, null))))))),
                        react_1.default.createElement("td", null))))));
    };
    return Block;
}(react_1.default.Component));
exports.Block = Block;
//# sourceMappingURL=Block.js.map