var BuilderWidgets = (function (exports) {
    'use strict';

    /*! *****************************************************************************
    Copyright (c) Microsoft Corporation. All rights reserved.
    Licensed under the Apache License, Version 2.0 (the "License"); you may not use
    this file except in compliance with the License. You may obtain a copy of the
    License at http://www.apache.org/licenses/LICENSE-2.0

    THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
    WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
    MERCHANTABLITY OR NON-INFRINGEMENT.

    See the Apache Version 2.0 License for specific language governing permissions
    and limitations under the License.
    ***************************************************************************** */
    /* global Reflect, Promise */

    var extendStatics = function(d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };

    function __extends(d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    }

    var __assign = function() {
        __assign = Object.assign || function __assign(t) {
            for (var s, i = 1, n = arguments.length; i < n; i++) {
                s = arguments[i];
                for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
            }
            return t;
        };
        return __assign.apply(this, arguments);
    };

    function __decorate(decorators, target, key, desc) {
        var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
        if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
        else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
        return c > 3 && r && Object.defineProperty(target, key, r), r;
    }

    function pad (hash, len) {
      while (hash.length < len) {
        hash = '0' + hash;
      }
      return hash;
    }

    function fold (hash, text) {
      var i;
      var chr;
      var len;
      if (text.length === 0) {
        return hash;
      }
      for (i = 0, len = text.length; i < len; i++) {
        chr = text.charCodeAt(i);
        hash = ((hash << 5) - hash) + chr;
        hash |= 0;
      }
      return hash < 0 ? hash * -2 : hash;
    }

    function foldObject (hash, o, seen) {
      return Object.keys(o).sort().reduce(foldKey, hash);
      function foldKey (hash, key) {
        return foldValue(hash, o[key], key, seen);
      }
    }

    function foldValue (input, value, key, seen) {
      var hash = fold(fold(fold(input, key), toString$1(value)), typeof value);
      if (value === null) {
        return fold(hash, 'null');
      }
      if (value === undefined) {
        return fold(hash, 'undefined');
      }
      if (typeof value === 'object' || typeof value === 'function') {
        if (seen.indexOf(value) !== -1) {
          return fold(hash, '[Circular]' + key);
        }
        seen.push(value);

        var objHash = foldObject(hash, value, seen);

        if (!('valueOf' in value) || typeof value.valueOf !== 'function') {
          return objHash;
        }

        try {
          return fold(objHash, String(value.valueOf()))
        } catch (err) {
          return fold(objHash, '[valueOf exception]' + (err.stack || err.message))
        }
      }
      return fold(hash, value.toString());
    }

    function toString$1 (o) {
      return Object.prototype.toString.call(o);
    }

    function sum (o) {
      return pad(foldValue(0, o, '', []).toString(16), 8);
    }

    var hashSum = sum;

    (function () {
      if (typeof window === 'undefined' || typeof window.CustomEvent === 'function') return false;

      function CustomEvent(event, params) {
        params = params || { bubbles: false, cancelable: false, detail: null };
        var evt = document.createEvent('CustomEvent');
        evt.initCustomEvent(event, params.bubbles, params.cancelable, params.detail);
        return evt;
      }

      window.CustomEvent = CustomEvent;
    })();

    var isSafari = typeof window !== 'undefined' &&
        /^((?!chrome|android).)*safari/i.test(window.navigator.userAgent);
    // TODO: queue all of these in a debounceNextTick
    function nextTick(fn) {
        // React native
        if (typeof setImmediate === 'function' && typeof window === 'undefined') {
            return setImmediate(fn);
        }
        // TODO: should this be setImmediate instead? Forgot if that is micro or macro task
        // TODO: detect specifically if is server
        // if (typeof process !== 'undefined' && process.nextTick) {
        //   console.log('process.nextTick?');
        //   process.nextTick(fn);
        //   return;
        // }
        // FIXME: fix the real safari issue of this randomly not working
        if (isSafari || typeof MutationObserver === 'undefined') {
            setTimeout(fn);
            return;
        }
        var called = 0;
        var observer = new MutationObserver(function () { return fn(); });
        var element = document.createTextNode('');
        observer.observe(element, {
            characterData: true,
        });
        // tslint:disable-next-line
        element.data = String((called = ++called));
    }

    // TODO: unit tests
    var QueryString = /** @class */ (function () {
        function QueryString() {
        }
        QueryString.parseDeep = function (queryString) {
            var obj = this.parse(queryString);
            return this.deepen(obj);
        };
        QueryString.stringifyDeep = function (obj) {
            var map = this.flatten(obj);
            return this.stringify(map);
        };
        QueryString.parse = function (queryString) {
            var query = {};
            var pairs = (queryString[0] === '?' ? queryString.substr(1) : queryString).split('&');
            for (var i = 0; i < pairs.length; i++) {
                var pair = pairs[i].split('=');
                // TODO: node support?
                query[decodeURIComponent(pair[0])] = decodeURIComponent(pair[1] || '');
            }
            return query;
        };
        QueryString.stringify = function (map) {
            var str = '';
            for (var key in map) {
                if (map.hasOwnProperty(key)) {
                    var value = map[key];
                    if (str) {
                        str += '&';
                    }
                    str += encodeURIComponent(key) + '=' + encodeURIComponent(value);
                }
            }
            return str;
        };
        QueryString.deepen = function (map) {
            var output = {};
            for (var k in map) {
                var t = output;
                var parts = k.split('.');
                var key = parts.pop();
                while (parts.length) {
                    var part = parts.shift();
                    t = t[part] = t[part] || {};
                }
                t[key] = map[k];
            }
            return output;
        };
        QueryString.flatten = function (obj, _current, _res) {
            if (_res === void 0) { _res = {}; }
            for (var key in obj) {
                var value = obj[key];
                var newKey = _current ? _current + '.' + key : key;
                if (value && typeof value === 'object') {
                    this.flatten(value, newKey, _res);
                }
                else {
                    _res[newKey] = value;
                }
            }
            return _res;
        };
        return QueryString;
    }());

    var version = "1.1.20-alpha.9";

    var Subscription = /** @class */ (function () {
        function Subscription(listeners, listener) {
            this.listeners = listeners;
            this.listener = listener;
            this.unsubscribed = false;
            this.otherSubscriptions = [];
        }
        Object.defineProperty(Subscription.prototype, "closed", {
            get: function () {
                return this.unsubscribed;
            },
            enumerable: true,
            configurable: true
        });
        Subscription.prototype.add = function (subscription) {
            this.otherSubscriptions.push(subscription);
        };
        Subscription.prototype.unsubscribe = function () {
            if (this.unsubscribed) {
                return;
            }
            if (this.listener && this.listeners) {
                var index = this.listeners.indexOf(this.listener);
                if (index > -1) {
                    this.listeners.splice(index, 1);
                }
            }
            this.otherSubscriptions.forEach(function (sub) { return sub.unsubscribe(); });
            this.unsubscribed = true;
        };
        return Subscription;
    }());
    // TODO: follow minimal basic spec: https://github.com/tc39/proposal-observable
    var BehaviorSubject = /** @class */ (function () {
        function BehaviorSubject(value) {
            this.value = value;
            this.listeners = [];
            this.errorListeners = [];
        }
        BehaviorSubject.prototype.next = function (value) {
            this.value = value;
            for (var _i = 0, _a = this.listeners; _i < _a.length; _i++) {
                var listener = _a[_i];
                listener(value);
            }
        };
        // TODO: implement this as PIPE instead
        BehaviorSubject.prototype.map = function (fn) {
            var newSubject = new BehaviorSubject(fn(this.value));
            // TODO: on destroy delete these
            this.subscribe(function (val) {
                newSubject.next(fn(val));
            });
            this.catch(function (err) {
                newSubject.error(err);
            });
            return newSubject;
        };
        BehaviorSubject.prototype.catch = function (errorListener) {
            this.errorListeners.push(errorListener);
            return new Subscription(this.errorListeners, errorListener);
        };
        BehaviorSubject.prototype.error = function (error) {
            for (var _i = 0, _a = this.errorListeners; _i < _a.length; _i++) {
                var listener = _a[_i];
                listener(error);
            }
        };
        BehaviorSubject.prototype.subscribe = function (listener, errorListener) {
            this.listeners.push(listener);
            if (errorListener) {
                this.errorListeners.push(errorListener);
            }
            return new Subscription(this.listeners, listener);
        };
        BehaviorSubject.prototype.toPromise = function () {
            var _this = this;
            return new Promise(function (resolve, reject) {
                var subscription = _this.subscribe(function (value) {
                    resolve(value);
                    subscription.unsubscribe();
                }, function (err) {
                    reject(err);
                    subscription.unsubscribe();
                });
            });
        };
        BehaviorSubject.prototype.promise = function () {
            return this.toPromise();
        };
        return BehaviorSubject;
    }());

    var State = {
        Pending: 'Pending',
        Fulfilled: 'Fulfilled',
        Rejected: 'Rejected',
    };
    function isFunction(val) {
        return val && typeof val === 'function';
    }
    function isObject(val) {
        return val && typeof val === 'object';
    }
    var TinyPromise = /** @class */ (function () {
        function TinyPromise(executor) {
            this._state = State.Pending;
            this._handlers = [];
            this._value = null;
            executor(this._resolve.bind(this), this._reject.bind(this));
        }
        TinyPromise.prototype._resolve = function (x) {
            var _this = this;
            if (x instanceof TinyPromise) {
                x.then(this._resolve.bind(this), this._reject.bind(this));
            }
            else if (isObject(x) || isFunction(x)) {
                var called_1 = false;
                try {
                    var thenable = x.then;
                    if (isFunction(thenable)) {
                        thenable.call(x, function (result) {
                            if (!called_1)
                                _this._resolve(result);
                            called_1 = true;
                            return undefined;
                        }, function (error) {
                            if (!called_1)
                                _this._reject(error);
                            called_1 = true;
                            return undefined;
                        });
                    }
                    else {
                        this._fulfill(x);
                    }
                }
                catch (ex) {
                    if (!called_1) {
                        this._reject(ex);
                    }
                }
            }
            else {
                this._fulfill(x);
            }
        };
        TinyPromise.prototype._fulfill = function (result) {
            var _this = this;
            this._state = State.Fulfilled;
            this._value = result;
            this._handlers.forEach(function (handler) { return _this._callHandler(handler); });
        };
        TinyPromise.prototype._reject = function (error) {
            var _this = this;
            this._state = State.Rejected;
            this._value = error;
            this._handlers.forEach(function (handler) { return _this._callHandler(handler); });
        };
        TinyPromise.prototype._isPending = function () {
            return this._state === State.Pending;
        };
        TinyPromise.prototype._isFulfilled = function () {
            return this._state === State.Fulfilled;
        };
        TinyPromise.prototype._isRejected = function () {
            return this._state === State.Rejected;
        };
        TinyPromise.prototype._addHandler = function (onFulfilled, onRejected) {
            this._handlers.push({
                onFulfilled: onFulfilled,
                onRejected: onRejected,
            });
        };
        TinyPromise.prototype._callHandler = function (handler) {
            if (this._isFulfilled() && isFunction(handler.onFulfilled)) {
                handler.onFulfilled(this._value);
            }
            else if (this._isRejected() && isFunction(handler.onRejected)) {
                handler.onRejected(this._value);
            }
        };
        TinyPromise.prototype.then = function (onFulfilled, onRejected) {
            var _this = this;
            switch (this._state) {
                case State.Pending: {
                    return new TinyPromise(function (resolve, reject) {
                        _this._addHandler(function (value) {
                            nextTick(function () {
                                try {
                                    if (isFunction(onFulfilled)) {
                                        resolve(onFulfilled(value));
                                    }
                                    else {
                                        resolve(value);
                                    }
                                }
                                catch (ex) {
                                    reject(ex);
                                }
                            });
                        }, function (error) {
                            nextTick(function () {
                                try {
                                    if (isFunction(onRejected)) {
                                        resolve(onRejected(error));
                                    }
                                    else {
                                        reject(error);
                                    }
                                }
                                catch (ex) {
                                    reject(ex);
                                }
                            });
                        });
                    });
                }
                case State.Fulfilled: {
                    return new TinyPromise(function (resolve, reject) {
                        nextTick(function () {
                            try {
                                if (isFunction(onFulfilled)) {
                                    resolve(onFulfilled(_this._value));
                                }
                                else {
                                    resolve(_this._value);
                                }
                            }
                            catch (ex) {
                                reject(ex);
                            }
                        });
                    });
                }
                case State.Rejected: {
                    return new TinyPromise(function (resolve, reject) {
                        nextTick(function () {
                            try {
                                if (isFunction(onRejected)) {
                                    resolve(onRejected(_this._value));
                                }
                                else {
                                    reject(_this._value);
                                }
                            }
                            catch (ex) {
                                reject(ex);
                            }
                        });
                    });
                }
            }
        };
        return TinyPromise;
    }());
    var Promise$1 = (typeof Promise !== 'undefined' ? Promise : TinyPromise);

    // Webpack workaround to conditionally require certain external modules
    // only on the server and not bundle them on the client
    var serverOnlyRequire;
    try {
        // tslint:disable-next-line:no-eval
        serverOnlyRequire = eval('require');
    }
    catch (err) {
        // all good
        serverOnlyRequire = (function () { return null; });
    }
    var serverOnlyRequire$1 = serverOnlyRequire;

    function promiseResolve(value) {
        return new Promise$1(function (resolve) { return resolve(value); });
    }
    // Adapted from https://raw.githubusercontent.com/developit/unfetch/master/src/index.mjs
    function tinyFetch(url, options) {
        if (options === void 0) { options = {}; }
        return new Promise$1(function (resolve, reject) {
            var request = new XMLHttpRequest();
            request.open(options.method || 'get', url, true);
            if (options.headers) {
                for (var i in options.headers) {
                    request.setRequestHeader(i, options.headers[i]);
                }
            }
            request.withCredentials = options.credentials === 'include';
            request.onload = function () {
                resolve(response());
            };
            request.onerror = reject;
            request.send(options.body);
            function response() {
                var keys = [];
                var all = [];
                var headers = {};
                var header = undefined;
                request
                    .getAllResponseHeaders()
                    .replace(/^(.*?):[^\S\n]*([\s\S]*?)$/gm, function (_match, _key, value) {
                    var key = _key;
                    keys.push((key = key.toLowerCase()));
                    all.push([key, value]);
                    header = headers[key];
                    headers[key] = header ? header + "," + value : value;
                    return '';
                });
                return {
                    ok: ((request.status / 100) | 0) === 2,
                    status: request.status,
                    statusText: request.statusText,
                    url: request.responseURL,
                    clone: response,
                    text: function () { return promiseResolve(request.responseText); },
                    json: function () { return promiseResolve(request.responseText).then(JSON.parse); },
                    blob: function () { return promiseResolve(new Blob([request.response])); },
                    headers: {
                        keys: function () { return keys; },
                        entries: function () { return all; },
                        get: function (n) { return headers[n.toLowerCase()]; },
                        has: function (n) { return n.toLowerCase() in headers; },
                    },
                };
            }
        });
    }
    var fetch$1 = typeof global === 'object' && typeof global.fetch === 'function'
        ? global.fetch
        : typeof window === 'undefined'
            ? serverOnlyRequire$1('node-fetch')
            : typeof window.fetch !== 'undefined'
                ? window.fetch
                : tinyFetch;

    function assign(target) {
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        var to = Object(target);
        for (var index = 1; index < arguments.length; index++) {
            var nextSource = arguments[index];
            if (nextSource != null) {
                // Skip over if undefined or null
                for (var nextKey in nextSource) {
                    // Avoid bugs when hasOwnProperty is shadowed
                    if (Object.prototype.hasOwnProperty.call(nextSource, nextKey)) {
                        to[nextKey] = nextSource[nextKey];
                    }
                }
            }
        }
        return to;
    }

    function throttle(func, wait, options) {
        if (options === void 0) { options = {}; }
        var context;
        var args;
        var result;
        var timeout = null;
        var previous = 0;
        var later = function () {
            previous = options.leading === false ? 0 : Date.now();
            timeout = null;
            result = func.apply(context, args);
            if (!timeout)
                context = args = null;
        };
        return function () {
            var now = Date.now();
            if (!previous && options.leading === false)
                previous = now;
            var remaining = wait - (now - previous);
            context = this;
            args = arguments;
            if (remaining <= 0 || remaining > wait) {
                if (timeout) {
                    clearTimeout(timeout);
                    timeout = null;
                }
                previous = now;
                result = func.apply(context, args);
                if (!timeout)
                    context = args = null;
            }
            else if (!timeout && options.trailing !== false) {
                timeout = setTimeout(later, remaining);
            }
            return result;
        };
    }

    var camelCaseToKebabCase = function (str) {
        return str ? str.replace(/([A-Z])/g, function (g) { return "-" + g[0].toLowerCase(); }) : '';
    };
    var Animator = /** @class */ (function () {
        function Animator() {
        }
        Animator.prototype.bindAnimations = function (animations) {
            for (var _i = 0, animations_1 = animations; _i < animations_1.length; _i++) {
                var animation = animations_1[_i];
                switch (animation.trigger) {
                    case 'pageLoad':
                        this.triggerAnimation(animation);
                        break;
                    case 'hover':
                        this.bindHoverAnimation(animation);
                        break;
                    case 'scrollInView':
                        this.bindScrollInViewAnimation(animation);
                        break;
                }
            }
        };
        Animator.prototype.warnElementNotPresent = function (id) {
            console.warn("Cannot animate element: element with ID " + id + " not found!");
        };
        Animator.prototype.augmentAnimation = function (animation, element) {
            var stylesUsed = this.getAllStylesUsed(animation);
            var computedStyle = getComputedStyle(element);
            // const computedStyle = getComputedStyle(element);
            // // FIXME: this will break if original load is in one reponsive size then resize to another hmmm
            // Need to use transform instead of left since left can change on screen sizes
            var firstStyles = animation.steps[0].styles;
            var lastStyles = animation.steps[animation.steps.length - 1].styles;
            var bothStyles = [firstStyles, lastStyles];
            // FIXME: this won't work as expected for augmented animations - may need the editor itself to manage this
            for (var _i = 0, bothStyles_1 = bothStyles; _i < bothStyles_1.length; _i++) {
                var styles = bothStyles_1[_i];
                for (var _a = 0, stylesUsed_1 = stylesUsed; _a < stylesUsed_1.length; _a++) {
                    var style = stylesUsed_1[_a];
                    if (!(style in styles)) {
                        styles[style] = computedStyle[style];
                    }
                }
            }
        };
        Animator.prototype.getAllStylesUsed = function (animation) {
            var properties = [];
            for (var _i = 0, _a = animation.steps; _i < _a.length; _i++) {
                var step = _a[_i];
                for (var key in step.styles) {
                    if (properties.indexOf(key) === -1) {
                        properties.push(key);
                    }
                }
            }
            return properties;
        };
        Animator.prototype.triggerAnimation = function (animation) {
            var _this = this;
            // TODO: do for ALL elements
            var elements = Array.prototype.slice.call(document.getElementsByClassName(animation.elementId || animation.id || ''));
            if (!elements.length) {
                this.warnElementNotPresent(animation.elementId || animation.id || '');
                return;
            }
            Array.from(elements).forEach(function (element) {
                _this.augmentAnimation(animation, element);
                // TODO: do this properly, may have other animations of different properties
                // TODO: only override the properties
                // TODO: if there is an entrance and hover animation, the transition duration will get effed
                // element.setAttribute('style', '');
                // const styledUsed = this.getAllStylesUsed(animation);
                element.style.transition = 'none';
                element.style.transitionDelay = '0';
                assign(element.style, animation.steps[0].styles);
                // TODO: queue/batch these timeouts
                // TODO: only include properties explicitly set in the animation
                // using Object.keys(styles)
                setTimeout(function () {
                    element.style.transition = "all " + animation.duration + "s " + camelCaseToKebabCase(animation.easing);
                    if (animation.delay) {
                        element.style.transitionDelay = animation.delay + 's';
                    }
                    assign(element.style, animation.steps[1].styles);
                    // TODO: maybe remove/reset transitoin property after animation duration
                    // TODO: queue timers
                    setTimeout(function () {
                        // TODO: what if has other transition (reset back to what it was)
                        element.style.transition = '';
                        element.style.transitionDelay = '';
                    }, (animation.delay || 0) * 1000 + animation.duration * 1000 + 100);
                });
            });
        };
        Animator.prototype.bindHoverAnimation = function (animation) {
            var _this = this;
            // TODO: is it multiple binding when editing...?
            // TODO: unbind on element remove
            // TODO: apply to ALL elements
            var elements = Array.prototype.slice.call(document.getElementsByClassName(animation.elementId || animation.id || ''));
            if (!elements.length) {
                this.warnElementNotPresent(animation.elementId || animation.id || '');
                return;
            }
            Array.from(elements).forEach(function (element) {
                _this.augmentAnimation(animation, element);
                var defaultState = animation.steps[0].styles;
                var hoverState = animation.steps[1].styles;
                function attachDefaultState() {
                    assign(element.style, defaultState);
                }
                function attachHoverState() {
                    assign(element.style, hoverState);
                }
                attachDefaultState();
                element.addEventListener('mouseenter', attachHoverState);
                element.addEventListener('mouseleave', attachDefaultState);
                // TODO: queue/batch these timeouts
                setTimeout(function () {
                    element.style.transition = "all " + animation.duration + "s " + camelCaseToKebabCase(animation.easing);
                    if (animation.delay) {
                        element.style.transitionDelay = animation.delay + 's';
                    }
                });
            });
        };
        // TODO: unbind on element remove
        Animator.prototype.bindScrollInViewAnimation = function (animation) {
            var _this = this;
            // TODO: apply to ALL matching elements
            var elements = Array.prototype.slice.call(document.getElementsByClassName(animation.elementId || animation.id || ''));
            if (!elements.length) {
                this.warnElementNotPresent(animation.elementId || animation.id || '');
                return;
            }
            // TODO: if server side rendered and scrolled into view don't animate...
            Array.from(elements).forEach(function (element) {
                _this.augmentAnimation(animation, element);
                var triggered = false;
                function immediateOnScroll() {
                    if (!triggered && isScrolledIntoView(element)) {
                        triggered = true;
                        setTimeout(function () {
                            assign(element.style, animation.steps[1].styles);
                            document.removeEventListener('scroll', onScroll);
                            setTimeout(function () {
                                element.style.transition = '';
                                element.style.transitionDelay = '';
                            }, (animation.duration * 1000 + (animation.delay || 0)) * 1000 + 100);
                        });
                    }
                }
                // TODO: roll all of these in one for more efficiency of checking all the rects
                var onScroll = throttle(immediateOnScroll, 200, { leading: false });
                // TODO: fully in view or partially
                function isScrolledIntoView(elem) {
                    var rect = elem.getBoundingClientRect();
                    var windowHeight = window.innerHeight;
                    var thresholdPrecent = 0;
                    var threshold = thresholdPrecent * windowHeight;
                    // TODO: partial in view? or what if element is larger than screen itself
                    return (rect.bottom > threshold && rect.top < windowHeight - threshold // Element is peeking top or bottom
                    // (rect.top > 0 && rect.bottom < window.innerHeight) || // element fits within the screen and is fully on screen (not hanging off at all)
                    // (rect.top < 0 && rect.bottom > window.innerHeight) // element is larger than the screen and hangs over the top and bottom
                    );
                }
                var defaultState = animation.steps[0].styles;
                function attachDefaultState() {
                    assign(element.style, defaultState);
                }
                attachDefaultState();
                // TODO: queue/batch these timeouts!
                setTimeout(function () {
                    element.style.transition = "all " + animation.duration + "s " + camelCaseToKebabCase(animation.easing);
                    if (animation.delay) {
                        element.style.transitionDelay = animation.delay + 's';
                    }
                });
                // TODO: one listener for everything
                document.addEventListener('scroll', onScroll, { capture: true, passive: true });
                // Do an initial check
                immediateOnScroll();
            });
        };
        return Animator;
    }());

    /**
     * Only gets one level up from hostname
     * wwww.example.com -> example.com
     * www.example.co.uk -> example.co.uk
     */
    function getTopLevelDomain(host) {
        var parts = host.split('.');
        if (parts.length > 2) {
            return parts.slice(1).join('.');
        }
        return host;
    }

    /**
     * RegExp to match field-content in RFC 7230 sec 3.2
     *
     * field-content = field-vchar [ 1*( SP / HTAB ) field-vchar ]
     * field-vchar   = VCHAR / obs-text
     * obs-text      = %x80-FF
     */
    var fieldContentRegExp = /^[\u0009\u0020-\u007e\u0080-\u00ff]+$/;
    var Cookies = /** @class */ (function () {
        function Cookies(request, response) {
            this.request = request;
            this.response = response;
        }
        Cookies.prototype.get = function (name) {
            var header = this.request.headers['cookie'];
            if (!header) {
                return;
            }
            var match = header.match(getPattern(name));
            if (!match) {
                return;
            }
            var value = match[1];
            return value;
        };
        Cookies.prototype.set = function (name, value, opts) {
            var res = this.response;
            var req = this.request;
            var headers = res.getHeader('Set-Cookie') || [];
            // TODO: just make this always true
            var secure = this.secure !== undefined
                ? !!this.secure
                : req.protocol === 'https' || req.connection.encrypted;
            var cookie = new Cookie(name, value, opts);
            if (typeof headers === 'string') {
                headers = [headers];
            }
            if (!secure && opts && opts.secure) {
                throw new Error('Cannot send secure cookie over unencrypted connection');
            }
            cookie.secure = secure;
            if (opts && 'secure' in opts) {
                cookie.secure = !!opts.secure;
            }
            cookie.domain = req.headers.host && getTopLevelDomain(req.headers.host);
            pushCookie(headers, cookie);
            var setHeader = res.setHeader;
            setHeader.call(res, 'Set-Cookie', headers);
            return this;
        };
        return Cookies;
    }());
    var Cookie = /** @class */ (function () {
        function Cookie(name, value, attrs) {
            this.path = '/';
            this.domain = undefined;
            this.httpOnly = true;
            this.sameSite = false;
            this.secure = false;
            this.overwrite = false;
            this.name = '';
            this.value = '';
            if (!fieldContentRegExp.test(name)) {
                throw new TypeError('argument name is invalid');
            }
            if (value && !fieldContentRegExp.test(value)) {
                throw new TypeError('argument value is invalid');
            }
            if (!value) {
                this.expires = new Date(0);
            }
            this.name = name;
            this.value = value || '';
            if (attrs.expires) {
                this.expires = attrs.expires;
            }
            if (attrs.secure) {
                this.secure = attrs.secure;
            }
        }
        Cookie.prototype.toString = function () {
            return this.name + "=" + this.value;
        };
        Cookie.prototype.toHeader = function () {
            var header = this.toString();
            if (this.maxAge) {
                this.expires = new Date(Date.now() + this.maxAge);
            }
            if (this.path) {
                header += "; path=" + this.path;
            }
            if (this.expires) {
                header += "; expires=" + this.expires.toUTCString();
            }
            if (this.domain) {
                header += "; domain=" + this.domain;
            }
            // TODO: samesite=none by default (?)
            header += "; SameSite=" + (this.sameSite === true ? 'strict' : 'None');
            // TODO: On by default
            if (this.secure) {
                header += '; secure';
            }
            if (this.httpOnly) {
                header += '; httponly';
            }
            return header;
        };
        return Cookie;
    }());
    function getPattern(name) {
        return new RegExp("(?:^|;) *" + name.replace(/[-[\]{}()*+?.,\\^$|#\s]/g, '\\$&') + "=([^;]*)");
    }
    function pushCookie(headers, cookie) {
        if (cookie.overwrite) {
            for (var i = headers.length - 1; i >= 0; i--) {
                if (headers[i].indexOf(cookie.name + "=") === 0) {
                    headers.splice(i, 1);
                }
            }
        }
        headers.push(cookie.toHeader());
    }

    function omit(obj) {
        var values = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            values[_i - 1] = arguments[_i];
        }
        var newObject = Object.assign({}, obj);
        for (var _a = 0, values_1 = values; _a < values_1.length; _a++) {
            var key = values_1[_a];
            delete newObject[key];
        }
        return newObject;
    }

    /**
     * @credit https://stackoverflow.com/a/2117523
     */
    function uuidv4() {
        return 'xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx'.replace(/[xy]/g, function (c) {
            var r = (Math.random() * 16) | 0, v = c == 'x' ? r : (r & 0x3) | 0x8;
            return v.toString(16);
        });
    }
    /**
     * Slightly cleaner and smaller UUIDs
     */
    function uuid() {
        return uuidv4().replace(/-/g, '');
    }

    function datePlusMinutes(minutes) {
        if (minutes === void 0) { minutes = 30; }
        return new Date(Date.now() + minutes * 60000);
    }
    var isPositiveNumber = function (thing) {
        return typeof thing === 'number' && !isNaN(thing) && thing >= 0;
    };
    var isReactNative = typeof navigator === 'object' && navigator.product === 'ReactNative';
    var validEnvList = [
        'production',
        'qa',
        'development',
        'dev',
        'cdn-qa',
        'cloud',
        'fast',
        'cdn2',
    ];
    function getQueryParam(url, variable) {
        var query = url.split('?')[1] || '';
        var vars = query.split('&');
        for (var i = 0; i < vars.length; i++) {
            var pair = vars[i].split('=');
            if (decodeURIComponent(pair[0]) === variable) {
                return decodeURIComponent(pair[1]);
            }
        }
        return null;
    }
    var urlParser = {
        parse: function (url) {
            var parser = document.createElement('a');
            parser.href = url;
            var out = {};
            var props = 'username password host hostname port protocol origin pathname search hash'.split(' ');
            for (var i = props.length; i--;) {
                out[props[i]] = parser[props[i]];
            }
            // IE 11 pathname handling workaround
            // (IE omits preceeding '/', unlike other browsers)
            if ((out.pathname || out.pathname === '') &&
                typeof out.pathname === 'string' &&
                out.pathname.indexOf('/') !== 0) {
                out.pathname = '/' + out.pathname;
            }
            return out;
        },
    };
    var parse = isReactNative
        ? function () { return ({}); }
        : typeof window === 'object'
            ? urlParser.parse
            : serverOnlyRequire$1('url').parse;
    function setCookie(name$$1, value, expires) {
        try {
            var expiresString = '';
            // TODO: need to know if secure server side
            if (expires) {
                expiresString = '; expires=' + expires.toUTCString();
            }
            var secure = isBrowser ? location.protocol === 'https:' : true;
            document.cookie =
                name$$1 +
                    '=' +
                    (value || '') +
                    expiresString +
                    '; path=/' +
                    ("; domain=" + getTopLevelDomain(location.hostname)) +
                    (secure ? ';secure ; SameSite=None' : '');
        }
        catch (err) {
            console.warn('Could not set cookie', err);
        }
    }
    function getCookie(name$$1) {
        try {
            return (decodeURIComponent(document.cookie.replace(new RegExp('(?:(?:^|.*;)\\s*' +
                encodeURIComponent(name$$1).replace(/[\-\.\+\*]/g, '\\$&') +
                '\\s*\\=\\s*([^;]*).*$)|^.*$'), '$1')) || null);
        }
        catch (err) {
            console.warn('Could not get cookie', err);
        }
    }
    function size(object) {
        return Object.keys(object).length;
    }
    function find(target, callback) {
        var list = target;
        // Makes sures is always has an positive integer as length.
        var length = list.length >>> 0;
        var thisArg = arguments[1];
        for (var i = 0; i < length; i++) {
            var element = list[i];
            if (callback.call(thisArg, element, i, list)) {
                return element;
            }
        }
    }
    var sessionStorageKey = 'builderSessionId';
    var localStorageKey = 'builderVisitorId';
    var isBrowser = typeof window !== 'undefined' && !isReactNative;
    var isIframe = isBrowser && window.top !== window.self;
    var Builder = /** @class */ (function () {
        function Builder(apiKey, request, response, forceNewInstance) {
            var _this = this;
            if (apiKey === void 0) { apiKey = null; }
            if (forceNewInstance === void 0) { forceNewInstance = false; }
            this.request = request;
            this.response = response;
            this.authToken = '';
            this.eventsQueue = [];
            this.throttledClearEventsQueue = throttle(function () {
                _this.processEventsQueue();
                // Extend the session cookie
                _this.setCookie(sessionStorageKey, _this.sessionId, datePlusMinutes(30));
            }, 5);
            this.env = 'production';
            this.sessionId = this.getSessionId();
            this.targetContent = true;
            this.contentPerRequest = 1;
            // TODO: make array or function
            this.allowCustomFonts = true;
            this.cookies = null;
            // TODO: api options object
            this.cachebust = false;
            this.overrideParams = '';
            this.noCache = false;
            this.preview = false;
            this.canTrack$ = new BehaviorSubject(!this.browserTrackingDisabled);
            this.apiKey$ = new BehaviorSubject(null);
            this.userAttributesChanged = new BehaviorSubject(null);
            this.editingMode$ = new BehaviorSubject(isIframe);
            // TODO: decorator to do this stuff with the get/set (how do with typing too? compiler?)
            this.editingModel$ = new BehaviorSubject(null);
            this.userAgent = (typeof navigator === 'object' && navigator.userAgent) || '';
            this.trackingHooks = [];
            // Set this to control the userId
            // TODO: allow changing it mid session and updating existing data to be associated
            // e.g. for when a user navigates and then logs in
            this.visitorId = this.getVisitorId();
            this.autoTrack = !Builder.isBrowser
                ? false
                : !this.isDevelopmentEnv &&
                    !(Builder.isBrowser && location.search.indexOf('builder.preview=') !== -1);
            this.useNewContentApi = false;
            this.trackingUserAttributes = {};
            this.blockContentLoading = '';
            this.observersByKey = {};
            this.overrides = {};
            this.getContentQueue = null;
            this.priorContentQueue = null;
            this.testCookiePrefix = 'builder.tests';
            this.cookieQueue = [];
            // TODO: use a window variable for this perhaps, e.g. bc webcomponents may be loading builder twice
            // with it's and react (use rollup build to fix)
            if (Builder.isBrowser && !forceNewInstance && Builder.singletonInstance) {
                return Builder.singletonInstance;
            }
            if (this.request && this.response) {
                this.setUserAgent(this.request.headers['user-agent'] || '');
                this.cookies = new Cookies(this.request, this.response);
            }
            if (apiKey) {
                this.apiKey = apiKey;
            }
            if (isBrowser) {
                this.bindMessageListeners();
                // TODO: postmessage to parent the builder info for every package
                // type: 'builder.sdk', data: { name: '@builder.io/react', version: '0.1.23' }
                // (window as any).BUILDER_VERSION = Builder.VERSION;
                // Ensure always one Builder global singleton
                // TODO: some people won't want this, e.g. rakuten
                // Maybe hide this behind symbol or on document, etc
                // if ((window as any).Builder) {
                //   Builder.components = (window as any).Builder.components;
                // } else {
                //   (window as any).Builder = Builder;
                // }
            }
            if (isIframe) {
                this.messageFrameLoaded();
            }
            // TODO: on destroy clear subscription
            this.canTrack$.subscribe(function (value) {
                if (value) {
                    if (typeof sessionStorage !== 'undefined') {
                        try {
                            if (!sessionStorage.getItem(sessionStorageKey)) {
                                sessionStorage.setItem(sessionStorageKey, _this.sessionId);
                            }
                        }
                        catch (err) {
                            console.debug('Session storage error', err);
                        }
                    }
                    if (_this.eventsQueue.length) {
                        _this.throttledClearEventsQueue();
                    }
                    if (_this.cookieQueue.length) {
                        _this.cookieQueue.forEach(function (item) {
                            _this.setCookie(item[0], item[1]);
                        });
                        _this.cookieQueue.length = 0;
                    }
                }
            });
            if (isBrowser) {
                // TODO: defer so subclass constructor runs and injects location service
                this.setTestsFromUrl();
                // TODO: do this on every request send?
                this.getOverridesFromQueryString();
            }
        }
        Builder.register = function (type, info) {
            // TODO: all must have name and can't conflict?
            var typeList = this.registry[type];
            if (!typeList) {
                typeList = this.registry[type] = [];
            }
            typeList.push(info);
            if (Builder.isBrowser) {
                var message = {
                    type: 'builder.register',
                    data: {
                        type: type,
                        info: info,
                    },
                };
                try {
                    parent.postMessage(message, '*');
                    if (parent !== window) {
                        window.postMessage(message, '*');
                    }
                }
                catch (err) {
                    console.debug('Could not postmessage', err);
                }
            }
            this.registryChange.next(this.registry);
        };
        Builder.registerEditor = function (info) {
            if (Builder.isBrowser) {
                window.postMessage({
                    type: 'builder.registerEditor',
                    data: omit(info, 'component'),
                }, '*');
                var hostname = location.hostname;
                if (!Builder.isTrustedHost(hostname)) {
                    console.error('Builder.registerEditor() called in the wrong environment! You cannot load custom editors from your app, they must be loaded through the Builder.io app itself. Follow the readme here for more details: https://github.com/builderio/builder/tree/master/plugins/cloudinary or contact chat us in our Spectrum community for help: https://spectrum.chat/builder');
                }
            }
            this.editors.push(info);
        };
        Builder.registerPlugin = function (info) {
            this.plugins.push(info);
        };
        Builder.registerAction = function (action) {
            this.actions.push(action);
        };
        Builder.registerTrustedHost = function (host) {
            this.trustedHosts.push(host);
        };
        Builder.isTrustedHost = function (hostname) {
            return (this.trustedHosts.findIndex(function (trustedHost) { return trustedHost === hostname || hostname.endsWith("." + trustedHost); }) > -1);
        };
        Builder.runAction = function (action) {
            // TODO
            var actionObject = typeof action === 'string' ? find(this.actions, function (item) { return item.name === action; }) : action;
            if (!actionObject) {
                throw new Error("Action not found: " + action);
            }
        };
        Builder.fields = function (name$$1, fields) {
            var _a;
            (_a = window.parent) === null || _a === void 0 ? void 0 : _a.postMessage({
                type: 'builder.fields',
                data: { name: name$$1, fields: fields },
            }, '*');
        };
        Builder.set = function (settings) {
            if (Builder.isBrowser) {
                // TODO: merge
                Object.assign(this.settings, settings);
                var message = {
                    type: 'builder.settingsChange',
                    data: this.settings,
                };
                parent.postMessage(message, '*');
            }
            this.settingsChange.next(this.settings);
        };
        Builder.import = function (packageName) {
            if (!Builder.isBrowser) {
                // TODO: server side support *maybe*
                console.warn('Builder.import used on the server - this should only be used in the browser');
                return;
            }
            var System = window.System;
            if (!System) {
                console.warn('System.js not available. Please include System.js when using Builder.import');
                return;
            }
            return System.import("https://cdn.builder.io/systemjs/" + packageName);
        };
        Object.defineProperty(Builder, "editingPage", {
            // useCdnApi = false;
            get: function () {
                return this._editingPage;
            },
            set: function (editingPage) {
                this._editingPage = editingPage;
                if (isBrowser && isIframe) {
                    if (editingPage) {
                        document.body.classList.add('builder-editing-page');
                    }
                    else {
                        document.body.classList.remove('builder-editing-page');
                    }
                }
            },
            enumerable: true,
            configurable: true
        });
        Builder.prepareComponentSpecToSend = function (spec) {
            return __assign(__assign(__assign({}, spec), (spec.inputs && {
                inputs: spec.inputs.map(function (input) {
                    var _a;
                    // TODO: do for nexted fields too
                    // TODO: probably just convert all functions, not just
                    // TODO: put this in input hooks: { onChange: ..., showIf: ... }
                    var keysToConvertFnToString = ['onChange', 'showIf'];
                    for (var _i = 0, keysToConvertFnToString_1 = keysToConvertFnToString; _i < keysToConvertFnToString_1.length; _i++) {
                        var key = keysToConvertFnToString_1[_i];
                        if (input[key] && typeof input[key] === 'function') {
                            var fn = input[key];
                            input = __assign(__assign({}, input), (_a = {}, _a[key] = "return (" + fn.toString() + ").apply(this, arguments)", _a));
                        }
                    }
                    return input;
                }),
            })), { hooks: Object.keys(spec.hooks || {}).reduce(function (memo, key) {
                    var value = spec.hooks && spec.hooks[key];
                    if (!value) {
                        return memo;
                    }
                    if (typeof value === 'string') {
                        memo[key] = value;
                    }
                    else {
                        memo[key] = "return (" + value.toString() + ").apply(this, arguments)";
                    }
                    return memo;
                }, {}), class: undefined });
        };
        // static registerComponent(...) { .. }
        Builder.registerComponent = function (component, options) {
            var _a;
            var spec = __assign(__assign({ class: component }, component.builderOptions), options);
            this.addComponent(spec);
            if (isBrowser) {
                var sendSpec = this.prepareComponentSpecToSend(spec);
                (_a = window.parent) === null || _a === void 0 ? void 0 : _a.postMessage({
                    type: 'builder.registerComponent',
                    data: sendSpec,
                }, '*');
            }
        };
        Builder.addComponent = function (component) {
            var current = find(this.components, function (item) { return item.name === component.name; });
            if (current) {
                // FIXME: why does sometimes we get an extra post without class - probably
                // from postMessage handler wrong in some place
                if (current.class && !component.class) {
                    return;
                }
                this.components.splice(this.components.indexOf(current), 1, component);
            }
            else {
                this.components.push(component);
            }
        };
        // TODO: style guide, etc off this system as well?
        Builder.component = function (info) {
            var _this = this;
            if (info === void 0) { info = {}; }
            return function (component) {
                var _a;
                var spec = __assign(__assign({}, info), { class: component });
                if (!spec.name) {
                    spec.name = component.name;
                }
                _this.addComponent(spec);
                var sendSpec = _this.prepareComponentSpecToSend(spec);
                // TODO: serialize component name and inputs
                if (isBrowser) {
                    (_a = window.parent) === null || _a === void 0 ? void 0 : _a.postMessage({
                        type: 'builder.registerComponent',
                        data: sendSpec,
                    }, '*');
                }
                return component;
            };
        };
        Object.defineProperty(Builder, "Component", {
            get: function () {
                return this.component;
            },
            enumerable: true,
            configurable: true
        });
        Builder.prototype.processEventsQueue = function () {
            if (!this.eventsQueue.length) {
                return;
            }
            var events = this.eventsQueue;
            this.eventsQueue = [];
            var fullUserAttributes = __assign(__assign({}, Builder.overrideUserAttributes), this.trackingUserAttributes);
            for (var _i = 0, events_1 = events; _i < events_1.length; _i++) {
                var event_1 = events_1[_i];
                if (!event_1.data.metadata) {
                    event_1.data.metadata = {};
                }
                if (!event_1.data.metadata.user) {
                    event_1.data.metadata.user = {};
                }
                Object.assign(event_1.data.metadata.user, fullUserAttributes, event_1.data.metadata.user);
            }
            var host = this.host;
            fetch$1(host + "/api/v1/track", {
                method: 'POST',
                body: JSON.stringify({ events: events }),
                headers: {
                    'content-type': 'application/json',
                },
                mode: 'cors',
            }).catch(function () {
                // Not the end of the world
            });
        };
        Object.defineProperty(Builder.prototype, "browserTrackingDisabled", {
            get: function () {
                return Boolean(Builder.isBrowser && (navigator.doNotTrack === '1' || window.builderNoTrack));
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(Builder.prototype, "canTrack", {
            get: function () {
                return this.canTrack$.value;
            },
            set: function (canTrack) {
                if (this.canTrack !== canTrack) {
                    this.canTrack$.next(canTrack);
                }
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(Builder.prototype, "editingMode", {
            get: function () {
                return this.editingMode$.value;
            },
            set: function (value) {
                if (value !== this.editingMode) {
                    this.editingMode$.next(value);
                }
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(Builder.prototype, "editingModel", {
            get: function () {
                return this.editingModel$.value;
            },
            set: function (value) {
                if (value !== this.editingModel) {
                    this.editingModel$.next(value);
                }
            },
            enumerable: true,
            configurable: true
        });
        Builder.prototype.findParentElement = function (target, callback, checkElement) {
            if (checkElement === void 0) { checkElement = true; }
            if (!(target instanceof HTMLElement)) {
                return null;
            }
            var parent = checkElement ? target : target.parentElement;
            do {
                if (!parent) {
                    return null;
                }
                var matches = callback(parent);
                if (matches) {
                    return parent;
                }
            } while ((parent = parent.parentElement));
            return null;
        };
        Builder.prototype.findBuilderParent = function (target) {
            return this.findParentElement(target, function (el) {
                var id = el.getAttribute('builder-id') || el.id;
                return Boolean(id && id.indexOf('builder-') === 0);
            });
        };
        Builder.prototype.setUserAgent = function (userAgent) {
            this.userAgent = userAgent || '';
        };
        /**
         * Set a hook to modify events being tracked from builder, such as impressions and clicks
         *
         * For example, to track the model ID of each event associated with content for querying
         * by mode, you can do
         *
         *    builder.setTrackingHook((event, context) => {
         *      if (context.content) {
         *        event.data.metadata.modelId = context.content.modelId
         *      }
         *    })
         */
        Builder.prototype.setTrackingHook = function (hook) {
            this.trackingHooks.push(hook);
        };
        Builder.prototype.track = function (eventName, properties, context) {
            if (properties === void 0) { properties = {}; }
            // TODO: queue up track requests and fire them off when canTrack set to true - otherwise may get lots of clicks with no impressions
            if (isIframe || !isBrowser || Builder.isPreviewing) {
                return;
            }
            var eventData = JSON.parse(JSON.stringify({
                type: eventName,
                data: __assign(__assign({}, omit(properties, 'meta')), { metadata: __assign(__assign({ sdkVersion: Builder.VERSION, url: location.href }, properties.meta), properties.metadata), ownerId: this.apiKey, userAttributes: this.getUserAttributes(), sessionId: this.sessionId, visitorId: this.visitorId }),
            }));
            for (var _i = 0, _a = this.trackingHooks; _i < _a.length; _i++) {
                var hook = _a[_i];
                var returnValue = hook(eventData, context || {});
                if (returnValue) {
                    eventData = returnValue;
                }
            }
            // batch events
            this.eventsQueue.push(eventData);
            if (this.canTrack) {
                this.throttledClearEventsQueue();
            }
        };
        Builder.prototype.getSessionId = function () {
            var sessionId = null;
            try {
                if (Builder.isBrowser && typeof sessionStorage !== 'undefined') {
                    sessionId = this.getCookie(sessionStorageKey);
                }
            }
            catch (err) {
                console.debug('Session storage error', err);
                // It's ok
            }
            if (!sessionId) {
                sessionId = uuid();
            }
            // Give the app a second to start up and set canTrack to false if needed
            if (Builder.isBrowser) {
                this.setCookie(sessionStorageKey, sessionId, datePlusMinutes(30));
            }
            return sessionId;
        };
        Builder.prototype.getVisitorId = function () {
            var _this = this;
            if (this.visitorId) {
                return this.visitorId;
            }
            var visitorId = null;
            try {
                if (Builder.isBrowser && typeof localStorage !== 'undefined') {
                    // TODO: cookie instead?
                    visitorId = localStorage.getItem(localStorageKey);
                }
            }
            catch (err) {
                console.debug('Local storage error', err);
                // It's ok
            }
            if (!visitorId) {
                visitorId = uuid();
            }
            this.visitorId = visitorId;
            // Give the app a second to start up and set canTrack to false if needed
            if (Builder.isBrowser) {
                setTimeout(function () {
                    try {
                        if (_this.canTrack && typeof localStorage !== 'undefined' && visitorId) {
                            localStorage.setItem(localStorageKey, visitorId);
                        }
                    }
                    catch (err) {
                        console.debug('Session storage error', err);
                    }
                });
            }
            return visitorId;
        };
        Builder.prototype.trackImpression = function (contentId, variationId, properties, context) {
            if (isIframe || !isBrowser || Builder.isPreviewing) {
                return;
            }
            // TODO: use this.track method
            this.track('impression', {
                contentId: contentId,
                variationId: variationId !== contentId ? variationId : undefined,
                metadata: properties,
            }, context);
        };
        Builder.prototype.trackConversion = function (amount, contentId, variationId, customProperties, context) {
            if (isIframe || !isBrowser || Builder.isPreviewing) {
                return;
            }
            var meta = typeof contentId === 'object' ? contentId : customProperties;
            var useContentId = typeof contentId === 'string' ? contentId : undefined;
            this.track('conversion', { amount: amount, variationId: variationId, meta: meta, contentId: useContentId }, context);
        };
        Object.defineProperty(Builder.prototype, "isDevelopmentEnv", {
            // TODO: set this for QA
            get: function () {
                // Automatic determining of development environment
                return (Builder.isIframe ||
                    (Builder.isBrowser && (location.hostname === 'localhost' || location.port !== '')) ||
                    this.env !== 'production');
            },
            enumerable: true,
            configurable: true
        });
        Builder.prototype.trackInteraction = function (contentId, variationId, alreadyTrackedOne, event, context) {
            if (alreadyTrackedOne === void 0) { alreadyTrackedOne = false; }
            if (isIframe || !isBrowser || Builder.isPreviewing) {
                return;
            }
            var target = event && event.target;
            var targetBuilderElement = target && this.findBuilderParent(target);
            function round(num) {
                return Math.round(num * 1000) / 1000;
            }
            var metadata = {};
            if (event) {
                var clientX = event.clientX, clientY = event.clientY;
                if (target) {
                    var targetRect = target.getBoundingClientRect();
                    var xOffset = clientX - targetRect.left;
                    var yOffset = clientY - targetRect.top;
                    var xRatio = round(xOffset / targetRect.width);
                    var yRatio = round(yOffset / targetRect.height);
                    metadata.targetOffset = {
                        x: xRatio,
                        y: yRatio,
                    };
                }
                if (targetBuilderElement) {
                    var targetRect = targetBuilderElement.getBoundingClientRect();
                    var xOffset = clientX - targetRect.left;
                    var yOffset = clientY - targetRect.top;
                    var xRatio = round(xOffset / targetRect.width);
                    var yRatio = round(yOffset / targetRect.height);
                    metadata.builderTargetOffset = {
                        x: xRatio,
                        y: yRatio,
                    };
                }
            }
            var builderId = targetBuilderElement &&
                (targetBuilderElement.getAttribute('builder-id') || targetBuilderElement.id);
            if (builderId && targetBuilderElement) {
                metadata.builderElementIndex = [].slice
                    .call(document.getElementsByClassName(builderId))
                    .indexOf(targetBuilderElement);
            }
            this.track('click', {
                contentId: contentId,
                metadata: metadata,
                variationId: variationId !== contentId ? variationId : undefined,
                unique: !alreadyTrackedOne,
                targetBuilderElement: builderId || undefined,
            }, context);
        };
        Builder.prototype.component = function (info) {
            if (info === void 0) { info = {}; }
            return Builder.component(info);
        };
        Object.defineProperty(Builder.prototype, "apiKey", {
            get: function () {
                return this.apiKey$.value;
            },
            set: function (key) {
                this.apiKey$.next(key);
            },
            enumerable: true,
            configurable: true
        });
        Builder.prototype.modifySearch = function (search) {
            return search.replace(/(^|&|\?)(builder_.*?)=/gi, function (_match, group1, group2) { return group1 + group2.replace(/_/g, '.') + '='; });
        };
        Builder.prototype.setTestsFromUrl = function () {
            var search = this.getLocation().search;
            var params = QueryString.parseDeep(this.modifySearch(search || '').substr(1));
            var tests = params.builder && params.builder.tests;
            if (tests && typeof tests === 'object') {
                for (var key in tests) {
                    if (tests.hasOwnProperty(key)) {
                        this.setTestCookie(key, tests[key]);
                    }
                }
            }
        };
        Builder.prototype.resetOverrides = function () {
            // Ugly - pass down instances per request instead using react context
            // or use builder.get('foo', { req, res }) in react...........
            Builder.overrideUserAttributes = {};
            this.cachebust = false;
            this.noCache = false;
            this.preview = false;
            this.editingModel = null;
            this.overrides = {};
            this.env = 'production';
            this.userAgent = '';
            this.request = undefined;
            this.response = undefined;
        };
        Builder.prototype.getOverridesFromQueryString = function () {
            var location = this.getLocation();
            var params = QueryString.parseDeep(this.modifySearch(location.search || '').substr(1));
            var builder = params.builder;
            if (builder) {
                var userAttributes = builder.userAttributes, overrides = builder.overrides, env = builder.env, host = builder.host, api = builder.api, cachebust = builder.cachebust, noCache = builder.noCache, preview = builder.preview, editing = builder.editing, frameEditing = builder.frameEditing, overrideParams = builder.params;
                if (userAttributes) {
                    this.setUserAttributes(userAttributes);
                }
                if (overrides) {
                    this.overrides = overrides;
                }
                if (validEnvList.indexOf(env || api) > -1) {
                    this.env = env || api;
                }
                if (Builder.isEditing) {
                    var editingModel = frameEditing || editing || preview;
                    if (editingModel && editingModel !== 'true') {
                        this.editingModel = editingModel;
                    }
                }
                if (cachebust) {
                    this.cachebust = true;
                }
                if (noCache) {
                    this.noCache = true;
                }
                if (preview) {
                    this.preview = true;
                }
                if (params) {
                    this.overrideParams = overrideParams;
                }
            }
        };
        Builder.prototype.messageFrameLoaded = function () {
            var _a;
            (_a = window.parent) === null || _a === void 0 ? void 0 : _a.postMessage({
                type: 'builder.loaded',
                data: {
                    value: true,
                },
            }, '*');
        };
        Builder.prototype.bindMessageListeners = function () {
            var _this = this;
            if (isBrowser) {
                addEventListener('message', function (event) {
                    var _a, _b, _c, _d, _e;
                    var url = parse(event.origin);
                    var isRestricted = ['builder.register', 'builder.registerComponent'].indexOf((_a = event.data) === null || _a === void 0 ? void 0 : _a.type) === -1;
                    var isTrusted = url.hostname && Builder.isTrustedHost(url.hostname);
                    if (isRestricted && !isTrusted) {
                        return;
                    }
                    var data = event.data;
                    if (data) {
                        switch (data.type) {
                            case 'builder.ping': {
                                (_b = window.parent) === null || _b === void 0 ? void 0 : _b.postMessage({
                                    type: 'builder.pong',
                                    data: {},
                                }, '*');
                                break;
                            }
                            case 'builder.register': {
                                // TODO: possibly do this for all...
                                if (event.source === window) {
                                    break;
                                }
                                var options = data.data;
                                if (!options) {
                                    break;
                                }
                                var type = options.type, info = options.info;
                                // TODO: all must have name and can't conflict?
                                var typeList = Builder.registry[type];
                                if (!typeList) {
                                    typeList = Builder.registry[type] = [];
                                }
                                typeList.push(info);
                                Builder.registryChange.next(Builder.registry);
                                break;
                            }
                            case 'builder.settingsChange': {
                                // TODO: possibly do this for all...
                                if (event.source === window) {
                                    break;
                                }
                                var settings = data.data;
                                if (!settings) {
                                    break;
                                }
                                Object.assign(Builder.settings, settings);
                                Builder.settingsChange.next(Builder.settings);
                                break;
                            }
                            case 'builder.registerEditor': {
                                // TODO: possibly do this for all...
                                if (event.source === window) {
                                    break;
                                }
                                var info_1 = data.data;
                                if (!info_1) {
                                    break;
                                }
                                var hasComponent_1 = !!info_1.component;
                                Builder.editors.every(function (thisInfo, index) {
                                    if (info_1.name === thisInfo.name) {
                                        if (thisInfo.component && !hasComponent_1) {
                                            return false;
                                        }
                                        else {
                                            Builder.editors[index] = thisInfo;
                                        }
                                        return false;
                                    }
                                    return true;
                                });
                                break;
                            }
                            case 'builder.triggerAnimation': {
                                Builder.animator.triggerAnimation(data.data);
                                break;
                            }
                            case 'builder.contentUpdate':
                                var key = data.data.key || data.data.alias || data.data.entry || data.data.modelName;
                                var contentData = data.data.data; // hmmm...
                                var observer = _this.observersByKey[key];
                                if (observer) {
                                    observer.next([contentData]);
                                }
                                break;
                            case 'builder.getComponents':
                                (_c = window.parent) === null || _c === void 0 ? void 0 : _c.postMessage({
                                    type: 'builder.components',
                                    data: Builder.components.map(function (item) { return Builder.prepareComponentSpecToSend(item); }),
                                }, '*');
                                break;
                            case 'builder.editingModel':
                                _this.editingModel = data.data.model;
                                break;
                            case 'builder.registerComponent':
                                var componentData = data.data;
                                Builder.addComponent(componentData);
                                break;
                            case 'builder.blockContentLoading':
                                if (typeof data.data.model === 'string') {
                                    _this.blockContentLoading = data.data.model;
                                }
                                break;
                            case 'builder.editingMode':
                                var editingMode = data.data;
                                if (editingMode) {
                                    _this.editingMode = true;
                                    document.body.classList.add('builder-editing');
                                }
                                else {
                                    _this.editingMode = false;
                                    document.body.classList.remove('builder-editing');
                                }
                                break;
                            case 'builder.editingPageMode':
                                var editingPageMode = data.data;
                                Builder.editingPage = editingPageMode;
                                break;
                            case 'builder.overrideUserAttributes':
                                var userAttributes = data.data;
                                assign(Builder.overrideUserAttributes, userAttributes);
                                _this.flushGetContentQueue(true);
                                // TODO: refetch too
                                break;
                            case 'builder.overrideTestGroup':
                                var _f = data.data, variationId = _f.variationId, contentId = _f.contentId;
                                if (variationId && contentId) {
                                    _this.setTestCookie(contentId, variationId);
                                    _this.flushGetContentQueue(true);
                                }
                                break;
                            case 'builder.evaluate': {
                                var text = data.data.text;
                                var args = data.data.arguments || [];
                                var id_1 = data.data.id;
                                // tslint:disable-next-line:no-function-constructor-with-string-args
                                var fn = new Function(text);
                                var result = void 0;
                                var error = null;
                                try {
                                    result = fn.apply(_this, args);
                                }
                                catch (err) {
                                    error = err;
                                }
                                if (error) {
                                    (_d = window.parent) === null || _d === void 0 ? void 0 : _d.postMessage({
                                        type: 'builder.evaluateError',
                                        data: { id: id_1, error: error.message },
                                    }, '*');
                                }
                                else {
                                    if (result && typeof result.then === 'function') {
                                        result
                                            .then(function (finalResult) {
                                            var _a;
                                            (_a = window.parent) === null || _a === void 0 ? void 0 : _a.postMessage({
                                                type: 'builder.evaluateResult',
                                                data: { id: id_1, result: finalResult },
                                            }, '*');
                                        })
                                            .catch(console.error);
                                    }
                                    else {
                                        (_e = window.parent) === null || _e === void 0 ? void 0 : _e.postMessage({
                                            type: 'builder.evaluateResult',
                                            data: { result: result, id: id_1 },
                                        }, '*');
                                    }
                                }
                                break;
                            }
                        }
                    }
                });
            }
        };
        Object.defineProperty(Builder.prototype, "defaultCanTrack", {
            get: function () {
                return Boolean(Builder.isBrowser &&
                    navigator.userAgent.trim() &&
                    !navigator.userAgent.match(/bot|crawler|spider|robot|crawling|prerender|google|baidu|bing|msn|duckduckbot|teoma|slurp|yandex|phantom|headless|selenium|puppeteer/i) &&
                    !this.browserTrackingDisabled);
            },
            enumerable: true,
            configurable: true
        });
        Builder.prototype.init = function (apiKey, canTrack, req, res) {
            if (canTrack === void 0) { canTrack = this.defaultCanTrack; }
            if (req) {
                this.request = req;
            }
            if (res) {
                this.response = res;
            }
            this.canTrack = canTrack;
            this.apiKey = apiKey;
            return this;
        };
        // TODO: allow adding location object as property and/or in constructor
        Builder.prototype.getLocation = function () {
            var parsedLocation = {};
            // in ssr mode
            if (this.request) {
                parsedLocation = parse(this.request.url);
            }
            else if (typeof location === 'object') {
                // in the browser
                parsedLocation = parse(location.href);
            }
            // IE11 bug with parsed path being empty string
            // causes issues with our user targeting
            if (parsedLocation.pathname === '') {
                parsedLocation.pathname = '/';
            }
            return parsedLocation;
        };
        Builder.prototype.getUserAttributes = function (userAgent) {
            if (userAgent === void 0) { userAgent = this.userAgent || ''; }
            var isMobile = {
                Android: function () {
                    return userAgent.match(/Android/i);
                },
                BlackBerry: function () {
                    return userAgent.match(/BlackBerry/i);
                },
                iOS: function () {
                    return userAgent.match(/iPhone|iPod/i);
                },
                Opera: function () {
                    return userAgent.match(/Opera Mini/i);
                },
                Windows: function () {
                    return userAgent.match(/IEMobile/i) || userAgent.match(/WPDesktop/i);
                },
                any: function () {
                    return (isMobile.Android() ||
                        isMobile.BlackBerry() ||
                        isMobile.iOS() ||
                        isMobile.Opera() ||
                        isMobile.Windows());
                },
            };
            var isTablet = userAgent.match(/Tablet|iPad/i);
            var url = this.getLocation();
            return __assign({ urlPath: url.pathname, host: url.host || url.hostname, 
                // TODO: maybe an option to choose to target off of mobile/tablet/desktop or just mobile/desktop
                device: isTablet ? 'tablet' : isMobile.any() ? 'mobile' : 'desktop' }, Builder.overrideUserAttributes);
        };
        Builder.prototype.setUserAttributes = function (options) {
            assign(Builder.overrideUserAttributes, options);
            this.userAttributesChanged.next(options);
        };
        /**
         * Set user attributes just for tracking purposes.
         *
         * Do this so properties exist on event objects for querying insights, but
         * won't affect targeting
         *
         * Use this when you want to track properties but don't need to target off
         * of them to optimize cache efficiency
         */
        Builder.prototype.setTrackingUserAttributes = function (attributes) {
            assign(this.trackingUserAttributes, attributes);
        };
        Builder.prototype.get = function (modelName, options) {
            if (options === void 0) { options = {}; }
            var instance = this;
            if (!Builder.isBrowser && (options.req || options.res)) {
                instance = new Builder(options.apiKey || this.apiKey, options.req, options.res);
            }
            else {
                if (options.apiKey && !this.apiKey) {
                    this.apiKey = options.apiKey;
                }
            }
            return instance.queueGetContent(modelName, options).map(
            /* map( */ function (matches) {
                var match = matches && matches[0];
                if (Builder.isStatic) {
                    return match;
                }
                var matchData = match && match.data;
                if (!matchData) {
                    return null;
                }
                if (typeof matchData.blocksString !== 'undefined') {
                    matchData.blocks = JSON.parse(matchData.blocksString);
                    delete matchData.blocksString;
                }
                return {
                    // TODO: add ab test info here and other high level stuff
                    data: matchData,
                    id: match.id,
                    variationId: match.testVariationId || match.variationId,
                    testVariationId: match.testVariationId || match.variationId,
                    testVariationName: match.testVariationName,
                };
            });
            // );
        };
        // TODO: entry id in options
        Builder.prototype.queueGetContent = function (modelName, options) {
            var _this = this;
            if (options === void 0) { options = {}; }
            // TODO: if query do modelName + query
            var key = options.key ||
                options.alias ||
                // TODO: SDKs only pass entry key when given to them, and never when editing...
                // options.entry ||
                // TODO: this is ugly - instead of multiple of same model with different options are sent
                // say requires key/alias. Or if not perhaps make a reliable hash of the options and use that.
                // TODO: store last user state on last request and if user attributes different now
                // give a warning that need to use keys to request new contente
                // (options &&
                //   Object.keys(options).filter(key => key !== 'model').length &&
                //   JSON.stringify({ model: modelName, ...options, initialContent: undefined })) ||
                modelName;
            var isEditingThisModel = this.editingModel === modelName;
            // TODO: include params in this key........
            var currentObservable = this.observersByKey[key];
            // if (options.query && options.query._id) {
            //   this.flushGetContentQueue([options])
            // }
            if (this.apiKey === 'DEMO' && !this.overrides[key] && !options.initialContent) {
                options.initialContent = [];
            }
            var initialContent = options.initialContent;
            // TODO: refresh option in options
            if (currentObservable && (!currentObservable.value || options.cache)) {
                // TODO: test if this ran, otherwise on 404 some observers may never be called...
                if (currentObservable.value) {
                    nextTick(function () {
                        // TODO: return a new observable and only that one fires subscribers, don't refire for existing ones
                        currentObservable.next(currentObservable.value);
                    });
                }
                return currentObservable;
            }
            if (isEditingThisModel) {
                if (Builder.isBrowser) {
                    parent.postMessage({ type: 'builder.updateContent' }, '*');
                }
            }
            if (!initialContent /* || isEditingThisModel */) {
                if (!this.getContentQueue) {
                    this.getContentQueue = [];
                }
                this.getContentQueue.push(__assign(__assign({}, options), { model: modelName, key: key }));
                if (this.getContentQueue && this.getContentQueue.length >= this.contentPerRequest) {
                    var queue_1 = this.getContentQueue.slice();
                    this.getContentQueue = [];
                    nextTick(function () {
                        _this.flushGetContentQueue(false, queue_1);
                    });
                }
                else {
                    nextTick(function () {
                        _this.flushGetContentQueue();
                    });
                }
            }
            var observable = new BehaviorSubject(null);
            this.observersByKey[key] = observable;
            if (initialContent) {
                nextTick(function () {
                    // TODO: need to testModify this I think...?
                    observable.next(initialContent);
                });
            }
            return observable;
        };
        Builder.prototype.requestUrl = function (url) {
            if (Builder.isBrowser) {
                // TODO: send auth header if builder.authToken
                return fetch$1(url, this.authToken
                    ? {
                        headers: {
                            Authorization: "Bearer " + this.authToken,
                        },
                    }
                    : undefined).then(function (res) { return res.json(); });
            }
            return new Promise(function (resolve, reject) {
                var module = url.indexOf('http:') === 0 ? serverOnlyRequire$1('http') : serverOnlyRequire$1('https');
                module
                    .get(url, function (resp) {
                    var data = '';
                    // A chunk of data has been recieved.
                    resp.on('data', function (chunk) {
                        data += chunk;
                    });
                    // The whole response has been received. Print out the result.
                    resp.on('end', function () {
                        resolve(JSON.parse(data));
                    });
                })
                    .on('error', function (error) {
                    reject(error);
                });
            });
        };
        Object.defineProperty(Builder.prototype, "host", {
            get: function () {
                if (this.env.includes('//')) {
                    return this.env;
                }
                if (this.env.includes('.')) {
                    return 'http://' + this.env;
                }
                switch (this.env) {
                    case 'qa':
                        return 'https://qa.builder.io';
                    case 'fast':
                        return 'https://fast.builder.io';
                    case 'cloud':
                        return 'https://cloud.builder.io';
                    case 'cdn2':
                        return 'https://cdn2.builder.io';
                    case 'cdn-qa':
                        return 'https://cdn-qa.builder.io';
                    case 'development':
                    case 'dev':
                        return 'http://localhost:5000';
                    default:
                        return 'https://cdn.builder.io';
                }
            },
            enumerable: true,
            configurable: true
        });
        Builder.prototype.flushGetContentQueue = function (usePastQueue, useQueue) {
            var _this = this;
            if (usePastQueue === void 0) { usePastQueue = false; }
            if (!this.apiKey) {
                throw new Error('Builder needs to be initialized with an API key!');
            }
            if (!usePastQueue && !this.getContentQueue) {
                return;
            }
            var queue = useQueue || (usePastQueue ? this.priorContentQueue : this.getContentQueue) || [];
            // TODO: do this on every request send?
            this.getOverridesFromQueryString();
            var queryParams = __assign({ 
                // TODO: way to force a request to be in a separate queue. or just lower queue limit to be 1 by default
                omit: queue[0].omit || 'meta.componentsUsed', apiKey: this.apiKey }, queue[0].options);
            if (queue[0].fields) {
                queryParams.fields = queue[0].fields;
            }
            var pageQueryParams = typeof location !== 'undefined'
                ? QueryString.parseDeep(location.search.substr(1))
                : undefined || {};
            var userAttributes = 
            // FIXME: HACK: only checks first in queue for user attributes overrides, should check all
            // TODO: merge user attributes provided here with defaults and current user attiributes (?)
            queue && queue[0].userAttributes
                ? queue[0].userAttributes
                : this.targetContent
                    ? this.getUserAttributes()
                    : {
                        urlPath: this.getLocation().pathname,
                    };
            var fullUrlQueueItem = queue.find(function (item) { return !!item.includeUrl; });
            if (fullUrlQueueItem) {
                var location_1 = this.getLocation();
                if (location_1.origin) {
                    queryParams.url = "" + location_1.origin + location_1.pathname + location_1.search;
                }
            }
            var urlQueueItem = useQueue === null || useQueue === void 0 ? void 0 : useQueue.find(function (item) { return item.url; });
            if (urlQueueItem === null || urlQueueItem === void 0 ? void 0 : urlQueueItem.url) {
                userAttributes.urlPath = urlQueueItem.url.split('?')[0];
            }
            // TODO: merge in the attribute from query string ones
            // TODO: make this an option per component/request
            queryParams.userAttributes = Builder.useNewApi
                ? userAttributes
                : JSON.stringify(userAttributes);
            if (!usePastQueue && !useQueue) {
                this.priorContentQueue = queue;
                this.getContentQueue = null;
            }
            var cachebust = this.cachebust ||
                isIframe ||
                pageQueryParams.cachebust ||
                pageQueryParams['builder.cachebust'];
            if (cachebust || this.env !== 'production') {
                queryParams.cachebust = true;
            }
            if (Builder.isEditing) {
                queryParams.isEditing = true;
            }
            if (this.noCache || this.env !== 'production') {
                queryParams.noCache = true;
            }
            if (size(this.overrides)) {
                for (var key in this.overrides) {
                    if (this.overrides.hasOwnProperty(key)) {
                        queryParams["overrides." + key] = this.overrides[key];
                    }
                }
            }
            if (Builder.useNewApi && !Builder.isReact) {
                // TODO: remove me once v1 page editors converted to v2
                // queryParams.extractCss = true;
                queryParams.prerender = true;
            }
            if (Builder.useNewApi) {
                for (var _i = 0, queue_2 = queue; _i < queue_2.length; _i++) {
                    var options = queue_2[_i];
                    if (options.format) {
                        queryParams.format = options.format;
                    }
                    // TODO: remove me and make permodel
                    if (options.static) {
                        queryParams.static = options.static;
                    }
                    if (options.cachebust) {
                        queryParams.cachebust = options.cachebust;
                    }
                    if (isPositiveNumber(options.cacheSeconds)) {
                        queryParams.cacheSeconds = options.cacheSeconds;
                    }
                    if (isPositiveNumber(options.staleCacheSeconds)) {
                        queryParams.staleCacheSeconds = options.staleCacheSeconds;
                    }
                    var properties = [
                        'prerender',
                        'extractCss',
                        'limit',
                        'offset',
                        'query',
                        'preview',
                        'model',
                        'entry',
                        'rev',
                        'static',
                    ];
                    for (var _a = 0, properties_1 = properties; _a < properties_1.length; _a++) {
                        var key = properties_1[_a];
                        var value = options[key];
                        if (value !== undefined) {
                            queryParams.options = queryParams.options || {};
                            queryParams.options[options.key] = queryParams.options[options.key] || {};
                            queryParams.options[options.key][key] = JSON.stringify(value);
                        }
                    }
                }
            }
            if (this.preview) {
                queryParams.preview = 'true';
            }
            var hasParams = Object.keys(queryParams).length > 0;
            // TODO: option to force dev or qa api here
            var host = this.useNewContentApi ? 'https://lambda.builder.codes' : this.host;
            var keyNames = queue.map(function (item) { return encodeURIComponent(item.key); }).join(',');
            if (this.overrideParams) {
                var params = omit(QueryString.parse(this.overrideParams), 'apiKey');
                assign(queryParams, params);
            }
            var queryStr = Builder.useNewApi
                ? QueryString.stringifyDeep(queryParams)
                : QueryString.stringify(queryParams);
            var promise = this.requestUrl(host + "/api/v1/" + (Builder.useNewApi ? 'query' : 'content') + "/" + this.apiKey + "/" + keyNames +
                (queryParams && hasParams ? "?" + queryStr : '')).then(function (result) {
                for (var _i = 0, queue_3 = queue; _i < queue_3.length; _i++) {
                    var options = queue_3[_i];
                    var keyName = options.key;
                    if (options.model === _this.blockContentLoading) {
                        continue;
                    }
                    var isEditingThisModel = _this.editingModel === options.model;
                    if (isEditingThisModel && Builder.isEditing) {
                        parent.postMessage({ type: 'builder.updateContent' }, '*');
                        // return;
                    }
                    var observer = _this.observersByKey[keyName];
                    if (!observer) {
                        return;
                    }
                    var data = result[keyName];
                    var sorted = data; // sortBy(data, item => item.priority);
                    if (data) {
                        var testModifiedResults = Builder.isStatic
                            ? sorted
                            : _this.processResultsForTests(sorted);
                        observer.next(testModifiedResults);
                    }
                    else {
                        var search = _this.getLocation().search;
                        if ((search || '').includes('builder.preview=' + options.model)) {
                            var previewData = {
                                id: 'preview',
                                name: 'Preview',
                                data: {},
                            };
                            observer.next([previewData]);
                        }
                        observer.next([]);
                    }
                }
            }, function (err) {
                for (var _i = 0, queue_4 = queue; _i < queue_4.length; _i++) {
                    var options = queue_4[_i];
                    var observer = _this.observersByKey[options.key];
                    if (!observer) {
                        return;
                    }
                    observer.error(err);
                }
            });
            return promise;
        };
        Builder.prototype.processResultsForTests = function (results) {
            var _this = this;
            var _a;
            var mappedResults = results.map(function (item) {
                if (!item.variations) {
                    return item;
                }
                var cookieValue = _this.getTestCookie(item.id);
                var cookieVariation = cookieValue === item.id ? item : item.variations[cookieValue];
                if (cookieVariation) {
                    return __assign(__assign({}, item), { data: cookieVariation.data, variationId: cookieValue, testVariationId: cookieValue, testVariationName: cookieVariation.name });
                }
                if (item.variations && size(item.variations)) {
                    var n = 0;
                    var random = Math.random();
                    for (var id in item.variations) {
                        var variation = item.variations[id];
                        var testRatio = variation.testRatio;
                        n += testRatio;
                        if (random < n) {
                            _this.setTestCookie(item.id, variation.id);
                            var variationName = variation.name || (variation.id === item.id ? 'Default variation' : '');
                            return __assign(__assign({}, item), { data: variation.data, variationId: variation.id, testVariationId: variation.id, variationName: variationName, testVariationName: variationName });
                        }
                    }
                    _this.setTestCookie(item.id, item.id);
                }
                return __assign(__assign(__assign({}, item), { variationId: item.id }), (item.variations &&
                    size(item.variations) && {
                    testVariationId: item.id,
                    testVariationName: 'Default variation',
                }));
            });
            if (isIframe) {
                (_a = window.parent) === null || _a === void 0 ? void 0 : _a.postMessage({ type: 'builder.contentResults', data: { results: mappedResults } }, '*');
            }
            return mappedResults;
        };
        Builder.prototype.getTestCookie = function (contentId) {
            return this.getCookie(this.testCookiePrefix + "." + contentId);
        };
        Builder.prototype.setTestCookie = function (contentId, variationId) {
            if (!this.canTrack) {
                this.cookieQueue.push([contentId, variationId]);
                return;
            }
            // 30 days from now
            var future = new Date();
            future.setDate(future.getDate() + 30);
            return this.setCookie(this.testCookiePrefix + "." + contentId, variationId, future);
        };
        Builder.prototype.getCookie = function (name$$1) {
            if (this.cookies) {
                return this.cookies.get(name$$1);
            }
            return Builder.isBrowser && getCookie(name$$1);
        };
        Builder.prototype.setCookie = function (name$$1, value, expires) {
            if (this.cookies && !(Builder.isServer && Builder.isStatic)) {
                return this.cookies.set(name$$1, value, {
                    expires: expires,
                    secure: this.getLocation().protocol === 'https:',
                });
            }
            return Builder.isBrowser && setCookie(name$$1, value, expires);
        };
        Builder.prototype.getContent = function (modelName, options) {
            if (options === void 0) { options = {}; }
            if (!this.apiKey) {
                throw new Error('Builder needs to be initialized with an API key!');
            }
            return this.queueGetContent(modelName, options);
        };
        Builder.prototype.getAll = function (modelName, options) {
            if (options === void 0) { options = {}; }
            var instance = this;
            if (!Builder.isBrowser && (options.req || options.res)) {
                instance = new Builder(options.apiKey || this.apiKey, options.req, options.res);
            }
            else {
                if (options.apiKey && !this.apiKey) {
                    this.apiKey = options.apiKey;
                }
            }
            return instance
                .getContent(modelName, __assign(__assign({ limit: 30 }, options), { key: options.key ||
                    // Make the key include all options so we don't reuse cache for the same conent fetched
                    // with different options
                    (Builder.isBrowser &&
                        modelName + ":" + hashSum(omit(options, 'initialContent', 'req', 'res'))) ||
                    undefined }))
                .promise();
        };
        Builder.VERSION = version;
        Builder.components = [];
        Builder.useNewApi = true;
        // isStatic delegates all variants rendering and election to the variants provider
        // which in turn will always render default variation on server and winning variation on client
        Builder.isStatic = false;
        Builder.animator = new Animator();
        Builder.nextTick = nextTick;
        Builder.throttle = throttle;
        Builder.editors = [];
        Builder.trustedHosts = ['builder.io', 'localhost'];
        Builder.plugins = [];
        Builder.actions = [];
        Builder.registry = {};
        Builder.registryChange = new BehaviorSubject({});
        Builder._editingPage = false;
        Builder.isIframe = isIframe;
        Builder.isBrowser = isBrowser;
        Builder.isReactNative = isReactNative;
        Builder.isServer = !isBrowser && !isReactNative;
        Builder.previewingModel = Builder.isBrowser && getQueryParam(location.href, 'builder.preview');
        Builder.settings = {};
        Builder.settingsChange = new BehaviorSubject({});
        // TODO: this is quick and dirty, do better implementation later. Also can be unreliable
        // if page 301s etc. Use a query param instead? also could have issues with redirects. Injecting var could
        // work but is async...
        Builder.isEditing = Boolean(isIframe &&
            ((document.referrer && document.referrer.match(/builder\.io|localhost:1234/)) ||
                location.search.indexOf('builder.frameEditing=') !== -1));
        Builder.isPreviewing = Boolean(isBrowser &&
            (location.search.indexOf('builder.preview=') !== -1 ||
                location.search.indexOf('builder.frameEditing=') !== -1));
        Builder.isReact = false;
        Builder.overrideUserAttributes = {};
        return Builder;
    }());

    var builder = new Builder(null, undefined, undefined, true);
    Builder.singletonInstance = builder;

    function _inheritsLoose(subClass, superClass) {
      subClass.prototype = Object.create(superClass.prototype);
      subClass.prototype.constructor = subClass;
      subClass.__proto__ = superClass;
    }

    var inheritsLoose = _inheritsLoose;

    function unwrapExports (x) {
    	return x && x.__esModule && Object.prototype.hasOwnProperty.call(x, 'default') ? x['default'] : x;
    }

    function createCommonjsModule(fn, module) {
    	return module = { exports: {} }, fn(module, module.exports), module.exports;
    }

    /*
    object-assign
    (c) Sindre Sorhus
    @license MIT
    */
    /* eslint-disable no-unused-vars */
    var getOwnPropertySymbols = Object.getOwnPropertySymbols;
    var hasOwnProperty = Object.prototype.hasOwnProperty;
    var propIsEnumerable = Object.prototype.propertyIsEnumerable;

    function toObject(val) {
    	if (val === null || val === undefined) {
    		throw new TypeError('Object.assign cannot be called with null or undefined');
    	}

    	return Object(val);
    }

    function shouldUseNative() {
    	try {
    		if (!Object.assign) {
    			return false;
    		}

    		// Detect buggy property enumeration order in older V8 versions.

    		// https://bugs.chromium.org/p/v8/issues/detail?id=4118
    		var test1 = new String('abc');  // eslint-disable-line no-new-wrappers
    		test1[5] = 'de';
    		if (Object.getOwnPropertyNames(test1)[0] === '5') {
    			return false;
    		}

    		// https://bugs.chromium.org/p/v8/issues/detail?id=3056
    		var test2 = {};
    		for (var i = 0; i < 10; i++) {
    			test2['_' + String.fromCharCode(i)] = i;
    		}
    		var order2 = Object.getOwnPropertyNames(test2).map(function (n) {
    			return test2[n];
    		});
    		if (order2.join('') !== '0123456789') {
    			return false;
    		}

    		// https://bugs.chromium.org/p/v8/issues/detail?id=3056
    		var test3 = {};
    		'abcdefghijklmnopqrst'.split('').forEach(function (letter) {
    			test3[letter] = letter;
    		});
    		if (Object.keys(Object.assign({}, test3)).join('') !==
    				'abcdefghijklmnopqrst') {
    			return false;
    		}

    		return true;
    	} catch (err) {
    		// We don't expect any of the above to throw, but better to be safe.
    		return false;
    	}
    }

    var objectAssign = shouldUseNative() ? Object.assign : function (target, source) {
    	var from;
    	var to = toObject(target);
    	var symbols;

    	for (var s = 1; s < arguments.length; s++) {
    		from = Object(arguments[s]);

    		for (var key in from) {
    			if (hasOwnProperty.call(from, key)) {
    				to[key] = from[key];
    			}
    		}

    		if (getOwnPropertySymbols) {
    			symbols = getOwnPropertySymbols(from);
    			for (var i = 0; i < symbols.length; i++) {
    				if (propIsEnumerable.call(from, symbols[i])) {
    					to[symbols[i]] = from[symbols[i]];
    				}
    			}
    		}
    	}

    	return to;
    };

    var n="function"===typeof Symbol&&Symbol.for,p=n?Symbol.for("react.element"):60103,q=n?Symbol.for("react.portal"):60106,r=n?Symbol.for("react.fragment"):60107,t=n?Symbol.for("react.strict_mode"):60108,u=n?Symbol.for("react.profiler"):60114,v=n?Symbol.for("react.provider"):60109,w=n?Symbol.for("react.context"):60110,x=n?Symbol.for("react.forward_ref"):60112,y=n?Symbol.for("react.suspense"):60113;var z=n?Symbol.for("react.memo"):60115,aa=n?Symbol.for("react.lazy"):60116;var A="function"===typeof Symbol&&Symbol.iterator;
    function B(a){for(var b="https://reactjs.org/docs/error-decoder.html?invariant="+a,c=1;c<arguments.length;c++)b+="&args[]="+encodeURIComponent(arguments[c]);return"Minified React error #"+a+"; visit "+b+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}var C={isMounted:function(){return!1},enqueueForceUpdate:function(){},enqueueReplaceState:function(){},enqueueSetState:function(){}},D={};
    function E(a,b,c){this.props=a;this.context=b;this.refs=D;this.updater=c||C;}E.prototype.isReactComponent={};E.prototype.setState=function(a,b){if("object"!==typeof a&&"function"!==typeof a&&null!=a)throw Error(B(85));this.updater.enqueueSetState(this,a,b,"setState");};E.prototype.forceUpdate=function(a){this.updater.enqueueForceUpdate(this,a,"forceUpdate");};function F(){}F.prototype=E.prototype;function G(a,b,c){this.props=a;this.context=b;this.refs=D;this.updater=c||C;}var H=G.prototype=new F;
    H.constructor=G;objectAssign(H,E.prototype);H.isPureReactComponent=!0;var I={current:null},J={current:null},K=Object.prototype.hasOwnProperty,L={key:!0,ref:!0,__self:!0,__source:!0};
    function M(a,b,c){var e,d={},g=null,l=null;if(null!=b)for(e in void 0!==b.ref&&(l=b.ref),void 0!==b.key&&(g=""+b.key),b)K.call(b,e)&&!L.hasOwnProperty(e)&&(d[e]=b[e]);var f=arguments.length-2;if(1===f)d.children=c;else if(1<f){for(var k=Array(f),m=0;m<f;m++)k[m]=arguments[m+2];d.children=k;}if(a&&a.defaultProps)for(e in f=a.defaultProps,f)void 0===d[e]&&(d[e]=f[e]);return{$$typeof:p,type:a,key:g,ref:l,props:d,_owner:J.current}}
    function ba(a,b){return{$$typeof:p,type:a.type,key:b,ref:a.ref,props:a.props,_owner:a._owner}}function N(a){return"object"===typeof a&&null!==a&&a.$$typeof===p}function escape(a){var b={"=":"=0",":":"=2"};return"$"+(""+a).replace(/[=:]/g,function(a){return b[a]})}var O=/\/+/g,P=[];function Q(a,b,c,e){if(P.length){var d=P.pop();d.result=a;d.keyPrefix=b;d.func=c;d.context=e;d.count=0;return d}return{result:a,keyPrefix:b,func:c,context:e,count:0}}
    function R(a){a.result=null;a.keyPrefix=null;a.func=null;a.context=null;a.count=0;10>P.length&&P.push(a);}
    function S(a,b,c,e){var d=typeof a;if("undefined"===d||"boolean"===d)a=null;var g=!1;if(null===a)g=!0;else switch(d){case "string":case "number":g=!0;break;case "object":switch(a.$$typeof){case p:case q:g=!0;}}if(g)return c(e,a,""===b?"."+T(a,0):b),1;g=0;b=""===b?".":b+":";if(Array.isArray(a))for(var l=0;l<a.length;l++){d=a[l];var f=b+T(d,l);g+=S(d,f,c,e);}else if(null===a||"object"!==typeof a?f=null:(f=A&&a[A]||a["@@iterator"],f="function"===typeof f?f:null),"function"===typeof f)for(a=f.call(a),l=
    0;!(d=a.next()).done;)d=d.value,f=b+T(d,l++),g+=S(d,f,c,e);else if("object"===d)throw c=""+a,Error(B(31,"[object Object]"===c?"object with keys {"+Object.keys(a).join(", ")+"}":c,""));return g}function U(a,b,c){return null==a?0:S(a,"",b,c)}function T(a,b){return"object"===typeof a&&null!==a&&null!=a.key?escape(a.key):b.toString(36)}function ca(a,b){a.func.call(a.context,b,a.count++);}
    function da(a,b,c){var e=a.result,d=a.keyPrefix;a=a.func.call(a.context,b,a.count++);Array.isArray(a)?V(a,e,c,function(a){return a}):null!=a&&(N(a)&&(a=ba(a,d+(!a.key||b&&b.key===a.key?"":(""+a.key).replace(O,"$&/")+"/")+c)),e.push(a));}function V(a,b,c,e,d){var g="";null!=c&&(g=(""+c).replace(O,"$&/")+"/");b=Q(b,g,e,d);U(a,da,b);R(b);}function W(){var a=I.current;if(null===a)throw Error(B(321));return a}
    var X={Children:{map:function(a,b,c){if(null==a)return a;var e=[];V(a,e,null,b,c);return e},forEach:function(a,b,c){if(null==a)return a;b=Q(null,null,b,c);U(a,ca,b);R(b);},count:function(a){return U(a,function(){return null},null)},toArray:function(a){var b=[];V(a,b,null,function(a){return a});return b},only:function(a){if(!N(a))throw Error(B(143));return a}},createRef:function(){return{current:null}},Component:E,PureComponent:G,createContext:function(a,b){void 0===b&&(b=null);a={$$typeof:w,_calculateChangedBits:b,
    _currentValue:a,_currentValue2:a,_threadCount:0,Provider:null,Consumer:null};a.Provider={$$typeof:v,_context:a};return a.Consumer=a},forwardRef:function(a){return{$$typeof:x,render:a}},lazy:function(a){return{$$typeof:aa,_ctor:a,_status:-1,_result:null}},memo:function(a,b){return{$$typeof:z,type:a,compare:void 0===b?null:b}},useCallback:function(a,b){return W().useCallback(a,b)},useContext:function(a,b){return W().useContext(a,b)},useEffect:function(a,b){return W().useEffect(a,b)},useImperativeHandle:function(a,
    b,c){return W().useImperativeHandle(a,b,c)},useDebugValue:function(){},useLayoutEffect:function(a,b){return W().useLayoutEffect(a,b)},useMemo:function(a,b){return W().useMemo(a,b)},useReducer:function(a,b,c){return W().useReducer(a,b,c)},useRef:function(a){return W().useRef(a)},useState:function(a){return W().useState(a)},Fragment:r,Profiler:u,StrictMode:t,Suspense:y,createElement:M,cloneElement:function(a,b,c){if(null===a||void 0===a)throw Error(B(267,a));var e=objectAssign({},a.props),d=a.key,g=a.ref,l=a._owner;
    if(null!=b){void 0!==b.ref&&(g=b.ref,l=J.current);void 0!==b.key&&(d=""+b.key);if(a.type&&a.type.defaultProps)var f=a.type.defaultProps;for(k in b)K.call(b,k)&&!L.hasOwnProperty(k)&&(e[k]=void 0===b[k]&&void 0!==f?f[k]:b[k]);}var k=arguments.length-2;if(1===k)e.children=c;else if(1<k){f=Array(k);for(var m=0;m<k;m++)f[m]=arguments[m+2];e.children=f;}return{$$typeof:p,type:a.type,key:d,ref:g,props:e,_owner:l}},createFactory:function(a){var b=M.bind(null,a);b.type=a;return b},isValidElement:N,version:"16.12.0",
    __SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED:{ReactCurrentDispatcher:I,ReactCurrentBatchConfig:{suspense:null},ReactCurrentOwner:J,IsSomeRendererActing:{current:!1},assign:objectAssign}},Y={default:X},Z=Y&&X||Y;var react_production_min=Z.default||Z;

    var react = createCommonjsModule(function (module) {

    {
      module.exports = react_production_min;
    }
    });
    var react_1 = react.cloneElement;
    var react_2 = react.createContext;
    var react_3 = react.Component;
    var react_4 = react.createElement;
    var react_5 = react.forwardRef;
    var react_6 = react.Fragment;

    /*

    Based off glamor's StyleSheet, thanks Sunil ❤️

    high performance StyleSheet for css-in-js systems

    - uses multiple style tags behind the scenes for millions of rules
    - uses `insertRule` for appending in production for *much* faster performance

    // usage

    import { StyleSheet } from '@emotion/sheet'

    let styleSheet = new StyleSheet({ key: '', container: document.head })

    styleSheet.insert('#box { border: 1px solid red; }')
    - appends a css rule into the stylesheet

    styleSheet.flush()
    - empties the stylesheet of all its contents

    */
    // $FlowFixMe
    function sheetForTag(tag) {
      if (tag.sheet) {
        // $FlowFixMe
        return tag.sheet;
      } // this weirdness brought to you by firefox

      /* istanbul ignore next */


      for (var i = 0; i < document.styleSheets.length; i++) {
        if (document.styleSheets[i].ownerNode === tag) {
          // $FlowFixMe
          return document.styleSheets[i];
        }
      }
    }

    function createStyleElement(options) {
      var tag = document.createElement('style');
      tag.setAttribute('data-emotion', options.key);

      if (options.nonce !== undefined) {
        tag.setAttribute('nonce', options.nonce);
      }

      tag.appendChild(document.createTextNode(''));
      return tag;
    }

    var StyleSheet =
    /*#__PURE__*/
    function () {
      function StyleSheet(options) {
        this.isSpeedy = options.speedy === undefined ? "production" === 'production' : options.speedy;
        this.tags = [];
        this.ctr = 0;
        this.nonce = options.nonce; // key is the value of the data-emotion attribute, it's used to identify different sheets

        this.key = options.key;
        this.container = options.container;
        this.before = null;
      }

      var _proto = StyleSheet.prototype;

      _proto.insert = function insert(rule) {
        // the max length is how many rules we have per style tag, it's 65000 in speedy mode
        // it's 1 in dev because we insert source maps that map a single rule to a location
        // and you can only have one source map per style tag
        if (this.ctr % (this.isSpeedy ? 65000 : 1) === 0) {
          var _tag = createStyleElement(this);

          var before;

          if (this.tags.length === 0) {
            before = this.before;
          } else {
            before = this.tags[this.tags.length - 1].nextSibling;
          }

          this.container.insertBefore(_tag, before);
          this.tags.push(_tag);
        }

        var tag = this.tags[this.tags.length - 1];

        if (this.isSpeedy) {
          var sheet = sheetForTag(tag);

          try {
            // this is a really hot path
            // we check the second character first because having "i"
            // as the second character will happen less often than
            // having "@" as the first character
            var isImportRule = rule.charCodeAt(1) === 105 && rule.charCodeAt(0) === 64; // this is the ultrafast version, works across browsers
            // the big drawback is that the css won't be editable in devtools

            sheet.insertRule(rule, // we need to insert @import rules before anything else
            // otherwise there will be an error
            // technically this means that the @import rules will
            // _usually_(not always since there could be multiple style tags)
            // be the first ones in prod and generally later in dev
            // this shouldn't really matter in the real world though
            // @import is generally only used for font faces from google fonts and etc.
            // so while this could be technically correct then it would be slower and larger
            // for a tiny bit of correctness that won't matter in the real world
            isImportRule ? 0 : sheet.cssRules.length);
          } catch (e) {
          }
        } else {
          tag.appendChild(document.createTextNode(rule));
        }

        this.ctr++;
      };

      _proto.flush = function flush() {
        // $FlowFixMe
        this.tags.forEach(function (tag) {
          return tag.parentNode.removeChild(tag);
        });
        this.tags = [];
        this.ctr = 0;
      };

      return StyleSheet;
    }();

    function stylis_min (W) {
      function M(d, c, e, h, a) {
        for (var m = 0, b = 0, v = 0, n = 0, q, g, x = 0, K = 0, k, u = k = q = 0, l = 0, r = 0, I = 0, t = 0, B = e.length, J = B - 1, y, f = '', p = '', F = '', G = '', C; l < B;) {
          g = e.charCodeAt(l);
          l === J && 0 !== b + n + v + m && (0 !== b && (g = 47 === b ? 10 : 47), n = v = m = 0, B++, J++);

          if (0 === b + n + v + m) {
            if (l === J && (0 < r && (f = f.replace(N, '')), 0 < f.trim().length)) {
              switch (g) {
                case 32:
                case 9:
                case 59:
                case 13:
                case 10:
                  break;

                default:
                  f += e.charAt(l);
              }

              g = 59;
            }

            switch (g) {
              case 123:
                f = f.trim();
                q = f.charCodeAt(0);
                k = 1;

                for (t = ++l; l < B;) {
                  switch (g = e.charCodeAt(l)) {
                    case 123:
                      k++;
                      break;

                    case 125:
                      k--;
                      break;

                    case 47:
                      switch (g = e.charCodeAt(l + 1)) {
                        case 42:
                        case 47:
                          a: {
                            for (u = l + 1; u < J; ++u) {
                              switch (e.charCodeAt(u)) {
                                case 47:
                                  if (42 === g && 42 === e.charCodeAt(u - 1) && l + 2 !== u) {
                                    l = u + 1;
                                    break a;
                                  }

                                  break;

                                case 10:
                                  if (47 === g) {
                                    l = u + 1;
                                    break a;
                                  }

                              }
                            }

                            l = u;
                          }

                      }

                      break;

                    case 91:
                      g++;

                    case 40:
                      g++;

                    case 34:
                    case 39:
                      for (; l++ < J && e.charCodeAt(l) !== g;) {
                      }

                  }

                  if (0 === k) break;
                  l++;
                }

                k = e.substring(t, l);
                0 === q && (q = (f = f.replace(ca, '').trim()).charCodeAt(0));

                switch (q) {
                  case 64:
                    0 < r && (f = f.replace(N, ''));
                    g = f.charCodeAt(1);

                    switch (g) {
                      case 100:
                      case 109:
                      case 115:
                      case 45:
                        r = c;
                        break;

                      default:
                        r = O;
                    }

                    k = M(c, r, k, g, a + 1);
                    t = k.length;
                    0 < A && (r = X(O, f, I), C = H(3, k, r, c, D, z, t, g, a, h), f = r.join(''), void 0 !== C && 0 === (t = (k = C.trim()).length) && (g = 0, k = ''));
                    if (0 < t) switch (g) {
                      case 115:
                        f = f.replace(da, ea);

                      case 100:
                      case 109:
                      case 45:
                        k = f + '{' + k + '}';
                        break;

                      case 107:
                        f = f.replace(fa, '$1 $2');
                        k = f + '{' + k + '}';
                        k = 1 === w || 2 === w && L('@' + k, 3) ? '@-webkit-' + k + '@' + k : '@' + k;
                        break;

                      default:
                        k = f + k, 112 === h && (k = (p += k, ''));
                    } else k = '';
                    break;

                  default:
                    k = M(c, X(c, f, I), k, h, a + 1);
                }

                F += k;
                k = I = r = u = q = 0;
                f = '';
                g = e.charCodeAt(++l);
                break;

              case 125:
              case 59:
                f = (0 < r ? f.replace(N, '') : f).trim();
                if (1 < (t = f.length)) switch (0 === u && (q = f.charCodeAt(0), 45 === q || 96 < q && 123 > q) && (t = (f = f.replace(' ', ':')).length), 0 < A && void 0 !== (C = H(1, f, c, d, D, z, p.length, h, a, h)) && 0 === (t = (f = C.trim()).length) && (f = '\x00\x00'), q = f.charCodeAt(0), g = f.charCodeAt(1), q) {
                  case 0:
                    break;

                  case 64:
                    if (105 === g || 99 === g) {
                      G += f + e.charAt(l);
                      break;
                    }

                  default:
                    58 !== f.charCodeAt(t - 1) && (p += P(f, q, g, f.charCodeAt(2)));
                }
                I = r = u = q = 0;
                f = '';
                g = e.charCodeAt(++l);
            }
          }

          switch (g) {
            case 13:
            case 10:
              47 === b ? b = 0 : 0 === 1 + q && 107 !== h && 0 < f.length && (r = 1, f += '\x00');
              0 < A * Y && H(0, f, c, d, D, z, p.length, h, a, h);
              z = 1;
              D++;
              break;

            case 59:
            case 125:
              if (0 === b + n + v + m) {
                z++;
                break;
              }

            default:
              z++;
              y = e.charAt(l);

              switch (g) {
                case 9:
                case 32:
                  if (0 === n + m + b) switch (x) {
                    case 44:
                    case 58:
                    case 9:
                    case 32:
                      y = '';
                      break;

                    default:
                      32 !== g && (y = ' ');
                  }
                  break;

                case 0:
                  y = '\\0';
                  break;

                case 12:
                  y = '\\f';
                  break;

                case 11:
                  y = '\\v';
                  break;

                case 38:
                  0 === n + b + m && (r = I = 1, y = '\f' + y);
                  break;

                case 108:
                  if (0 === n + b + m + E && 0 < u) switch (l - u) {
                    case 2:
                      112 === x && 58 === e.charCodeAt(l - 3) && (E = x);

                    case 8:
                      111 === K && (E = K);
                  }
                  break;

                case 58:
                  0 === n + b + m && (u = l);
                  break;

                case 44:
                  0 === b + v + n + m && (r = 1, y += '\r');
                  break;

                case 34:
                case 39:
                  0 === b && (n = n === g ? 0 : 0 === n ? g : n);
                  break;

                case 91:
                  0 === n + b + v && m++;
                  break;

                case 93:
                  0 === n + b + v && m--;
                  break;

                case 41:
                  0 === n + b + m && v--;
                  break;

                case 40:
                  if (0 === n + b + m) {
                    if (0 === q) switch (2 * x + 3 * K) {
                      case 533:
                        break;

                      default:
                        q = 1;
                    }
                    v++;
                  }

                  break;

                case 64:
                  0 === b + v + n + m + u + k && (k = 1);
                  break;

                case 42:
                case 47:
                  if (!(0 < n + m + v)) switch (b) {
                    case 0:
                      switch (2 * g + 3 * e.charCodeAt(l + 1)) {
                        case 235:
                          b = 47;
                          break;

                        case 220:
                          t = l, b = 42;
                      }

                      break;

                    case 42:
                      47 === g && 42 === x && t + 2 !== l && (33 === e.charCodeAt(t + 2) && (p += e.substring(t, l + 1)), y = '', b = 0);
                  }
              }

              0 === b && (f += y);
          }

          K = x;
          x = g;
          l++;
        }

        t = p.length;

        if (0 < t) {
          r = c;
          if (0 < A && (C = H(2, p, r, d, D, z, t, h, a, h), void 0 !== C && 0 === (p = C).length)) return G + p + F;
          p = r.join(',') + '{' + p + '}';

          if (0 !== w * E) {
            2 !== w || L(p, 2) || (E = 0);

            switch (E) {
              case 111:
                p = p.replace(ha, ':-moz-$1') + p;
                break;

              case 112:
                p = p.replace(Q, '::-webkit-input-$1') + p.replace(Q, '::-moz-$1') + p.replace(Q, ':-ms-input-$1') + p;
            }

            E = 0;
          }
        }

        return G + p + F;
      }

      function X(d, c, e) {
        var h = c.trim().split(ia);
        c = h;
        var a = h.length,
            m = d.length;

        switch (m) {
          case 0:
          case 1:
            var b = 0;

            for (d = 0 === m ? '' : d[0] + ' '; b < a; ++b) {
              c[b] = Z(d, c[b], e).trim();
            }

            break;

          default:
            var v = b = 0;

            for (c = []; b < a; ++b) {
              for (var n = 0; n < m; ++n) {
                c[v++] = Z(d[n] + ' ', h[b], e).trim();
              }
            }

        }

        return c;
      }

      function Z(d, c, e) {
        var h = c.charCodeAt(0);
        33 > h && (h = (c = c.trim()).charCodeAt(0));

        switch (h) {
          case 38:
            return c.replace(F, '$1' + d.trim());

          case 58:
            return d.trim() + c.replace(F, '$1' + d.trim());

          default:
            if (0 < 1 * e && 0 < c.indexOf('\f')) return c.replace(F, (58 === d.charCodeAt(0) ? '' : '$1') + d.trim());
        }

        return d + c;
      }

      function P(d, c, e, h) {
        var a = d + ';',
            m = 2 * c + 3 * e + 4 * h;

        if (944 === m) {
          d = a.indexOf(':', 9) + 1;
          var b = a.substring(d, a.length - 1).trim();
          b = a.substring(0, d).trim() + b + ';';
          return 1 === w || 2 === w && L(b, 1) ? '-webkit-' + b + b : b;
        }

        if (0 === w || 2 === w && !L(a, 1)) return a;

        switch (m) {
          case 1015:
            return 97 === a.charCodeAt(10) ? '-webkit-' + a + a : a;

          case 951:
            return 116 === a.charCodeAt(3) ? '-webkit-' + a + a : a;

          case 963:
            return 110 === a.charCodeAt(5) ? '-webkit-' + a + a : a;

          case 1009:
            if (100 !== a.charCodeAt(4)) break;

          case 969:
          case 942:
            return '-webkit-' + a + a;

          case 978:
            return '-webkit-' + a + '-moz-' + a + a;

          case 1019:
          case 983:
            return '-webkit-' + a + '-moz-' + a + '-ms-' + a + a;

          case 883:
            if (45 === a.charCodeAt(8)) return '-webkit-' + a + a;
            if (0 < a.indexOf('image-set(', 11)) return a.replace(ja, '$1-webkit-$2') + a;
            break;

          case 932:
            if (45 === a.charCodeAt(4)) switch (a.charCodeAt(5)) {
              case 103:
                return '-webkit-box-' + a.replace('-grow', '') + '-webkit-' + a + '-ms-' + a.replace('grow', 'positive') + a;

              case 115:
                return '-webkit-' + a + '-ms-' + a.replace('shrink', 'negative') + a;

              case 98:
                return '-webkit-' + a + '-ms-' + a.replace('basis', 'preferred-size') + a;
            }
            return '-webkit-' + a + '-ms-' + a + a;

          case 964:
            return '-webkit-' + a + '-ms-flex-' + a + a;

          case 1023:
            if (99 !== a.charCodeAt(8)) break;
            b = a.substring(a.indexOf(':', 15)).replace('flex-', '').replace('space-between', 'justify');
            return '-webkit-box-pack' + b + '-webkit-' + a + '-ms-flex-pack' + b + a;

          case 1005:
            return ka.test(a) ? a.replace(aa, ':-webkit-') + a.replace(aa, ':-moz-') + a : a;

          case 1e3:
            b = a.substring(13).trim();
            c = b.indexOf('-') + 1;

            switch (b.charCodeAt(0) + b.charCodeAt(c)) {
              case 226:
                b = a.replace(G, 'tb');
                break;

              case 232:
                b = a.replace(G, 'tb-rl');
                break;

              case 220:
                b = a.replace(G, 'lr');
                break;

              default:
                return a;
            }

            return '-webkit-' + a + '-ms-' + b + a;

          case 1017:
            if (-1 === a.indexOf('sticky', 9)) break;

          case 975:
            c = (a = d).length - 10;
            b = (33 === a.charCodeAt(c) ? a.substring(0, c) : a).substring(d.indexOf(':', 7) + 1).trim();

            switch (m = b.charCodeAt(0) + (b.charCodeAt(7) | 0)) {
              case 203:
                if (111 > b.charCodeAt(8)) break;

              case 115:
                a = a.replace(b, '-webkit-' + b) + ';' + a;
                break;

              case 207:
              case 102:
                a = a.replace(b, '-webkit-' + (102 < m ? 'inline-' : '') + 'box') + ';' + a.replace(b, '-webkit-' + b) + ';' + a.replace(b, '-ms-' + b + 'box') + ';' + a;
            }

            return a + ';';

          case 938:
            if (45 === a.charCodeAt(5)) switch (a.charCodeAt(6)) {
              case 105:
                return b = a.replace('-items', ''), '-webkit-' + a + '-webkit-box-' + b + '-ms-flex-' + b + a;

              case 115:
                return '-webkit-' + a + '-ms-flex-item-' + a.replace(ba, '') + a;

              default:
                return '-webkit-' + a + '-ms-flex-line-pack' + a.replace('align-content', '').replace(ba, '') + a;
            }
            break;

          case 973:
          case 989:
            if (45 !== a.charCodeAt(3) || 122 === a.charCodeAt(4)) break;

          case 931:
          case 953:
            if (!0 === la.test(d)) return 115 === (b = d.substring(d.indexOf(':') + 1)).charCodeAt(0) ? P(d.replace('stretch', 'fill-available'), c, e, h).replace(':fill-available', ':stretch') : a.replace(b, '-webkit-' + b) + a.replace(b, '-moz-' + b.replace('fill-', '')) + a;
            break;

          case 962:
            if (a = '-webkit-' + a + (102 === a.charCodeAt(5) ? '-ms-' + a : '') + a, 211 === e + h && 105 === a.charCodeAt(13) && 0 < a.indexOf('transform', 10)) return a.substring(0, a.indexOf(';', 27) + 1).replace(ma, '$1-webkit-$2') + a;
        }

        return a;
      }

      function L(d, c) {
        var e = d.indexOf(1 === c ? ':' : '{'),
            h = d.substring(0, 3 !== c ? e : 10);
        e = d.substring(e + 1, d.length - 1);
        return R(2 !== c ? h : h.replace(na, '$1'), e, c);
      }

      function ea(d, c) {
        var e = P(c, c.charCodeAt(0), c.charCodeAt(1), c.charCodeAt(2));
        return e !== c + ';' ? e.replace(oa, ' or ($1)').substring(4) : '(' + c + ')';
      }

      function H(d, c, e, h, a, m, b, v, n, q) {
        for (var g = 0, x = c, w; g < A; ++g) {
          switch (w = S[g].call(B, d, x, e, h, a, m, b, v, n, q)) {
            case void 0:
            case !1:
            case !0:
            case null:
              break;

            default:
              x = w;
          }
        }

        if (x !== c) return x;
      }

      function T(d) {
        switch (d) {
          case void 0:
          case null:
            A = S.length = 0;
            break;

          default:
            if ('function' === typeof d) S[A++] = d;else if ('object' === typeof d) for (var c = 0, e = d.length; c < e; ++c) {
              T(d[c]);
            } else Y = !!d | 0;
        }

        return T;
      }

      function U(d) {
        d = d.prefix;
        void 0 !== d && (R = null, d ? 'function' !== typeof d ? w = 1 : (w = 2, R = d) : w = 0);
        return U;
      }

      function B(d, c) {
        var e = d;
        33 > e.charCodeAt(0) && (e = e.trim());
        V = e;
        e = [V];

        if (0 < A) {
          var h = H(-1, c, e, e, D, z, 0, 0, 0, 0);
          void 0 !== h && 'string' === typeof h && (c = h);
        }

        var a = M(O, e, c, 0, 0);
        0 < A && (h = H(-2, a, e, e, D, z, a.length, 0, 0, 0), void 0 !== h && (a = h));
        V = '';
        E = 0;
        z = D = 1;
        return a;
      }

      var ca = /^\0+/g,
          N = /[\0\r\f]/g,
          aa = /: */g,
          ka = /zoo|gra/,
          ma = /([,: ])(transform)/g,
          ia = /,\r+?/g,
          F = /([\t\r\n ])*\f?&/g,
          fa = /@(k\w+)\s*(\S*)\s*/,
          Q = /::(place)/g,
          ha = /:(read-only)/g,
          G = /[svh]\w+-[tblr]{2}/,
          da = /\(\s*(.*)\s*\)/g,
          oa = /([\s\S]*?);/g,
          ba = /-self|flex-/g,
          na = /[^]*?(:[rp][el]a[\w-]+)[^]*/,
          la = /stretch|:\s*\w+\-(?:conte|avail)/,
          ja = /([^-])(image-set\()/,
          z = 1,
          D = 1,
          E = 0,
          w = 1,
          O = [],
          S = [],
          A = 0,
          R = null,
          Y = 0,
          V = '';
      B.use = T;
      B.set = U;
      void 0 !== W && U(W);
      return B;
    }

    var weakMemoize = function weakMemoize(func) {
      // $FlowFixMe flow doesn't include all non-primitive types as allowed for weakmaps
      var cache = new WeakMap();
      return function (arg) {
        if (cache.has(arg)) {
          // $FlowFixMe
          return cache.get(arg);
        }

        var ret = func(arg);
        cache.set(arg, ret);
        return ret;
      };
    };

    // https://github.com/thysultan/stylis.js/tree/master/plugins/rule-sheet
    // inlined to avoid umd wrapper and peerDep warnings/installing stylis
    // since we use stylis after closure compiler
    var delimiter = '/*|*/';
    var needle = delimiter + '}';

    function toSheet(block) {
      if (block) {
        Sheet.current.insert(block + '}');
      }
    }

    var Sheet = {
      current: null
    };
    var ruleSheet = function ruleSheet(context, content, selectors, parents, line, column, length, ns, depth, at) {
      switch (context) {
        // property
        case 1:
          {
            switch (content.charCodeAt(0)) {
              case 64:
                {
                  // @import
                  Sheet.current.insert(content + ';');
                  return '';
                }
              // charcode for l

              case 108:
                {
                  // charcode for b
                  // this ignores label
                  if (content.charCodeAt(2) === 98) {
                    return '';
                  }
                }
            }

            break;
          }
        // selector

        case 2:
          {
            if (ns === 0) return content + delimiter;
            break;
          }
        // at-rule

        case 3:
          {
            switch (ns) {
              // @font-face, @page
              case 102:
              case 112:
                {
                  Sheet.current.insert(selectors[0] + content);
                  return '';
                }

              default:
                {
                  return content + (at === 0 ? delimiter : '');
                }
            }
          }

        case -2:
          {
            content.split(needle).forEach(toSheet);
          }
      }
    };
    var removeLabel = function removeLabel(context, content) {
      if (context === 1 && // charcode for l
      content.charCodeAt(0) === 108 && // charcode for b
      content.charCodeAt(2) === 98 // this ignores label
      ) {
          return '';
        }
    };

    var isBrowser$1 = typeof document !== 'undefined';
    var rootServerStylisCache = {};
    var getServerStylisCache = isBrowser$1 ? undefined : weakMemoize(function () {
      var getCache = weakMemoize(function () {
        return {};
      });
      var prefixTrueCache = {};
      var prefixFalseCache = {};
      return function (prefix) {
        if (prefix === undefined || prefix === true) {
          return prefixTrueCache;
        }

        if (prefix === false) {
          return prefixFalseCache;
        }

        return getCache(prefix);
      };
    });

    var createCache = function createCache(options) {
      if (options === undefined) options = {};
      var key = options.key || 'css';
      var stylisOptions;

      if (options.prefix !== undefined) {
        stylisOptions = {
          prefix: options.prefix
        };
      }

      var stylis = new stylis_min(stylisOptions);

      var inserted = {}; // $FlowFixMe

      var container;

      if (isBrowser$1) {
        container = options.container || document.head;
        var nodes = document.querySelectorAll("style[data-emotion-" + key + "]");
        Array.prototype.forEach.call(nodes, function (node) {
          var attrib = node.getAttribute("data-emotion-" + key); // $FlowFixMe

          attrib.split(' ').forEach(function (id) {
            inserted[id] = true;
          });

          if (node.parentNode !== container) {
            container.appendChild(node);
          }
        });
      }

      var _insert;

      if (isBrowser$1) {
        stylis.use(options.stylisPlugins)(ruleSheet);

        _insert = function insert(selector, serialized, sheet, shouldCache) {
          var name = serialized.name;
          Sheet.current = sheet;

          stylis(selector, serialized.styles);

          if (shouldCache) {
            cache.inserted[name] = true;
          }
        };
      } else {
        stylis.use(removeLabel);
        var serverStylisCache = rootServerStylisCache;

        if (options.stylisPlugins || options.prefix !== undefined) {
          stylis.use(options.stylisPlugins); // $FlowFixMe

          serverStylisCache = getServerStylisCache(options.stylisPlugins || rootServerStylisCache)(options.prefix);
        }

        var getRules = function getRules(selector, serialized) {
          var name = serialized.name;

          if (serverStylisCache[name] === undefined) {
            serverStylisCache[name] = stylis(selector, serialized.styles);
          }

          return serverStylisCache[name];
        };

        _insert = function _insert(selector, serialized, sheet, shouldCache) {
          var name = serialized.name;
          var rules = getRules(selector, serialized);

          if (cache.compat === undefined) {
            // in regular mode, we don't set the styles on the inserted cache
            // since we don't need to and that would be wasting memory
            // we return them so that they are rendered in a style tag
            if (shouldCache) {
              cache.inserted[name] = true;
            }

            return rules;
          } else {
            // in compat mode, we put the styles on the inserted cache so
            // that emotion-server can pull out the styles
            // except when we don't want to cache it which was in Global but now
            // is nowhere but we don't want to do a major right now
            // and just in case we're going to leave the case here
            // it's also not affecting client side bundle size
            // so it's really not a big deal
            if (shouldCache) {
              cache.inserted[name] = rules;
            } else {
              return rules;
            }
          }
        };
      }

      var cache = {
        key: key,
        sheet: new StyleSheet({
          key: key,
          container: container,
          nonce: options.nonce,
          speedy: options.speedy
        }),
        nonce: options.nonce,
        inserted: inserted,
        registered: {},
        insert: _insert
      };
      return cache;
    };

    var isBrowser$2 = typeof document !== 'undefined';
    function getRegisteredStyles(registered, registeredStyles, classNames) {
      var rawClassName = '';
      classNames.split(' ').forEach(function (className) {
        if (registered[className] !== undefined) {
          registeredStyles.push(registered[className]);
        } else {
          rawClassName += className + " ";
        }
      });
      return rawClassName;
    }
    var insertStyles = function insertStyles(cache, serialized, isStringTag) {
      var className = cache.key + "-" + serialized.name;

      if ( // we only need to add the styles to the registered cache if the
      // class name could be used further down
      // the tree but if it's a string tag, we know it won't
      // so we don't have to add it to registered cache.
      // this improves memory usage since we can avoid storing the whole style string
      (isStringTag === false || // we need to always store it if we're in compat mode and
      // in node since emotion-server relies on whether a style is in
      // the registered cache to know whether a style is global or not
      // also, note that this check will be dead code eliminated in the browser
      isBrowser$2 === false && cache.compat !== undefined) && cache.registered[className] === undefined) {
        cache.registered[className] = serialized.styles;
      }

      if (cache.inserted[serialized.name] === undefined) {
        var stylesForSSR = '';
        var current = serialized;

        do {
          var maybeStyles = cache.insert("." + className, current, cache.sheet, true);

          if (!isBrowser$2 && maybeStyles !== undefined) {
            stylesForSSR += maybeStyles;
          }

          current = current.next;
        } while (current !== undefined);

        if (!isBrowser$2 && stylesForSSR.length !== 0) {
          return stylesForSSR;
        }
      }
    };

    /* eslint-disable */
    // murmurhash2 via https://github.com/garycourt/murmurhash-js/blob/master/murmurhash2_gc.js
    function murmurhash2_32_gc(str) {
      var l = str.length,
          h = l ^ l,
          i = 0,
          k;

      while (l >= 4) {
        k = str.charCodeAt(i) & 0xff | (str.charCodeAt(++i) & 0xff) << 8 | (str.charCodeAt(++i) & 0xff) << 16 | (str.charCodeAt(++i) & 0xff) << 24;
        k = (k & 0xffff) * 0x5bd1e995 + (((k >>> 16) * 0x5bd1e995 & 0xffff) << 16);
        k ^= k >>> 24;
        k = (k & 0xffff) * 0x5bd1e995 + (((k >>> 16) * 0x5bd1e995 & 0xffff) << 16);
        h = (h & 0xffff) * 0x5bd1e995 + (((h >>> 16) * 0x5bd1e995 & 0xffff) << 16) ^ k;
        l -= 4;
        ++i;
      }

      switch (l) {
        case 3:
          h ^= (str.charCodeAt(i + 2) & 0xff) << 16;

        case 2:
          h ^= (str.charCodeAt(i + 1) & 0xff) << 8;

        case 1:
          h ^= str.charCodeAt(i) & 0xff;
          h = (h & 0xffff) * 0x5bd1e995 + (((h >>> 16) * 0x5bd1e995 & 0xffff) << 16);
      }

      h ^= h >>> 13;
      h = (h & 0xffff) * 0x5bd1e995 + (((h >>> 16) * 0x5bd1e995 & 0xffff) << 16);
      h ^= h >>> 15;
      return (h >>> 0).toString(36);
    }

    var unitless_cjs_prod = createCommonjsModule(function (module, exports) {

    Object.defineProperty(exports, "__esModule", {
      value: !0
    });

    var unitlessKeys = {
      animationIterationCount: 1,
      borderImageOutset: 1,
      borderImageSlice: 1,
      borderImageWidth: 1,
      boxFlex: 1,
      boxFlexGroup: 1,
      boxOrdinalGroup: 1,
      columnCount: 1,
      columns: 1,
      flex: 1,
      flexGrow: 1,
      flexPositive: 1,
      flexShrink: 1,
      flexNegative: 1,
      flexOrder: 1,
      gridRow: 1,
      gridRowEnd: 1,
      gridRowSpan: 1,
      gridRowStart: 1,
      gridColumn: 1,
      gridColumnEnd: 1,
      gridColumnSpan: 1,
      gridColumnStart: 1,
      msGridRow: 1,
      msGridRowSpan: 1,
      msGridColumn: 1,
      msGridColumnSpan: 1,
      fontWeight: 1,
      lineHeight: 1,
      opacity: 1,
      order: 1,
      orphans: 1,
      tabSize: 1,
      widows: 1,
      zIndex: 1,
      zoom: 1,
      WebkitLineClamp: 1,
      fillOpacity: 1,
      floodOpacity: 1,
      stopOpacity: 1,
      strokeDasharray: 1,
      strokeDashoffset: 1,
      strokeMiterlimit: 1,
      strokeOpacity: 1,
      strokeWidth: 1
    };

    exports.default = unitlessKeys;
    });

    unwrapExports(unitless_cjs_prod);

    var unitless_cjs = createCommonjsModule(function (module) {

    {
      module.exports = unitless_cjs_prod;
    }
    });

    function memoize(fn) {
      var cache = {};
      return function (arg) {
        if (cache[arg] === undefined) cache[arg] = fn(arg);
        return cache[arg];
      };
    }

    var hyphenateRegex = /[A-Z]|^ms/g;
    var animationRegex = /_EMO_([^_]+?)_([^]*?)_EMO_/g;

    var isCustomProperty = function isCustomProperty(property) {
      return property.charCodeAt(1) === 45;
    };

    var isProcessableValue = function isProcessableValue(value) {
      return value != null && typeof value !== 'boolean';
    };

    var processStyleName = memoize(function (styleName) {
      return isCustomProperty(styleName) ? styleName : styleName.replace(hyphenateRegex, '-$&').toLowerCase();
    });

    var processStyleValue = function processStyleValue(key, value) {
      switch (key) {
        case 'animation':
        case 'animationName':
          {
            if (typeof value === 'string') {
              return value.replace(animationRegex, function (match, p1, p2) {
                cursor = {
                  name: p1,
                  styles: p2,
                  next: cursor
                };
                return p1;
              });
            }
          }
      }

      if (unitless_cjs[key] !== 1 && !isCustomProperty(key) && typeof value === 'number' && value !== 0) {
        return value + 'px';
      }

      return value;
    };

    function handleInterpolation(mergedProps, registered, interpolation, couldBeSelectorInterpolation) {
      if (interpolation == null) {
        return '';
      }

      if (interpolation.__emotion_styles !== undefined) {

        return interpolation;
      }

      switch (typeof interpolation) {
        case 'boolean':
          {
            return '';
          }

        case 'object':
          {
            if (interpolation.anim === 1) {
              cursor = {
                name: interpolation.name,
                styles: interpolation.styles,
                next: cursor
              };
              return interpolation.name;
            }

            if (interpolation.styles !== undefined) {
              var next = interpolation.next;

              if (next !== undefined) {
                // not the most efficient thing ever but this is a pretty rare case
                // and there will be very few iterations of this generally
                while (next !== undefined) {
                  cursor = {
                    name: next.name,
                    styles: next.styles,
                    next: cursor
                  };
                  next = next.next;
                }
              }

              var styles = interpolation.styles + ";";

              return styles;
            }

            return createStringFromObject(mergedProps, registered, interpolation);
          }

        case 'function':
          {
            if (mergedProps !== undefined) {
              var previousCursor = cursor;
              var result = interpolation(mergedProps);
              cursor = previousCursor;
              return handleInterpolation(mergedProps, registered, result, couldBeSelectorInterpolation);
            }

            break;
          }

        case 'string':

          break;
      } // finalize string values (regular strings and functions interpolated into css calls)


      if (registered == null) {
        return interpolation;
      }

      var cached = registered[interpolation];

      return cached !== undefined && !couldBeSelectorInterpolation ? cached : interpolation;
    }

    function createStringFromObject(mergedProps, registered, obj) {
      var string = '';

      if (Array.isArray(obj)) {
        for (var i = 0; i < obj.length; i++) {
          string += handleInterpolation(mergedProps, registered, obj[i], false);
        }
      } else {
        for (var _key in obj) {
          var value = obj[_key];

          if (typeof value !== 'object') {
            if (registered != null && registered[value] !== undefined) {
              string += _key + "{" + registered[value] + "}";
            } else if (isProcessableValue(value)) {
              string += processStyleName(_key) + ":" + processStyleValue(_key, value) + ";";
            }
          } else {
            if (_key === 'NO_COMPONENT_SELECTOR' && "production" !== 'production') {
              throw new Error('Component selectors can only be used in conjunction with babel-plugin-emotion.');
            }

            if (Array.isArray(value) && typeof value[0] === 'string' && (registered == null || registered[value[0]] === undefined)) {
              for (var _i = 0; _i < value.length; _i++) {
                if (isProcessableValue(value[_i])) {
                  string += processStyleName(_key) + ":" + processStyleValue(_key, value[_i]) + ";";
                }
              }
            } else {
              var interpolated = handleInterpolation(mergedProps, registered, value, false);

              switch (_key) {
                case 'animation':
                case 'animationName':
                  {
                    string += processStyleName(_key) + ":" + interpolated + ";";
                    break;
                  }

                default:
                  {

                    string += _key + "{" + interpolated + "}";
                  }
              }
            }
          }
        }
      }

      return string;
    }

    var labelPattern = /label:\s*([^\s;\n{]+)\s*;/g;
    // keyframes are stored on the SerializedStyles object as a linked list


    var cursor;
    var serializeStyles = function serializeStyles(args, registered, mergedProps) {
      if (args.length === 1 && typeof args[0] === 'object' && args[0] !== null && args[0].styles !== undefined) {
        return args[0];
      }

      var stringMode = true;
      var styles = '';
      cursor = undefined;
      var strings = args[0];

      if (strings == null || strings.raw === undefined) {
        stringMode = false;
        styles += handleInterpolation(mergedProps, registered, strings, false);
      } else {

        styles += strings[0];
      } // we start at 1 since we've already handled the first arg


      for (var i = 1; i < args.length; i++) {
        styles += handleInterpolation(mergedProps, registered, args[i], styles.charCodeAt(styles.length - 1) === 46);

        if (stringMode) {

          styles += strings[i];
        }
      }


      labelPattern.lastIndex = 0;
      var identifierName = '';
      var match; // https://esbench.com/bench/5b809c2cf2949800a0f61fb5

      while ((match = labelPattern.exec(styles)) !== null) {
        identifierName += '-' + // $FlowFixMe we know it's not null
        match[1];
      }

      var name = murmurhash2_32_gc(styles) + identifierName;

      return {
        name: name,
        styles: styles,
        next: cursor
      };
    };

    var isBrowser$3 = typeof document !== 'undefined';

    var EmotionCacheContext = react_2( // we're doing this to avoid preconstruct's dead code elimination in this one case
    // because this module is primarily intended for the browser and node
    // but it's also required in react native and similar environments sometimes
    // and we could have a special build just for that
    // but this is much easier and the native packages
    // might use a different theme context in the future anyway
    typeof HTMLElement !== 'undefined' ? createCache() : null);
    var ThemeContext = react_2({});
    var CacheProvider = EmotionCacheContext.Provider;

    var withEmotionCache = function withEmotionCache(func) {
      var render = function render(props, ref) {
        return react_4(EmotionCacheContext.Consumer, null, function (cache) {
          return func(props, cache, ref);
        });
      }; // $FlowFixMe


      return react_5(render);
    };

    if (!isBrowser$3) {
      var BasicProvider =
      /*#__PURE__*/
      function (_React$Component) {
        inheritsLoose(BasicProvider, _React$Component);

        function BasicProvider(props, context, updater) {
          var _this;

          _this = _React$Component.call(this, props, context, updater) || this;
          _this.state = {
            value: createCache()
          };
          return _this;
        }

        var _proto = BasicProvider.prototype;

        _proto.render = function render() {
          return react_4(EmotionCacheContext.Provider, this.state, this.props.children(this.state.value));
        };

        return BasicProvider;
      }(react_3);

      withEmotionCache = function withEmotionCache(func) {
        return function (props) {
          return react_4(EmotionCacheContext.Consumer, null, function (context) {
            if (context === null) {
              return react_4(BasicProvider, null, function (newContext) {
                return func(props, newContext);
              });
            } else {
              return func(props, context);
            }
          });
        };
      };
    }

    var typePropName = '__EMOTION_TYPE_PLEASE_DO_NOT_USE__';
    var hasOwnProperty$1 = Object.prototype.hasOwnProperty;

    var render = function render(cache, props, theme, ref) {
      var cssProp = theme === null ? props.css : props.css(theme); // so that using `css` from `emotion` and passing the result to the css prop works
      // not passing the registered cache to serializeStyles because it would
      // make certain babel optimisations not possible

      if (typeof cssProp === 'string' && cache.registered[cssProp] !== undefined) {
        cssProp = cache.registered[cssProp];
      }

      var type = props[typePropName];
      var registeredStyles = [cssProp];
      var className = '';

      if (typeof props.className === 'string') {
        className = getRegisteredStyles(cache.registered, registeredStyles, props.className);
      } else if (props.className != null) {
        className = props.className + " ";
      }

      var serialized = serializeStyles(registeredStyles);

      var rules = insertStyles(cache, serialized, typeof type === 'string');
      className += cache.key + "-" + serialized.name;
      var newProps = {};

      for (var key in props) {
        if (hasOwnProperty$1.call(props, key) && key !== 'css' && key !== typePropName && ("production" === 'production')) {
          newProps[key] = props[key];
        }
      }

      newProps.ref = ref;
      newProps.className = className;
      var ele = react_4(type, newProps);

      if (!isBrowser$3 && rules !== undefined) {
        var _ref;

        var serializedNames = serialized.name;
        var next = serialized.next;

        while (next !== undefined) {
          serializedNames += ' ' + next.name;
          next = next.next;
        }

        return react_4(react_6, null, react_4("style", (_ref = {}, _ref["data-emotion-" + cache.key] = serializedNames, _ref.dangerouslySetInnerHTML = {
          __html: rules
        }, _ref.nonce = cache.sheet.nonce, _ref)), ele);
      }

      return ele;
    };

    var Emotion =
    /* #__PURE__ */
    withEmotionCache(function (props, cache, ref) {
      // use Context.read for the theme when it's stable
      if (typeof props.css === 'function') {
        return react_4(ThemeContext.Consumer, null, function (theme) {
          return render(cache, props, theme, ref);
        });
      }

      return render(cache, props, null, ref);
    });


    var jsx = function jsx(type, props) {
      var args = arguments;

      if (props == null || !hasOwnProperty$1.call(props, 'css')) {
        // $FlowFixMe
        return react_4.apply(undefined, args);
      }

      var argsLength = args.length;
      var createElementArgArray = new Array(argsLength);
      createElementArgArray[0] = Emotion;
      var newProps = {};

      for (var key in props) {
        if (hasOwnProperty$1.call(props, key)) {
          newProps[key] = props[key];
        }
      }

      newProps[typePropName] = type;

      createElementArgArray[1] = newProps;

      for (var i = 2; i < argsLength; i++) {
        createElementArgArray[i] = args[i];
      } // $FlowFixMe


      return react_4.apply(null, createElementArgArray);
    };
    var Global =
    /* #__PURE__ */
    withEmotionCache(function (props, cache) {

      var styles = props.styles;

      if (typeof styles === 'function') {
        return react_4(ThemeContext.Consumer, null, function (theme) {
          var serialized = serializeStyles([styles(theme)]);
          return react_4(InnerGlobal, {
            serialized: serialized,
            cache: cache
          });
        });
      }

      var serialized = serializeStyles([styles]);
      return react_4(InnerGlobal, {
        serialized: serialized,
        cache: cache
      });
    });

    // maintain place over rerenders.
    // initial render from browser, insertBefore context.sheet.tags[0] or if a style hasn't been inserted there yet, appendChild
    // initial client-side render from SSR, use place of hydrating tag
    var InnerGlobal =
    /*#__PURE__*/
    function (_React$Component) {
      inheritsLoose(InnerGlobal, _React$Component);

      function InnerGlobal(props, context, updater) {
        return _React$Component.call(this, props, context, updater) || this;
      }

      var _proto = InnerGlobal.prototype;

      _proto.componentDidMount = function componentDidMount() {
        this.sheet = new StyleSheet({
          key: this.props.cache.key + "-global",
          nonce: this.props.cache.sheet.nonce,
          container: this.props.cache.sheet.container
        }); // $FlowFixMe

        var node = document.querySelector("style[data-emotion-" + this.props.cache.key + "=\"" + this.props.serialized.name + "\"]");

        if (node !== null) {
          this.sheet.tags.push(node);
        }

        if (this.props.cache.sheet.tags.length) {
          this.sheet.before = this.props.cache.sheet.tags[0];
        }

        this.insertStyles();
      };

      _proto.componentDidUpdate = function componentDidUpdate(prevProps) {
        if (prevProps.serialized.name !== this.props.serialized.name) {
          this.insertStyles();
        }
      };

      _proto.insertStyles = function insertStyles$1() {
        if (this.props.serialized.next !== undefined) {
          // insert keyframes
          insertStyles(this.props.cache, this.props.serialized.next, true);
        }

        if (this.sheet.tags.length) {
          // if this doesn't exist then it will be null so the style element will be appended
          var element = this.sheet.tags[this.sheet.tags.length - 1].nextElementSibling;
          this.sheet.before = element;
          this.sheet.flush();
        }

        this.props.cache.insert("", this.props.serialized, this.sheet, false);
      };

      _proto.componentWillUnmount = function componentWillUnmount() {
        this.sheet.flush();
      };

      _proto.render = function render() {
        if (!isBrowser$3) {
          var serialized = this.props.serialized;
          var serializedNames = serialized.name;
          var serializedStyles = serialized.styles;
          var next = serialized.next;

          while (next !== undefined) {
            serializedNames += ' ' + next.name;
            serializedStyles += next.styles;
            next = next.next;
          }

          var shouldCache = this.props.cache.compat === true;
          var rules = this.props.cache.insert("", {
            name: serializedNames,
            styles: serializedStyles
          }, this.sheet, shouldCache);

          if (!shouldCache) {
            var _ref;

            return react_4("style", (_ref = {}, _ref["data-emotion-" + this.props.cache.key] = serializedNames, _ref.dangerouslySetInnerHTML = {
              __html: rules
            }, _ref.nonce = this.props.cache.sheet.nonce, _ref));
          }
        }

        return null;
      };

      return InnerGlobal;
    }(react_3);

    var classnames = function classnames(args) {
      var len = args.length;
      var i = 0;
      var cls = '';

      for (; i < len; i++) {
        var arg = args[i];
        if (arg == null) continue;
        var toAdd = void 0;

        switch (typeof arg) {
          case 'boolean':
            break;

          case 'object':
            {
              if (Array.isArray(arg)) {
                toAdd = classnames(arg);
              } else {
                toAdd = '';

                for (var k in arg) {
                  if (arg[k] && k) {
                    toAdd && (toAdd += ' ');
                    toAdd += k;
                  }
                }
              }

              break;
            }

          default:
            {
              toAdd = arg;
            }
        }

        if (toAdd) {
          cls && (cls += ' ');
          cls += toAdd;
        }
      }

      return cls;
    };

    function merge(registered, css$$1, className) {
      var registeredStyles = [];
      var rawClassName = getRegisteredStyles(registered, registeredStyles, className);

      if (registeredStyles.length < 2) {
        return className;
      }

      return rawClassName + css$$1(registeredStyles);
    }

    var ClassNames = withEmotionCache(function (props, context) {
      return react_4(ThemeContext.Consumer, null, function (theme) {
        var rules = '';
        var serializedHashes = '';
        var hasRendered = false;

        var css$$1 = function css$$1() {
          if (hasRendered && "production" !== 'production') {
            throw new Error('css can only be used during render');
          }

          for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
            args[_key] = arguments[_key];
          }

          var serialized = serializeStyles(args, context.registered);

          if (isBrowser$3) {
            insertStyles(context, serialized, false);
          } else {
            var res = insertStyles(context, serialized, false);

            if (res !== undefined) {
              rules += res;
            }
          }

          if (!isBrowser$3) {
            serializedHashes += " " + serialized.name;
          }

          return context.key + "-" + serialized.name;
        };

        var cx = function cx() {
          if (hasRendered && "production" !== 'production') {
            throw new Error('cx can only be used during render');
          }

          for (var _len2 = arguments.length, args = new Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
            args[_key2] = arguments[_key2];
          }

          return merge(context.registered, css$$1, classnames(args));
        };

        var content = {
          css: css$$1,
          cx: cx,
          theme: theme
        };
        var ele = props.children(content);
        hasRendered = true;

        if (!isBrowser$3 && rules.length !== 0) {
          var _ref;

          return react_4(react_6, null, react_4("style", (_ref = {}, _ref["data-emotion-" + context.key] = serializedHashes.substring(1), _ref.dangerouslySetInnerHTML = {
            __html: rules
          }, _ref.nonce = context.sheet.nonce, _ref)), ele);
        }

        return ele;
      });
    });

    var scheduler_production_min = createCommonjsModule(function (module, exports) {
    Object.defineProperty(exports,"__esModule",{value:!0});var f,g,h,k,l;
    if("undefined"===typeof window||"function"!==typeof MessageChannel){var p=null,q=null,t=function(){if(null!==p)try{var a=exports.unstable_now();p(!0,a);p=null;}catch(b){throw setTimeout(t,0),b;}},u=Date.now();exports.unstable_now=function(){return Date.now()-u};f=function(a){null!==p?setTimeout(f,0,a):(p=a,setTimeout(t,0));};g=function(a,b){q=setTimeout(a,b);};h=function(){clearTimeout(q);};k=function(){return!1};l=exports.unstable_forceFrameRate=function(){};}else{var w=window.performance,x=window.Date,
    y=window.setTimeout,z=window.clearTimeout;if("undefined"!==typeof console){var A=window.cancelAnimationFrame;"function"!==typeof window.requestAnimationFrame&&console.error("This browser doesn't support requestAnimationFrame. Make sure that you load a polyfill in older browsers. https://fb.me/react-polyfills");"function"!==typeof A&&console.error("This browser doesn't support cancelAnimationFrame. Make sure that you load a polyfill in older browsers. https://fb.me/react-polyfills");}if("object"===
    typeof w&&"function"===typeof w.now)exports.unstable_now=function(){return w.now()};else{var B=x.now();exports.unstable_now=function(){return x.now()-B};}var C=!1,D=null,E=-1,F=5,G=0;k=function(){return exports.unstable_now()>=G};l=function(){};exports.unstable_forceFrameRate=function(a){0>a||125<a?console.error("forceFrameRate takes a positive int between 0 and 125, forcing framerates higher than 125 fps is not unsupported"):F=0<a?Math.floor(1E3/a):5;};var H=new MessageChannel,I=H.port2;H.port1.onmessage=
    function(){if(null!==D){var a=exports.unstable_now();G=a+F;try{D(!0,a)?I.postMessage(null):(C=!1,D=null);}catch(b){throw I.postMessage(null),b;}}else C=!1;};f=function(a){D=a;C||(C=!0,I.postMessage(null));};g=function(a,b){E=y(function(){a(exports.unstable_now());},b);};h=function(){z(E);E=-1;};}function J(a,b){var c=a.length;a.push(b);a:for(;;){var d=Math.floor((c-1)/2),e=a[d];if(void 0!==e&&0<K(e,b))a[d]=b,a[c]=e,c=d;else break a}}function L(a){a=a[0];return void 0===a?null:a}
    function M(a){var b=a[0];if(void 0!==b){var c=a.pop();if(c!==b){a[0]=c;a:for(var d=0,e=a.length;d<e;){var m=2*(d+1)-1,n=a[m],v=m+1,r=a[v];if(void 0!==n&&0>K(n,c))void 0!==r&&0>K(r,n)?(a[d]=r,a[v]=c,d=v):(a[d]=n,a[m]=c,d=m);else if(void 0!==r&&0>K(r,c))a[d]=r,a[v]=c,d=v;else break a}}return b}return null}function K(a,b){var c=a.sortIndex-b.sortIndex;return 0!==c?c:a.id-b.id}var N=[],O=[],P=1,Q=null,R=3,S=!1,T=!1,U=!1;
    function V(a){for(var b=L(O);null!==b;){if(null===b.callback)M(O);else if(b.startTime<=a)M(O),b.sortIndex=b.expirationTime,J(N,b);else break;b=L(O);}}function W(a){U=!1;V(a);if(!T)if(null!==L(N))T=!0,f(X);else{var b=L(O);null!==b&&g(W,b.startTime-a);}}
    function X(a,b){T=!1;U&&(U=!1,h());S=!0;var c=R;try{V(b);for(Q=L(N);null!==Q&&(!(Q.expirationTime>b)||a&&!k());){var d=Q.callback;if(null!==d){Q.callback=null;R=Q.priorityLevel;var e=d(Q.expirationTime<=b);b=exports.unstable_now();"function"===typeof e?Q.callback=e:Q===L(N)&&M(N);V(b);}else M(N);Q=L(N);}if(null!==Q)var m=!0;else{var n=L(O);null!==n&&g(W,n.startTime-b);m=!1;}return m}finally{Q=null,R=c,S=!1;}}
    function Y(a){switch(a){case 1:return-1;case 2:return 250;case 5:return 1073741823;case 4:return 1E4;default:return 5E3}}var Z=l;exports.unstable_ImmediatePriority=1;exports.unstable_UserBlockingPriority=2;exports.unstable_NormalPriority=3;exports.unstable_IdlePriority=5;exports.unstable_LowPriority=4;exports.unstable_runWithPriority=function(a,b){switch(a){case 1:case 2:case 3:case 4:case 5:break;default:a=3;}var c=R;R=a;try{return b()}finally{R=c;}};
    exports.unstable_next=function(a){switch(R){case 1:case 2:case 3:var b=3;break;default:b=R;}var c=R;R=b;try{return a()}finally{R=c;}};
    exports.unstable_scheduleCallback=function(a,b,c){var d=exports.unstable_now();if("object"===typeof c&&null!==c){var e=c.delay;e="number"===typeof e&&0<e?d+e:d;c="number"===typeof c.timeout?c.timeout:Y(a);}else c=Y(a),e=d;c=e+c;a={id:P++,callback:b,priorityLevel:a,startTime:e,expirationTime:c,sortIndex:-1};e>d?(a.sortIndex=e,J(O,a),null===L(N)&&a===L(O)&&(U?h():U=!0,g(W,e-d))):(a.sortIndex=c,J(N,a),T||S||(T=!0,f(X)));return a};exports.unstable_cancelCallback=function(a){a.callback=null;};
    exports.unstable_wrapCallback=function(a){var b=R;return function(){var c=R;R=b;try{return a.apply(this,arguments)}finally{R=c;}}};exports.unstable_getCurrentPriorityLevel=function(){return R};exports.unstable_shouldYield=function(){var a=exports.unstable_now();V(a);var b=L(N);return b!==Q&&null!==Q&&null!==b&&null!==b.callback&&b.startTime<=a&&b.expirationTime<Q.expirationTime||k()};exports.unstable_requestPaint=Z;exports.unstable_continueExecution=function(){T||S||(T=!0,f(X));};
    exports.unstable_pauseExecution=function(){};exports.unstable_getFirstCallbackNode=function(){return L(N)};exports.unstable_Profiling=null;
    });

    unwrapExports(scheduler_production_min);
    var scheduler_production_min_1 = scheduler_production_min.unstable_now;
    var scheduler_production_min_2 = scheduler_production_min.unstable_forceFrameRate;
    var scheduler_production_min_3 = scheduler_production_min.unstable_ImmediatePriority;
    var scheduler_production_min_4 = scheduler_production_min.unstable_UserBlockingPriority;
    var scheduler_production_min_5 = scheduler_production_min.unstable_NormalPriority;
    var scheduler_production_min_6 = scheduler_production_min.unstable_IdlePriority;
    var scheduler_production_min_7 = scheduler_production_min.unstable_LowPriority;
    var scheduler_production_min_8 = scheduler_production_min.unstable_runWithPriority;
    var scheduler_production_min_9 = scheduler_production_min.unstable_next;
    var scheduler_production_min_10 = scheduler_production_min.unstable_scheduleCallback;
    var scheduler_production_min_11 = scheduler_production_min.unstable_cancelCallback;
    var scheduler_production_min_12 = scheduler_production_min.unstable_wrapCallback;
    var scheduler_production_min_13 = scheduler_production_min.unstable_getCurrentPriorityLevel;
    var scheduler_production_min_14 = scheduler_production_min.unstable_shouldYield;
    var scheduler_production_min_15 = scheduler_production_min.unstable_requestPaint;
    var scheduler_production_min_16 = scheduler_production_min.unstable_continueExecution;
    var scheduler_production_min_17 = scheduler_production_min.unstable_pauseExecution;
    var scheduler_production_min_18 = scheduler_production_min.unstable_getFirstCallbackNode;
    var scheduler_production_min_19 = scheduler_production_min.unstable_Profiling;

    var scheduler = createCommonjsModule(function (module) {

    {
      module.exports = scheduler_production_min;
    }
    });

    function u$1(a){for(var b="https://reactjs.org/docs/error-decoder.html?invariant="+a,c=1;c<arguments.length;c++)b+="&args[]="+encodeURIComponent(arguments[c]);return"Minified React error #"+a+"; visit "+b+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}if(!react)throw Error(u$1(227));var ba$1=null,ca$1={};
    function da$1(){if(ba$1)for(var a in ca$1){var b=ca$1[a],c=ba$1.indexOf(a);if(!(-1<c))throw Error(u$1(96,a));if(!ea[c]){if(!b.extractEvents)throw Error(u$1(97,a));ea[c]=b;c=b.eventTypes;for(var d in c){var e=void 0;var f=c[d],g=b,h=d;if(fa.hasOwnProperty(h))throw Error(u$1(99,h));fa[h]=f;var k=f.phasedRegistrationNames;if(k){for(e in k)k.hasOwnProperty(e)&&ha(k[e],g,h);e=!0;}else f.registrationName?(ha(f.registrationName,g,h),e=!0):e=!1;if(!e)throw Error(u$1(98,d,a));}}}}
    function ha(a,b,c){if(ia[a])throw Error(u$1(100,a));ia[a]=b;ja[a]=b.eventTypes[c].dependencies;}var ea=[],fa={},ia={},ja={};function ka(a,b,c,d,e,f,g,h,k){var l=Array.prototype.slice.call(arguments,3);try{b.apply(c,l);}catch(m){this.onError(m);}}var la=!1,ma=null,na=!1,oa=null,pa={onError:function(a){la=!0;ma=a;}};function qa(a,b,c,d,e,f,g,h,k){la=!1;ma=null;ka.apply(pa,arguments);}
    function ra(a,b,c,d,e,f,g,h,k){qa.apply(this,arguments);if(la){if(la){var l=ma;la=!1;ma=null;}else throw Error(u$1(198));na||(na=!0,oa=l);}}var sa=null,ua=null,va=null;function wa(a,b,c){var d=a.type||"unknown-event";a.currentTarget=va(c);ra(d,b,void 0,a);a.currentTarget=null;}function xa(a,b){if(null==b)throw Error(u$1(30));if(null==a)return b;if(Array.isArray(a)){if(Array.isArray(b))return a.push.apply(a,b),a;a.push(b);return a}return Array.isArray(b)?[a].concat(b):[a,b]}
    function ya(a,b,c){Array.isArray(a)?a.forEach(b,c):a&&b.call(c,a);}var za=null;function Aa(a){if(a){var b=a._dispatchListeners,c=a._dispatchInstances;if(Array.isArray(b))for(var d=0;d<b.length&&!a.isPropagationStopped();d++)wa(a,b[d],c[d]);else b&&wa(a,b,c);a._dispatchListeners=null;a._dispatchInstances=null;a.isPersistent()||a.constructor.release(a);}}function Ba(a){null!==a&&(za=xa(za,a));a=za;za=null;if(a){ya(a,Aa);if(za)throw Error(u$1(95));if(na)throw a=oa,na=!1,oa=null,a;}}
    var Ca={injectEventPluginOrder:function(a){if(ba$1)throw Error(u$1(101));ba$1=Array.prototype.slice.call(a);da$1();},injectEventPluginsByName:function(a){var b=!1,c;for(c in a)if(a.hasOwnProperty(c)){var d=a[c];if(!ca$1.hasOwnProperty(c)||ca$1[c]!==d){if(ca$1[c])throw Error(u$1(102,c));ca$1[c]=d;b=!0;}}b&&da$1();}};
    function Da(a,b){var c=a.stateNode;if(!c)return null;var d=sa(c);if(!d)return null;c=d[b];a:switch(b){case "onClick":case "onClickCapture":case "onDoubleClick":case "onDoubleClickCapture":case "onMouseDown":case "onMouseDownCapture":case "onMouseMove":case "onMouseMoveCapture":case "onMouseUp":case "onMouseUpCapture":(d=!d.disabled)||(a=a.type,d=!("button"===a||"input"===a||"select"===a||"textarea"===a));a=!d;break a;default:a=!1;}if(a)return null;if(c&&"function"!==typeof c)throw Error(u$1(231,b,typeof c));
    return c}var Ea=react.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED;Ea.hasOwnProperty("ReactCurrentDispatcher")||(Ea.ReactCurrentDispatcher={current:null});Ea.hasOwnProperty("ReactCurrentBatchConfig")||(Ea.ReactCurrentBatchConfig={suspense:null});
    var Fa=/^(.*)[\\\/]/,w$1="function"===typeof Symbol&&Symbol.for,Ga=w$1?Symbol.for("react.element"):60103,Ha=w$1?Symbol.for("react.portal"):60106,Ia=w$1?Symbol.for("react.fragment"):60107,Ja=w$1?Symbol.for("react.strict_mode"):60108,Ka=w$1?Symbol.for("react.profiler"):60114,La=w$1?Symbol.for("react.provider"):60109,Ma=w$1?Symbol.for("react.context"):60110,Na=w$1?Symbol.for("react.concurrent_mode"):60111,Oa=w$1?Symbol.for("react.forward_ref"):60112,Pa=w$1?Symbol.for("react.suspense"):60113,Qa=w$1?Symbol.for("react.suspense_list"):
    60120,Ra=w$1?Symbol.for("react.memo"):60115,Sa=w$1?Symbol.for("react.lazy"):60116;var Ta="function"===typeof Symbol&&Symbol.iterator;function Ua(a){if(null===a||"object"!==typeof a)return null;a=Ta&&a[Ta]||a["@@iterator"];return"function"===typeof a?a:null}
    function Va(a){if(-1===a._status){a._status=0;var b=a._ctor;b=b();a._result=b;b.then(function(b){0===a._status&&(b=b.default,a._status=1,a._result=b);},function(b){0===a._status&&(a._status=2,a._result=b);});}}
    function Wa(a){if(null==a)return null;if("function"===typeof a)return a.displayName||a.name||null;if("string"===typeof a)return a;switch(a){case Ia:return"Fragment";case Ha:return"Portal";case Ka:return"Profiler";case Ja:return"StrictMode";case Pa:return"Suspense";case Qa:return"SuspenseList"}if("object"===typeof a)switch(a.$$typeof){case Ma:return"Context.Consumer";case La:return"Context.Provider";case Oa:var b=a.render;b=b.displayName||b.name||"";return a.displayName||(""!==b?"ForwardRef("+b+")":
    "ForwardRef");case Ra:return Wa(a.type);case Sa:if(a=1===a._status?a._result:null)return Wa(a)}return null}function Xa(a){var b="";do{a:switch(a.tag){case 3:case 4:case 6:case 7:case 10:case 9:var c="";break a;default:var d=a._debugOwner,e=a._debugSource,f=Wa(a.type);c=null;d&&(c=Wa(d.type));d=f;f="";e?f=" (at "+e.fileName.replace(Fa,"")+":"+e.lineNumber+")":c&&(f=" (created by "+c+")");c="\n    in "+(d||"Unknown")+f;}b+=c;a=a.return;}while(a);return b}
    var Ya=!("undefined"===typeof window||"undefined"===typeof window.document||"undefined"===typeof window.document.createElement),Za=null,$a=null,ab=null;function bb(a){if(a=ua(a)){if("function"!==typeof Za)throw Error(u$1(280));var b=sa(a.stateNode);Za(a.stateNode,a.type,b);}}function cb(a){$a?ab?ab.push(a):ab=[a]:$a=a;}function db(){if($a){var a=$a,b=ab;ab=$a=null;bb(a);if(b)for(a=0;a<b.length;a++)bb(b[a]);}}function eb(a,b){return a(b)}function fb(a,b,c,d){return a(b,c,d)}function gb(){}
    var hb=eb,ib=!1,jb=!1;function kb(){if(null!==$a||null!==ab)gb(),db();}var lb=/^[:A-Z_a-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD][:A-Z_a-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD\-.0-9\u00B7\u0300-\u036F\u203F-\u2040]*$/,mb=Object.prototype.hasOwnProperty,nb={},ob={};
    function pb(a){if(mb.call(ob,a))return!0;if(mb.call(nb,a))return!1;if(lb.test(a))return ob[a]=!0;nb[a]=!0;return!1}function qb(a,b,c,d){if(null!==c&&0===c.type)return!1;switch(typeof b){case "function":case "symbol":return!0;case "boolean":if(d)return!1;if(null!==c)return!c.acceptsBooleans;a=a.toLowerCase().slice(0,5);return"data-"!==a&&"aria-"!==a;default:return!1}}
    function rb(a,b,c,d){if(null===b||"undefined"===typeof b||qb(a,b,c,d))return!0;if(d)return!1;if(null!==c)switch(c.type){case 3:return!b;case 4:return!1===b;case 5:return isNaN(b);case 6:return isNaN(b)||1>b}return!1}function B$1(a,b,c,d,e,f){this.acceptsBooleans=2===b||3===b||4===b;this.attributeName=d;this.attributeNamespace=e;this.mustUseProperty=c;this.propertyName=a;this.type=b;this.sanitizeURL=f;}var D$1={};
    "children dangerouslySetInnerHTML defaultValue defaultChecked innerHTML suppressContentEditableWarning suppressHydrationWarning style".split(" ").forEach(function(a){D$1[a]=new B$1(a,0,!1,a,null,!1);});[["acceptCharset","accept-charset"],["className","class"],["htmlFor","for"],["httpEquiv","http-equiv"]].forEach(function(a){var b=a[0];D$1[b]=new B$1(b,1,!1,a[1],null,!1);});["contentEditable","draggable","spellCheck","value"].forEach(function(a){D$1[a]=new B$1(a,2,!1,a.toLowerCase(),null,!1);});
    ["autoReverse","externalResourcesRequired","focusable","preserveAlpha"].forEach(function(a){D$1[a]=new B$1(a,2,!1,a,null,!1);});"allowFullScreen async autoFocus autoPlay controls default defer disabled disablePictureInPicture formNoValidate hidden loop noModule noValidate open playsInline readOnly required reversed scoped seamless itemScope".split(" ").forEach(function(a){D$1[a]=new B$1(a,3,!1,a.toLowerCase(),null,!1);});
    ["checked","multiple","muted","selected"].forEach(function(a){D$1[a]=new B$1(a,3,!0,a,null,!1);});["capture","download"].forEach(function(a){D$1[a]=new B$1(a,4,!1,a,null,!1);});["cols","rows","size","span"].forEach(function(a){D$1[a]=new B$1(a,6,!1,a,null,!1);});["rowSpan","start"].forEach(function(a){D$1[a]=new B$1(a,5,!1,a.toLowerCase(),null,!1);});var sb=/[\-:]([a-z])/g;function tb(a){return a[1].toUpperCase()}
    "accent-height alignment-baseline arabic-form baseline-shift cap-height clip-path clip-rule color-interpolation color-interpolation-filters color-profile color-rendering dominant-baseline enable-background fill-opacity fill-rule flood-color flood-opacity font-family font-size font-size-adjust font-stretch font-style font-variant font-weight glyph-name glyph-orientation-horizontal glyph-orientation-vertical horiz-adv-x horiz-origin-x image-rendering letter-spacing lighting-color marker-end marker-mid marker-start overline-position overline-thickness paint-order panose-1 pointer-events rendering-intent shape-rendering stop-color stop-opacity strikethrough-position strikethrough-thickness stroke-dasharray stroke-dashoffset stroke-linecap stroke-linejoin stroke-miterlimit stroke-opacity stroke-width text-anchor text-decoration text-rendering underline-position underline-thickness unicode-bidi unicode-range units-per-em v-alphabetic v-hanging v-ideographic v-mathematical vector-effect vert-adv-y vert-origin-x vert-origin-y word-spacing writing-mode xmlns:xlink x-height".split(" ").forEach(function(a){var b=a.replace(sb,
    tb);D$1[b]=new B$1(b,1,!1,a,null,!1);});"xlink:actuate xlink:arcrole xlink:role xlink:show xlink:title xlink:type".split(" ").forEach(function(a){var b=a.replace(sb,tb);D$1[b]=new B$1(b,1,!1,a,"http://www.w3.org/1999/xlink",!1);});["xml:base","xml:lang","xml:space"].forEach(function(a){var b=a.replace(sb,tb);D$1[b]=new B$1(b,1,!1,a,"http://www.w3.org/XML/1998/namespace",!1);});["tabIndex","crossOrigin"].forEach(function(a){D$1[a]=new B$1(a,1,!1,a.toLowerCase(),null,!1);});
    D$1.xlinkHref=new B$1("xlinkHref",1,!1,"xlink:href","http://www.w3.org/1999/xlink",!0);["src","href","action","formAction"].forEach(function(a){D$1[a]=new B$1(a,1,!1,a.toLowerCase(),null,!0);});function ub(a){switch(typeof a){case "boolean":case "number":case "object":case "string":case "undefined":return a;default:return""}}
    function vb(a,b,c,d){var e=D$1.hasOwnProperty(b)?D$1[b]:null;var f=null!==e?0===e.type:d?!1:!(2<b.length)||"o"!==b[0]&&"O"!==b[0]||"n"!==b[1]&&"N"!==b[1]?!1:!0;f||(rb(b,c,e,d)&&(c=null),d||null===e?pb(b)&&(null===c?a.removeAttribute(b):a.setAttribute(b,""+c)):e.mustUseProperty?a[e.propertyName]=null===c?3===e.type?!1:"":c:(b=e.attributeName,d=e.attributeNamespace,null===c?a.removeAttribute(b):(e=e.type,c=3===e||4===e&&!0===c?"":""+c,d?a.setAttributeNS(d,b,c):a.setAttribute(b,c))));}
    function wb(a){var b=a.type;return(a=a.nodeName)&&"input"===a.toLowerCase()&&("checkbox"===b||"radio"===b)}
    function xb(a){var b=wb(a)?"checked":"value",c=Object.getOwnPropertyDescriptor(a.constructor.prototype,b),d=""+a[b];if(!a.hasOwnProperty(b)&&"undefined"!==typeof c&&"function"===typeof c.get&&"function"===typeof c.set){var e=c.get,f=c.set;Object.defineProperty(a,b,{configurable:!0,get:function(){return e.call(this)},set:function(a){d=""+a;f.call(this,a);}});Object.defineProperty(a,b,{enumerable:c.enumerable});return{getValue:function(){return d},setValue:function(a){d=""+a;},stopTracking:function(){a._valueTracker=
    null;delete a[b];}}}}function yb(a){a._valueTracker||(a._valueTracker=xb(a));}function zb(a){if(!a)return!1;var b=a._valueTracker;if(!b)return!0;var c=b.getValue();var d="";a&&(d=wb(a)?a.checked?"true":"false":a.value);a=d;return a!==c?(b.setValue(a),!0):!1}function Ab(a,b){var c=b.checked;return objectAssign({},b,{defaultChecked:void 0,defaultValue:void 0,value:void 0,checked:null!=c?c:a._wrapperState.initialChecked})}
    function Bb(a,b){var c=null==b.defaultValue?"":b.defaultValue,d=null!=b.checked?b.checked:b.defaultChecked;c=ub(null!=b.value?b.value:c);a._wrapperState={initialChecked:d,initialValue:c,controlled:"checkbox"===b.type||"radio"===b.type?null!=b.checked:null!=b.value};}function Cb(a,b){b=b.checked;null!=b&&vb(a,"checked",b,!1);}
    function Eb(a,b){Cb(a,b);var c=ub(b.value),d=b.type;if(null!=c)if("number"===d){if(0===c&&""===a.value||a.value!=c)a.value=""+c;}else a.value!==""+c&&(a.value=""+c);else if("submit"===d||"reset"===d){a.removeAttribute("value");return}b.hasOwnProperty("value")?Fb(a,b.type,c):b.hasOwnProperty("defaultValue")&&Fb(a,b.type,ub(b.defaultValue));null==b.checked&&null!=b.defaultChecked&&(a.defaultChecked=!!b.defaultChecked);}
    function Gb(a,b,c){if(b.hasOwnProperty("value")||b.hasOwnProperty("defaultValue")){var d=b.type;if(!("submit"!==d&&"reset"!==d||void 0!==b.value&&null!==b.value))return;b=""+a._wrapperState.initialValue;c||b===a.value||(a.value=b);a.defaultValue=b;}c=a.name;""!==c&&(a.name="");a.defaultChecked=!a.defaultChecked;a.defaultChecked=!!a._wrapperState.initialChecked;""!==c&&(a.name=c);}
    function Fb(a,b,c){if("number"!==b||a.ownerDocument.activeElement!==a)null==c?a.defaultValue=""+a._wrapperState.initialValue:a.defaultValue!==""+c&&(a.defaultValue=""+c);}function Hb(a){var b="";react.Children.forEach(a,function(a){null!=a&&(b+=a);});return b}function Ib(a,b){a=objectAssign({children:void 0},b);if(b=Hb(b.children))a.children=b;return a}
    function Jb(a,b,c,d){a=a.options;if(b){b={};for(var e=0;e<c.length;e++)b["$"+c[e]]=!0;for(c=0;c<a.length;c++)e=b.hasOwnProperty("$"+a[c].value),a[c].selected!==e&&(a[c].selected=e),e&&d&&(a[c].defaultSelected=!0);}else{c=""+ub(c);b=null;for(e=0;e<a.length;e++){if(a[e].value===c){a[e].selected=!0;d&&(a[e].defaultSelected=!0);return}null!==b||a[e].disabled||(b=a[e]);}null!==b&&(b.selected=!0);}}
    function Kb(a,b){if(null!=b.dangerouslySetInnerHTML)throw Error(u$1(91));return objectAssign({},b,{value:void 0,defaultValue:void 0,children:""+a._wrapperState.initialValue})}function Lb(a,b){var c=b.value;if(null==c){c=b.defaultValue;b=b.children;if(null!=b){if(null!=c)throw Error(u$1(92));if(Array.isArray(b)){if(!(1>=b.length))throw Error(u$1(93));b=b[0];}c=b;}null==c&&(c="");}a._wrapperState={initialValue:ub(c)};}
    function Mb(a,b){var c=ub(b.value),d=ub(b.defaultValue);null!=c&&(c=""+c,c!==a.value&&(a.value=c),null==b.defaultValue&&a.defaultValue!==c&&(a.defaultValue=c));null!=d&&(a.defaultValue=""+d);}function Nb(a){var b=a.textContent;b===a._wrapperState.initialValue&&""!==b&&null!==b&&(a.value=b);}var Ob={html:"http://www.w3.org/1999/xhtml",mathml:"http://www.w3.org/1998/Math/MathML",svg:"http://www.w3.org/2000/svg"};
    function Pb(a){switch(a){case "svg":return"http://www.w3.org/2000/svg";case "math":return"http://www.w3.org/1998/Math/MathML";default:return"http://www.w3.org/1999/xhtml"}}function Qb(a,b){return null==a||"http://www.w3.org/1999/xhtml"===a?Pb(b):"http://www.w3.org/2000/svg"===a&&"foreignObject"===b?"http://www.w3.org/1999/xhtml":a}
    var Rb,Sb=function(a){return"undefined"!==typeof MSApp&&MSApp.execUnsafeLocalFunction?function(b,c,d,e){MSApp.execUnsafeLocalFunction(function(){return a(b,c,d,e)});}:a}(function(a,b){if(a.namespaceURI!==Ob.svg||"innerHTML"in a)a.innerHTML=b;else{Rb=Rb||document.createElement("div");Rb.innerHTML="<svg>"+b.valueOf().toString()+"</svg>";for(b=Rb.firstChild;a.firstChild;)a.removeChild(a.firstChild);for(;b.firstChild;)a.appendChild(b.firstChild);}});
    function Tb(a,b){if(b){var c=a.firstChild;if(c&&c===a.lastChild&&3===c.nodeType){c.nodeValue=b;return}}a.textContent=b;}function Ub(a,b){var c={};c[a.toLowerCase()]=b.toLowerCase();c["Webkit"+a]="webkit"+b;c["Moz"+a]="moz"+b;return c}var Vb={animationend:Ub("Animation","AnimationEnd"),animationiteration:Ub("Animation","AnimationIteration"),animationstart:Ub("Animation","AnimationStart"),transitionend:Ub("Transition","TransitionEnd")},Wb={},Xb={};
    Ya&&(Xb=document.createElement("div").style,"AnimationEvent"in window||(delete Vb.animationend.animation,delete Vb.animationiteration.animation,delete Vb.animationstart.animation),"TransitionEvent"in window||delete Vb.transitionend.transition);function Yb(a){if(Wb[a])return Wb[a];if(!Vb[a])return a;var b=Vb[a],c;for(c in b)if(b.hasOwnProperty(c)&&c in Xb)return Wb[a]=b[c];return a}var Zb=Yb("animationend"),$b=Yb("animationiteration"),ac=Yb("animationstart"),bc=Yb("transitionend"),cc="abort canplay canplaythrough durationchange emptied encrypted ended error loadeddata loadedmetadata loadstart pause play playing progress ratechange seeked seeking stalled suspend timeupdate volumechange waiting".split(" ");
    function ec(a){var b=a,c=a;if(a.alternate)for(;b.return;)b=b.return;else{a=b;do b=a,0!==(b.effectTag&1026)&&(c=b.return),a=b.return;while(a)}return 3===b.tag?c:null}function fc(a){if(13===a.tag){var b=a.memoizedState;null===b&&(a=a.alternate,null!==a&&(b=a.memoizedState));if(null!==b)return b.dehydrated}return null}function gc(a){if(ec(a)!==a)throw Error(u$1(188));}
    function hc(a){var b=a.alternate;if(!b){b=ec(a);if(null===b)throw Error(u$1(188));return b!==a?null:a}for(var c=a,d=b;;){var e=c.return;if(null===e)break;var f=e.alternate;if(null===f){d=e.return;if(null!==d){c=d;continue}break}if(e.child===f.child){for(f=e.child;f;){if(f===c)return gc(e),a;if(f===d)return gc(e),b;f=f.sibling;}throw Error(u$1(188));}if(c.return!==d.return)c=e,d=f;else{for(var g=!1,h=e.child;h;){if(h===c){g=!0;c=e;d=f;break}if(h===d){g=!0;d=e;c=f;break}h=h.sibling;}if(!g){for(h=f.child;h;){if(h===
    c){g=!0;c=f;d=e;break}if(h===d){g=!0;d=f;c=e;break}h=h.sibling;}if(!g)throw Error(u$1(189));}}if(c.alternate!==d)throw Error(u$1(190));}if(3!==c.tag)throw Error(u$1(188));return c.stateNode.current===c?a:b}function ic(a){a=hc(a);if(!a)return null;for(var b=a;;){if(5===b.tag||6===b.tag)return b;if(b.child)b.child.return=b,b=b.child;else{if(b===a)break;for(;!b.sibling;){if(!b.return||b.return===a)return null;b=b.return;}b.sibling.return=b.return;b=b.sibling;}}return null}
    var jc,kc,lc,mc=!1,nc=[],oc=null,pc=null,qc=null,rc=new Map,sc=new Map,tc=[],uc="mousedown mouseup touchcancel touchend touchstart auxclick dblclick pointercancel pointerdown pointerup dragend dragstart drop compositionend compositionstart keydown keypress keyup input textInput close cancel copy cut paste click change contextmenu reset submit".split(" "),vc="focus blur dragenter dragleave mouseover mouseout pointerover pointerout gotpointercapture lostpointercapture".split(" ");
    function wc(a){var b=xc(a);uc.forEach(function(c){yc(c,a,b);});vc.forEach(function(c){yc(c,a,b);});}function zc(a,b,c,d){return{blockedOn:a,topLevelType:b,eventSystemFlags:c|32,nativeEvent:d}}function Ac(a,b){switch(a){case "focus":case "blur":oc=null;break;case "dragenter":case "dragleave":pc=null;break;case "mouseover":case "mouseout":qc=null;break;case "pointerover":case "pointerout":rc.delete(b.pointerId);break;case "gotpointercapture":case "lostpointercapture":sc.delete(b.pointerId);}}
    function Bc(a,b,c,d,e){if(null===a||a.nativeEvent!==e)return a=zc(b,c,d,e),null!==b&&(b=Cc(b),null!==b&&kc(b)),a;a.eventSystemFlags|=d;return a}function Dc(a,b,c,d){switch(b){case "focus":return oc=Bc(oc,a,b,c,d),!0;case "dragenter":return pc=Bc(pc,a,b,c,d),!0;case "mouseover":return qc=Bc(qc,a,b,c,d),!0;case "pointerover":var e=d.pointerId;rc.set(e,Bc(rc.get(e)||null,a,b,c,d));return!0;case "gotpointercapture":return e=d.pointerId,sc.set(e,Bc(sc.get(e)||null,a,b,c,d)),!0}return!1}
    function Ec(a){var b=Fc(a.target);if(null!==b){var c=ec(b);if(null!==c)if(b=c.tag,13===b){if(b=fc(c),null!==b){a.blockedOn=b;scheduler.unstable_runWithPriority(a.priority,function(){lc(c);});return}}else if(3===b&&c.stateNode.hydrate){a.blockedOn=3===c.tag?c.stateNode.containerInfo:null;return}}a.blockedOn=null;}function Gc(a){if(null!==a.blockedOn)return!1;var b=Hc(a.topLevelType,a.eventSystemFlags,a.nativeEvent);if(null!==b){var c=Cc(b);null!==c&&kc(c);a.blockedOn=b;return!1}return!0}
    function Ic(a,b,c){Gc(a)&&c.delete(b);}function Jc(){for(mc=!1;0<nc.length;){var a=nc[0];if(null!==a.blockedOn){a=Cc(a.blockedOn);null!==a&&jc(a);break}var b=Hc(a.topLevelType,a.eventSystemFlags,a.nativeEvent);null!==b?a.blockedOn=b:nc.shift();}null!==oc&&Gc(oc)&&(oc=null);null!==pc&&Gc(pc)&&(pc=null);null!==qc&&Gc(qc)&&(qc=null);rc.forEach(Ic);sc.forEach(Ic);}function Kc(a,b){a.blockedOn===b&&(a.blockedOn=null,mc||(mc=!0,scheduler.unstable_scheduleCallback(scheduler.unstable_NormalPriority,Jc)));}
    function Lc(a){function b(b){return Kc(b,a)}if(0<nc.length){Kc(nc[0],a);for(var c=1;c<nc.length;c++){var d=nc[c];d.blockedOn===a&&(d.blockedOn=null);}}null!==oc&&Kc(oc,a);null!==pc&&Kc(pc,a);null!==qc&&Kc(qc,a);rc.forEach(b);sc.forEach(b);for(c=0;c<tc.length;c++)d=tc[c],d.blockedOn===a&&(d.blockedOn=null);for(;0<tc.length&&(c=tc[0],null===c.blockedOn);)Ec(c),null===c.blockedOn&&tc.shift();}
    function Mc(a){a=a.target||a.srcElement||window;a.correspondingUseElement&&(a=a.correspondingUseElement);return 3===a.nodeType?a.parentNode:a}function Nc(a){do a=a.return;while(a&&5!==a.tag);return a?a:null}function Oc(a,b,c){if(b=Da(a,c.dispatchConfig.phasedRegistrationNames[b]))c._dispatchListeners=xa(c._dispatchListeners,b),c._dispatchInstances=xa(c._dispatchInstances,a);}
    function Pc(a){if(a&&a.dispatchConfig.phasedRegistrationNames){for(var b=a._targetInst,c=[];b;)c.push(b),b=Nc(b);for(b=c.length;0<b--;)Oc(c[b],"captured",a);for(b=0;b<c.length;b++)Oc(c[b],"bubbled",a);}}function Qc(a,b,c){a&&c&&c.dispatchConfig.registrationName&&(b=Da(a,c.dispatchConfig.registrationName))&&(c._dispatchListeners=xa(c._dispatchListeners,b),c._dispatchInstances=xa(c._dispatchInstances,a));}function Rc(a){a&&a.dispatchConfig.registrationName&&Qc(a._targetInst,null,a);}
    function Sc(a){ya(a,Pc);}function Tc(){return!0}function Uc(){return!1}function E$1(a,b,c,d){this.dispatchConfig=a;this._targetInst=b;this.nativeEvent=c;a=this.constructor.Interface;for(var e in a)a.hasOwnProperty(e)&&((b=a[e])?this[e]=b(c):"target"===e?this.target=d:this[e]=c[e]);this.isDefaultPrevented=(null!=c.defaultPrevented?c.defaultPrevented:!1===c.returnValue)?Tc:Uc;this.isPropagationStopped=Uc;return this}
    objectAssign(E$1.prototype,{preventDefault:function(){this.defaultPrevented=!0;var a=this.nativeEvent;a&&(a.preventDefault?a.preventDefault():"unknown"!==typeof a.returnValue&&(a.returnValue=!1),this.isDefaultPrevented=Tc);},stopPropagation:function(){var a=this.nativeEvent;a&&(a.stopPropagation?a.stopPropagation():"unknown"!==typeof a.cancelBubble&&(a.cancelBubble=!0),this.isPropagationStopped=Tc);},persist:function(){this.isPersistent=Tc;},isPersistent:Uc,destructor:function(){var a=this.constructor.Interface,
    b;for(b in a)this[b]=null;this.nativeEvent=this._targetInst=this.dispatchConfig=null;this.isPropagationStopped=this.isDefaultPrevented=Uc;this._dispatchInstances=this._dispatchListeners=null;}});E$1.Interface={type:null,target:null,currentTarget:function(){return null},eventPhase:null,bubbles:null,cancelable:null,timeStamp:function(a){return a.timeStamp||Date.now()},defaultPrevented:null,isTrusted:null};
    E$1.extend=function(a){function b(){}function c(){return d.apply(this,arguments)}var d=this;b.prototype=d.prototype;var e=new b;objectAssign(e,c.prototype);c.prototype=e;c.prototype.constructor=c;c.Interface=objectAssign({},d.Interface,a);c.extend=d.extend;Vc(c);return c};Vc(E$1);function Wc(a,b,c,d){if(this.eventPool.length){var e=this.eventPool.pop();this.call(e,a,b,c,d);return e}return new this(a,b,c,d)}
    function Xc(a){if(!(a instanceof this))throw Error(u$1(279));a.destructor();10>this.eventPool.length&&this.eventPool.push(a);}function Vc(a){a.eventPool=[];a.getPooled=Wc;a.release=Xc;}var Yc=E$1.extend({animationName:null,elapsedTime:null,pseudoElement:null}),Zc=E$1.extend({clipboardData:function(a){return"clipboardData"in a?a.clipboardData:window.clipboardData}}),$c=E$1.extend({view:null,detail:null}),ad=$c.extend({relatedTarget:null});
    function bd(a){var b=a.keyCode;"charCode"in a?(a=a.charCode,0===a&&13===b&&(a=13)):a=b;10===a&&(a=13);return 32<=a||13===a?a:0}
    var cd={Esc:"Escape",Spacebar:" ",Left:"ArrowLeft",Up:"ArrowUp",Right:"ArrowRight",Down:"ArrowDown",Del:"Delete",Win:"OS",Menu:"ContextMenu",Apps:"ContextMenu",Scroll:"ScrollLock",MozPrintableKey:"Unidentified"},dd={8:"Backspace",9:"Tab",12:"Clear",13:"Enter",16:"Shift",17:"Control",18:"Alt",19:"Pause",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",45:"Insert",46:"Delete",112:"F1",113:"F2",114:"F3",115:"F4",
    116:"F5",117:"F6",118:"F7",119:"F8",120:"F9",121:"F10",122:"F11",123:"F12",144:"NumLock",145:"ScrollLock",224:"Meta"},ed={Alt:"altKey",Control:"ctrlKey",Meta:"metaKey",Shift:"shiftKey"};function gd(a){var b=this.nativeEvent;return b.getModifierState?b.getModifierState(a):(a=ed[a])?!!b[a]:!1}function hd(){return gd}
    var id=$c.extend({key:function(a){if(a.key){var b=cd[a.key]||a.key;if("Unidentified"!==b)return b}return"keypress"===a.type?(a=bd(a),13===a?"Enter":String.fromCharCode(a)):"keydown"===a.type||"keyup"===a.type?dd[a.keyCode]||"Unidentified":""},location:null,ctrlKey:null,shiftKey:null,altKey:null,metaKey:null,repeat:null,locale:null,getModifierState:hd,charCode:function(a){return"keypress"===a.type?bd(a):0},keyCode:function(a){return"keydown"===a.type||"keyup"===a.type?a.keyCode:0},which:function(a){return"keypress"===
    a.type?bd(a):"keydown"===a.type||"keyup"===a.type?a.keyCode:0}}),jd=0,kd=0,ld=!1,md=!1,nd=$c.extend({screenX:null,screenY:null,clientX:null,clientY:null,pageX:null,pageY:null,ctrlKey:null,shiftKey:null,altKey:null,metaKey:null,getModifierState:hd,button:null,buttons:null,relatedTarget:function(a){return a.relatedTarget||(a.fromElement===a.srcElement?a.toElement:a.fromElement)},movementX:function(a){if("movementX"in a)return a.movementX;var b=jd;jd=a.screenX;return ld?"mousemove"===a.type?a.screenX-
    b:0:(ld=!0,0)},movementY:function(a){if("movementY"in a)return a.movementY;var b=kd;kd=a.screenY;return md?"mousemove"===a.type?a.screenY-b:0:(md=!0,0)}}),od=nd.extend({pointerId:null,width:null,height:null,pressure:null,tangentialPressure:null,tiltX:null,tiltY:null,twist:null,pointerType:null,isPrimary:null}),pd=nd.extend({dataTransfer:null}),qd=$c.extend({touches:null,targetTouches:null,changedTouches:null,altKey:null,metaKey:null,ctrlKey:null,shiftKey:null,getModifierState:hd}),rd=E$1.extend({propertyName:null,
    elapsedTime:null,pseudoElement:null}),sd=nd.extend({deltaX:function(a){return"deltaX"in a?a.deltaX:"wheelDeltaX"in a?-a.wheelDeltaX:0},deltaY:function(a){return"deltaY"in a?a.deltaY:"wheelDeltaY"in a?-a.wheelDeltaY:"wheelDelta"in a?-a.wheelDelta:0},deltaZ:null,deltaMode:null}),td=[["blur","blur",0],["cancel","cancel",0],["click","click",0],["close","close",0],["contextmenu","contextMenu",0],["copy","copy",0],["cut","cut",0],["auxclick","auxClick",0],["dblclick","doubleClick",0],["dragend","dragEnd",
    0],["dragstart","dragStart",0],["drop","drop",0],["focus","focus",0],["input","input",0],["invalid","invalid",0],["keydown","keyDown",0],["keypress","keyPress",0],["keyup","keyUp",0],["mousedown","mouseDown",0],["mouseup","mouseUp",0],["paste","paste",0],["pause","pause",0],["play","play",0],["pointercancel","pointerCancel",0],["pointerdown","pointerDown",0],["pointerup","pointerUp",0],["ratechange","rateChange",0],["reset","reset",0],["seeked","seeked",0],["submit","submit",0],["touchcancel","touchCancel",
    0],["touchend","touchEnd",0],["touchstart","touchStart",0],["volumechange","volumeChange",0],["drag","drag",1],["dragenter","dragEnter",1],["dragexit","dragExit",1],["dragleave","dragLeave",1],["dragover","dragOver",1],["mousemove","mouseMove",1],["mouseout","mouseOut",1],["mouseover","mouseOver",1],["pointermove","pointerMove",1],["pointerout","pointerOut",1],["pointerover","pointerOver",1],["scroll","scroll",1],["toggle","toggle",1],["touchmove","touchMove",1],["wheel","wheel",1],["abort","abort",
    2],[Zb,"animationEnd",2],[$b,"animationIteration",2],[ac,"animationStart",2],["canplay","canPlay",2],["canplaythrough","canPlayThrough",2],["durationchange","durationChange",2],["emptied","emptied",2],["encrypted","encrypted",2],["ended","ended",2],["error","error",2],["gotpointercapture","gotPointerCapture",2],["load","load",2],["loadeddata","loadedData",2],["loadedmetadata","loadedMetadata",2],["loadstart","loadStart",2],["lostpointercapture","lostPointerCapture",2],["playing","playing",2],["progress",
    "progress",2],["seeking","seeking",2],["stalled","stalled",2],["suspend","suspend",2],["timeupdate","timeUpdate",2],[bc,"transitionEnd",2],["waiting","waiting",2]],ud={},vd={},wd=0;for(;wd<td.length;wd++){var yd=td[wd],zd=yd[0],Ad=yd[1],Bd=yd[2],Cd="on"+(Ad[0].toUpperCase()+Ad.slice(1)),Dd={phasedRegistrationNames:{bubbled:Cd,captured:Cd+"Capture"},dependencies:[zd],eventPriority:Bd};ud[Ad]=Dd;vd[zd]=Dd;}
    var Ed={eventTypes:ud,getEventPriority:function(a){a=vd[a];return void 0!==a?a.eventPriority:2},extractEvents:function(a,b,c,d){var e=vd[a];if(!e)return null;switch(a){case "keypress":if(0===bd(c))return null;case "keydown":case "keyup":a=id;break;case "blur":case "focus":a=ad;break;case "click":if(2===c.button)return null;case "auxclick":case "dblclick":case "mousedown":case "mousemove":case "mouseup":case "mouseout":case "mouseover":case "contextmenu":a=nd;break;case "drag":case "dragend":case "dragenter":case "dragexit":case "dragleave":case "dragover":case "dragstart":case "drop":a=
    pd;break;case "touchcancel":case "touchend":case "touchmove":case "touchstart":a=qd;break;case Zb:case $b:case ac:a=Yc;break;case bc:a=rd;break;case "scroll":a=$c;break;case "wheel":a=sd;break;case "copy":case "cut":case "paste":a=Zc;break;case "gotpointercapture":case "lostpointercapture":case "pointercancel":case "pointerdown":case "pointermove":case "pointerout":case "pointerover":case "pointerup":a=od;break;default:a=E$1;}b=a.getPooled(e,b,c,d);Sc(b);return b}},Fd=scheduler.unstable_UserBlockingPriority,
    Gd=scheduler.unstable_runWithPriority,Hd=Ed.getEventPriority,Id=10,Jd=[];
    function Kd(a){var b=a.targetInst,c=b;do{if(!c){a.ancestors.push(c);break}var d=c;if(3===d.tag)d=d.stateNode.containerInfo;else{for(;d.return;)d=d.return;d=3!==d.tag?null:d.stateNode.containerInfo;}if(!d)break;b=c.tag;5!==b&&6!==b||a.ancestors.push(c);c=Fc(d);}while(c);for(c=0;c<a.ancestors.length;c++){b=a.ancestors[c];var e=Mc(a.nativeEvent);d=a.topLevelType;for(var f=a.nativeEvent,g=a.eventSystemFlags,h=null,k=0;k<ea.length;k++){var l=ea[k];l&&(l=l.extractEvents(d,b,f,e,g))&&(h=xa(h,l));}Ba(h);}}
    var Ld=!0;function F$1(a,b){Md(b,a,!1);}function Md(a,b,c){switch(Hd(b)){case 0:var d=Nd.bind(null,b,1);break;case 1:d=Od.bind(null,b,1);break;default:d=Pd.bind(null,b,1);}c?a.addEventListener(b,d,!0):a.addEventListener(b,d,!1);}function Nd(a,b,c){ib||gb();var d=Pd,e=ib;ib=!0;try{fb(d,a,b,c);}finally{(ib=e)||kb();}}function Od(a,b,c){Gd(Fd,Pd.bind(null,a,b,c));}
    function Qd(a,b,c,d){if(Jd.length){var e=Jd.pop();e.topLevelType=a;e.eventSystemFlags=b;e.nativeEvent=c;e.targetInst=d;a=e;}else a={topLevelType:a,eventSystemFlags:b,nativeEvent:c,targetInst:d,ancestors:[]};try{if(b=Kd,c=a,jb)b(c,void 0);else{jb=!0;try{hb(b,c,void 0);}finally{jb=!1,kb();}}}finally{a.topLevelType=null,a.nativeEvent=null,a.targetInst=null,a.ancestors.length=0,Jd.length<Id&&Jd.push(a);}}
    function Pd(a,b,c){if(Ld)if(0<nc.length&&-1<uc.indexOf(a))a=zc(null,a,b,c),nc.push(a);else{var d=Hc(a,b,c);null===d?Ac(a,c):-1<uc.indexOf(a)?(a=zc(d,a,b,c),nc.push(a)):Dc(d,a,b,c)||(Ac(a,c),Qd(a,b,c,null));}}function Hc(a,b,c){var d=Mc(c);d=Fc(d);if(null!==d){var e=ec(d);if(null===e)d=null;else{var f=e.tag;if(13===f){d=fc(e);if(null!==d)return d;d=null;}else if(3===f){if(e.stateNode.hydrate)return 3===e.tag?e.stateNode.containerInfo:null;d=null;}else e!==d&&(d=null);}}Qd(a,b,c,d);return null}
    function Rd(a){if(!Ya)return!1;a="on"+a;var b=a in document;b||(b=document.createElement("div"),b.setAttribute(a,"return;"),b="function"===typeof b[a]);return b}var Sd=new ("function"===typeof WeakMap?WeakMap:Map);function xc(a){var b=Sd.get(a);void 0===b&&(b=new Set,Sd.set(a,b));return b}
    function yc(a,b,c){if(!c.has(a)){switch(a){case "scroll":Md(b,"scroll",!0);break;case "focus":case "blur":Md(b,"focus",!0);Md(b,"blur",!0);c.add("blur");c.add("focus");break;case "cancel":case "close":Rd(a)&&Md(b,a,!0);break;case "invalid":case "submit":case "reset":break;default:-1===cc.indexOf(a)&&F$1(a,b);}c.add(a);}}
    var Td={animationIterationCount:!0,borderImageOutset:!0,borderImageSlice:!0,borderImageWidth:!0,boxFlex:!0,boxFlexGroup:!0,boxOrdinalGroup:!0,columnCount:!0,columns:!0,flex:!0,flexGrow:!0,flexPositive:!0,flexShrink:!0,flexNegative:!0,flexOrder:!0,gridArea:!0,gridRow:!0,gridRowEnd:!0,gridRowSpan:!0,gridRowStart:!0,gridColumn:!0,gridColumnEnd:!0,gridColumnSpan:!0,gridColumnStart:!0,fontWeight:!0,lineClamp:!0,lineHeight:!0,opacity:!0,order:!0,orphans:!0,tabSize:!0,widows:!0,zIndex:!0,zoom:!0,fillOpacity:!0,
    floodOpacity:!0,stopOpacity:!0,strokeDasharray:!0,strokeDashoffset:!0,strokeMiterlimit:!0,strokeOpacity:!0,strokeWidth:!0},Ud=["Webkit","ms","Moz","O"];Object.keys(Td).forEach(function(a){Ud.forEach(function(b){b=b+a.charAt(0).toUpperCase()+a.substring(1);Td[b]=Td[a];});});function Vd(a,b,c){return null==b||"boolean"===typeof b||""===b?"":c||"number"!==typeof b||0===b||Td.hasOwnProperty(a)&&Td[a]?(""+b).trim():b+"px"}
    function Wd(a,b){a=a.style;for(var c in b)if(b.hasOwnProperty(c)){var d=0===c.indexOf("--"),e=Vd(c,b[c],d);"float"===c&&(c="cssFloat");d?a.setProperty(c,e):a[c]=e;}}var Xd=objectAssign({menuitem:!0},{area:!0,base:!0,br:!0,col:!0,embed:!0,hr:!0,img:!0,input:!0,keygen:!0,link:!0,meta:!0,param:!0,source:!0,track:!0,wbr:!0});
    function Yd(a,b){if(b){if(Xd[a]&&(null!=b.children||null!=b.dangerouslySetInnerHTML))throw Error(u$1(137,a,""));if(null!=b.dangerouslySetInnerHTML){if(null!=b.children)throw Error(u$1(60));if(!("object"===typeof b.dangerouslySetInnerHTML&&"__html"in b.dangerouslySetInnerHTML))throw Error(u$1(61));}if(null!=b.style&&"object"!==typeof b.style)throw Error(u$1(62,""));}}
    function Zd(a,b){if(-1===a.indexOf("-"))return"string"===typeof b.is;switch(a){case "annotation-xml":case "color-profile":case "font-face":case "font-face-src":case "font-face-uri":case "font-face-format":case "font-face-name":case "missing-glyph":return!1;default:return!0}}function $d(a,b){a=9===a.nodeType||11===a.nodeType?a:a.ownerDocument;var c=xc(a);b=ja[b];for(var d=0;d<b.length;d++)yc(b[d],a,c);}function ae(){}
    function be(a){a=a||("undefined"!==typeof document?document:void 0);if("undefined"===typeof a)return null;try{return a.activeElement||a.body}catch(b){return a.body}}function ce(a){for(;a&&a.firstChild;)a=a.firstChild;return a}function de(a,b){var c=ce(a);a=0;for(var d;c;){if(3===c.nodeType){d=a+c.textContent.length;if(a<=b&&d>=b)return{node:c,offset:b-a};a=d;}a:{for(;c;){if(c.nextSibling){c=c.nextSibling;break a}c=c.parentNode;}c=void 0;}c=ce(c);}}
    function ee(a,b){return a&&b?a===b?!0:a&&3===a.nodeType?!1:b&&3===b.nodeType?ee(a,b.parentNode):"contains"in a?a.contains(b):a.compareDocumentPosition?!!(a.compareDocumentPosition(b)&16):!1:!1}function fe(){for(var a=window,b=be();b instanceof a.HTMLIFrameElement;){try{var c="string"===typeof b.contentWindow.location.href;}catch(d){c=!1;}if(c)a=b.contentWindow;else break;b=be(a.document);}return b}
    function ge(a){var b=a&&a.nodeName&&a.nodeName.toLowerCase();return b&&("input"===b&&("text"===a.type||"search"===a.type||"tel"===a.type||"url"===a.type||"password"===a.type)||"textarea"===b||"true"===a.contentEditable)}var he="$",ie="/$",je="$?",ke="$!",le=null,me=null;function ne(a,b){switch(a){case "button":case "input":case "select":case "textarea":return!!b.autoFocus}return!1}
    function oe(a,b){return"textarea"===a||"option"===a||"noscript"===a||"string"===typeof b.children||"number"===typeof b.children||"object"===typeof b.dangerouslySetInnerHTML&&null!==b.dangerouslySetInnerHTML&&null!=b.dangerouslySetInnerHTML.__html}var pe="function"===typeof setTimeout?setTimeout:void 0,qe="function"===typeof clearTimeout?clearTimeout:void 0;function re(a){for(;null!=a;a=a.nextSibling){var b=a.nodeType;if(1===b||3===b)break}return a}
    function se(a){a=a.previousSibling;for(var b=0;a;){if(8===a.nodeType){var c=a.data;if(c===he||c===ke||c===je){if(0===b)return a;b--;}else c===ie&&b++;}a=a.previousSibling;}return null}var te=Math.random().toString(36).slice(2),ue="__reactInternalInstance$"+te,ve="__reactEventHandlers$"+te,we="__reactContainere$"+te;
    function Fc(a){var b=a[ue];if(b)return b;for(var c=a.parentNode;c;){if(b=c[we]||c[ue]){c=b.alternate;if(null!==b.child||null!==c&&null!==c.child)for(a=se(a);null!==a;){if(c=a[ue])return c;a=se(a);}return b}a=c;c=a.parentNode;}return null}function Cc(a){a=a[ue]||a[we];return!a||5!==a.tag&&6!==a.tag&&13!==a.tag&&3!==a.tag?null:a}function xe(a){if(5===a.tag||6===a.tag)return a.stateNode;throw Error(u$1(33));}function ye(a){return a[ve]||null}var ze=null,Ae=null,Be=null;
    function Ce(){if(Be)return Be;var a,b=Ae,c=b.length,d,e="value"in ze?ze.value:ze.textContent,f=e.length;for(a=0;a<c&&b[a]===e[a];a++);var g=c-a;for(d=1;d<=g&&b[c-d]===e[f-d];d++);return Be=e.slice(a,1<d?1-d:void 0)}var De=E$1.extend({data:null}),Ee=E$1.extend({data:null}),Fe=[9,13,27,32],Ge=Ya&&"CompositionEvent"in window,He=null;Ya&&"documentMode"in document&&(He=document.documentMode);
    var Ie=Ya&&"TextEvent"in window&&!He,Je=Ya&&(!Ge||He&&8<He&&11>=He),Ke=String.fromCharCode(32),Le={beforeInput:{phasedRegistrationNames:{bubbled:"onBeforeInput",captured:"onBeforeInputCapture"},dependencies:["compositionend","keypress","textInput","paste"]},compositionEnd:{phasedRegistrationNames:{bubbled:"onCompositionEnd",captured:"onCompositionEndCapture"},dependencies:"blur compositionend keydown keypress keyup mousedown".split(" ")},compositionStart:{phasedRegistrationNames:{bubbled:"onCompositionStart",
    captured:"onCompositionStartCapture"},dependencies:"blur compositionstart keydown keypress keyup mousedown".split(" ")},compositionUpdate:{phasedRegistrationNames:{bubbled:"onCompositionUpdate",captured:"onCompositionUpdateCapture"},dependencies:"blur compositionupdate keydown keypress keyup mousedown".split(" ")}},Me=!1;
    function Ne(a,b){switch(a){case "keyup":return-1!==Fe.indexOf(b.keyCode);case "keydown":return 229!==b.keyCode;case "keypress":case "mousedown":case "blur":return!0;default:return!1}}function Oe(a){a=a.detail;return"object"===typeof a&&"data"in a?a.data:null}var Pe=!1;function Qe(a,b){switch(a){case "compositionend":return Oe(b);case "keypress":if(32!==b.which)return null;Me=!0;return Ke;case "textInput":return a=b.data,a===Ke&&Me?null:a;default:return null}}
    function Re(a,b){if(Pe)return"compositionend"===a||!Ge&&Ne(a,b)?(a=Ce(),Be=Ae=ze=null,Pe=!1,a):null;switch(a){case "paste":return null;case "keypress":if(!(b.ctrlKey||b.altKey||b.metaKey)||b.ctrlKey&&b.altKey){if(b.char&&1<b.char.length)return b.char;if(b.which)return String.fromCharCode(b.which)}return null;case "compositionend":return Je&&"ko"!==b.locale?null:b.data;default:return null}}
    var Se={eventTypes:Le,extractEvents:function(a,b,c,d){var e;if(Ge)b:{switch(a){case "compositionstart":var f=Le.compositionStart;break b;case "compositionend":f=Le.compositionEnd;break b;case "compositionupdate":f=Le.compositionUpdate;break b}f=void 0;}else Pe?Ne(a,c)&&(f=Le.compositionEnd):"keydown"===a&&229===c.keyCode&&(f=Le.compositionStart);f?(Je&&"ko"!==c.locale&&(Pe||f!==Le.compositionStart?f===Le.compositionEnd&&Pe&&(e=Ce()):(ze=d,Ae="value"in ze?ze.value:ze.textContent,Pe=!0)),f=De.getPooled(f,
    b,c,d),e?f.data=e:(e=Oe(c),null!==e&&(f.data=e)),Sc(f),e=f):e=null;(a=Ie?Qe(a,c):Re(a,c))?(b=Ee.getPooled(Le.beforeInput,b,c,d),b.data=a,Sc(b)):b=null;return null===e?b:null===b?e:[e,b]}},Te={color:!0,date:!0,datetime:!0,"datetime-local":!0,email:!0,month:!0,number:!0,password:!0,range:!0,search:!0,tel:!0,text:!0,time:!0,url:!0,week:!0};function Ue(a){var b=a&&a.nodeName&&a.nodeName.toLowerCase();return"input"===b?!!Te[a.type]:"textarea"===b?!0:!1}
    var Ve={change:{phasedRegistrationNames:{bubbled:"onChange",captured:"onChangeCapture"},dependencies:"blur change click focus input keydown keyup selectionchange".split(" ")}};function We(a,b,c){a=E$1.getPooled(Ve.change,a,b,c);a.type="change";cb(c);Sc(a);return a}var Xe=null,Ye=null;function Ze(a){Ba(a);}function $e(a){var b=xe(a);if(zb(b))return a}function af(a,b){if("change"===a)return b}var bf=!1;Ya&&(bf=Rd("input")&&(!document.documentMode||9<document.documentMode));
    function cf(){Xe&&(Xe.detachEvent("onpropertychange",df),Ye=Xe=null);}function df(a){if("value"===a.propertyName&&$e(Ye))if(a=We(Ye,a,Mc(a)),ib)Ba(a);else{ib=!0;try{eb(Ze,a);}finally{ib=!1,kb();}}}function ef(a,b,c){"focus"===a?(cf(),Xe=b,Ye=c,Xe.attachEvent("onpropertychange",df)):"blur"===a&&cf();}function ff(a){if("selectionchange"===a||"keyup"===a||"keydown"===a)return $e(Ye)}function gf(a,b){if("click"===a)return $e(b)}function hf(a,b){if("input"===a||"change"===a)return $e(b)}
    var jf={eventTypes:Ve,_isInputEventSupported:bf,extractEvents:function(a,b,c,d){var e=b?xe(b):window,f=e.nodeName&&e.nodeName.toLowerCase();if("select"===f||"input"===f&&"file"===e.type)var g=af;else if(Ue(e))if(bf)g=hf;else{g=ff;var h=ef;}else(f=e.nodeName)&&"input"===f.toLowerCase()&&("checkbox"===e.type||"radio"===e.type)&&(g=gf);if(g&&(g=g(a,b)))return We(g,c,d);h&&h(a,e,b);"blur"===a&&(a=e._wrapperState)&&a.controlled&&"number"===e.type&&Fb(e,"number",e.value);}},kf={mouseEnter:{registrationName:"onMouseEnter",
    dependencies:["mouseout","mouseover"]},mouseLeave:{registrationName:"onMouseLeave",dependencies:["mouseout","mouseover"]},pointerEnter:{registrationName:"onPointerEnter",dependencies:["pointerout","pointerover"]},pointerLeave:{registrationName:"onPointerLeave",dependencies:["pointerout","pointerover"]}},lf,mf={eventTypes:kf,extractEvents:function(a,b,c,d,e){var f="mouseover"===a||"pointerover"===a,g="mouseout"===a||"pointerout"===a;if(f&&0===(e&32)&&(c.relatedTarget||c.fromElement)||!g&&!f)return null;
    e=d.window===d?d:(e=d.ownerDocument)?e.defaultView||e.parentWindow:window;if(g){if(g=b,b=(b=c.relatedTarget||c.toElement)?Fc(b):null,null!==b&&(f=ec(b),b!==f||5!==b.tag&&6!==b.tag))b=null;}else g=null;if(g===b)return null;if("mouseout"===a||"mouseover"===a){var h=nd;var k=kf.mouseLeave;var l=kf.mouseEnter;var m="mouse";}else if("pointerout"===a||"pointerover"===a)h=od,k=kf.pointerLeave,l=kf.pointerEnter,m="pointer";a=null==g?e:xe(g);e=null==b?e:xe(b);k=h.getPooled(k,g,c,d);k.type=m+"leave";k.target=
    a;k.relatedTarget=e;d=h.getPooled(l,b,c,d);d.type=m+"enter";d.target=e;d.relatedTarget=a;h=g;m=b;if(h&&m)a:{l=h;a=m;g=0;for(b=l;b;b=Nc(b))g++;b=0;for(e=a;e;e=Nc(e))b++;for(;0<g-b;)l=Nc(l),g--;for(;0<b-g;)a=Nc(a),b--;for(;g--;){if(l===a||l===a.alternate)break a;l=Nc(l);a=Nc(a);}l=null;}else l=null;a=l;for(l=[];h&&h!==a;){g=h.alternate;if(null!==g&&g===a)break;l.push(h);h=Nc(h);}for(h=[];m&&m!==a;){g=m.alternate;if(null!==g&&g===a)break;h.push(m);m=Nc(m);}for(m=0;m<l.length;m++)Qc(l[m],"bubbled",k);for(m=
    h.length;0<m--;)Qc(h[m],"captured",d);if(c===lf)return lf=null,[k];lf=c;return[k,d]}};function nf(a,b){return a===b&&(0!==a||1/a===1/b)||a!==a&&b!==b}var of="function"===typeof Object.is?Object.is:nf,pf=Object.prototype.hasOwnProperty;function qf(a,b){if(of(a,b))return!0;if("object"!==typeof a||null===a||"object"!==typeof b||null===b)return!1;var c=Object.keys(a),d=Object.keys(b);if(c.length!==d.length)return!1;for(d=0;d<c.length;d++)if(!pf.call(b,c[d])||!of(a[c[d]],b[c[d]]))return!1;return!0}
    var rf=Ya&&"documentMode"in document&&11>=document.documentMode,sf={select:{phasedRegistrationNames:{bubbled:"onSelect",captured:"onSelectCapture"},dependencies:"blur contextmenu dragend focus keydown keyup mousedown mouseup selectionchange".split(" ")}},tf=null,uf=null,vf=null,wf=!1;
    function xf(a,b){var c=b.window===b?b.document:9===b.nodeType?b:b.ownerDocument;if(wf||null==tf||tf!==be(c))return null;c=tf;"selectionStart"in c&&ge(c)?c={start:c.selectionStart,end:c.selectionEnd}:(c=(c.ownerDocument&&c.ownerDocument.defaultView||window).getSelection(),c={anchorNode:c.anchorNode,anchorOffset:c.anchorOffset,focusNode:c.focusNode,focusOffset:c.focusOffset});return vf&&qf(vf,c)?null:(vf=c,a=E$1.getPooled(sf.select,uf,a,b),a.type="select",a.target=tf,Sc(a),a)}
    var yf={eventTypes:sf,extractEvents:function(a,b,c,d){var e=d.window===d?d.document:9===d.nodeType?d:d.ownerDocument,f;if(!(f=!e)){a:{e=xc(e);f=ja.onSelect;for(var g=0;g<f.length;g++)if(!e.has(f[g])){e=!1;break a}e=!0;}f=!e;}if(f)return null;e=b?xe(b):window;switch(a){case "focus":if(Ue(e)||"true"===e.contentEditable)tf=e,uf=b,vf=null;break;case "blur":vf=uf=tf=null;break;case "mousedown":wf=!0;break;case "contextmenu":case "mouseup":case "dragend":return wf=!1,xf(c,d);case "selectionchange":if(rf)break;
    case "keydown":case "keyup":return xf(c,d)}return null}};Ca.injectEventPluginOrder("ResponderEventPlugin SimpleEventPlugin EnterLeaveEventPlugin ChangeEventPlugin SelectEventPlugin BeforeInputEventPlugin".split(" "));var zf=Cc;sa=ye;ua=zf;va=xe;Ca.injectEventPluginsByName({SimpleEventPlugin:Ed,EnterLeaveEventPlugin:mf,ChangeEventPlugin:jf,SelectEventPlugin:yf,BeforeInputEventPlugin:Se});var Af=[],Bf=-1;function G$1(a){0>Bf||(a.current=Af[Bf],Af[Bf]=null,Bf--);}
    function I$1(a,b){Bf++;Af[Bf]=a.current;a.current=b;}var Cf={},J$1={current:Cf},K$1={current:!1},Df=Cf;function Ef(a,b){var c=a.type.contextTypes;if(!c)return Cf;var d=a.stateNode;if(d&&d.__reactInternalMemoizedUnmaskedChildContext===b)return d.__reactInternalMemoizedMaskedChildContext;var e={},f;for(f in c)e[f]=b[f];d&&(a=a.stateNode,a.__reactInternalMemoizedUnmaskedChildContext=b,a.__reactInternalMemoizedMaskedChildContext=e);return e}function L$1(a){a=a.childContextTypes;return null!==a&&void 0!==a}
    function Ff(a){G$1(K$1,a);G$1(J$1,a);}function Gf(a){G$1(K$1,a);G$1(J$1,a);}function Hf(a,b,c){if(J$1.current!==Cf)throw Error(u$1(168));I$1(J$1,b,a);I$1(K$1,c,a);}function If(a,b,c){var d=a.stateNode;a=b.childContextTypes;if("function"!==typeof d.getChildContext)return c;d=d.getChildContext();for(var e in d)if(!(e in a))throw Error(u$1(108,Wa(b)||"Unknown",e));return objectAssign({},c,{},d)}function Jf(a){var b=a.stateNode;b=b&&b.__reactInternalMemoizedMergedChildContext||Cf;Df=J$1.current;I$1(J$1,b,a);I$1(K$1,K$1.current,a);return!0}
    function Kf(a,b,c){var d=a.stateNode;if(!d)throw Error(u$1(169));c?(b=If(a,b,Df),d.__reactInternalMemoizedMergedChildContext=b,G$1(K$1,a),G$1(J$1,a),I$1(J$1,b,a)):G$1(K$1,a);I$1(K$1,c,a);}
    var Lf=scheduler.unstable_runWithPriority,Mf=scheduler.unstable_scheduleCallback,Nf=scheduler.unstable_cancelCallback,Of=scheduler.unstable_shouldYield,Pf=scheduler.unstable_requestPaint,Qf=scheduler.unstable_now,Rf=scheduler.unstable_getCurrentPriorityLevel,Sf=scheduler.unstable_ImmediatePriority,Tf=scheduler.unstable_UserBlockingPriority,Uf=scheduler.unstable_NormalPriority,Vf=scheduler.unstable_LowPriority,Wf=scheduler.unstable_IdlePriority,Xf={},Yf=void 0!==Pf?Pf:function(){},Zf=null,$f=null,ag=!1,bg=Qf(),cg=1E4>bg?Qf:function(){return Qf()-bg};
    function dg(){switch(Rf()){case Sf:return 99;case Tf:return 98;case Uf:return 97;case Vf:return 96;case Wf:return 95;default:throw Error(u$1(332));}}function eg(a){switch(a){case 99:return Sf;case 98:return Tf;case 97:return Uf;case 96:return Vf;case 95:return Wf;default:throw Error(u$1(332));}}function fg(a,b){a=eg(a);return Lf(a,b)}function gg(a,b,c){a=eg(a);return Mf(a,b,c)}function hg(a){null===Zf?(Zf=[a],$f=Mf(Sf,ig)):Zf.push(a);return Xf}function jg(){if(null!==$f){var a=$f;$f=null;Nf(a);}ig();}
    function ig(){if(!ag&&null!==Zf){ag=!0;var a=0;try{var b=Zf;fg(99,function(){for(;a<b.length;a++){var c=b[a];do c=c(!0);while(null!==c)}});Zf=null;}catch(c){throw null!==Zf&&(Zf=Zf.slice(a+1)),Mf(Sf,jg),c;}finally{ag=!1;}}}var kg=3;function lg(a,b,c){c/=10;return 1073741821-(((1073741821-a+b/10)/c|0)+1)*c}function mg(a,b){if(a&&a.defaultProps){b=objectAssign({},b);a=a.defaultProps;for(var c in a)void 0===b[c]&&(b[c]=a[c]);}return b}var ng={current:null},og=null,pg=null,qg=null;function rg(){qg=pg=og=null;}
    function sg(a,b){var c=a.type._context;I$1(ng,c._currentValue,a);c._currentValue=b;}function tg(a){var b=ng.current;G$1(ng,a);a.type._context._currentValue=b;}function ug(a,b){for(;null!==a;){var c=a.alternate;if(a.childExpirationTime<b)a.childExpirationTime=b,null!==c&&c.childExpirationTime<b&&(c.childExpirationTime=b);else if(null!==c&&c.childExpirationTime<b)c.childExpirationTime=b;else break;a=a.return;}}
    function vg(a,b){og=a;qg=pg=null;a=a.dependencies;null!==a&&null!==a.firstContext&&(a.expirationTime>=b&&(wg=!0),a.firstContext=null);}function xg(a,b){if(qg!==a&&!1!==b&&0!==b){if("number"!==typeof b||1073741823===b)qg=a,b=1073741823;b={context:a,observedBits:b,next:null};if(null===pg){if(null===og)throw Error(u$1(308));pg=b;og.dependencies={expirationTime:0,firstContext:b,responders:null};}else pg=pg.next=b;}return a._currentValue}var yg=!1;
    function zg(a){return{baseState:a,firstUpdate:null,lastUpdate:null,firstCapturedUpdate:null,lastCapturedUpdate:null,firstEffect:null,lastEffect:null,firstCapturedEffect:null,lastCapturedEffect:null}}function Ag(a){return{baseState:a.baseState,firstUpdate:a.firstUpdate,lastUpdate:a.lastUpdate,firstCapturedUpdate:null,lastCapturedUpdate:null,firstEffect:null,lastEffect:null,firstCapturedEffect:null,lastCapturedEffect:null}}
    function Bg(a,b){return{expirationTime:a,suspenseConfig:b,tag:0,payload:null,callback:null,next:null,nextEffect:null}}function Cg(a,b){null===a.lastUpdate?a.firstUpdate=a.lastUpdate=b:(a.lastUpdate.next=b,a.lastUpdate=b);}
    function Dg(a,b){var c=a.alternate;if(null===c){var d=a.updateQueue;var e=null;null===d&&(d=a.updateQueue=zg(a.memoizedState));}else d=a.updateQueue,e=c.updateQueue,null===d?null===e?(d=a.updateQueue=zg(a.memoizedState),e=c.updateQueue=zg(c.memoizedState)):d=a.updateQueue=Ag(e):null===e&&(e=c.updateQueue=Ag(d));null===e||d===e?Cg(d,b):null===d.lastUpdate||null===e.lastUpdate?(Cg(d,b),Cg(e,b)):(Cg(d,b),e.lastUpdate=b);}
    function Eg(a,b){var c=a.updateQueue;c=null===c?a.updateQueue=zg(a.memoizedState):Fg(a,c);null===c.lastCapturedUpdate?c.firstCapturedUpdate=c.lastCapturedUpdate=b:(c.lastCapturedUpdate.next=b,c.lastCapturedUpdate=b);}function Fg(a,b){var c=a.alternate;null!==c&&b===c.updateQueue&&(b=a.updateQueue=Ag(b));return b}
    function Gg(a,b,c,d,e,f){switch(c.tag){case 1:return a=c.payload,"function"===typeof a?a.call(f,d,e):a;case 3:a.effectTag=a.effectTag&-4097|64;case 0:a=c.payload;e="function"===typeof a?a.call(f,d,e):a;if(null===e||void 0===e)break;return objectAssign({},d,e);case 2:yg=!0;}return d}
    function Hg(a,b,c,d,e){yg=!1;b=Fg(a,b);for(var f=b.baseState,g=null,h=0,k=b.firstUpdate,l=f;null!==k;){var m=k.expirationTime;m<e?(null===g&&(g=k,f=l),h<m&&(h=m)):(Ig(m,k.suspenseConfig),l=Gg(a,b,k,l,c,d),null!==k.callback&&(a.effectTag|=32,k.nextEffect=null,null===b.lastEffect?b.firstEffect=b.lastEffect=k:(b.lastEffect.nextEffect=k,b.lastEffect=k)));k=k.next;}m=null;for(k=b.firstCapturedUpdate;null!==k;){var C=k.expirationTime;C<e?(null===m&&(m=k,null===g&&(f=l)),h<C&&(h=C)):(l=Gg(a,b,k,l,c,d),null!==
    k.callback&&(a.effectTag|=32,k.nextEffect=null,null===b.lastCapturedEffect?b.firstCapturedEffect=b.lastCapturedEffect=k:(b.lastCapturedEffect.nextEffect=k,b.lastCapturedEffect=k)));k=k.next;}null===g&&(b.lastUpdate=null);null===m?b.lastCapturedUpdate=null:a.effectTag|=32;null===g&&null===m&&(f=l);b.baseState=f;b.firstUpdate=g;b.firstCapturedUpdate=m;Jg(h);a.expirationTime=h;a.memoizedState=l;}
    function Kg(a,b,c){null!==b.firstCapturedUpdate&&(null!==b.lastUpdate&&(b.lastUpdate.next=b.firstCapturedUpdate,b.lastUpdate=b.lastCapturedUpdate),b.firstCapturedUpdate=b.lastCapturedUpdate=null);Lg(b.firstEffect,c);b.firstEffect=b.lastEffect=null;Lg(b.firstCapturedEffect,c);b.firstCapturedEffect=b.lastCapturedEffect=null;}function Lg(a,b){for(;null!==a;){var c=a.callback;if(null!==c){a.callback=null;var d=b;if("function"!==typeof c)throw Error(u$1(191,c));c.call(d);}a=a.nextEffect;}}
    var Mg=Ea.ReactCurrentBatchConfig,Ng=(new react.Component).refs;function Og(a,b,c,d){b=a.memoizedState;c=c(d,b);c=null===c||void 0===c?b:objectAssign({},b,c);a.memoizedState=c;d=a.updateQueue;null!==d&&0===a.expirationTime&&(d.baseState=c);}
    var Sg={isMounted:function(a){return(a=a._reactInternalFiber)?ec(a)===a:!1},enqueueSetState:function(a,b,c){a=a._reactInternalFiber;var d=Pg(),e=Mg.suspense;d=Qg(d,a,e);e=Bg(d,e);e.payload=b;void 0!==c&&null!==c&&(e.callback=c);Dg(a,e);Rg(a,d);},enqueueReplaceState:function(a,b,c){a=a._reactInternalFiber;var d=Pg(),e=Mg.suspense;d=Qg(d,a,e);e=Bg(d,e);e.tag=1;e.payload=b;void 0!==c&&null!==c&&(e.callback=c);Dg(a,e);Rg(a,d);},enqueueForceUpdate:function(a,b){a=a._reactInternalFiber;var c=Pg(),d=Mg.suspense;
    c=Qg(c,a,d);d=Bg(c,d);d.tag=2;void 0!==b&&null!==b&&(d.callback=b);Dg(a,d);Rg(a,c);}};function Tg(a,b,c,d,e,f,g){a=a.stateNode;return"function"===typeof a.shouldComponentUpdate?a.shouldComponentUpdate(d,f,g):b.prototype&&b.prototype.isPureReactComponent?!qf(c,d)||!qf(e,f):!0}
    function Ug(a,b,c){var d=!1,e=Cf;var f=b.contextType;"object"===typeof f&&null!==f?f=xg(f):(e=L$1(b)?Df:J$1.current,d=b.contextTypes,f=(d=null!==d&&void 0!==d)?Ef(a,e):Cf);b=new b(c,f);a.memoizedState=null!==b.state&&void 0!==b.state?b.state:null;b.updater=Sg;a.stateNode=b;b._reactInternalFiber=a;d&&(a=a.stateNode,a.__reactInternalMemoizedUnmaskedChildContext=e,a.__reactInternalMemoizedMaskedChildContext=f);return b}
    function Vg(a,b,c,d){a=b.state;"function"===typeof b.componentWillReceiveProps&&b.componentWillReceiveProps(c,d);"function"===typeof b.UNSAFE_componentWillReceiveProps&&b.UNSAFE_componentWillReceiveProps(c,d);b.state!==a&&Sg.enqueueReplaceState(b,b.state,null);}
    function Wg(a,b,c,d){var e=a.stateNode;e.props=c;e.state=a.memoizedState;e.refs=Ng;var f=b.contextType;"object"===typeof f&&null!==f?e.context=xg(f):(f=L$1(b)?Df:J$1.current,e.context=Ef(a,f));f=a.updateQueue;null!==f&&(Hg(a,f,c,e,d),e.state=a.memoizedState);f=b.getDerivedStateFromProps;"function"===typeof f&&(Og(a,b,f,c),e.state=a.memoizedState);"function"===typeof b.getDerivedStateFromProps||"function"===typeof e.getSnapshotBeforeUpdate||"function"!==typeof e.UNSAFE_componentWillMount&&"function"!==
    typeof e.componentWillMount||(b=e.state,"function"===typeof e.componentWillMount&&e.componentWillMount(),"function"===typeof e.UNSAFE_componentWillMount&&e.UNSAFE_componentWillMount(),b!==e.state&&Sg.enqueueReplaceState(e,e.state,null),f=a.updateQueue,null!==f&&(Hg(a,f,c,e,d),e.state=a.memoizedState));"function"===typeof e.componentDidMount&&(a.effectTag|=4);}var Xg=Array.isArray;
    function Yg(a,b,c){a=c.ref;if(null!==a&&"function"!==typeof a&&"object"!==typeof a){if(c._owner){c=c._owner;if(c){if(1!==c.tag)throw Error(u$1(309));var d=c.stateNode;}if(!d)throw Error(u$1(147,a));var e=""+a;if(null!==b&&null!==b.ref&&"function"===typeof b.ref&&b.ref._stringRef===e)return b.ref;b=function(a){var b=d.refs;b===Ng&&(b=d.refs={});null===a?delete b[e]:b[e]=a;};b._stringRef=e;return b}if("string"!==typeof a)throw Error(u$1(284));if(!c._owner)throw Error(u$1(290,a));}return a}
    function Zg(a,b){if("textarea"!==a.type)throw Error(u$1(31,"[object Object]"===Object.prototype.toString.call(b)?"object with keys {"+Object.keys(b).join(", ")+"}":b,""));}
    function $g(a){function b(b,c){if(a){var d=b.lastEffect;null!==d?(d.nextEffect=c,b.lastEffect=c):b.firstEffect=b.lastEffect=c;c.nextEffect=null;c.effectTag=8;}}function c(c,d){if(!a)return null;for(;null!==d;)b(c,d),d=d.sibling;return null}function d(a,b){for(a=new Map;null!==b;)null!==b.key?a.set(b.key,b):a.set(b.index,b),b=b.sibling;return a}function e(a,b,c){a=ah(a,b,c);a.index=0;a.sibling=null;return a}function f(b,c,d){b.index=d;if(!a)return c;d=b.alternate;if(null!==d)return d=d.index,d<c?(b.effectTag=
    2,c):d;b.effectTag=2;return c}function g(b){a&&null===b.alternate&&(b.effectTag=2);return b}function h(a,b,c,d){if(null===b||6!==b.tag)return b=bh(c,a.mode,d),b.return=a,b;b=e(b,c,d);b.return=a;return b}function k(a,b,c,d){if(null!==b&&b.elementType===c.type)return d=e(b,c.props,d),d.ref=Yg(a,b,c),d.return=a,d;d=ch(c.type,c.key,c.props,null,a.mode,d);d.ref=Yg(a,b,c);d.return=a;return d}function l(a,b,c,d){if(null===b||4!==b.tag||b.stateNode.containerInfo!==c.containerInfo||b.stateNode.implementation!==
    c.implementation)return b=dh(c,a.mode,d),b.return=a,b;b=e(b,c.children||[],d);b.return=a;return b}function m(a,b,c,d,f){if(null===b||7!==b.tag)return b=eh(c,a.mode,d,f),b.return=a,b;b=e(b,c,d);b.return=a;return b}function C(a,b,c){if("string"===typeof b||"number"===typeof b)return b=bh(""+b,a.mode,c),b.return=a,b;if("object"===typeof b&&null!==b){switch(b.$$typeof){case Ga:return c=ch(b.type,b.key,b.props,null,a.mode,c),c.ref=Yg(a,null,b),c.return=a,c;case Ha:return b=dh(b,a.mode,c),b.return=a,b}if(Xg(b)||
    Ua(b))return b=eh(b,a.mode,c,null),b.return=a,b;Zg(a,b);}return null}function y(a,b,c,d){var e=null!==b?b.key:null;if("string"===typeof c||"number"===typeof c)return null!==e?null:h(a,b,""+c,d);if("object"===typeof c&&null!==c){switch(c.$$typeof){case Ga:return c.key===e?c.type===Ia?m(a,b,c.props.children,d,e):k(a,b,c,d):null;case Ha:return c.key===e?l(a,b,c,d):null}if(Xg(c)||Ua(c))return null!==e?null:m(a,b,c,d,null);Zg(a,c);}return null}function H(a,b,c,d,e){if("string"===typeof d||"number"===typeof d)return a=
    a.get(c)||null,h(b,a,""+d,e);if("object"===typeof d&&null!==d){switch(d.$$typeof){case Ga:return a=a.get(null===d.key?c:d.key)||null,d.type===Ia?m(b,a,d.props.children,e,d.key):k(b,a,d,e);case Ha:return a=a.get(null===d.key?c:d.key)||null,l(b,a,d,e)}if(Xg(d)||Ua(d))return a=a.get(c)||null,m(b,a,d,e,null);Zg(b,d);}return null}function z(e,g,h,k){for(var l=null,m=null,r=g,x=g=0,A=null;null!==r&&x<h.length;x++){r.index>x?(A=r,r=null):A=r.sibling;var p=y(e,r,h[x],k);if(null===p){null===r&&(r=A);break}a&&
    r&&null===p.alternate&&b(e,r);g=f(p,g,x);null===m?l=p:m.sibling=p;m=p;r=A;}if(x===h.length)return c(e,r),l;if(null===r){for(;x<h.length;x++)r=C(e,h[x],k),null!==r&&(g=f(r,g,x),null===m?l=r:m.sibling=r,m=r);return l}for(r=d(e,r);x<h.length;x++)A=H(r,e,x,h[x],k),null!==A&&(a&&null!==A.alternate&&r.delete(null===A.key?x:A.key),g=f(A,g,x),null===m?l=A:m.sibling=A,m=A);a&&r.forEach(function(a){return b(e,a)});return l}function ta(e,g,h,k){var l=Ua(h);if("function"!==typeof l)throw Error(u$1(150));h=l.call(h);
    if(null==h)throw Error(u$1(151));for(var m=l=null,r=g,x=g=0,A=null,p=h.next();null!==r&&!p.done;x++,p=h.next()){r.index>x?(A=r,r=null):A=r.sibling;var z=y(e,r,p.value,k);if(null===z){null===r&&(r=A);break}a&&r&&null===z.alternate&&b(e,r);g=f(z,g,x);null===m?l=z:m.sibling=z;m=z;r=A;}if(p.done)return c(e,r),l;if(null===r){for(;!p.done;x++,p=h.next())p=C(e,p.value,k),null!==p&&(g=f(p,g,x),null===m?l=p:m.sibling=p,m=p);return l}for(r=d(e,r);!p.done;x++,p=h.next())p=H(r,e,x,p.value,k),null!==p&&(a&&null!==
    p.alternate&&r.delete(null===p.key?x:p.key),g=f(p,g,x),null===m?l=p:m.sibling=p,m=p);a&&r.forEach(function(a){return b(e,a)});return l}return function(a,d,f,h){var k="object"===typeof f&&null!==f&&f.type===Ia&&null===f.key;k&&(f=f.props.children);var l="object"===typeof f&&null!==f;if(l)switch(f.$$typeof){case Ga:a:{l=f.key;for(k=d;null!==k;){if(k.key===l)if(7===k.tag?f.type===Ia:k.elementType===f.type){c(a,k.sibling);d=e(k,f.type===Ia?f.props.children:f.props,h);d.ref=Yg(a,k,f);d.return=a;a=d;break a}else{c(a,
    k);break}else b(a,k);k=k.sibling;}f.type===Ia?(d=eh(f.props.children,a.mode,h,f.key),d.return=a,a=d):(h=ch(f.type,f.key,f.props,null,a.mode,h),h.ref=Yg(a,d,f),h.return=a,a=h);}return g(a);case Ha:a:{for(k=f.key;null!==d;){if(d.key===k)if(4===d.tag&&d.stateNode.containerInfo===f.containerInfo&&d.stateNode.implementation===f.implementation){c(a,d.sibling);d=e(d,f.children||[],h);d.return=a;a=d;break a}else{c(a,d);break}else b(a,d);d=d.sibling;}d=dh(f,a.mode,h);d.return=a;a=d;}return g(a)}if("string"===
    typeof f||"number"===typeof f)return f=""+f,null!==d&&6===d.tag?(c(a,d.sibling),d=e(d,f,h),d.return=a,a=d):(c(a,d),d=bh(f,a.mode,h),d.return=a,a=d),g(a);if(Xg(f))return z(a,d,f,h);if(Ua(f))return ta(a,d,f,h);l&&Zg(a,f);if("undefined"===typeof f&&!k)switch(a.tag){case 1:case 0:throw a=a.type,Error(u$1(152,a.displayName||a.name||"Component"));}return c(a,d)}}var fh=$g(!0),gh=$g(!1),hh={},ih={current:hh},jh={current:hh},kh={current:hh};function lh(a){if(a===hh)throw Error(u$1(174));return a}
    function mh(a,b){I$1(kh,b,a);I$1(jh,a,a);I$1(ih,hh,a);var c=b.nodeType;switch(c){case 9:case 11:b=(b=b.documentElement)?b.namespaceURI:Qb(null,"");break;default:c=8===c?b.parentNode:b,b=c.namespaceURI||null,c=c.tagName,b=Qb(b,c);}G$1(ih,a);I$1(ih,b,a);}function nh(a){G$1(ih,a);G$1(jh,a);G$1(kh,a);}function oh(a){lh(kh.current);var b=lh(ih.current);var c=Qb(b,a.type);b!==c&&(I$1(jh,a,a),I$1(ih,c,a));}function ph(a){jh.current===a&&(G$1(ih,a),G$1(jh,a));}var M$1={current:0};
    function qh(a){for(var b=a;null!==b;){if(13===b.tag){var c=b.memoizedState;if(null!==c&&(c=c.dehydrated,null===c||c.data===je||c.data===ke))return b}else if(19===b.tag&&void 0!==b.memoizedProps.revealOrder){if(0!==(b.effectTag&64))return b}else if(null!==b.child){b.child.return=b;b=b.child;continue}if(b===a)break;for(;null===b.sibling;){if(null===b.return||b.return===a)return null;b=b.return;}b.sibling.return=b.return;b=b.sibling;}return null}function rh(a,b){return{responder:a,props:b}}
    var sh=Ea.ReactCurrentDispatcher,N$1=Ea.ReactCurrentBatchConfig,th=0,uh=null,O$1=null,vh=null,wh=null,P$1=null,xh=null,yh=0,zh=null,Ah=0,Bh=!1,Ch=null,Gh=0;function Q$1(){throw Error(u$1(321));}function Hh(a,b){if(null===b)return!1;for(var c=0;c<b.length&&c<a.length;c++)if(!of(a[c],b[c]))return!1;return!0}
    function Ih(a,b,c,d,e,f){th=f;uh=b;vh=null!==a?a.memoizedState:null;sh.current=null===vh?Jh:Kh;b=c(d,e);if(Bh){do Bh=!1,Gh+=1,vh=null!==a?a.memoizedState:null,xh=wh,zh=P$1=O$1=null,sh.current=Kh,b=c(d,e);while(Bh);Ch=null;Gh=0;}sh.current=Lh;a=uh;a.memoizedState=wh;a.expirationTime=yh;a.updateQueue=zh;a.effectTag|=Ah;a=null!==O$1&&null!==O$1.next;th=0;xh=P$1=wh=vh=O$1=uh=null;yh=0;zh=null;Ah=0;if(a)throw Error(u$1(300));return b}
    function Mh(){sh.current=Lh;th=0;xh=P$1=wh=vh=O$1=uh=null;yh=0;zh=null;Ah=0;Bh=!1;Ch=null;Gh=0;}function Nh(){var a={memoizedState:null,baseState:null,queue:null,baseUpdate:null,next:null};null===P$1?wh=P$1=a:P$1=P$1.next=a;return P$1}function Oh(){if(null!==xh)P$1=xh,xh=P$1.next,O$1=vh,vh=null!==O$1?O$1.next:null;else{if(null===vh)throw Error(u$1(310));O$1=vh;var a={memoizedState:O$1.memoizedState,baseState:O$1.baseState,queue:O$1.queue,baseUpdate:O$1.baseUpdate,next:null};P$1=null===P$1?wh=a:P$1.next=a;vh=O$1.next;}return P$1}
    function Ph(a,b){return"function"===typeof b?b(a):b}
    function Qh(a){var b=Oh(),c=b.queue;if(null===c)throw Error(u$1(311));c.lastRenderedReducer=a;if(0<Gh){var d=c.dispatch;if(null!==Ch){var e=Ch.get(c);if(void 0!==e){Ch.delete(c);var f=b.memoizedState;do f=a(f,e.action),e=e.next;while(null!==e);of(f,b.memoizedState)||(wg=!0);b.memoizedState=f;b.baseUpdate===c.last&&(b.baseState=f);c.lastRenderedState=f;return[f,d]}}return[b.memoizedState,d]}d=c.last;var g=b.baseUpdate;f=b.baseState;null!==g?(null!==d&&(d.next=null),d=g.next):d=null!==d?d.next:null;if(null!==
    d){var h=e=null,k=d,l=!1;do{var m=k.expirationTime;m<th?(l||(l=!0,h=g,e=f),m>yh&&(yh=m,Jg(yh))):(Ig(m,k.suspenseConfig),f=k.eagerReducer===a?k.eagerState:a(f,k.action));g=k;k=k.next;}while(null!==k&&k!==d);l||(h=g,e=f);of(f,b.memoizedState)||(wg=!0);b.memoizedState=f;b.baseUpdate=h;b.baseState=e;c.lastRenderedState=f;}return[b.memoizedState,c.dispatch]}
    function Rh(a){var b=Nh();"function"===typeof a&&(a=a());b.memoizedState=b.baseState=a;a=b.queue={last:null,dispatch:null,lastRenderedReducer:Ph,lastRenderedState:a};a=a.dispatch=Sh.bind(null,uh,a);return[b.memoizedState,a]}function Th(a){return Qh(Ph,a)}function Uh(a,b,c,d){a={tag:a,create:b,destroy:c,deps:d,next:null};null===zh?(zh={lastEffect:null},zh.lastEffect=a.next=a):(b=zh.lastEffect,null===b?zh.lastEffect=a.next=a:(c=b.next,b.next=a,a.next=c,zh.lastEffect=a));return a}
    function Vh(a,b,c,d){var e=Nh();Ah|=a;e.memoizedState=Uh(b,c,void 0,void 0===d?null:d);}function Wh(a,b,c,d){var e=Oh();d=void 0===d?null:d;var f=void 0;if(null!==O$1){var g=O$1.memoizedState;f=g.destroy;if(null!==d&&Hh(d,g.deps)){Uh(0,c,f,d);return}}Ah|=a;e.memoizedState=Uh(b,c,f,d);}function Xh(a,b){return Vh(516,192,a,b)}function Yh(a,b){return Wh(516,192,a,b)}
    function Zh(a,b){if("function"===typeof b)return a=a(),b(a),function(){b(null);};if(null!==b&&void 0!==b)return a=a(),b.current=a,function(){b.current=null;}}function $h(){}function ai(a,b){Nh().memoizedState=[a,void 0===b?null:b];return a}function bi(a,b){var c=Oh();b=void 0===b?null:b;var d=c.memoizedState;if(null!==d&&null!==b&&Hh(b,d[1]))return d[0];c.memoizedState=[a,b];return a}
    function Sh(a,b,c){if(!(25>Gh))throw Error(u$1(301));var d=a.alternate;if(a===uh||null!==d&&d===uh)if(Bh=!0,a={expirationTime:th,suspenseConfig:null,action:c,eagerReducer:null,eagerState:null,next:null},null===Ch&&(Ch=new Map),c=Ch.get(b),void 0===c)Ch.set(b,a);else{for(b=c;null!==b.next;)b=b.next;b.next=a;}else{var e=Pg(),f=Mg.suspense;e=Qg(e,a,f);f={expirationTime:e,suspenseConfig:f,action:c,eagerReducer:null,eagerState:null,next:null};var g=b.last;if(null===g)f.next=f;else{var h=g.next;null!==h&&
    (f.next=h);g.next=f;}b.last=f;if(0===a.expirationTime&&(null===d||0===d.expirationTime)&&(d=b.lastRenderedReducer,null!==d))try{var k=b.lastRenderedState,l=d(k,c);f.eagerReducer=d;f.eagerState=l;if(of(l,k))return}catch(m){}finally{}Rg(a,e);}}
    var Lh={readContext:xg,useCallback:Q$1,useContext:Q$1,useEffect:Q$1,useImperativeHandle:Q$1,useLayoutEffect:Q$1,useMemo:Q$1,useReducer:Q$1,useRef:Q$1,useState:Q$1,useDebugValue:Q$1,useResponder:Q$1,useDeferredValue:Q$1,useTransition:Q$1},Jh={readContext:xg,useCallback:ai,useContext:xg,useEffect:Xh,useImperativeHandle:function(a,b,c){c=null!==c&&void 0!==c?c.concat([a]):null;return Vh(4,36,Zh.bind(null,b,a),c)},useLayoutEffect:function(a,b){return Vh(4,36,a,b)},useMemo:function(a,b){var c=Nh();b=void 0===b?null:b;a=a();c.memoizedState=
    [a,b];return a},useReducer:function(a,b,c){var d=Nh();b=void 0!==c?c(b):b;d.memoizedState=d.baseState=b;a=d.queue={last:null,dispatch:null,lastRenderedReducer:a,lastRenderedState:b};a=a.dispatch=Sh.bind(null,uh,a);return[d.memoizedState,a]},useRef:function(a){var b=Nh();a={current:a};return b.memoizedState=a},useState:Rh,useDebugValue:$h,useResponder:rh,useDeferredValue:function(a,b){var c=Rh(a),d=c[0],e=c[1];Xh(function(){scheduler.unstable_next(function(){var c=N$1.suspense;N$1.suspense=void 0===b?null:b;try{e(a);}finally{N$1.suspense=
    c;}});},[a,b]);return d},useTransition:function(a){var b=Rh(!1),c=b[0],d=b[1];return[ai(function(b){d(!0);scheduler.unstable_next(function(){var c=N$1.suspense;N$1.suspense=void 0===a?null:a;try{d(!1),b();}finally{N$1.suspense=c;}});},[a,c]),c]}},Kh={readContext:xg,useCallback:bi,useContext:xg,useEffect:Yh,useImperativeHandle:function(a,b,c){c=null!==c&&void 0!==c?c.concat([a]):null;return Wh(4,36,Zh.bind(null,b,a),c)},useLayoutEffect:function(a,b){return Wh(4,36,a,b)},useMemo:function(a,b){var c=Oh();b=void 0===b?
    null:b;var d=c.memoizedState;if(null!==d&&null!==b&&Hh(b,d[1]))return d[0];a=a();c.memoizedState=[a,b];return a},useReducer:Qh,useRef:function(){return Oh().memoizedState},useState:Th,useDebugValue:$h,useResponder:rh,useDeferredValue:function(a,b){var c=Th(a),d=c[0],e=c[1];Yh(function(){scheduler.unstable_next(function(){var c=N$1.suspense;N$1.suspense=void 0===b?null:b;try{e(a);}finally{N$1.suspense=c;}});},[a,b]);return d},useTransition:function(a){var b=Th(!1),c=b[0],d=b[1];return[bi(function(b){d(!0);scheduler.unstable_next(function(){var c=
    N$1.suspense;N$1.suspense=void 0===a?null:a;try{d(!1),b();}finally{N$1.suspense=c;}});},[a,c]),c]}},ci=null,di=null,ei=!1;function fi(a,b){var c=gi(5,null,null,0);c.elementType="DELETED";c.type="DELETED";c.stateNode=b;c.return=a;c.effectTag=8;null!==a.lastEffect?(a.lastEffect.nextEffect=c,a.lastEffect=c):a.firstEffect=a.lastEffect=c;}
    function hi(a,b){switch(a.tag){case 5:var c=a.type;b=1!==b.nodeType||c.toLowerCase()!==b.nodeName.toLowerCase()?null:b;return null!==b?(a.stateNode=b,!0):!1;case 6:return b=""===a.pendingProps||3!==b.nodeType?null:b,null!==b?(a.stateNode=b,!0):!1;case 13:return!1;default:return!1}}
    function ii(a){if(ei){var b=di;if(b){var c=b;if(!hi(a,b)){b=re(c.nextSibling);if(!b||!hi(a,b)){a.effectTag=a.effectTag&-1025|2;ei=!1;ci=a;return}fi(ci,c);}ci=a;di=re(b.firstChild);}else a.effectTag=a.effectTag&-1025|2,ei=!1,ci=a;}}function ji(a){for(a=a.return;null!==a&&5!==a.tag&&3!==a.tag&&13!==a.tag;)a=a.return;ci=a;}
    function ki(a){if(a!==ci)return!1;if(!ei)return ji(a),ei=!0,!1;var b=a.type;if(5!==a.tag||"head"!==b&&"body"!==b&&!oe(b,a.memoizedProps))for(b=di;b;)fi(a,b),b=re(b.nextSibling);ji(a);if(13===a.tag){a=a.memoizedState;a=null!==a?a.dehydrated:null;if(!a)throw Error(u$1(317));a:{a=a.nextSibling;for(b=0;a;){if(8===a.nodeType){var c=a.data;if(c===ie){if(0===b){di=re(a.nextSibling);break a}b--;}else c!==he&&c!==ke&&c!==je||b++;}a=a.nextSibling;}di=null;}}else di=ci?re(a.stateNode.nextSibling):null;return!0}
    function li(){di=ci=null;ei=!1;}var mi=Ea.ReactCurrentOwner,wg=!1;function R$1(a,b,c,d){b.child=null===a?gh(b,null,c,d):fh(b,a.child,c,d);}function ni(a,b,c,d,e){c=c.render;var f=b.ref;vg(b,e);d=Ih(a,b,c,d,f,e);if(null!==a&&!wg)return b.updateQueue=a.updateQueue,b.effectTag&=-517,a.expirationTime<=e&&(a.expirationTime=0),oi(a,b,e);b.effectTag|=1;R$1(a,b,d,e);return b.child}
    function pi(a,b,c,d,e,f){if(null===a){var g=c.type;if("function"===typeof g&&!qi(g)&&void 0===g.defaultProps&&null===c.compare&&void 0===c.defaultProps)return b.tag=15,b.type=g,ri(a,b,g,d,e,f);a=ch(c.type,null,d,null,b.mode,f);a.ref=b.ref;a.return=b;return b.child=a}g=a.child;if(e<f&&(e=g.memoizedProps,c=c.compare,c=null!==c?c:qf,c(e,d)&&a.ref===b.ref))return oi(a,b,f);b.effectTag|=1;a=ah(g,d,f);a.ref=b.ref;a.return=b;return b.child=a}
    function ri(a,b,c,d,e,f){return null!==a&&qf(a.memoizedProps,d)&&a.ref===b.ref&&(wg=!1,e<f)?oi(a,b,f):si(a,b,c,d,f)}function ti(a,b){var c=b.ref;if(null===a&&null!==c||null!==a&&a.ref!==c)b.effectTag|=128;}function si(a,b,c,d,e){var f=L$1(c)?Df:J$1.current;f=Ef(b,f);vg(b,e);c=Ih(a,b,c,d,f,e);if(null!==a&&!wg)return b.updateQueue=a.updateQueue,b.effectTag&=-517,a.expirationTime<=e&&(a.expirationTime=0),oi(a,b,e);b.effectTag|=1;R$1(a,b,c,e);return b.child}
    function ui(a,b,c,d,e){if(L$1(c)){var f=!0;Jf(b);}else f=!1;vg(b,e);if(null===b.stateNode)null!==a&&(a.alternate=null,b.alternate=null,b.effectTag|=2),Ug(b,c,d,e),Wg(b,c,d,e),d=!0;else if(null===a){var g=b.stateNode,h=b.memoizedProps;g.props=h;var k=g.context,l=c.contextType;"object"===typeof l&&null!==l?l=xg(l):(l=L$1(c)?Df:J$1.current,l=Ef(b,l));var m=c.getDerivedStateFromProps,C="function"===typeof m||"function"===typeof g.getSnapshotBeforeUpdate;C||"function"!==typeof g.UNSAFE_componentWillReceiveProps&&
    "function"!==typeof g.componentWillReceiveProps||(h!==d||k!==l)&&Vg(b,g,d,l);yg=!1;var y=b.memoizedState;k=g.state=y;var H=b.updateQueue;null!==H&&(Hg(b,H,d,g,e),k=b.memoizedState);h!==d||y!==k||K$1.current||yg?("function"===typeof m&&(Og(b,c,m,d),k=b.memoizedState),(h=yg||Tg(b,c,h,d,y,k,l))?(C||"function"!==typeof g.UNSAFE_componentWillMount&&"function"!==typeof g.componentWillMount||("function"===typeof g.componentWillMount&&g.componentWillMount(),"function"===typeof g.UNSAFE_componentWillMount&&
    g.UNSAFE_componentWillMount()),"function"===typeof g.componentDidMount&&(b.effectTag|=4)):("function"===typeof g.componentDidMount&&(b.effectTag|=4),b.memoizedProps=d,b.memoizedState=k),g.props=d,g.state=k,g.context=l,d=h):("function"===typeof g.componentDidMount&&(b.effectTag|=4),d=!1);}else g=b.stateNode,h=b.memoizedProps,g.props=b.type===b.elementType?h:mg(b.type,h),k=g.context,l=c.contextType,"object"===typeof l&&null!==l?l=xg(l):(l=L$1(c)?Df:J$1.current,l=Ef(b,l)),m=c.getDerivedStateFromProps,(C=
    "function"===typeof m||"function"===typeof g.getSnapshotBeforeUpdate)||"function"!==typeof g.UNSAFE_componentWillReceiveProps&&"function"!==typeof g.componentWillReceiveProps||(h!==d||k!==l)&&Vg(b,g,d,l),yg=!1,k=b.memoizedState,y=g.state=k,H=b.updateQueue,null!==H&&(Hg(b,H,d,g,e),y=b.memoizedState),h!==d||k!==y||K$1.current||yg?("function"===typeof m&&(Og(b,c,m,d),y=b.memoizedState),(m=yg||Tg(b,c,h,d,k,y,l))?(C||"function"!==typeof g.UNSAFE_componentWillUpdate&&"function"!==typeof g.componentWillUpdate||
    ("function"===typeof g.componentWillUpdate&&g.componentWillUpdate(d,y,l),"function"===typeof g.UNSAFE_componentWillUpdate&&g.UNSAFE_componentWillUpdate(d,y,l)),"function"===typeof g.componentDidUpdate&&(b.effectTag|=4),"function"===typeof g.getSnapshotBeforeUpdate&&(b.effectTag|=256)):("function"!==typeof g.componentDidUpdate||h===a.memoizedProps&&k===a.memoizedState||(b.effectTag|=4),"function"!==typeof g.getSnapshotBeforeUpdate||h===a.memoizedProps&&k===a.memoizedState||(b.effectTag|=256),b.memoizedProps=
    d,b.memoizedState=y),g.props=d,g.state=y,g.context=l,d=m):("function"!==typeof g.componentDidUpdate||h===a.memoizedProps&&k===a.memoizedState||(b.effectTag|=4),"function"!==typeof g.getSnapshotBeforeUpdate||h===a.memoizedProps&&k===a.memoizedState||(b.effectTag|=256),d=!1);return vi(a,b,c,d,f,e)}
    function vi(a,b,c,d,e,f){ti(a,b);var g=0!==(b.effectTag&64);if(!d&&!g)return e&&Kf(b,c,!1),oi(a,b,f);d=b.stateNode;mi.current=b;var h=g&&"function"!==typeof c.getDerivedStateFromError?null:d.render();b.effectTag|=1;null!==a&&g?(b.child=fh(b,a.child,null,f),b.child=fh(b,null,h,f)):R$1(a,b,h,f);b.memoizedState=d.state;e&&Kf(b,c,!0);return b.child}function wi(a){var b=a.stateNode;b.pendingContext?Hf(a,b.pendingContext,b.pendingContext!==b.context):b.context&&Hf(a,b.context,!1);mh(a,b.containerInfo);}
    var xi={dehydrated:null,retryTime:0};
    function yi(a,b,c){var d=b.mode,e=b.pendingProps,f=M$1.current,g=!1,h;(h=0!==(b.effectTag&64))||(h=0!==(f&2)&&(null===a||null!==a.memoizedState));h?(g=!0,b.effectTag&=-65):null!==a&&null===a.memoizedState||void 0===e.fallback||!0===e.unstable_avoidThisFallback||(f|=1);I$1(M$1,f&1,b);if(null===a){void 0!==e.fallback&&ii(b);if(g){g=e.fallback;e=eh(null,d,0,null);e.return=b;if(0===(b.mode&2))for(a=null!==b.memoizedState?b.child.child:b.child,e.child=a;null!==a;)a.return=e,a=a.sibling;c=eh(g,d,c,null);c.return=
    b;e.sibling=c;b.memoizedState=xi;b.child=e;return c}d=e.children;b.memoizedState=null;return b.child=gh(b,null,d,c)}if(null!==a.memoizedState){a=a.child;d=a.sibling;if(g){e=e.fallback;c=ah(a,a.pendingProps,0);c.return=b;if(0===(b.mode&2)&&(g=null!==b.memoizedState?b.child.child:b.child,g!==a.child))for(c.child=g;null!==g;)g.return=c,g=g.sibling;d=ah(d,e,d.expirationTime);d.return=b;c.sibling=d;c.childExpirationTime=0;b.memoizedState=xi;b.child=c;return d}c=fh(b,a.child,e.children,c);b.memoizedState=
    null;return b.child=c}a=a.child;if(g){g=e.fallback;e=eh(null,d,0,null);e.return=b;e.child=a;null!==a&&(a.return=e);if(0===(b.mode&2))for(a=null!==b.memoizedState?b.child.child:b.child,e.child=a;null!==a;)a.return=e,a=a.sibling;c=eh(g,d,c,null);c.return=b;e.sibling=c;c.effectTag|=2;e.childExpirationTime=0;b.memoizedState=xi;b.child=e;return c}b.memoizedState=null;return b.child=fh(b,a,e.children,c)}
    function zi(a,b){a.expirationTime<b&&(a.expirationTime=b);var c=a.alternate;null!==c&&c.expirationTime<b&&(c.expirationTime=b);ug(a.return,b);}function Ai(a,b,c,d,e,f){var g=a.memoizedState;null===g?a.memoizedState={isBackwards:b,rendering:null,last:d,tail:c,tailExpiration:0,tailMode:e,lastEffect:f}:(g.isBackwards=b,g.rendering=null,g.last=d,g.tail=c,g.tailExpiration=0,g.tailMode=e,g.lastEffect=f);}
    function Bi(a,b,c){var d=b.pendingProps,e=d.revealOrder,f=d.tail;R$1(a,b,d.children,c);d=M$1.current;if(0!==(d&2))d=d&1|2,b.effectTag|=64;else{if(null!==a&&0!==(a.effectTag&64))a:for(a=b.child;null!==a;){if(13===a.tag)null!==a.memoizedState&&zi(a,c);else if(19===a.tag)zi(a,c);else if(null!==a.child){a.child.return=a;a=a.child;continue}if(a===b)break a;for(;null===a.sibling;){if(null===a.return||a.return===b)break a;a=a.return;}a.sibling.return=a.return;a=a.sibling;}d&=1;}I$1(M$1,d,b);if(0===(b.mode&2))b.memoizedState=
    null;else switch(e){case "forwards":c=b.child;for(e=null;null!==c;)a=c.alternate,null!==a&&null===qh(a)&&(e=c),c=c.sibling;c=e;null===c?(e=b.child,b.child=null):(e=c.sibling,c.sibling=null);Ai(b,!1,e,c,f,b.lastEffect);break;case "backwards":c=null;e=b.child;for(b.child=null;null!==e;){a=e.alternate;if(null!==a&&null===qh(a)){b.child=e;break}a=e.sibling;e.sibling=c;c=e;e=a;}Ai(b,!0,c,null,f,b.lastEffect);break;case "together":Ai(b,!1,null,null,void 0,b.lastEffect);break;default:b.memoizedState=null;}return b.child}
    function oi(a,b,c){null!==a&&(b.dependencies=a.dependencies);var d=b.expirationTime;0!==d&&Jg(d);if(b.childExpirationTime<c)return null;if(null!==a&&b.child!==a.child)throw Error(u$1(153));if(null!==b.child){a=b.child;c=ah(a,a.pendingProps,a.expirationTime);b.child=c;for(c.return=b;null!==a.sibling;)a=a.sibling,c=c.sibling=ah(a,a.pendingProps,a.expirationTime),c.return=b;c.sibling=null;}return b.child}function Ci(a){a.effectTag|=4;}var Hi,Ii,Ji,Ki;
    Hi=function(a,b){for(var c=b.child;null!==c;){if(5===c.tag||6===c.tag)a.appendChild(c.stateNode);else if(4!==c.tag&&null!==c.child){c.child.return=c;c=c.child;continue}if(c===b)break;for(;null===c.sibling;){if(null===c.return||c.return===b)return;c=c.return;}c.sibling.return=c.return;c=c.sibling;}};Ii=function(){};
    Ji=function(a,b,c,d,e){var f=a.memoizedProps;if(f!==d){var g=b.stateNode;lh(ih.current);a=null;switch(c){case "input":f=Ab(g,f);d=Ab(g,d);a=[];break;case "option":f=Ib(g,f);d=Ib(g,d);a=[];break;case "select":f=objectAssign({},f,{value:void 0});d=objectAssign({},d,{value:void 0});a=[];break;case "textarea":f=Kb(g,f);d=Kb(g,d);a=[];break;default:"function"!==typeof f.onClick&&"function"===typeof d.onClick&&(g.onclick=ae);}Yd(c,d);var h,k;c=null;for(h in f)if(!d.hasOwnProperty(h)&&f.hasOwnProperty(h)&&null!=f[h])if("style"===
    h)for(k in g=f[h],g)g.hasOwnProperty(k)&&(c||(c={}),c[k]="");else"dangerouslySetInnerHTML"!==h&&"children"!==h&&"suppressContentEditableWarning"!==h&&"suppressHydrationWarning"!==h&&"autoFocus"!==h&&(ia.hasOwnProperty(h)?a||(a=[]):(a=a||[]).push(h,null));for(h in d){var l=d[h];g=null!=f?f[h]:void 0;if(d.hasOwnProperty(h)&&l!==g&&(null!=l||null!=g))if("style"===h)if(g){for(k in g)!g.hasOwnProperty(k)||l&&l.hasOwnProperty(k)||(c||(c={}),c[k]="");for(k in l)l.hasOwnProperty(k)&&g[k]!==l[k]&&(c||(c={}),
    c[k]=l[k]);}else c||(a||(a=[]),a.push(h,c)),c=l;else"dangerouslySetInnerHTML"===h?(l=l?l.__html:void 0,g=g?g.__html:void 0,null!=l&&g!==l&&(a=a||[]).push(h,""+l)):"children"===h?g===l||"string"!==typeof l&&"number"!==typeof l||(a=a||[]).push(h,""+l):"suppressContentEditableWarning"!==h&&"suppressHydrationWarning"!==h&&(ia.hasOwnProperty(h)?(null!=l&&$d(e,h),a||g===l||(a=[])):(a=a||[]).push(h,l));}c&&(a=a||[]).push("style",c);e=a;(b.updateQueue=e)&&Ci(b);}};Ki=function(a,b,c,d){c!==d&&Ci(b);};
    function Li(a,b){switch(a.tailMode){case "hidden":b=a.tail;for(var c=null;null!==b;)null!==b.alternate&&(c=b),b=b.sibling;null===c?a.tail=null:c.sibling=null;break;case "collapsed":c=a.tail;for(var d=null;null!==c;)null!==c.alternate&&(d=c),c=c.sibling;null===d?b||null===a.tail?a.tail=null:a.tail.sibling=null:d.sibling=null;}}
    function Mi(a){switch(a.tag){case 1:L$1(a.type)&&Ff(a);var b=a.effectTag;return b&4096?(a.effectTag=b&-4097|64,a):null;case 3:nh(a);Gf(a);b=a.effectTag;if(0!==(b&64))throw Error(u$1(285));a.effectTag=b&-4097|64;return a;case 5:return ph(a),null;case 13:return G$1(M$1,a),b=a.effectTag,b&4096?(a.effectTag=b&-4097|64,a):null;case 19:return G$1(M$1,a),null;case 4:return nh(a),null;case 10:return tg(a),null;default:return null}}function Ni(a,b){return{value:a,source:b,stack:Xa(b)}}
    var Oi="function"===typeof WeakSet?WeakSet:Set;function Pi(a,b){var c=b.source,d=b.stack;null===d&&null!==c&&(d=Xa(c));null!==c&&Wa(c.type);b=b.value;null!==a&&1===a.tag&&Wa(a.type);try{console.error(b);}catch(e){setTimeout(function(){throw e;});}}function Qi(a,b){try{b.props=a.memoizedProps,b.state=a.memoizedState,b.componentWillUnmount();}catch(c){Ri(a,c);}}function Si(a){var b=a.ref;if(null!==b)if("function"===typeof b)try{b(null);}catch(c){Ri(a,c);}else b.current=null;}
    function Ti(a,b){switch(b.tag){case 0:case 11:case 15:Ui(2,0,b);break;case 1:if(b.effectTag&256&&null!==a){var c=a.memoizedProps,d=a.memoizedState;a=b.stateNode;b=a.getSnapshotBeforeUpdate(b.elementType===b.type?c:mg(b.type,c),d);a.__reactInternalSnapshotBeforeUpdate=b;}break;case 3:case 5:case 6:case 4:case 17:break;default:throw Error(u$1(163));}}
    function Ui(a,b,c){c=c.updateQueue;c=null!==c?c.lastEffect:null;if(null!==c){var d=c=c.next;do{if(0!==(d.tag&a)){var e=d.destroy;d.destroy=void 0;void 0!==e&&e();}0!==(d.tag&b)&&(e=d.create,d.destroy=e());d=d.next;}while(d!==c)}}
    function Vi(a,b,c){"function"===typeof Wi&&Wi(b);switch(b.tag){case 0:case 11:case 14:case 15:a=b.updateQueue;if(null!==a&&(a=a.lastEffect,null!==a)){var d=a.next;fg(97<c?97:c,function(){var a=d;do{var c=a.destroy;if(void 0!==c){var g=b;try{c();}catch(h){Ri(g,h);}}a=a.next;}while(a!==d)});}break;case 1:Si(b);c=b.stateNode;"function"===typeof c.componentWillUnmount&&Qi(b,c);break;case 5:Si(b);break;case 4:Xi(a,b,c);}}
    function Yi(a){var b=a.alternate;a.return=null;a.child=null;a.memoizedState=null;a.updateQueue=null;a.dependencies=null;a.alternate=null;a.firstEffect=null;a.lastEffect=null;a.pendingProps=null;a.memoizedProps=null;null!==b&&Yi(b);}function Zi(a){return 5===a.tag||3===a.tag||4===a.tag}
    function $i(a){a:{for(var b=a.return;null!==b;){if(Zi(b)){var c=b;break a}b=b.return;}throw Error(u$1(160));}b=c.stateNode;switch(c.tag){case 5:var d=!1;break;case 3:b=b.containerInfo;d=!0;break;case 4:b=b.containerInfo;d=!0;break;default:throw Error(u$1(161));}c.effectTag&16&&(Tb(b,""),c.effectTag&=-17);a:b:for(c=a;;){for(;null===c.sibling;){if(null===c.return||Zi(c.return)){c=null;break a}c=c.return;}c.sibling.return=c.return;for(c=c.sibling;5!==c.tag&&6!==c.tag&&18!==c.tag;){if(c.effectTag&2)continue b;
    if(null===c.child||4===c.tag)continue b;else c.child.return=c,c=c.child;}if(!(c.effectTag&2)){c=c.stateNode;break a}}for(var e=a;;){var f=5===e.tag||6===e.tag;if(f){var g=f?e.stateNode:e.stateNode.instance;if(c)if(d){f=b;var h=g;g=c;8===f.nodeType?f.parentNode.insertBefore(h,g):f.insertBefore(h,g);}else b.insertBefore(g,c);else d?(h=b,8===h.nodeType?(f=h.parentNode,f.insertBefore(g,h)):(f=h,f.appendChild(g)),h=h._reactRootContainer,null!==h&&void 0!==h||null!==f.onclick||(f.onclick=ae)):b.appendChild(g);}else if(4!==
    e.tag&&null!==e.child){e.child.return=e;e=e.child;continue}if(e===a)break;for(;null===e.sibling;){if(null===e.return||e.return===a)return;e=e.return;}e.sibling.return=e.return;e=e.sibling;}}
    function Xi(a,b,c){for(var d=b,e=!1,f,g;;){if(!e){e=d.return;a:for(;;){if(null===e)throw Error(u$1(160));f=e.stateNode;switch(e.tag){case 5:g=!1;break a;case 3:f=f.containerInfo;g=!0;break a;case 4:f=f.containerInfo;g=!0;break a}e=e.return;}e=!0;}if(5===d.tag||6===d.tag){a:for(var h=a,k=d,l=c,m=k;;)if(Vi(h,m,l),null!==m.child&&4!==m.tag)m.child.return=m,m=m.child;else{if(m===k)break;for(;null===m.sibling;){if(null===m.return||m.return===k)break a;m=m.return;}m.sibling.return=m.return;m=m.sibling;}g?(h=
    f,k=d.stateNode,8===h.nodeType?h.parentNode.removeChild(k):h.removeChild(k)):f.removeChild(d.stateNode);}else if(4===d.tag){if(null!==d.child){f=d.stateNode.containerInfo;g=!0;d.child.return=d;d=d.child;continue}}else if(Vi(a,d,c),null!==d.child){d.child.return=d;d=d.child;continue}if(d===b)break;for(;null===d.sibling;){if(null===d.return||d.return===b)return;d=d.return;4===d.tag&&(e=!1);}d.sibling.return=d.return;d=d.sibling;}}
    function aj(a,b){switch(b.tag){case 0:case 11:case 14:case 15:Ui(4,8,b);break;case 1:break;case 5:var c=b.stateNode;if(null!=c){var d=b.memoizedProps,e=null!==a?a.memoizedProps:d;a=b.type;var f=b.updateQueue;b.updateQueue=null;if(null!==f){c[ve]=d;"input"===a&&"radio"===d.type&&null!=d.name&&Cb(c,d);Zd(a,e);b=Zd(a,d);for(e=0;e<f.length;e+=2){var g=f[e],h=f[e+1];"style"===g?Wd(c,h):"dangerouslySetInnerHTML"===g?Sb(c,h):"children"===g?Tb(c,h):vb(c,g,h,b);}switch(a){case "input":Eb(c,d);break;case "textarea":Mb(c,
    d);break;case "select":b=c._wrapperState.wasMultiple,c._wrapperState.wasMultiple=!!d.multiple,a=d.value,null!=a?Jb(c,!!d.multiple,a,!1):b!==!!d.multiple&&(null!=d.defaultValue?Jb(c,!!d.multiple,d.defaultValue,!0):Jb(c,!!d.multiple,d.multiple?[]:"",!1));}}}break;case 6:if(null===b.stateNode)throw Error(u$1(162));b.stateNode.nodeValue=b.memoizedProps;break;case 3:b=b.stateNode;b.hydrate&&(b.hydrate=!1,Lc(b.containerInfo));break;case 12:break;case 13:c=b;null===b.memoizedState?d=!1:(d=!0,c=b.child,bj=cg());
    if(null!==c)a:for(a=c;;){if(5===a.tag)f=a.stateNode,d?(f=f.style,"function"===typeof f.setProperty?f.setProperty("display","none","important"):f.display="none"):(f=a.stateNode,e=a.memoizedProps.style,e=void 0!==e&&null!==e&&e.hasOwnProperty("display")?e.display:null,f.style.display=Vd("display",e));else if(6===a.tag)a.stateNode.nodeValue=d?"":a.memoizedProps;else if(13===a.tag&&null!==a.memoizedState&&null===a.memoizedState.dehydrated){f=a.child.sibling;f.return=a;a=f;continue}else if(null!==a.child){a.child.return=
    a;a=a.child;continue}if(a===c)break a;for(;null===a.sibling;){if(null===a.return||a.return===c)break a;a=a.return;}a.sibling.return=a.return;a=a.sibling;}cj(b);break;case 19:cj(b);break;case 17:break;case 20:break;case 21:break;default:throw Error(u$1(163));}}function cj(a){var b=a.updateQueue;if(null!==b){a.updateQueue=null;var c=a.stateNode;null===c&&(c=a.stateNode=new Oi);b.forEach(function(b){var d=dj.bind(null,a,b);c.has(b)||(c.add(b),b.then(d,d));});}}var ej="function"===typeof WeakMap?WeakMap:Map;
    function fj(a,b,c){c=Bg(c,null);c.tag=3;c.payload={element:null};var d=b.value;c.callback=function(){gj||(gj=!0,hj=d);Pi(a,b);};return c}
    function ij(a,b,c){c=Bg(c,null);c.tag=3;var d=a.type.getDerivedStateFromError;if("function"===typeof d){var e=b.value;c.payload=function(){Pi(a,b);return d(e)};}var f=a.stateNode;null!==f&&"function"===typeof f.componentDidCatch&&(c.callback=function(){"function"!==typeof d&&(null===jj?jj=new Set([this]):jj.add(this),Pi(a,b));var c=b.stack;this.componentDidCatch(b.value,{componentStack:null!==c?c:""});});return c}
    var kj=Math.ceil,lj=Ea.ReactCurrentDispatcher,mj=Ea.ReactCurrentOwner,S$1=0,nj=8,oj=16,pj=32,qj=0,rj=1,sj=2,tj=3,uj=4,vj=5,T$1=S$1,U$1=null,V$1=null,W$1=0,X$1=qj,wj=null,xj=1073741823,yj=1073741823,zj=null,Aj=0,Bj=!1,bj=0,Cj=500,Y$1=null,gj=!1,hj=null,jj=null,Dj=!1,Ej=null,Fj=90,Gj=null,Hj=0,Ij=null,Jj=0;function Pg(){return(T$1&(oj|pj))!==S$1?1073741821-(cg()/10|0):0!==Jj?Jj:Jj=1073741821-(cg()/10|0)}
    function Qg(a,b,c){b=b.mode;if(0===(b&2))return 1073741823;var d=dg();if(0===(b&4))return 99===d?1073741823:1073741822;if((T$1&oj)!==S$1)return W$1;if(null!==c)a=lg(a,c.timeoutMs|0||5E3,250);else switch(d){case 99:a=1073741823;break;case 98:a=lg(a,150,100);break;case 97:case 96:a=lg(a,5E3,250);break;case 95:a=2;break;default:throw Error(u$1(326));}null!==U$1&&a===W$1&&--a;return a}
    function Rg(a,b){if(50<Hj)throw Hj=0,Ij=null,Error(u$1(185));a=Kj(a,b);if(null!==a){var c=dg();1073741823===b?(T$1&nj)!==S$1&&(T$1&(oj|pj))===S$1?Lj(a):(Z$1(a),T$1===S$1&&jg()):Z$1(a);(T$1&4)===S$1||98!==c&&99!==c||(null===Gj?Gj=new Map([[a,b]]):(c=Gj.get(a),(void 0===c||c>b)&&Gj.set(a,b)));}}
    function Kj(a,b){a.expirationTime<b&&(a.expirationTime=b);var c=a.alternate;null!==c&&c.expirationTime<b&&(c.expirationTime=b);var d=a.return,e=null;if(null===d&&3===a.tag)e=a.stateNode;else for(;null!==d;){c=d.alternate;d.childExpirationTime<b&&(d.childExpirationTime=b);null!==c&&c.childExpirationTime<b&&(c.childExpirationTime=b);if(null===d.return&&3===d.tag){e=d.stateNode;break}d=d.return;}null!==e&&(U$1===e&&(Jg(b),X$1===uj&&Mj(e,W$1)),Nj(e,b));return e}
    function Oj(a){var b=a.lastExpiredTime;if(0!==b)return b;b=a.firstPendingTime;if(!Pj(a,b))return b;b=a.lastPingedTime;a=a.nextKnownPendingLevel;return b>a?b:a}
    function Z$1(a){if(0!==a.lastExpiredTime)a.callbackExpirationTime=1073741823,a.callbackPriority=99,a.callbackNode=hg(Lj.bind(null,a));else{var b=Oj(a),c=a.callbackNode;if(0===b)null!==c&&(a.callbackNode=null,a.callbackExpirationTime=0,a.callbackPriority=90);else{var d=Pg();1073741823===b?d=99:1===b||2===b?d=95:(d=10*(1073741821-b)-10*(1073741821-d),d=0>=d?99:250>=d?98:5250>=d?97:95);if(null!==c){var e=a.callbackPriority;if(a.callbackExpirationTime===b&&e>=d)return;c!==Xf&&Nf(c);}a.callbackExpirationTime=
    b;a.callbackPriority=d;b=1073741823===b?hg(Lj.bind(null,a)):gg(d,Qj.bind(null,a),{timeout:10*(1073741821-b)-cg()});a.callbackNode=b;}}}
    function Qj(a,b){Jj=0;if(b)return b=Pg(),Rj(a,b),Z$1(a),null;var c=Oj(a);if(0!==c){b=a.callbackNode;if((T$1&(oj|pj))!==S$1)throw Error(u$1(327));Sj();a===U$1&&c===W$1||Tj(a,c);if(null!==V$1){var d=T$1;T$1|=oj;var e=Uj(a);do try{Vj();break}catch(h){Wj(a,h);}while(1);rg();T$1=d;lj.current=e;if(X$1===rj)throw b=wj,Tj(a,c),Mj(a,c),Z$1(a),b;if(null===V$1)switch(e=a.finishedWork=a.current.alternate,a.finishedExpirationTime=c,d=X$1,U$1=null,d){case qj:case rj:throw Error(u$1(345));case sj:Rj(a,2<c?2:c);break;case tj:Mj(a,c);d=a.lastSuspendedTime;
    c===d&&(a.nextKnownPendingLevel=Xj(e));if(1073741823===xj&&(e=bj+Cj-cg(),10<e)){if(Bj){var f=a.lastPingedTime;if(0===f||f>=c){a.lastPingedTime=c;Tj(a,c);break}}f=Oj(a);if(0!==f&&f!==c)break;if(0!==d&&d!==c){a.lastPingedTime=d;break}a.timeoutHandle=pe(Yj.bind(null,a),e);break}Yj(a);break;case uj:Mj(a,c);d=a.lastSuspendedTime;c===d&&(a.nextKnownPendingLevel=Xj(e));if(Bj&&(e=a.lastPingedTime,0===e||e>=c)){a.lastPingedTime=c;Tj(a,c);break}e=Oj(a);if(0!==e&&e!==c)break;if(0!==d&&d!==c){a.lastPingedTime=
    d;break}1073741823!==yj?d=10*(1073741821-yj)-cg():1073741823===xj?d=0:(d=10*(1073741821-xj)-5E3,e=cg(),c=10*(1073741821-c)-e,d=e-d,0>d&&(d=0),d=(120>d?120:480>d?480:1080>d?1080:1920>d?1920:3E3>d?3E3:4320>d?4320:1960*kj(d/1960))-d,c<d&&(d=c));if(10<d){a.timeoutHandle=pe(Yj.bind(null,a),d);break}Yj(a);break;case vj:if(1073741823!==xj&&null!==zj){f=xj;var g=zj;d=g.busyMinDurationMs|0;0>=d?d=0:(e=g.busyDelayMs|0,f=cg()-(10*(1073741821-f)-(g.timeoutMs|0||5E3)),d=f<=e?0:e+d-f);if(10<d){Mj(a,c);a.timeoutHandle=
    pe(Yj.bind(null,a),d);break}}Yj(a);break;default:throw Error(u$1(329));}Z$1(a);if(a.callbackNode===b)return Qj.bind(null,a)}}return null}
    function Lj(a){var b=a.lastExpiredTime;b=0!==b?b:1073741823;if(a.finishedExpirationTime===b)Yj(a);else{if((T$1&(oj|pj))!==S$1)throw Error(u$1(327));Sj();a===U$1&&b===W$1||Tj(a,b);if(null!==V$1){var c=T$1;T$1|=oj;var d=Uj(a);do try{Zj();break}catch(e){Wj(a,e);}while(1);rg();T$1=c;lj.current=d;if(X$1===rj)throw c=wj,Tj(a,b),Mj(a,b),Z$1(a),c;if(null!==V$1)throw Error(u$1(261));a.finishedWork=a.current.alternate;a.finishedExpirationTime=b;U$1=null;Yj(a);Z$1(a);}}return null}
    function ak(){if(null!==Gj){var a=Gj;Gj=null;a.forEach(function(a,c){Rj(c,a);Z$1(c);});jg();}}function bk(a,b){var c=T$1;T$1|=1;try{return a(b)}finally{T$1=c,T$1===S$1&&jg();}}function ck(a,b){var c=T$1;T$1&=-2;T$1|=nj;try{return a(b)}finally{T$1=c,T$1===S$1&&jg();}}
    function Tj(a,b){a.finishedWork=null;a.finishedExpirationTime=0;var c=a.timeoutHandle;-1!==c&&(a.timeoutHandle=-1,qe(c));if(null!==V$1)for(c=V$1.return;null!==c;){var d=c;switch(d.tag){case 1:var e=d.type.childContextTypes;null!==e&&void 0!==e&&Ff(d);break;case 3:nh(d);Gf(d);break;case 5:ph(d);break;case 4:nh(d);break;case 13:G$1(M$1,d);break;case 19:G$1(M$1,d);break;case 10:tg(d);}c=c.return;}U$1=a;V$1=ah(a.current,null,b);W$1=b;X$1=qj;wj=null;yj=xj=1073741823;zj=null;Aj=0;Bj=!1;}
    function Wj(a,b){do{try{rg();Mh();if(null===V$1||null===V$1.return)return X$1=rj,wj=b,null;a:{var c=a,d=V$1.return,e=V$1,f=b;b=W$1;e.effectTag|=2048;e.firstEffect=e.lastEffect=null;if(null!==f&&"object"===typeof f&&"function"===typeof f.then){var g=f,h=0!==(M$1.current&1),k=d;do{var l;if(l=13===k.tag){var m=k.memoizedState;if(null!==m)l=null!==m.dehydrated?!0:!1;else{var C=k.memoizedProps;l=void 0===C.fallback?!1:!0!==C.unstable_avoidThisFallback?!0:h?!1:!0;}}if(l){var y=k.updateQueue;if(null===y){var H=new Set;
    H.add(g);k.updateQueue=H;}else y.add(g);if(0===(k.mode&2)){k.effectTag|=64;e.effectTag&=-2981;if(1===e.tag)if(null===e.alternate)e.tag=17;else{var z=Bg(1073741823,null);z.tag=2;Dg(e,z);}e.expirationTime=1073741823;break a}f=void 0;e=b;var ta=c.pingCache;null===ta?(ta=c.pingCache=new ej,f=new Set,ta.set(g,f)):(f=ta.get(g),void 0===f&&(f=new Set,ta.set(g,f)));if(!f.has(e)){f.add(e);var r=dk.bind(null,c,g,e);g.then(r,r);}k.effectTag|=4096;k.expirationTime=b;break a}k=k.return;}while(null!==k);f=Error((Wa(e.type)||
    "A React component")+" suspended while rendering, but no fallback UI was specified.\n\nAdd a <Suspense fallback=...> component higher in the tree to provide a loading indicator or placeholder to display."+Xa(e));}X$1!==vj&&(X$1=sj);f=Ni(f,e);k=d;do{switch(k.tag){case 3:g=f;k.effectTag|=4096;k.expirationTime=b;var x=fj(k,g,b);Eg(k,x);break a;case 1:g=f;var A=k.type,p=k.stateNode;if(0===(k.effectTag&64)&&("function"===typeof A.getDerivedStateFromError||null!==p&&"function"===typeof p.componentDidCatch&&
    (null===jj||!jj.has(p)))){k.effectTag|=4096;k.expirationTime=b;var t=ij(k,g,b);Eg(k,t);break a}}k=k.return;}while(null!==k)}V$1=ek(V$1);}catch(v){b=v;continue}break}while(1)}function Uj(){var a=lj.current;lj.current=Lh;return null===a?Lh:a}function Ig(a,b){a<xj&&2<a&&(xj=a);null!==b&&a<yj&&2<a&&(yj=a,zj=b);}function Jg(a){a>Aj&&(Aj=a);}function Zj(){for(;null!==V$1;)V$1=fk(V$1);}function Vj(){for(;null!==V$1&&!Of();)V$1=fk(V$1);}
    function fk(a){var b=gk(a.alternate,a,W$1);a.memoizedProps=a.pendingProps;null===b&&(b=ek(a));mj.current=null;return b}
    function ek(a){V$1=a;do{var b=V$1.alternate;a=V$1.return;if(0===(V$1.effectTag&2048)){a:{var c=b;b=V$1;var d=W$1;var e=b.pendingProps;switch(b.tag){case 2:break;case 16:break;case 15:case 0:break;case 1:L$1(b.type)&&Ff(b);break;case 3:nh(b);Gf(b);e=b.stateNode;e.pendingContext&&(e.context=e.pendingContext,e.pendingContext=null);(null===c||null===c.child)&&ki(b)&&Ci(b);Ii(b);break;case 5:ph(b);d=lh(kh.current);var f=b.type;if(null!==c&&null!=b.stateNode)Ji(c,b,f,e,d),c.ref!==b.ref&&(b.effectTag|=128);else if(e){var g=
    lh(ih.current);if(ki(b)){e=b;var h=e.stateNode;c=e.type;var k=e.memoizedProps,l=d;h[ue]=e;h[ve]=k;f=void 0;d=h;switch(c){case "iframe":case "object":case "embed":F$1("load",d);break;case "video":case "audio":for(h=0;h<cc.length;h++)F$1(cc[h],d);break;case "source":F$1("error",d);break;case "img":case "image":case "link":F$1("error",d);F$1("load",d);break;case "form":F$1("reset",d);F$1("submit",d);break;case "details":F$1("toggle",d);break;case "input":Bb(d,k);F$1("invalid",d);$d(l,"onChange");break;case "select":d._wrapperState=
    {wasMultiple:!!k.multiple};F$1("invalid",d);$d(l,"onChange");break;case "textarea":Lb(d,k),F$1("invalid",d),$d(l,"onChange");}Yd(c,k);h=null;for(f in k)k.hasOwnProperty(f)&&(g=k[f],"children"===f?"string"===typeof g?d.textContent!==g&&(h=["children",g]):"number"===typeof g&&d.textContent!==""+g&&(h=["children",""+g]):ia.hasOwnProperty(f)&&null!=g&&$d(l,f));switch(c){case "input":yb(d);Gb(d,k,!0);break;case "textarea":yb(d);Nb(d,k);break;case "select":case "option":break;default:"function"===typeof k.onClick&&
    (d.onclick=ae);}f=h;e.updateQueue=f;e=null!==f?!0:!1;e&&Ci(b);}else{c=b;l=f;k=e;h=9===d.nodeType?d:d.ownerDocument;g===Ob.html&&(g=Pb(l));g===Ob.html?"script"===l?(k=h.createElement("div"),k.innerHTML="<script>\x3c/script>",h=k.removeChild(k.firstChild)):"string"===typeof k.is?h=h.createElement(l,{is:k.is}):(h=h.createElement(l),"select"===l&&(l=h,k.multiple?l.multiple=!0:k.size&&(l.size=k.size))):h=h.createElementNS(g,l);k=h;k[ue]=c;k[ve]=e;Hi(k,b,!1,!1);b.stateNode=k;l=f;c=e;var m=d,C=Zd(l,c);switch(l){case "iframe":case "object":case "embed":F$1("load",
    k);d=c;break;case "video":case "audio":for(d=0;d<cc.length;d++)F$1(cc[d],k);d=c;break;case "source":F$1("error",k);d=c;break;case "img":case "image":case "link":F$1("error",k);F$1("load",k);d=c;break;case "form":F$1("reset",k);F$1("submit",k);d=c;break;case "details":F$1("toggle",k);d=c;break;case "input":Bb(k,c);d=Ab(k,c);F$1("invalid",k);$d(m,"onChange");break;case "option":d=Ib(k,c);break;case "select":k._wrapperState={wasMultiple:!!c.multiple};d=objectAssign({},c,{value:void 0});F$1("invalid",k);$d(m,"onChange");break;case "textarea":Lb(k,
    c);d=Kb(k,c);F$1("invalid",k);$d(m,"onChange");break;default:d=c;}Yd(l,d);h=void 0;g=l;var y=k,H=d;for(h in H)if(H.hasOwnProperty(h)){var z=H[h];"style"===h?Wd(y,z):"dangerouslySetInnerHTML"===h?(z=z?z.__html:void 0,null!=z&&Sb(y,z)):"children"===h?"string"===typeof z?("textarea"!==g||""!==z)&&Tb(y,z):"number"===typeof z&&Tb(y,""+z):"suppressContentEditableWarning"!==h&&"suppressHydrationWarning"!==h&&"autoFocus"!==h&&(ia.hasOwnProperty(h)?null!=z&&$d(m,h):null!=z&&vb(y,h,z,C));}switch(l){case "input":yb(k);
    Gb(k,c,!1);break;case "textarea":yb(k);Nb(k,c);break;case "option":null!=c.value&&k.setAttribute("value",""+ub(c.value));break;case "select":d=k;d.multiple=!!c.multiple;k=c.value;null!=k?Jb(d,!!c.multiple,k,!1):null!=c.defaultValue&&Jb(d,!!c.multiple,c.defaultValue,!0);break;default:"function"===typeof d.onClick&&(k.onclick=ae);}(e=ne(f,e))&&Ci(b);}null!==b.ref&&(b.effectTag|=128);}else if(null===b.stateNode)throw Error(u$1(166));break;case 6:if(c&&null!=b.stateNode)Ki(c,b,c.memoizedProps,e);else{if("string"!==
    typeof e&&null===b.stateNode)throw Error(u$1(166));d=lh(kh.current);lh(ih.current);ki(b)?(e=b,f=e.stateNode,d=e.memoizedProps,f[ue]=e,(e=f.nodeValue!==d)&&Ci(b)):(f=b,e=(9===d.nodeType?d:d.ownerDocument).createTextNode(e),e[ue]=f,b.stateNode=e);}break;case 11:break;case 13:G$1(M$1,b);e=b.memoizedState;if(0!==(b.effectTag&64)){b.expirationTime=d;break a}e=null!==e;f=!1;null===c?void 0!==b.memoizedProps.fallback&&ki(b):(d=c.memoizedState,f=null!==d,e||null===d||(d=c.child.sibling,null!==d&&(k=b.firstEffect,
    null!==k?(b.firstEffect=d,d.nextEffect=k):(b.firstEffect=b.lastEffect=d,d.nextEffect=null),d.effectTag=8)));if(e&&!f&&0!==(b.mode&2))if(null===c&&!0!==b.memoizedProps.unstable_avoidThisFallback||0!==(M$1.current&1))X$1===qj&&(X$1=tj);else{if(X$1===qj||X$1===tj)X$1=uj;0!==Aj&&null!==U$1&&(Mj(U$1,W$1),Nj(U$1,Aj));}if(e||f)b.effectTag|=4;break;case 7:break;case 8:break;case 12:break;case 4:nh(b);Ii(b);break;case 10:tg(b);break;case 9:break;case 14:break;case 17:L$1(b.type)&&Ff(b);break;case 19:G$1(M$1,b);e=b.memoizedState;if(null===
    e)break;f=0!==(b.effectTag&64);k=e.rendering;if(null===k)if(f)Li(e,!1);else{if(X$1!==qj||null!==c&&0!==(c.effectTag&64))for(c=b.child;null!==c;){k=qh(c);if(null!==k){b.effectTag|=64;Li(e,!1);f=k.updateQueue;null!==f&&(b.updateQueue=f,b.effectTag|=4);null===e.lastEffect&&(b.firstEffect=null);b.lastEffect=e.lastEffect;e=d;for(f=b.child;null!==f;)d=f,c=e,d.effectTag&=2,d.nextEffect=null,d.firstEffect=null,d.lastEffect=null,k=d.alternate,null===k?(d.childExpirationTime=0,d.expirationTime=c,d.child=null,
    d.memoizedProps=null,d.memoizedState=null,d.updateQueue=null,d.dependencies=null):(d.childExpirationTime=k.childExpirationTime,d.expirationTime=k.expirationTime,d.child=k.child,d.memoizedProps=k.memoizedProps,d.memoizedState=k.memoizedState,d.updateQueue=k.updateQueue,c=k.dependencies,d.dependencies=null===c?null:{expirationTime:c.expirationTime,firstContext:c.firstContext,responders:c.responders}),f=f.sibling;I$1(M$1,M$1.current&1|2,b);b=b.child;break a}c=c.sibling;}}else{if(!f)if(c=qh(k),null!==c){if(b.effectTag|=
    64,f=!0,d=c.updateQueue,null!==d&&(b.updateQueue=d,b.effectTag|=4),Li(e,!0),null===e.tail&&"hidden"===e.tailMode&&!k.alternate){b=b.lastEffect=e.lastEffect;null!==b&&(b.nextEffect=null);break}}else cg()>e.tailExpiration&&1<d&&(b.effectTag|=64,f=!0,Li(e,!1),b.expirationTime=b.childExpirationTime=d-1);e.isBackwards?(k.sibling=b.child,b.child=k):(d=e.last,null!==d?d.sibling=k:b.child=k,e.last=k);}if(null!==e.tail){0===e.tailExpiration&&(e.tailExpiration=cg()+500);d=e.tail;e.rendering=d;e.tail=d.sibling;
    e.lastEffect=b.lastEffect;d.sibling=null;e=M$1.current;e=f?e&1|2:e&1;I$1(M$1,e,b);b=d;break a}break;case 20:break;case 21:break;default:throw Error(u$1(156,b.tag));}b=null;}e=V$1;if(1===W$1||1!==e.childExpirationTime){f=0;for(d=e.child;null!==d;)c=d.expirationTime,k=d.childExpirationTime,c>f&&(f=c),k>f&&(f=k),d=d.sibling;e.childExpirationTime=f;}if(null!==b)return b;null!==a&&0===(a.effectTag&2048)&&(null===a.firstEffect&&(a.firstEffect=V$1.firstEffect),null!==V$1.lastEffect&&(null!==a.lastEffect&&(a.lastEffect.nextEffect=
    V$1.firstEffect),a.lastEffect=V$1.lastEffect),1<V$1.effectTag&&(null!==a.lastEffect?a.lastEffect.nextEffect=V$1:a.firstEffect=V$1,a.lastEffect=V$1));}else{b=Mi(V$1,W$1);if(null!==b)return b.effectTag&=2047,b;null!==a&&(a.firstEffect=a.lastEffect=null,a.effectTag|=2048);}b=V$1.sibling;if(null!==b)return b;V$1=a;}while(null!==V$1);X$1===qj&&(X$1=vj);return null}function Xj(a){var b=a.expirationTime;a=a.childExpirationTime;return b>a?b:a}function Yj(a){var b=dg();fg(99,ik.bind(null,a,b));return null}
    function ik(a,b){do Sj();while(null!==Ej);if((T$1&(oj|pj))!==S$1)throw Error(u$1(327));var c=a.finishedWork,d=a.finishedExpirationTime;if(null===c)return null;a.finishedWork=null;a.finishedExpirationTime=0;if(c===a.current)throw Error(u$1(177));a.callbackNode=null;a.callbackExpirationTime=0;a.callbackPriority=90;a.nextKnownPendingLevel=0;var e=Xj(c);a.firstPendingTime=e;d<=a.lastSuspendedTime?a.firstSuspendedTime=a.lastSuspendedTime=a.nextKnownPendingLevel=0:d<=a.firstSuspendedTime&&(a.firstSuspendedTime=
    d-1);d<=a.lastPingedTime&&(a.lastPingedTime=0);d<=a.lastExpiredTime&&(a.lastExpiredTime=0);a===U$1&&(V$1=U$1=null,W$1=0);1<c.effectTag?null!==c.lastEffect?(c.lastEffect.nextEffect=c,e=c.firstEffect):e=c:e=c.firstEffect;if(null!==e){var f=T$1;T$1|=pj;mj.current=null;le=Ld;var g=fe();if(ge(g)){if("selectionStart"in g)var h={start:g.selectionStart,end:g.selectionEnd};else a:{h=(h=g.ownerDocument)&&h.defaultView||window;var k=h.getSelection&&h.getSelection();if(k&&0!==k.rangeCount){h=k.anchorNode;var l=k.anchorOffset,
    m=k.focusNode;k=k.focusOffset;try{h.nodeType,m.nodeType;}catch(Db){h=null;break a}var C=0,y=-1,H=-1,z=0,ta=0,r=g,x=null;b:for(;;){for(var A;;){r!==h||0!==l&&3!==r.nodeType||(y=C+l);r!==m||0!==k&&3!==r.nodeType||(H=C+k);3===r.nodeType&&(C+=r.nodeValue.length);if(null===(A=r.firstChild))break;x=r;r=A;}for(;;){if(r===g)break b;x===h&&++z===l&&(y=C);x===m&&++ta===k&&(H=C);if(null!==(A=r.nextSibling))break;r=x;x=r.parentNode;}r=A;}h=-1===y||-1===H?null:{start:y,end:H};}else h=null;}h=h||{start:0,end:0};}else h=
    null;me={focusedElem:g,selectionRange:h};Ld=!1;Y$1=e;do try{jk();}catch(Db){if(null===Y$1)throw Error(u$1(330));Ri(Y$1,Db);Y$1=Y$1.nextEffect;}while(null!==Y$1);Y$1=e;do try{for(g=a,h=b;null!==Y$1;){var p=Y$1.effectTag;p&16&&Tb(Y$1.stateNode,"");if(p&128){var t=Y$1.alternate;if(null!==t){var v=t.ref;null!==v&&("function"===typeof v?v(null):v.current=null);}}switch(p&1038){case 2:$i(Y$1);Y$1.effectTag&=-3;break;case 6:$i(Y$1);Y$1.effectTag&=-3;aj(Y$1.alternate,Y$1);break;case 1024:Y$1.effectTag&=-1025;break;case 1028:Y$1.effectTag&=-1025;aj(Y$1.alternate,
    Y$1);break;case 4:aj(Y$1.alternate,Y$1);break;case 8:l=Y$1,Xi(g,l,h),Yi(l);}Y$1=Y$1.nextEffect;}}catch(Db){if(null===Y$1)throw Error(u$1(330));Ri(Y$1,Db);Y$1=Y$1.nextEffect;}while(null!==Y$1);v=me;t=fe();p=v.focusedElem;h=v.selectionRange;if(t!==p&&p&&p.ownerDocument&&ee(p.ownerDocument.documentElement,p)){null!==h&&ge(p)&&(t=h.start,v=h.end,void 0===v&&(v=t),"selectionStart"in p?(p.selectionStart=t,p.selectionEnd=Math.min(v,p.value.length)):(v=(t=p.ownerDocument||document)&&t.defaultView||window,v.getSelection&&(v=v.getSelection(),
    l=p.textContent.length,g=Math.min(h.start,l),h=void 0===h.end?g:Math.min(h.end,l),!v.extend&&g>h&&(l=h,h=g,g=l),l=de(p,g),m=de(p,h),l&&m&&(1!==v.rangeCount||v.anchorNode!==l.node||v.anchorOffset!==l.offset||v.focusNode!==m.node||v.focusOffset!==m.offset)&&(t=t.createRange(),t.setStart(l.node,l.offset),v.removeAllRanges(),g>h?(v.addRange(t),v.extend(m.node,m.offset)):(t.setEnd(m.node,m.offset),v.addRange(t))))));t=[];for(v=p;v=v.parentNode;)1===v.nodeType&&t.push({element:v,left:v.scrollLeft,top:v.scrollTop});
    "function"===typeof p.focus&&p.focus();for(p=0;p<t.length;p++)v=t[p],v.element.scrollLeft=v.left,v.element.scrollTop=v.top;}me=null;Ld=!!le;le=null;a.current=c;Y$1=e;do try{for(p=d;null!==Y$1;){var Dh=Y$1.effectTag;if(Dh&36){var dc=Y$1.alternate;t=Y$1;v=p;switch(t.tag){case 0:case 11:case 15:Ui(16,32,t);break;case 1:var fd=t.stateNode;if(t.effectTag&4)if(null===dc)fd.componentDidMount();else{var hk=t.elementType===t.type?dc.memoizedProps:mg(t.type,dc.memoizedProps);fd.componentDidUpdate(hk,dc.memoizedState,
    fd.__reactInternalSnapshotBeforeUpdate);}var Eh=t.updateQueue;null!==Eh&&Kg(t,Eh,fd,v);break;case 3:var Fh=t.updateQueue;if(null!==Fh){g=null;if(null!==t.child)switch(t.child.tag){case 5:g=t.child.stateNode;break;case 1:g=t.child.stateNode;}Kg(t,Fh,g,v);}break;case 5:var xk=t.stateNode;null===dc&&t.effectTag&4&&ne(t.type,t.memoizedProps)&&xk.focus();break;case 6:break;case 4:break;case 12:break;case 13:if(null===t.memoizedState){var Di=t.alternate;if(null!==Di){var Ei=Di.memoizedState;if(null!==Ei){var Fi=
    Ei.dehydrated;null!==Fi&&Lc(Fi);}}}break;case 19:case 17:case 20:case 21:break;default:throw Error(u$1(163));}}if(Dh&128){t=void 0;var xd=Y$1.ref;if(null!==xd){var Gi=Y$1.stateNode;switch(Y$1.tag){case 5:t=Gi;break;default:t=Gi;}"function"===typeof xd?xd(t):xd.current=t;}}Y$1=Y$1.nextEffect;}}catch(Db){if(null===Y$1)throw Error(u$1(330));Ri(Y$1,Db);Y$1=Y$1.nextEffect;}while(null!==Y$1);Y$1=null;Yf();T$1=f;}else a.current=c;if(Dj)Dj=!1,Ej=a,Fj=b;else for(Y$1=e;null!==Y$1;)b=Y$1.nextEffect,Y$1.nextEffect=null,Y$1=b;b=a.firstPendingTime;0===b&&
    (jj=null);1073741823===b?a===Ij?Hj++:(Hj=0,Ij=a):Hj=0;"function"===typeof kk&&kk(c.stateNode,d);Z$1(a);if(gj)throw gj=!1,a=hj,hj=null,a;if((T$1&nj)!==S$1)return null;jg();return null}function jk(){for(;null!==Y$1;){var a=Y$1.effectTag;0!==(a&256)&&Ti(Y$1.alternate,Y$1);0===(a&512)||Dj||(Dj=!0,gg(97,function(){Sj();return null}));Y$1=Y$1.nextEffect;}}function Sj(){if(90!==Fj){var a=97<Fj?97:Fj;Fj=90;return fg(a,lk)}}
    function lk(){if(null===Ej)return!1;var a=Ej;Ej=null;if((T$1&(oj|pj))!==S$1)throw Error(u$1(331));var b=T$1;T$1|=pj;for(a=a.current.firstEffect;null!==a;){try{var c=a;if(0!==(c.effectTag&512))switch(c.tag){case 0:case 11:case 15:Ui(128,0,c),Ui(0,64,c);}}catch(d){if(null===a)throw Error(u$1(330));Ri(a,d);}c=a.nextEffect;a.nextEffect=null;a=c;}T$1=b;jg();return!0}function mk(a,b,c){b=Ni(c,b);b=fj(a,b,1073741823);Dg(a,b);a=Kj(a,1073741823);null!==a&&Z$1(a);}
    function Ri(a,b){if(3===a.tag)mk(a,a,b);else for(var c=a.return;null!==c;){if(3===c.tag){mk(c,a,b);break}else if(1===c.tag){var d=c.stateNode;if("function"===typeof c.type.getDerivedStateFromError||"function"===typeof d.componentDidCatch&&(null===jj||!jj.has(d))){a=Ni(b,a);a=ij(c,a,1073741823);Dg(c,a);c=Kj(c,1073741823);null!==c&&Z$1(c);break}}c=c.return;}}
    function dk(a,b,c){var d=a.pingCache;null!==d&&d.delete(b);U$1===a&&W$1===c?X$1===uj||X$1===tj&&1073741823===xj&&cg()-bj<Cj?Tj(a,W$1):Bj=!0:Pj(a,c)&&(b=a.lastPingedTime,0!==b&&b<c||(a.lastPingedTime=c,a.finishedExpirationTime===c&&(a.finishedExpirationTime=0,a.finishedWork=null),Z$1(a)));}function dj(a,b){var c=a.stateNode;null!==c&&c.delete(b);b=0;0===b&&(b=Pg(),b=Qg(b,a,null));a=Kj(a,b);null!==a&&Z$1(a);}var gk;
    gk=function(a,b,c){var d=b.expirationTime;if(null!==a){var e=b.pendingProps;if(a.memoizedProps!==e||K$1.current)wg=!0;else{if(d<c){wg=!1;switch(b.tag){case 3:wi(b);li();break;case 5:oh(b);if(b.mode&4&&1!==c&&e.hidden)return b.expirationTime=b.childExpirationTime=1,null;break;case 1:L$1(b.type)&&Jf(b);break;case 4:mh(b,b.stateNode.containerInfo);break;case 10:sg(b,b.memoizedProps.value);break;case 13:if(null!==b.memoizedState){d=b.child.childExpirationTime;if(0!==d&&d>=c)return yi(a,b,c);I$1(M$1,M$1.current&
    1,b);b=oi(a,b,c);return null!==b?b.sibling:null}I$1(M$1,M$1.current&1,b);break;case 19:d=b.childExpirationTime>=c;if(0!==(a.effectTag&64)){if(d)return Bi(a,b,c);b.effectTag|=64;}e=b.memoizedState;null!==e&&(e.rendering=null,e.tail=null);I$1(M$1,M$1.current,b);if(!d)return null}return oi(a,b,c)}wg=!1;}}else wg=!1;b.expirationTime=0;switch(b.tag){case 2:d=b.type;null!==a&&(a.alternate=null,b.alternate=null,b.effectTag|=2);a=b.pendingProps;e=Ef(b,J$1.current);vg(b,c);e=Ih(null,b,d,a,e,c);b.effectTag|=1;if("object"===
    typeof e&&null!==e&&"function"===typeof e.render&&void 0===e.$$typeof){b.tag=1;Mh();if(L$1(d)){var f=!0;Jf(b);}else f=!1;b.memoizedState=null!==e.state&&void 0!==e.state?e.state:null;var g=d.getDerivedStateFromProps;"function"===typeof g&&Og(b,d,g,a);e.updater=Sg;b.stateNode=e;e._reactInternalFiber=b;Wg(b,d,a,c);b=vi(null,b,d,!0,f,c);}else b.tag=0,R$1(null,b,e,c),b=b.child;return b;case 16:e=b.elementType;null!==a&&(a.alternate=null,b.alternate=null,b.effectTag|=2);a=b.pendingProps;Va(e);if(1!==e._status)throw e._result;
    e=e._result;b.type=e;f=b.tag=nk(e);a=mg(e,a);switch(f){case 0:b=si(null,b,e,a,c);break;case 1:b=ui(null,b,e,a,c);break;case 11:b=ni(null,b,e,a,c);break;case 14:b=pi(null,b,e,mg(e.type,a),d,c);break;default:throw Error(u$1(306,e,""));}return b;case 0:return d=b.type,e=b.pendingProps,e=b.elementType===d?e:mg(d,e),si(a,b,d,e,c);case 1:return d=b.type,e=b.pendingProps,e=b.elementType===d?e:mg(d,e),ui(a,b,d,e,c);case 3:wi(b);d=b.updateQueue;if(null===d)throw Error(u$1(282));e=b.memoizedState;e=null!==e?e.element:
    null;Hg(b,d,b.pendingProps,null,c);d=b.memoizedState.element;if(d===e)li(),b=oi(a,b,c);else{if(e=b.stateNode.hydrate)di=re(b.stateNode.containerInfo.firstChild),ci=b,e=ei=!0;if(e)for(c=gh(b,null,d,c),b.child=c;c;)c.effectTag=c.effectTag&-3|1024,c=c.sibling;else R$1(a,b,d,c),li();b=b.child;}return b;case 5:return oh(b),null===a&&ii(b),d=b.type,e=b.pendingProps,f=null!==a?a.memoizedProps:null,g=e.children,oe(d,e)?g=null:null!==f&&oe(d,f)&&(b.effectTag|=16),ti(a,b),b.mode&4&&1!==c&&e.hidden?(b.expirationTime=
    b.childExpirationTime=1,b=null):(R$1(a,b,g,c),b=b.child),b;case 6:return null===a&&ii(b),null;case 13:return yi(a,b,c);case 4:return mh(b,b.stateNode.containerInfo),d=b.pendingProps,null===a?b.child=fh(b,null,d,c):R$1(a,b,d,c),b.child;case 11:return d=b.type,e=b.pendingProps,e=b.elementType===d?e:mg(d,e),ni(a,b,d,e,c);case 7:return R$1(a,b,b.pendingProps,c),b.child;case 8:return R$1(a,b,b.pendingProps.children,c),b.child;case 12:return R$1(a,b,b.pendingProps.children,c),b.child;case 10:a:{d=b.type._context;
    e=b.pendingProps;g=b.memoizedProps;f=e.value;sg(b,f);if(null!==g){var h=g.value;f=of(h,f)?0:("function"===typeof d._calculateChangedBits?d._calculateChangedBits(h,f):1073741823)|0;if(0===f){if(g.children===e.children&&!K$1.current){b=oi(a,b,c);break a}}else for(h=b.child,null!==h&&(h.return=b);null!==h;){var k=h.dependencies;if(null!==k){g=h.child;for(var l=k.firstContext;null!==l;){if(l.context===d&&0!==(l.observedBits&f)){1===h.tag&&(l=Bg(c,null),l.tag=2,Dg(h,l));h.expirationTime<c&&(h.expirationTime=
    c);l=h.alternate;null!==l&&l.expirationTime<c&&(l.expirationTime=c);ug(h.return,c);k.expirationTime<c&&(k.expirationTime=c);break}l=l.next;}}else g=10===h.tag?h.type===b.type?null:h.child:h.child;if(null!==g)g.return=h;else for(g=h;null!==g;){if(g===b){g=null;break}h=g.sibling;if(null!==h){h.return=g.return;g=h;break}g=g.return;}h=g;}}R$1(a,b,e.children,c);b=b.child;}return b;case 9:return e=b.type,f=b.pendingProps,d=f.children,vg(b,c),e=xg(e,f.unstable_observedBits),d=d(e),b.effectTag|=1,R$1(a,b,d,c),b.child;
    case 14:return e=b.type,f=mg(e,b.pendingProps),f=mg(e.type,f),pi(a,b,e,f,d,c);case 15:return ri(a,b,b.type,b.pendingProps,d,c);case 17:return d=b.type,e=b.pendingProps,e=b.elementType===d?e:mg(d,e),null!==a&&(a.alternate=null,b.alternate=null,b.effectTag|=2),b.tag=1,L$1(d)?(a=!0,Jf(b)):a=!1,vg(b,c),Ug(b,d,e,c),Wg(b,d,e,c),vi(null,b,d,!0,a,c);case 19:return Bi(a,b,c)}throw Error(u$1(156,b.tag));};var kk=null,Wi=null;
    function ok(a){if("undefined"===typeof __REACT_DEVTOOLS_GLOBAL_HOOK__)return!1;var b=__REACT_DEVTOOLS_GLOBAL_HOOK__;if(b.isDisabled||!b.supportsFiber)return!0;try{var c=b.inject(a);kk=function(a){try{b.onCommitFiberRoot(c,a,void 0,64===(a.current.effectTag&64));}catch(e){}};Wi=function(a){try{b.onCommitFiberUnmount(c,a);}catch(e){}};}catch(d){}return!0}
    function pk(a,b,c,d){this.tag=a;this.key=c;this.sibling=this.child=this.return=this.stateNode=this.type=this.elementType=null;this.index=0;this.ref=null;this.pendingProps=b;this.dependencies=this.memoizedState=this.updateQueue=this.memoizedProps=null;this.mode=d;this.effectTag=0;this.lastEffect=this.firstEffect=this.nextEffect=null;this.childExpirationTime=this.expirationTime=0;this.alternate=null;}function gi(a,b,c,d){return new pk(a,b,c,d)}
    function qi(a){a=a.prototype;return!(!a||!a.isReactComponent)}function nk(a){if("function"===typeof a)return qi(a)?1:0;if(void 0!==a&&null!==a){a=a.$$typeof;if(a===Oa)return 11;if(a===Ra)return 14}return 2}
    function ah(a,b){var c=a.alternate;null===c?(c=gi(a.tag,b,a.key,a.mode),c.elementType=a.elementType,c.type=a.type,c.stateNode=a.stateNode,c.alternate=a,a.alternate=c):(c.pendingProps=b,c.effectTag=0,c.nextEffect=null,c.firstEffect=null,c.lastEffect=null);c.childExpirationTime=a.childExpirationTime;c.expirationTime=a.expirationTime;c.child=a.child;c.memoizedProps=a.memoizedProps;c.memoizedState=a.memoizedState;c.updateQueue=a.updateQueue;b=a.dependencies;c.dependencies=null===b?null:{expirationTime:b.expirationTime,
    firstContext:b.firstContext,responders:b.responders};c.sibling=a.sibling;c.index=a.index;c.ref=a.ref;return c}
    function ch(a,b,c,d,e,f){var g=2;d=a;if("function"===typeof a)qi(a)&&(g=1);else if("string"===typeof a)g=5;else a:switch(a){case Ia:return eh(c.children,e,f,b);case Na:g=8;e|=7;break;case Ja:g=8;e|=1;break;case Ka:return a=gi(12,c,b,e|8),a.elementType=Ka,a.type=Ka,a.expirationTime=f,a;case Pa:return a=gi(13,c,b,e),a.type=Pa,a.elementType=Pa,a.expirationTime=f,a;case Qa:return a=gi(19,c,b,e),a.elementType=Qa,a.expirationTime=f,a;default:if("object"===typeof a&&null!==a)switch(a.$$typeof){case La:g=
    10;break a;case Ma:g=9;break a;case Oa:g=11;break a;case Ra:g=14;break a;case Sa:g=16;d=null;break a}throw Error(u$1(130,null==a?a:typeof a,""));}b=gi(g,c,b,e);b.elementType=a;b.type=d;b.expirationTime=f;return b}function eh(a,b,c,d){a=gi(7,a,d,b);a.expirationTime=c;return a}function bh(a,b,c){a=gi(6,a,null,b);a.expirationTime=c;return a}
    function dh(a,b,c){b=gi(4,null!==a.children?a.children:[],a.key,b);b.expirationTime=c;b.stateNode={containerInfo:a.containerInfo,pendingChildren:null,implementation:a.implementation};return b}
    function qk(a,b,c){this.tag=b;this.current=null;this.containerInfo=a;this.pingCache=this.pendingChildren=null;this.finishedExpirationTime=0;this.finishedWork=null;this.timeoutHandle=-1;this.pendingContext=this.context=null;this.hydrate=c;this.callbackNode=null;this.callbackPriority=90;this.lastExpiredTime=this.lastPingedTime=this.nextKnownPendingLevel=this.lastSuspendedTime=this.firstSuspendedTime=this.firstPendingTime=0;}
    function Pj(a,b){var c=a.firstSuspendedTime;a=a.lastSuspendedTime;return 0!==c&&c>=b&&a<=b}function Mj(a,b){var c=a.firstSuspendedTime,d=a.lastSuspendedTime;c<b&&(a.firstSuspendedTime=b);if(d>b||0===c)a.lastSuspendedTime=b;b<=a.lastPingedTime&&(a.lastPingedTime=0);b<=a.lastExpiredTime&&(a.lastExpiredTime=0);}
    function Nj(a,b){b>a.firstPendingTime&&(a.firstPendingTime=b);var c=a.firstSuspendedTime;0!==c&&(b>=c?a.firstSuspendedTime=a.lastSuspendedTime=a.nextKnownPendingLevel=0:b>=a.lastSuspendedTime&&(a.lastSuspendedTime=b+1),b>a.nextKnownPendingLevel&&(a.nextKnownPendingLevel=b));}function Rj(a,b){var c=a.lastExpiredTime;if(0===c||c>b)a.lastExpiredTime=b;}
    function rk(a,b,c,d){var e=b.current,f=Pg(),g=Mg.suspense;f=Qg(f,e,g);a:if(c){c=c._reactInternalFiber;b:{if(ec(c)!==c||1!==c.tag)throw Error(u$1(170));var h=c;do{switch(h.tag){case 3:h=h.stateNode.context;break b;case 1:if(L$1(h.type)){h=h.stateNode.__reactInternalMemoizedMergedChildContext;break b}}h=h.return;}while(null!==h);throw Error(u$1(171));}if(1===c.tag){var k=c.type;if(L$1(k)){c=If(c,k,h);break a}}c=h;}else c=Cf;null===b.context?b.context=c:b.pendingContext=c;b=Bg(f,g);b.payload={element:a};d=void 0===
    d?null:d;null!==d&&(b.callback=d);Dg(e,b);Rg(e,f);return f}function sk(a){a=a.current;if(!a.child)return null;switch(a.child.tag){case 5:return a.child.stateNode;default:return a.child.stateNode}}function tk(a,b){a=a.memoizedState;null!==a&&null!==a.dehydrated&&a.retryTime<b&&(a.retryTime=b);}function uk(a,b){tk(a,b);(a=a.alternate)&&tk(a,b);}
    function vk(a,b,c){c=null!=c&&!0===c.hydrate;var d=new qk(a,b,c),e=gi(3,null,null,2===b?7:1===b?3:0);d.current=e;e.stateNode=d;a[we]=d.current;c&&0!==b&&wc(9===a.nodeType?a:a.ownerDocument);this._internalRoot=d;}vk.prototype.render=function(a,b){rk(a,this._internalRoot,null,void 0===b?null:b);};vk.prototype.unmount=function(a){var b=this._internalRoot,c=void 0===a?null:a,d=b.containerInfo;rk(null,b,null,function(){d[we]=null;null!==c&&c();});};
    function wk(a){return!(!a||1!==a.nodeType&&9!==a.nodeType&&11!==a.nodeType&&(8!==a.nodeType||" react-mount-point-unstable "!==a.nodeValue))}function yk(a,b){b||(b=a?9===a.nodeType?a.documentElement:a.firstChild:null,b=!(!b||1!==b.nodeType||!b.hasAttribute("data-reactroot")));if(!b)for(var c;c=a.lastChild;)a.removeChild(c);return new vk(a,0,b?{hydrate:!0}:void 0)}
    function zk(a,b,c,d,e){var f=c._reactRootContainer;if(f){var g=f._internalRoot;if("function"===typeof e){var h=e;e=function(){var a=sk(g);h.call(a);};}rk(b,g,a,e);}else{f=c._reactRootContainer=yk(c,d);g=f._internalRoot;if("function"===typeof e){var k=e;e=function(){var a=sk(g);k.call(a);};}ck(function(){rk(b,g,a,e);});}return sk(g)}function Ak(a,b,c){var d=3<arguments.length&&void 0!==arguments[3]?arguments[3]:null;return{$$typeof:Ha,key:null==d?null:""+d,children:a,containerInfo:b,implementation:c}}
    jc=function(a){if(13===a.tag){var b=lg(Pg(),150,100);Rg(a,b);uk(a,b);}};kc=function(a){if(13===a.tag){Pg();var b=kg++;Rg(a,b);uk(a,b);}};lc=function(a){if(13===a.tag){var b=Pg();b=Qg(b,a,null);Rg(a,b);uk(a,b);}};
    Za=function(a,b,c){switch(b){case "input":Eb(a,c);b=c.name;if("radio"===c.type&&null!=b){for(c=a;c.parentNode;)c=c.parentNode;c=c.querySelectorAll("input[name="+JSON.stringify(""+b)+'][type="radio"]');for(b=0;b<c.length;b++){var d=c[b];if(d!==a&&d.form===a.form){var e=ye(d);if(!e)throw Error(u$1(90));zb(d);Eb(d,e);}}}break;case "textarea":Mb(a,c);break;case "select":b=c.value,null!=b&&Jb(a,!!c.multiple,b,!1);}};eb=bk;
    fb=function(a,b,c,d){var e=T$1;T$1|=4;try{return fg(98,a.bind(null,b,c,d))}finally{T$1=e,T$1===S$1&&jg();}};gb=function(){(T$1&(1|oj|pj))===S$1&&(ak(),Sj());};hb=function(a,b){var c=T$1;T$1|=2;try{return a(b)}finally{T$1=c,T$1===S$1&&jg();}};function Bk(a,b){var c=2<arguments.length&&void 0!==arguments[2]?arguments[2]:null;if(!wk(b))throw Error(u$1(200));return Ak(a,b,null,c)}
    var Ck={createPortal:Bk,findDOMNode:function(a){if(null==a)return null;if(1===a.nodeType)return a;var b=a._reactInternalFiber;if(void 0===b){if("function"===typeof a.render)throw Error(u$1(188));throw Error(u$1(268,Object.keys(a)));}a=ic(b);a=null===a?null:a.stateNode;return a},hydrate:function(a,b,c){if(!wk(b))throw Error(u$1(200));return zk(null,a,b,!0,c)},render:function(a,b,c){if(!wk(b))throw Error(u$1(200));return zk(null,a,b,!1,c)},unstable_renderSubtreeIntoContainer:function(a,b,c,d){if(!wk(c))throw Error(u$1(200));
    if(null==a||void 0===a._reactInternalFiber)throw Error(u$1(38));return zk(a,b,c,!1,d)},unmountComponentAtNode:function(a){if(!wk(a))throw Error(u$1(40));return a._reactRootContainer?(ck(function(){zk(null,null,a,!1,function(){a._reactRootContainer=null;a[we]=null;});}),!0):!1},unstable_createPortal:function(){return Bk.apply(void 0,arguments)},unstable_batchedUpdates:bk,flushSync:function(a,b){if((T$1&(oj|pj))!==S$1)throw Error(u$1(187));var c=T$1;T$1|=1;try{return fg(99,a.bind(null,b))}finally{T$1=c,jg();}},__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED:{Events:[Cc,
    xe,ye,Ca.injectEventPluginsByName,fa,Sc,function(a){ya(a,Rc);},cb,db,Pd,Ba,Sj,{current:!1}]}};
    (function(a){var b=a.findFiberByHostInstance;return ok(objectAssign({},a,{overrideHookState:null,overrideProps:null,setSuspenseHandler:null,scheduleUpdate:null,currentDispatcherRef:Ea.ReactCurrentDispatcher,findHostInstanceByFiber:function(a){a=ic(a);return null===a?null:a.stateNode},findFiberByHostInstance:function(a){return b?b(a):null},findHostInstancesForRefresh:null,scheduleRefresh:null,scheduleRoot:null,setRefreshHandler:null,getCurrentFiber:null}))})({findFiberByHostInstance:Fc,bundleType:0,version:"16.12.0",
    rendererPackageName:"react-dom"});var Dk={default:Ck},Ek=Dk&&Ck||Dk;var reactDom_production_min=Ek.default||Ek;

    var reactDom = createCommonjsModule(function (module) {

    function checkDCE() {
      /* global __REACT_DEVTOOLS_GLOBAL_HOOK__ */
      if (
        typeof __REACT_DEVTOOLS_GLOBAL_HOOK__ === 'undefined' ||
        typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE !== 'function'
      ) {
        return;
      }
      try {
        // Verify that the code above has been dead code eliminated (DCE'd).
        __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(checkDCE);
      } catch (err) {
        // DevTools shouldn't crash React, no matter what.
        // We should still report in case we break this code.
        console.error(err);
      }
    }

    {
      // DCE check should happen before ReactDOM bundle executes so that
      // DevTools can report bad minification during injection.
      checkDCE();
      module.exports = reactDom_production_min;
    }
    });
    var reactDom_1 = reactDom.render;
    var reactDom_2 = reactDom.hydrate;

    function pad$1 (hash, len) {
      while (hash.length < len) {
        hash = '0' + hash;
      }
      return hash;
    }

    function fold$1 (hash, text) {
      var i;
      var chr;
      var len;
      if (text.length === 0) {
        return hash;
      }
      for (i = 0, len = text.length; i < len; i++) {
        chr = text.charCodeAt(i);
        hash = ((hash << 5) - hash) + chr;
        hash |= 0;
      }
      return hash < 0 ? hash * -2 : hash;
    }

    function foldObject$1 (hash, o, seen) {
      return Object.keys(o).sort().reduce(foldKey, hash);
      function foldKey (hash, key) {
        return foldValue$1(hash, o[key], key, seen);
      }
    }

    function foldValue$1 (input, value, key, seen) {
      var hash = fold$1(fold$1(fold$1(input, key), toString$2(value)), typeof value);
      if (value === null) {
        return fold$1(hash, 'null');
      }
      if (value === undefined) {
        return fold$1(hash, 'undefined');
      }
      if (typeof value === 'object' || typeof value === 'function') {
        if (seen.indexOf(value) !== -1) {
          return fold$1(hash, '[Circular]' + key);
        }
        seen.push(value);

        var objHash = foldObject$1(hash, value, seen);

        if (!('valueOf' in value) || typeof value.valueOf !== 'function') {
          return objHash;
        }

        try {
          return fold$1(objHash, String(value.valueOf()))
        } catch (err) {
          return fold$1(objHash, '[valueOf exception]' + (err.stack || err.message))
        }
      }
      return fold$1(hash, value.toString());
    }

    function toString$2 (o) {
      return Object.prototype.toString.call(o);
    }

    function sum$1 (o) {
      return pad$1(foldValue$1(0, o, '', []).toString(16), 8);
    }

    var hashSum$1 = sum$1;

    var version$1="1.1.31-alpha.9",_a;"undefined"!=typeof window&&(null===(_a=window.parent)||void 0===_a||_a.postMessage({type:"builder.isReactSdk",data:{value:!0,supportsPatchUpdates:"v3",priorVersion:version$1}},"*"))
    /*! *****************************************************************************
    Copyright (c) Microsoft Corporation. All rights reserved.
    Licensed under the Apache License, Version 2.0 (the "License"); you may not use
    this file except in compliance with the License. You may obtain a copy of the
    License at http://www.apache.org/licenses/LICENSE-2.0

    THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
    WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
    MERCHANTABLITY OR NON-INFRINGEMENT.

    See the Apache Version 2.0 License for specific language governing permissions
    and limitations under the License.
    ***************************************************************************** */;var extendStatics$1=function(e,t){return(extendStatics$1=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t;}||function(e,t){for(var n in t)t.hasOwnProperty(n)&&(e[n]=t[n]);})(e,t)};function __extends$1(e,t){function n(){this.constructor=e;}extendStatics$1(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n);}var __assign$1=function(){return(__assign$1=Object.assign||function(e){for(var t,n=1,r=arguments.length;n<r;n++)for(var i in t=arguments[n])Object.prototype.hasOwnProperty.call(t,i)&&(e[i]=t[i]);return e}).apply(this,arguments)};function __decorate$1(e,t,n,r){var i,o=arguments.length,a=o<3?t:null===r?r=Object.getOwnPropertyDescriptor(t,n):r;if("object"==typeof Reflect&&"function"==typeof Reflect.decorate)a=Reflect.decorate(e,t,n,r);else for(var s=e.length-1;s>=0;s--)(i=e[s])&&(a=(o<3?i(a):o>3?i(t,n,a):i(t,n))||a);return o>3&&a&&Object.defineProperty(t,n,a),a}function __metadata$1(e,t){if("object"==typeof Reflect&&"function"==typeof Reflect.metadata)return Reflect.metadata(e,t)}function __awaiter$1(e,t,n,r){return new(n||(n=Promise))((function(i,o){function a(e){try{l(r.next(e));}catch(e){o(e);}}function s(e){try{l(r.throw(e));}catch(e){o(e);}}function l(e){e.done?i(e.value):new n((function(t){t(e.value);})).then(a,s);}l((r=r.apply(e,t||[])).next());}))}function __generator$1(e,t){var n,r,i,o,a={label:0,sent:function(){if(1&i[0])throw i[1];return i[1]},trys:[],ops:[]};return o={next:s(0),throw:s(1),return:s(2)},"function"==typeof Symbol&&(o[Symbol.iterator]=function(){return this}),o;function s(o){return function(s){return function(o){if(n)throw new TypeError("Generator is already executing.");for(;a;)try{if(n=1,r&&(i=2&o[0]?r.return:o[0]?r.throw||((i=r.return)&&i.call(r),0):r.next)&&!(i=i.call(r,o[1])).done)return i;switch(r=0,i&&(o=[2&o[0],i.value]),o[0]){case 0:case 1:i=o;break;case 4:return a.label++,{value:o[1],done:!1};case 5:a.label++,r=o[1],o=[0];continue;case 7:o=a.ops.pop(),a.trys.pop();continue;default:if(!(i=(i=a.trys).length>0&&i[i.length-1])&&(6===o[0]||2===o[0])){a=0;continue}if(3===o[0]&&(!i||o[1]>i[0]&&o[1]<i[3])){a.label=o[1];break}if(6===o[0]&&a.label<i[1]){a.label=i[1],i=o;break}if(i&&a.label<i[2]){a.label=i[2],a.ops.push(o);break}i[2]&&a.ops.pop(),a.trys.pop();continue}o=t.call(e,a);}catch(e){o=[6,e],r=0;}finally{n=i=0;}if(5&o[0])throw o[1];return{value:o[0]?o[1]:void 0,done:!0}}([o,s])}}}function __spreadArrays$1(){for(var e=0,t=0,n=arguments.length;t<n;t++)e+=arguments[t].length;var r=Array(e),i=0;for(t=0;t<n;t++)for(var o=arguments[t],a=0,s=o.length;a<s;a++,i++)r[i]=o[a];return r}var sizeNames=["xsmall","small","medium","large"],sizes={xsmall:{min:0,default:0,max:0},small:{min:320,default:321,max:640},medium:{min:641,default:642,max:991},large:{min:990,default:991,max:1200},getWidthForSize:function(e){return this[e].default},getSizeForWidth:function(e){for(var t=0,n=sizeNames;t<n.length;t++){var r=n[t];if(e<=this[r].max)return r}return"large"}},set=function(e,t,n){if(Object(e)!==e)return e;var r=Array.isArray(t)?t:t.toString().match(/[^.[\]]+/g);return r.slice(0,-1).reduce((function(e,t,n){return Object(e[t])===e[t]?e[t]:e[t]=Math.abs(Number(r[n+1]))>>0==+r[n+1]?[]:{}}),e)[r[r.length-1]]=n,e},safeDynamicRequire=Builder.isServer?eval("require"):function(){return null},fnCache={},api=function(e){return builder};function stringToFunction(e,t,n,r){if(void 0===t&&(t=!0),!e||!e.trim())return function(){};var i=e+":"+t;if(fnCache[i])return fnCache[i];var o=t&&!(e.includes(";")||e.includes(" return ")||e.trim().startsWith("return "))||e.trim().startsWith("builder.run"),a=function(){};e=e.replace(/builder\s*\.\s*use[a-zA-Z]*\(/g,"return(").replace(/builder\s*\.\s*set([a-zA-Z]+)To\(/g,(function(e,t){return'builder.set("'+(t[0].toLowerCase()+t.substring(1))+'",'})).replace(/builder\s*\.\s*get([a-zA-Z]+)\s*\(\s*\)/g,(function(e,t){return"state."+(t[0].toLowerCase()+t.substring(1))}));try{Builder.isBrowser&&(a=new Function("state","event","block","builder","Device","update","Builder","context","\n          var names = [\n            'state',\n            'event',\n            'block',\n            'builder',\n            'Device',\n            'update',\n            'Builder',\n            'context'\n          ];\n          var rootState = state;\n          if (typeof Proxy !== 'undefined') {\n            rootState = new Proxy(rootState, {\n              set: function () {\n                return false;\n              },\n              get: function (target, key) {\n                if (names.includes(key)) {\n                  return undefined;\n                }\n                return target[key];\n              }\n            });\n          }\n          /* Alias */\n          var ctx = context;\n          with (rootState) {\n            "+(o?"return ("+e+");":e)+";\n          }\n        "));}catch(t){n&&n.push(t);var s=t&&t.message;s&&"string"==typeof s&&r&&-1===r.indexOf(s)&&r.push(s),Builder.isBrowser&&console.warn("Function compile error in "+e,t);}return fnCache[i]=function(){for(var t=[],r=0;r<arguments.length;r++)t[r]=arguments[r];try{if(Builder.isBrowser)return a.apply(void 0,t);var i=safeDynamicRequire("vm2").VM,o=t[0],s=t[1];return new i({timeout:100,sandbox:__assign$1(__assign$1(__assign$1(__assign$1({},o),{state:o}),{builder:api}),{event:s})}).run(e.replace(/(^|;)return /,"$1"))}catch(t){Builder.isBrowser?console.warn("Builder custom code error:",t.message||t,"in",e,t.stack||t):process.env.DEBUG&&console.debug("Builder custom code error:",t.message||t,"in",e,t.stack||t),n&&n.push(t);}}}var isPromise=function(e){return"function"==typeof e.then},isRequestInfo=function(e){return!isPromise(e)},BuilderAsyncRequestsContext=react.createContext({requests:[],errors:[],logs:[]}),BuilderStoreContext=react.createContext({state:{},rootState:{},content:{},context:{},update:function(e){return null}}),applyPatchWithMinimalMutationChain=function(e,t,n){if(void 0===n&&(n=!0),Object(e)!==e)return e;var r=t.path,i=t.op,o=t.value,a=r.split(/\//);""===a[0]&&a.shift();for(var s=n?e:__assign$1({},e),l=s,u=0;u<a.length;u++){var d=u===a.length-1,p=a[u];if(d){if("replace"===i)l[p]=o;else if("add"===i){var c=Number(p);Array.isArray(l)?"-"===p?l.push(o):l.splice(c,0,o):l[p]=o;}else if("remove"===i){c=Number(p);Array.isArray(l)?l.splice(c,1):delete l[p];}}else{var m=a[u+1],f=Object(l[p])===l[p]?l[p]:String(Number(m))===m?[]:{};l=l[p]=Array.isArray(f)?__spreadArrays$1(f):__assign$1({},f);}}return s},htmlEscape=function(e){return e.replace(/&/g,"&amp;").replace(/</g,"&lt;").replace(/>/g,"&gt;").replace(/"/g,"&quot;")},blockToHtmlString=function(e){var t;return("<"+htmlEscape(e.tagName||"div")+' \n    class="builder-block '+e.id+" "+(e.class||"")+'"\n    builder-id="'+e.id+'"\n  '+Object.keys(e.properties||{}).map((function(t){return htmlEscape(t)+'="'+htmlEscape(e.properties[t])+'"'})).join(" ")+"\n  >"+("Text"===(null===(t=null==e?void 0:e.component)||void 0===t?void 0:t.name)?e.component.options.text:e.children?e.children.map((function(e){return blockToHtmlString(e)})).join(""):"")+"</"+(e.tagName||"div")+">").replace(/\s+/g," ")},Link=function(e){return react.createElement(BuilderStoreContext.Consumer,null,(function(t){return t.renderLink?t.renderLink(e):react.createElement("a",__assign$1({},e))}))},camelCaseToKebabCase$1=function(e){return e?e.replace(/([A-Z])/g,(function(e){return"-"+e[0].toLowerCase()})):""},kebabCaseToCamelCase=function(e){return void 0===e&&(e=""),e.replace(/-([a-z])/g,(function(e){return e[1].toUpperCase()}))},Device={desktop:0,tablet:1,mobile:2},blocksMap={},voidElements=new Set(["area","base","br","col","embed","hr","img","input","link","meta","param","source","track","wbr"]);function pick(e,t){return t.reduce((function(t,n){return e&&e.hasOwnProperty(n)&&(t[n]=e[n]),t}),{})}var last=function(e){return e[e.length-1]};function omit$1(e,t){for(var n=Object.assign({},e),r=0,i=t;r<i.length;r++){delete n[i[r]];}return n}var cssCase=function(e){if(!e)return e;var t=camelCaseToKebabCase$1(e);return e[0]===e[0].toUpperCase()&&(t="-"+t),t},fastClone=function(e){return JSON.parse(JSON.stringify(e))};function mapToCss(e,t,n){return void 0===t&&(t=2),void 0===n&&(n=!1),Object.keys(e).reduce((function(r,i){var o=e[i];return"string"!=typeof o?r:r+(o&&o.trim()?"\n"+" ".repeat(t)+cssCase(i)+": "+o+(n?" !important":"")+";":"")}),"")}function capitalize(e){if(e)return e[0].toUpperCase()+e.slice(1)}var BuilderBlock=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.state={hasError:!1,updates:0},t.privateState={state:{},rootState:{},context:{},update:function(){}},t.onWindowMessage=function(e){var n=e.data;if(n)switch(n.type){case"builder.selectionChange":if(!(o=n.data))break;var r=o.selection,i=t.block&&t.block.id;i&&Array.isArray(r)&&r.indexOf(i)>-1&&setTimeout((function(){window.$block=t,window.$blocks||(window.$blocks=[]),window.$blocks.push(t);}));break;case"builder.patchUpdates":var o;if(!(o=n.data)||!o.data)break;var a=o.data[t.block.id];if(!a)return;location.href.includes("builder.debug=true")&&t.eval("debugger");for(var s=__assign$1({},t.block),l=0,u=a;l<u.length;l++){var d=u[l];applyPatchWithMinimalMutationChain(s,d);}blocksMap[t.props.block.id]=s,t.setState({updates:t.state.updates+1});}},t}return __extends$1(t,e),Object.defineProperty(t.prototype,"store",{get:function(){return this.privateState},enumerable:!0,configurable:!0}),t.getDerivedStateFromError=function(e){return{hasError:!0}},t.prototype.componentDidCatch=function(e,t){console.error("Builder block error:",e,t);},t.prototype.stringToFunction=function(e,t){return void 0===t&&(t=!0),stringToFunction(e,t,this._errors,this._logs)},Object.defineProperty(t.prototype,"block",{get:function(){return blocksMap[this.props.block.id]||this.props.block},enumerable:!0,configurable:!0}),t.prototype.UNSAFE_componentWillReceiveProps=function(e){Builder.isEditing&&blocksMap[e.block.id]!==e.block&&(blocksMap[e.block.id]=e.block);},Object.defineProperty(t.prototype,"styles",{get:function(){var e,t=this.props.size,n=this.block,r=[],i=sizeNames.indexOf(t||"large");if(n.responsiveStyles)for(var o=i;o<sizeNames.length;o+=1){var a=sizeNames[o];n.responsiveStyles[a]&&r.push(n.responsiveStyles[a]);}if(!!this.privateState.state.isServer){var s=n.animations&&n.animations[0],l=s&&s.steps&&s.steps[0],u=l&&l.styles;u&&(e=u);}return Object.assign.apply(Object,__spreadArrays$1([{}],r.reverse(),[e]))},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"emotionCss",{get:function(){var e,t,n,r=this.block;if(Builder.isServer){var i=r.animations&&r.animations[0];if(i&&"hover"!==i.trigger){var o=i&&i.steps&&i.steps[0],a=o&&o.styles;a&&(n=a);}}var s=sizeNames.slice().reverse(),l=this.block,u={};if(l.responsiveStyles)for(var d=0,p=s;d<p.length;d++){var c=p[d];"large"===c?this.props.emailMode||(u["&.builder-block"]=Object.assign({},l.responsiveStyles[c],n)):u["@media only screen and (max-width: "+sizes[c].max+"px)"]={"&.builder-block":l.responsiveStyles[c]};}var m=r.animations&&r.animations.find((function(e){return"hover"===e.trigger}));return m&&(u[":hover"]=(null===(t=null===(e=m.steps)||void 0===e?void 0:e[1])||void 0===t?void 0:t.styles)||{},u.transition="all "+m.duration+"s "+camelCaseToKebabCase$1(m.easing),m.delay&&(u.transitionDelay=m.delay+"s")),u},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"css",{get:function(){var e=this.block,t=__assign$1({},e.responsiveStyles&&e.responsiveStyles.large),n=this.props.emailMode?"":".builder-block."+e.id+" {"+mapToCss(t)+"}",r=sizeNames.slice().reverse();if(e.responsiveStyles)for(var i=0,o=r;i<o.length;i++){var a=o[i];if((!this.props.emailMode||"large"!==a)&&("large"!==a&&"xsmall"!==a&&e.responsiveStyles[a]&&Object.keys(e.responsiveStyles[a]).length)){var s=["display","width","verticalAlign"],l=e.responsiveStyles[a],u=this.props.emailMode&&pick(l,s);n+="\n@media only screen and (max-width: "+sizes[a].max+"px) { \n"+(this.props.emailMode?".":".builder-block.")+e.id+(this.props.emailMode?"-subject":"")+" {"+mapToCss(this.props.emailMode?omit$1(l,s):l,4,this.props.emailMode)+" } }",this.props.emailMode&&u&&Object.keys(u).length&&(n+="\n@media only screen and (max-width: "+sizes[a].max+"px) { \n.builder-block."+e.id+" {"+mapToCss(u,4,!0)+" } }");}}var d=e.animations;if(!this.privateState.state.isBrowser&&d&&d.length){var p=d[0];if(p){var c=p.steps&&p.steps[0];if(c)c.styles&&(n+="\n.builder-block."+e.id+" {"+mapToCss(c,2,!0)+"}");}}return n},enumerable:!0,configurable:!0}),t.prototype.eval=function(e){return this.stringToFunction(e)(this.privateState.state,void 0,this.block,builder,Device,this.privateState.update,Builder,this.privateState.context)},t.prototype.componentWillUnmount=function(){Builder.isEditing&&removeEventListener("message",this.onWindowMessage);},t.prototype.componentDidMount=function(){var e=this,t=this.block,n=t&&t.animations;if(Builder.isEditing&&addEventListener("message",this.onWindowMessage),n){var r={animations:fastClone(n)};if(t.bindings)for(var i in t.bindings)if(i.startsWith("animations.")){var o=this.stringToFunction(t.bindings[i]);void 0!==o&&set(r,i,o(this.privateState.state,null,t,builder,null,null,Builder,this.privateState.context));}Builder.animator.bindAnimations(r.animations.filter((function(e){return"hover"!==e.trigger})).map((function(t){return __assign$1(__assign$1({},t),{elementId:e.block.id})})));}},t.prototype.getElement=function(e,n){var r,i,o,a=this;void 0===e&&(e=0),void 0===n&&(n=this.privateState.state);var s,l=this.props,u=(l.child,l.fieldName,this.block),d=(u.tagName||"div").toLowerCase();if("template"===d){var p=u.children?u.children.map((function(e){return blockToHtmlString(e)})).join(" "):"";return console.debug("template html",p),jsx("template",__assign$1({},u.properties,{dangerouslySetInnerHTML:{__html:p}}))}var c=u.component&&(u.component.name||u.component.component),m=null;u.component&&!u.component.class&&(u.component&&u.component.tag?s=u.component.tag:(m=Builder.components.find((function(e){return e.name===c}))||null)&&m.class?s=m.class:m&&m.tag&&(s=m.tag));var f=__assign$1(__assign$1({},u.properties),{style:{}});if(f=__assign$1(__assign$1({},f.properties),f),u.component&&(f.component=fastClone(u.component)),u.bindings)for(var h in u.bindings){var g=this.stringToFunction(u.bindings[h]);set(f,h,g(n,null,u,api(),Device,null,Builder,this.privateState.context));}if(f.hide)return null;if(delete f.hide,("show"in f||u.bindings&&u.bindings.show)&&!f.show)return null;if(delete f.show,u.actions){var v=function(e){var t=u.actions[e];f["on"+capitalize(e)]=function(e){var r=n;return"undefined"!=typeof Proxy&&(r=new Proxy(n,{set:function(e,t,n){return e[t]=n,a.privateState.rootState[t]=n,!0}})),a.stringToFunction(t,!1)(r,e,a.block,builder,Device,a.privateState.update,Builder,a.privateState.context)};};for(var h in u.actions)v(h);}var b=(f.component||f.options)&&__assign$1(__assign$1({},f.options),f.component.options||f.component.data),y=voidElements.has(d),_=m&&(m.fragment||m.noWrap),x=(null===(i=f.attr)||void 0===i?void 0:i.style)||("string"==typeof f.style?f.style:"")||"";if("string"==typeof x){"object"!=typeof f.style&&(f.style={});for(var S=0,k=x.split(";");S<k.length;S++){var w=k[S].split(":");if(!w.length)return;h=w[0],g=w[1];w.length>2&&(g=w.slice(1).join(":")),f.style[kebabCaseToCamelCase(h)]=g;}}var B=__assign$1(__assign$1(__assign$1({},omit$1(f,["class","component","attr"])),((r={})["string"!=typeof d||d.includes("-")?"class":"className"]="builder-block "+this.id+(u.class?" "+u.class:"")+(!u.component||["Image","Video","Banner"].indexOf(c)>-1?"":" builder-has-component")+(f.class?" "+f.class:"")+(Builder.isEditing&&(null===(o=this.privateState.state._spacer)||void 0===o?void 0:o.parent)===u.id?" builder-spacer-parent":""),r.key=this.id+e,r["builder-id"]=this.id,r)),0!==e&&{"builder-index":e});Builder.isIframe&&(B["builder-inline-styles"]=f.attr&&f.attr.style?Object.keys(f.style).reduce((function(e,t){return(e?e+";":"")+cssCase(t)+":"+f.style[t]+";"}),""):""),(B.properties&&B.properties.href||B.href)&&"div"===d&&(d="a"),"a"===d&&(d=Link);var C=u.children||B.children||[];return jsx(react.Fragment,null,jsx(ClassNames,null,(function(e){var n=e.css;e.cx;if(!a.props.emailMode){var r=" "+n(a.emotionCss);B.class&&(B.class+=r),B.className&&(B.className+=r);}return jsx(BuilderAsyncRequestsContext.Consumer,null,(function(e){return a._asyncRequests=e&&e.requests,a._errors=e&&e.errors,a._logs=e&&e.logs,y?jsx(d,__assign$1({},B)):s&&(_||a.props.emailMode)?jsx(s,__assign$1({},b,{attributes:B,builderBlock:u,builderState:a.privateState})):jsx(d,__assign$1({},B),s&&jsx(s,__assign$1({builderState:a.privateState,builderBlock:u},b)),u.text||f.text?f.text:!s&&C&&Array.isArray(C)&&C.length?C.map((function(e,n){return jsx(t,{key:(a.id||"")+n,block:e,index:n,size:a.props.size,fieldName:a.props.fieldName,child:a.props.child,emailMode:a.props.emailMode})})):null)}))})))},Object.defineProperty(t.prototype,"id",{get:function(){var e=this.block;return e.id.startsWith("builder")?e.id:"builder-"+e.id},enumerable:!0,configurable:!0}),t.prototype.contents=function(e){var t=this,n=this.block;if(this.privateState=e,n.repeat&&n.repeat.collection){var r=n.repeat.collection,i=last((r||"").trim().split("(")[0].trim().split(".")),o=n.repeat.itemName||(i?i+"Item":"item"),a=this.stringToFunction(r)(e.state,null,n,api(),Device,null,Builder,this.privateState.context);return Array.isArray(a)?a.map((function(n,r){var i,a=__assign$1(__assign$1({},e.state),((i={$index:r,$item:n})[o]=n,i["$"+o+"Index"]=r,i));return jsx(BuilderStoreContext.Provider,{key:r,value:__assign$1(__assign$1({},e),{state:a})},t.getElement(r,a))})):null}return this.getElement()},t.prototype.render=function(){var e=this;return this.state.hasError?jsx("span",{css:{display:"inline-block",padding:5,color:"#999",fontSize:11,fontStyle:"italic"}},"Builder block error :( Check console for details"):jsx(BuilderStoreContext.Consumer,null,(function(t){return e.contents(t)}))},t}(react.Component),BuilderBlocks=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.onClickEmptyBlocks=function(){var e;Builder.isIframe&&t.noBlocks&&(null===(e=window.parent)||void 0===e||e.postMessage({type:"builder.clickEmptyBlocks",data:{parentElementId:t.parentId,dataPath:t.path}},"*"));},t}return __extends$1(t,e),Object.defineProperty(t.prototype,"isRoot",{get:function(){return!this.props.child},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"noBlocks",{get:function(){var e=this.props.blocks;return!(e&&e.length)},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"path",{get:function(){var e=this.props.dataPath||"";return e.trim()&&(e.startsWith("this.")?e=e.replace("this.",""):e.startsWith("component.options.")||(e="component.options."+e)),e},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"parentId",{get:function(){return this.props.parentElementId?this.props.parentElementId:this.props.parent&&this.props.parent.id},enumerable:!0,configurable:!0}),t.prototype.render=function(){var e=this,t=this.props.blocks,n=this.props.emailMode?"span":"div";return jsx(n,{className:"builder-blocks"+(this.noBlocks?" no-blocks":"")+(this.props.child?" builder-blocks-child":"")+(this.props.className?" "+this.props.className:""),"builder-type":"blocks","builder-path":Builder.isIframe?this.path:void 0,css:__assign$1(__assign$1({},!this.props.emailMode&&{display:"flex",flexDirection:"column",alignItems:"stretch"}),this.props.style),onClick:function(){e.noBlocks&&e.onClickEmptyBlocks();}},t&&Array.isArray(t)&&t.map((function(t,n){return t&&"@builder.io/sdk:Element"===t["@type"]?jsx(BuilderBlock,{key:t.id,block:t,index:n,fieldName:e.props.fieldName,child:e.props.child,emailMode:e.props.emailMode}):t}))||t)},t}(react.Component),NoWrap=function(e){return e.children};function getData(e){if(void 0!==(null==e?void 0:e.data)){var t=__assign$1(__assign$1({},e.data),{blocks:e.data.blocks||JSON.parse(e.data.blocksString)});return delete t.blocksString,t}}var variantsScript=function(e,t){return("\n(function() {\n  if (window.builderNoTrack) {\n    return;\n  }\n\n  var variants = "+e+';\n  function removeVariants() {\n    variants.forEach((template) => {\n      document.querySelector(\'template[data-template-variant-id="\' + template.id + \'"]\').remove();\n    });\n  }\n\n  if (typeof document.createElement("template").content === \'undefined\') {\n    removeVariants();\n    return ;\n  }\n\n  function setCookie(name,value,days) {\n    var expires = "";\n    if (days) {\n        var date = new Date();\n        date.setTime(date.getTime() + (days*24*60*60*1000));\n        expires = "; expires=" + date.toUTCString();\n    }\n    document.cookie = name + "=" + (value || "")  + expires + "; path=/" + "; Secure; SameSite=None";\n  }\n\n  function getCookie(name) {\n    var nameEQ = name + "=";\n    var ca = document.cookie.split(\';\');\n    for(var i=0;i < ca.length;i++) {\n        var c = ca[i];\n        while (c.charAt(0)==\' \') c = c.substring(1,c.length);\n        if (c.indexOf(nameEQ) == 0) return c.substring(nameEQ.length,c.length);\n    }\n    return null;\n  }\n  var cookieName = \'builder.tests.'+t+"';\n  var variantInCookie = getCookie(cookieName);\n  var availableIDs = variants.map(function(vr) { return vr.id }).concat('"+t+"');\n  var variantId;\n  if (availableIDs.indexOf(variantInCookie) > -1) {\n    variantId = variantInCookie;\n  }\n  if (!variantId) {\n    var n = 0;\n    var set = false;\n    var random = Math.random();\n    for (var i = 0; i < variants.length; i++) {\n      var variant = variants[i];\n      var testRatio = variant.testRatio;\n      n += testRatio;\n      if (random < n) {\n        setCookie(cookieName, variant.id);\n        variantId = variant.id;\n        break;\n      }\n    }\n    if (!variantId) {\n      variantId = \""+t+'";\n      setCookie(cookieName, "'+t+'");\n    }\n  }\n  if (variantId && variantId !== "'+t+"\") {\n    var winningTemplate = document.querySelector('template[data-template-variant-id=\"' + variantId + '\"]');\n    if (winningTemplate) {\n      var parentNode = winningTemplate.parentNode;\n      var newParent = parentNode.cloneNode(false);\n      newParent.appendChild(winningTemplate.content.firstChild);\n      parentNode.parentNode.replaceChild(newParent, parentNode);\n    }\n  } else if (variants.length > 0) {\n    removeVariants();\n  }\n})()").replace(/\s+/g," ")},VariantsProvider=function(e){var t=e.initialContent,n=e.children;if(!Boolean(Object.keys((null==t?void 0:t.variations)||{}).length))return n([t]);var r=Object.keys(t.variations).map((function(e){return __assign$1(__assign$1({id:e},t.variations[e]),{data:getData(t.variations[e])})})),i=__spreadArrays$1(r,[t]);if(Builder.isServer){var o=JSON.stringify(Object.keys(t.variations||{}).map((function(e){return{id:e,testRatio:t.variations[e].testRatio}})));return react_4(react_6,null,n(i,(function(){return react_4("script",{dangerouslySetInnerHTML:{__html:variantsScript(o,t.id)}})})))}var a="builder.tests."+t.id,s=builder.getCookie(a);if(!s&&Builder.isBrowser)for(var l=0,u=Math.random(),d=0;d<r.length;d++){var p=r[d];if(u<(l+=p.testRatio)){builder.setCookie(a,p.id),s=p.id;break}}return s||(s=t.id,builder.setCookie(a,s)),n([i.find((function(e){return e.id===s}))])},BuilderContent=function(_super){function BuilderContent(){var _this=null!==_super&&_super.apply(this,arguments)||this;return _this.ref=null,_this.state={loading:!0,data:null,updates:1},_this.onWindowMessage=function(event){var _a,message=event.data;if(message)switch(message.type){case"builder.patchUpdates":var data=message.data;if(!data||!data.data)break;var patches=data.data[null===(_a=_this.state.data)||void 0===_a?void 0:_a.id];if(!patches||!patches.length)return;location.href.includes("builder.debug=true")&&eval("debugger");for(var _i=0,patches_1=patches;_i<patches_1.length;_i++){var patch=patches_1[_i];applyPatchWithMinimalMutationChain(_this.state.data,patch);}_this.setState({updates:_this.state.updates+1,data:_this.state.data?__assign$1({},_this.state.data):_this.state.data}),_this.props.contentLoaded&&_this.props.contentLoaded(_this.state.data.data,_this.state.data);}},_this.subscriptions=new Subscription,_this.firstLoad=!0,_this.clicked=!1,_this.trackedImpression=!1,_this.intersectionObserver=null,_this.onClick=function(e){var t=e.nativeEvent,n=_this.data;n&&(builder.autoTrack&&_this.builder.trackInteraction(n.id,_this.renderedVairantId,_this.clicked,t,{content:n}),_this.clicked||(_this.clicked=!0));},_this}return __extends$1(BuilderContent,_super),Object.defineProperty(BuilderContent.prototype,"builder",{get:function(){return this.props.builder||builder},enumerable:!0,configurable:!0}),Object.defineProperty(BuilderContent.prototype,"renderedVairantId",{get:function(){var e,t,n=this.props.isStatic?this.builder.getCookie("builder.tests."+(null===(e=this.data)||void 0===e?void 0:e.id)):null===(t=this.data)||void 0===t?void 0:t.variationId;if(null!==n)return n},enumerable:!0,configurable:!0}),Object.defineProperty(BuilderContent.prototype,"options",{get:function(){var e,t=__assign$1({},this.props.options||{});return this.props.content&&!(null===(e=t.initialContent)||void 0===e?void 0:e.length)&&(t.initialContent=[this.props.content]),t},enumerable:!0,configurable:!0}),Object.defineProperty(BuilderContent.prototype,"data",{get:function(){var e=this.state.data;return(this.props.inline||!Builder.isBrowser||this.firstLoad)&&this.options.initialContent&&this.options.initialContent[0]||e},enumerable:!0,configurable:!0}),BuilderContent.prototype.componentDidMount=function(){var e,t;if(!this.props.inline||Builder.isEditing)this.subscribeToContent();else if(this.props.inline&&(null===(t=null===(e=this.options)||void 0===e?void 0:e.initialContent)||void 0===t?void 0:t.length)){var n=this.options.initialContent[0];this.builder.trackImpression(n.id,this.renderedVairantId,void 0,{content:n});}Builder.isEditing&&addEventListener("message",this.onWindowMessage);},BuilderContent.prototype.subscribeToContent=function(){var e=this;"_inline"!==this.props.modelName&&this.subscriptions.add(builder.queueGetContent(this.props.modelName,this.options).subscribe((function(t){var n=t&&t[0];if(e.setState({data:n}),n&&e.firstLoad){if(builder.autoTrack){var r=!1;if("function"==typeof IntersectionObserver&&e.ref)try{(e.intersectionObserver=new IntersectionObserver((function(t,r){t.forEach((function(t){t.intersectionRatio>0&&!e.trackedImpression&&(e.builder.trackImpression(n.id,e.renderedVairantId,void 0,{content:e.data}),e.data,e.trackedImpression=!0,e.ref&&r.unobserve(e.ref));}));}))).observe(e.ref),r=!0;}catch(e){console.warn("Could not bind intersection observer");}r||(e.trackedImpression=!0,e.builder.trackImpression(n.id,e.renderedVairantId,void 0,{content:n}));}e.firstLoad=!1;}e.props.contentLoaded&&e.props.contentLoaded(n&&n.data,n);}),(function(t){e.props.contentError&&e.props.contentError(t);})));},BuilderContent.prototype.componentWillUnmount=function(){Builder.isEditing&&removeEventListener("message",this.onWindowMessage),this.subscriptions.unsubscribe(),this.intersectionObserver&&this.ref&&this.intersectionObserver.unobserve(this.ref);},BuilderContent.prototype.render=function(){var e=this;if(this.props.dataOnly)return null;var t=this.state.loading,n=this.data,r=this.props.dataOnly?NoWrap:"div";return this.props.isStatic?react.createElement(VariantsProvider,{initialContent:n},(function(i,o){return react.createElement(react.Fragment,null,i.map((function(a,s){var l=s===i.length-1?react.Fragment:"template";return react.createElement(react.Fragment,{key:String((null==a?void 0:a.id)+s)},"template"!==l&&(null==o?void 0:o()),react.createElement(l,__assign$1({key:String((null==a?void 0:a.id)+s)},"template"===l&&{"data-template-variant-id":null==a?void 0:a.id}),react.createElement(r,__assign$1({},0===s&&!e.props.dataOnly&&{ref:function(t){return e.ref=t}},{className:"builder-content",onClick:e.onClick,"builder-content-id":null==a?void 0:a.id,"builder-model":e.props.modelName}),e.props.children(null==a?void 0:a.data,!e.props.inline&&t,n))))})))})):react.createElement(r,__assign$1({},!this.props.dataOnly&&{ref:function(t){return e.ref=t}},{className:"builder-content",onClick:this.onClick,"builder-content-id":null==n?void 0:n.id,"builder-model":this.props.modelName}),this.props.children(null==n?void 0:n.data,!this.props.inline&&t,n))},BuilderContent}(react.Component);function unwrapExports$1(e){return e&&e.__esModule&&Object.prototype.hasOwnProperty.call(e,"default")?e.default:e}function createCommonjsModule$1(e,t){return e(t={exports:{}},t.exports),t.exports}var onChange_1=createCommonjsModule$1((function(e,t){Object.defineProperty(t,"__esModule",{value:!0});var n=Symbol("target"),r=Symbol("unsubscribe"),i=function(e,t){return t&&t.toString&&(e&&(e+="."),e+=t.toString()),e},o=function(e){return Array.isArray(e)?e.slice():Object.assign({},e)},a=function(e,t,a){if("undefined"==typeof Proxy)return e;void 0===a&&(a={});var s,l,u=Symbol("ProxyTarget"),d=!1,p=!1,c=!1,m=a.equals||Object.is,f=new WeakMap,h=new WeakMap,g=new WeakMap,v=function(e,n,r,a){if(!c)if(d){if(d&&l&&void 0!==r&&void 0!==a&&"length"!==n){var u=l;e!==s&&function(e,t){for(var n;e;)-1===(n=e.indexOf("."))&&(n=e.length),t(e.slice(0,n)),e=e.slice(n+1);}(e=e.replace(s,"").slice(1),(function(e){u[e]=o(u[e]),u=u[e];})),u[n]=r;}p=!0;}else t(i(e,n),a,r);},b=function(e,t){var n=f?f.get(e):void 0;n&&n.delete(t);},y=function(e,t){if(c)return e;h.set(e,t);var n=g.get(e);return void 0===n&&(n=new Proxy(e,x),g.set(e,n)),n},_=function(e){return c||!0===a.ignoreSymbols&&"symbol"==typeof e},x={get:function(e,t,o){if(t===u||t===n)return e;if(t===r&&""===h.get(e))return function(e){return c=!0,f=null,h=null,g=null,e}(e);var s=Reflect.get(e,t,o);if(function(e){return null===e||"object"!=typeof e&&"function"!=typeof e}(s)||function(e){return e instanceof RegExp||e instanceof Number}(s)||"constructor"===t||!0===a.isShallow)return s;var l=function(e,t){var n=f?f.get(e):void 0;if(n)return n;n=new Map,f.set(e,n);var r=n.get(t);return r||(r=Reflect.getOwnPropertyDescriptor(e,t),n.set(t,r)),r}(e,t);if(l&&!l.configurable){if(l.set&&!l.get)return;if(!1===l.writable)return s}return y(s,i(h.get(e),t))},set:function(e,t,n,r){n&&void 0!==n[u]&&(n=n[u]);var i=_(t),o=i?null:Reflect.get(e,t,r),a=Reflect.set(e[u]||e,t,n);return i||m(o,n)||v(h.get(e),t,o,n),a},defineProperty:function(e,t,n){var r=Reflect.defineProperty(e,t,n);return _(t)||(b(e,t),v(h.get(e),t,void 0,n.value)),r},deleteProperty:function(e,t){if(!Reflect.has(e,t))return!0;var n=_(t),r=n?null:Reflect.get(e,t),i=Reflect.deleteProperty(e,t);return n||(b(e,t),v(h.get(e),t,r)),i},apply:function(e,t,n){var r=t instanceof Date;if(r&&(t=t[u]),!d){d=!0,r&&(l=t.valueOf()),(Array.isArray(t)||"[object Object]"===toString.call(t))&&(l=o(t[u])),s=(s=h.get(e)).slice(0,Math.max(s.lastIndexOf("."),0));var i=Reflect.apply(e,t,n);return d=!1,(p||r&&!m(l,t.valueOf()))&&(v(s,"",l,t[u]||t),l=null,p=!1),i}return Reflect.apply(e,t,n)}},S=y(e,"");return t=t.bind(S),S};a.target=function(e){return e[n]||e},a.unsubscribe=function(e){return e[r]||e},e.exports=a,t.default=a;})),onChange=unwrapExports$1(onChange_1),nextTick$1=Builder.nextTick;function debounceNextTick(e,t,n){return void 0===t&&"function"==typeof e?debounceNextTickImpl(e):{configurable:!0,enumerable:n.enumerable,get:function(){return Object.defineProperty(this,t,{configurable:!0,enumerable:n.enumerable,value:debounceNextTickImpl(n.value)}),this[t]}}}function debounceNextTickImpl(e){var t=null,n=null;return function(){var e=t;if(t=[].slice.call(arguments),n=this,null!==e)return;nextTick$1(r);};function r(){e.apply(n,t),t=null,n=null;}}function throttle$1(e,t,n){var r,i,o;void 0===n&&(n={});var a=null,s=0,l=function(){s=!1===n.leading?0:Date.now(),a=null,o=e.apply(r,i),a||(r=i=null);};return function(){var u=Date.now();s||!1!==n.leading||(s=u);var d=t-(u-s);return r=this,i=arguments,d<=0||d>t?(a&&(clearTimeout(a),a=null),s=u,o=e.apply(r,i),a||(r=i=null)):a||!1===n.trailing||(a=setTimeout(l,d)),o}}var BuilderMetaContext=react.createContext({emailMode:!1,ampMode:!1,isServer:!1}),size$1=function(e){return Object.keys(e).length};function debounce(e,t,n){var r;return void 0===n&&(n=!1),function(){var i=this,o=arguments;clearTimeout(r),r=setTimeout((function(){r=null,n||e.apply(i,o);}),t),n&&!r&&e.apply(i,o);}}var fontsLoaded=new Set;function pick$1(e,t){return t.reduce((function(t,n){return e&&e.hasOwnProperty(n)&&(t[n]=e[n]),t}),{})}var fetch$1$1=Builder.isBrowser?window.fetch:require("node-fetch"),sizeMap={desktop:"large",tablet:"medium",mobile:"small"};function decorator(e){return function(){for(var t=[],n=0;n<arguments.length;n++)t[n]=arguments[n];if(3===t.length){var r=t[0],i=t[1],o=t[2];if(o&&(o.value||o.get))return t=[],a(r,i,o)}return a;function a(n,r,i){var o,a=i.value?"value":"get";return __assign$1(__assign$1({},i),((o={})[a]=e.apply(void 0,__spreadArrays$1([i[a]],t)),o))}}}var Throttle=decorator(throttle$1),fetchCache={},tryEval=function(e,t,n){void 0===t&&(t={});var r=e;if("string"==typeof r&&r.trim()){var i=!(r.includes(";")||r.includes(" return ")),o=function(){};try{Builder.isBrowser&&(o=new Function("state","var rootState = state;\n        if (typeof Proxy !== 'undefined') {\n          rootState = new Proxy(rootState, {\n            set: function () {\n              return false;\n            },\n            get: function (target, key) {\n              if (key === 'state') {\n                return state;\n              }\n              return target[key]\n            }\n          });\n        }\n        with (rootState) {\n          "+(i?"return ("+e+");":e)+";\n        }"));}catch(e){Builder.isBrowser&&console.warn("Could not compile javascript",e);}try{return Builder.isBrowser?o(t||{}):new(safeDynamicRequire("vm2").VM)({sandbox:__assign$1(__assign$1({},t),{state:t})}).run(r.replace(/(^|;)return /,"$1"))}catch(t){n&&n.push(t),Builder.isBrowser?console.warn("Builder custom code error:",t.message,"in",e,t.stack):process.env.DEBUG&&console.debug("Builder custom code error:",t.message,"in",e,t.stack);}}};function searchToObject(e){var t=(e.search||"").substring(1).split("&"),n={};for(var r in t)if(t[r]&&"string"==typeof t[r]){var i=t[r].split("=");n[decodeURIComponent(i[0])]=decodeURIComponent(i[1]);}return n}var BuilderPage=function(e){function t(t){var n=e.call(this,t)||this;if(n.subscriptions=new Subscription,n.onStateChange=new BehaviorSubject(null),n.asServer=Builder.isServer,n.contentRef=null,n.styleRef=null,n.rootState=Builder.isServer?{}:onChange({},(function(){return n.updateState()})),n.lastJsCode="",n.lastHttpRequests={},n.httpSubscriptionPerKey={},n.ref=null,n.messageListener=function(e){var t=e.data;switch(t.type){case"builder.updateSpacer":var r=t.data;n.rootState._spacer;n.updateState((function(e){e._spacer=r;}));break;case"builder.resetState":var i=t.data,o=i.state;if(i.model===n.name){for(var a in n.rootState)"function"!=typeof n.rootState[a]&&delete n.rootState[a];Object.assign(n.rootState,o),n.setState(__assign$1(__assign$1({},n.state),{state:n.rootState,updates:(n.state&&n.state.updates||0)+1}));}break;case"builder.resetSymbolState":var s=t.data.state,l=(o=s.state,s.model,s.id);if(n.props.builderBlock&&n.props.builderBlock===l){for(var a in n.rootState)delete n.rootState[a];Object.assign(n.rootState,o),n.setState(__assign$1(__assign$1({},n.state),{state:n.rootState,updates:(n.state&&n.state.updates||0)+1}));}}},n.resizeFn=function(){var e=n.deviceSizeState;e!==n.state.state.deviceSize&&n.setState(__assign$1(__assign$1({},n.state),{updates:(n.state&&n.state.updates||0)+1,state:Object.assign(n.rootState,__assign$1(__assign$1({},n.state.state),{deviceSize:e}))}));},n.resizeListener=Builder.isEditing?throttle$1(n.resizeFn,200):debounce(n.resizeFn,400),n.mounted=!1,n.updateState=function(e){var t=n.rootState;e&&e(t),n.mounted?n.setState({update:n.updateState,state:t,updates:(n.state&&n.state.updates||0)+1}):n.state=__assign$1(__assign$1({},n.state),{update:n.updateState,state:t,updates:(n.state&&n.state.updates||0)+1}),n.notifyStateChange();},n.onContentLoaded=function(e,t){if("page"===n.name&&Builder.isBrowser&&e){var r=e.title,i=e.pageTitle,o=e.description,a=e.pageDescription;if((r||i)&&(document.title=r||i),o||a){var s=document.querySelector('meta[name="description"]');s||((s=document.createElement("meta")).setAttribute("name","description"),document.head.appendChild(s)),s.setAttribute("content",o||a);}}if(Builder.isEditing&&n.notifyStateChange(),n.props.contentLoaded&&n.props.contentLoaded(e,t),e&&e.inputs&&Array.isArray(e.inputs)&&e.inputs.length&&(e.state||(e.state={}),e.inputs.forEach((function(t){t&&t.name&&void 0!==t.defaultValue&&void 0===e.state[t.name]&&(e.state[t.name]=t.defaultValue);}))),e&&e.state){var l=__assign$1(__assign$1({},n.state),{updates:(n.state&&n.state.updates||0)+1,state:Object.assign(n.rootState,__assign$1(__assign$1(__assign$1(__assign$1({},n.state.state),{location:n.locationState,deviceSize:n.deviceSizeState,device:n.device}),e.state),n.props.data))});n.mounted?n.setState(l):n.state=l;}if(e&&e.jsCode&&Builder.isBrowser){var u=!1;if(Builder.isEditing&&(n.lastJsCode===e.jsCode?u=!0:n.lastJsCode=e.jsCode),!u){var d=n.state.state;try{new Function("data","ref","state","update","element","Builder","builder","context",e.jsCode)(e,n,d,n.state.update,n.ref,Builder,builder,n.state.context);}catch(t){Builder.isBrowser?console.warn("Builder custom code error:",t.message,"in",e.jsCode,t.stack):process.env.DEBUG&&console.debug("Builder custom code error:",t.message,"in",e.jsCode,t.stack);}}}if(e&&e.httpRequests&&!n.props.noAsync&&!(u=!1)){var p=function(t){var r=e.httpRequests[t];if(r&&(!n.data[t]||Builder.isEditing))if(Builder.isBrowser){var i=n.evalExpression(r);if(Builder.isEditing&&n.lastHttpRequests[t]===i)return"continue";n.lastHttpRequests[t]=i;var o=r.match(/builder\.io\/api\/v2\/([^\/\?]+)/i);o&&o[1];n.throttledHandleRequest(t,i);var a=n.httpSubscriptionPerKey[t];a&&a.unsubscribe();var s=n.httpSubscriptionPerKey[t]=n.onStateChange.subscribe((function(){var e=n.evalExpression(r);e!==i&&(n.throttledHandleRequest(t,e),n.lastHttpRequests[t]=e);}));n.subscriptions.add(s);}else n.handleRequest(t,n.evalExpression(r));};for(var c in e.httpRequests)p(c);}},n.state={context:t.context||{},state:Object.assign(n.rootState,__assign$1(__assign$1(__assign$1(__assign$1({},n.props.content&&n.props.content.data&&n.props.content.data.state),{isBrowser:Builder.isBrowser,isServer:!Builder.isBrowser,_hydrate:t.hydrate,location:n.locationState,deviceSize:n.deviceSizeState,device:n.device}),n.getHtmlData()),t.data)),updates:0,key:0,update:n.updateState},Builder.isBrowser){var r=n.props.apiKey;if(r&&r!==n.builder.apiKey&&(n.builder.apiKey=r),n.props.content){var i=n.props.content.content||n.props.content;n.onContentLoaded(null==i?void 0:i.data,i);}}return n}return __extends$1(t,e),Object.defineProperty(t.prototype,"name",{get:function(){return this.props.model||this.props.modelName||this.props.name},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"element",{get:function(){return this.ref},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"builder",{get:function(){return this.props.builder||builder},enumerable:!0,configurable:!0}),t.prototype.getHtmlData=function(){var e=this.props.content&&this.props.content.id||this.props.entry,t=e&&Builder.isBrowser&&document.querySelector('script[data-builder-json="'+e+'"],script[data-builder-state="'+e+'"]');if(t)try{return JSON.parse(t.innerText)}catch(e){console.warn("Could not parse Builder.io HTML data transfer",e,t.innerText);}return{}},Object.defineProperty(t.prototype,"device",{get:function(){return this.builder.getUserAttributes().device||"desktop"},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"locationState",{get:function(){return __assign$1(__assign$1({},pick$1(this.location,["pathname","hostname","search","host"])),{path:this.location.pathname&&this.location.pathname.split("/").slice(1)||"",query:searchToObject(this.location)})},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"deviceSizeState",{get:function(){return Builder.isBrowser?sizes.getSizeForWidth(window.innerWidth):sizeMap[this.device]||"large"},enumerable:!0,configurable:!0}),t.renderInto=function(e,n,r,i){if(void 0===n&&(n={}),void 0===r&&(r=!0),void 0===i&&(i=!1),console.debug("BuilderPage.renderInto",e,n,r,this),e){var o=null;if("string"==typeof e?o=document.querySelector(e):e instanceof Element&&(o=e),o){var a=o.classList.contains("builder-hydrated");if(!a||i){o.classList.add("builder-hydrated");var s=r&&o.innerHTML.includes("builder-block");if(!o.classList.contains("builder-component")){var l=o.querySelector(".builder-api-styles")||(o.previousElementSibling&&o.previousElementSibling.matches(".builder-api-styles")?o.previousElementSibling:null),u="";if(l)l.innerHTML.replace(/\/\*start:([^\*]+?)\*\/([\s\S]*?)\/\*end:([^\*]+?)\*\//g,(function(e,t,n){var r=null;try{r=document.querySelector('[data-emotion-css="'+t+'"]');}catch(e){console.warn(e);}return r?r.innerHTML=n:Builder.isEditing||(u+=e),e})),Builder.nextTick((function(){l.innerHTML=u;}));var d=o.querySelector(".builder-component");d?o=d:s=!1;}location.search.includes("builder.debug=true")&&console.debug("hydrate",s,o);var p=o;if(!a){var c=document.createElement("div");o.insertAdjacentElement("beforebegin",c),c.appendChild(o),p=c;}if((Builder.isEditing||Builder.isBrowser&&location.search.includes("builder.preview="))&&(s=!1),s&&o){var m=reactDom.render(react.createElement(t,__assign$1({},n)),p,p.builderRootRef);return p.builderRootRef=m,m}var f=reactDom.render(react.createElement(t,__assign$1({},n)),p,p.builderRootRef);return p.builderRootRef=f,f}console.debug("Tried to hydrate multiple times");}}},t.prototype.componentDidMount=function(){var e,t=this;this.mounted=!0,this.asServer&&(this.asServer=!1,this.updateState((function(e){e.isBrowser=!0,e.isServer=!1;}))),Builder.isIframe&&(null===(e=window.parent)||void 0===e||e.postMessage({type:"builder.sdkInjected",data:{modelName:this.name}},"*")),Builder.isBrowser&&(window.addEventListener("resize",this.resizeListener),Builder.isEditing&&window.addEventListener("message",this.messageListener),setTimeout((function(){window.dispatchEvent(new CustomEvent("builder:component:load",{detail:{ref:t}}));})));},t.prototype.notifyStateChange=function(){if(!Builder.isServer&&this&&this.state){var e=this.state.state;this.props.onStateChange&&this.props.onStateChange(e),Builder.isBrowser&&window.dispatchEvent(new CustomEvent("builder:component:stateChange",{detail:{state:e,ref:this}})),this.onStateChange.next(e);}},t.prototype.processStateFromApi=function(e){return e},Object.defineProperty(t.prototype,"location",{get:function(){return this.props.location||(Builder.isBrowser?location:{})},enumerable:!0,configurable:!0}),t.prototype.getCssFromFont=function(e,t){var n=e.family+(e.kind&&!e.kind.includes("#")?", "+e.kind:""),r=n.split(",")[0],i=e.fileUrl?e.fileUrl:e.files&&e.files.regular,o="";if(i&&n&&r&&(o+=('\n@font-face {\n  font-family: "'+n+'";\n  src: local("'+r+"\"), url('"+i+"') format('woff2');\n  font-display: fallback;\n  font-weight: 400;\n}\n        ").trim()),e.files)for(var a in e.files){if(String(Number(a))===a){var s=e.files[a];s&&s!==i&&(o+=('\n@font-face {\n  font-family: "'+n+"\";\n  src: url('"+s+"') format('woff2');\n  font-display: fallback;\n  font-weight: "+a+";\n}\n          ").trim());}}return o},t.prototype.componentWillUnmount=function(){this.unsubscribe(),Builder.isBrowser&&(window.removeEventListener("resize",this.resizeListener),window.removeEventListener("message",this.messageListener));},t.prototype.getFontCss=function(e){var t=this;return this.builder.allowCustomFonts&&(null==e?void 0:e.customFonts)&&e.customFonts.length&&e.customFonts.map((function(n){return t.getCssFromFont(n,e)})).join(" ")||""},t.prototype.ensureFontsLoaded=function(e){if(this.builder.allowCustomFonts&&(null==e?void 0:e.customFonts)&&Array.isArray(e.customFonts))for(var t=0,n=e.customFonts;t<n.length;t++){var r=n[t],i=r.fileUrl?r.fileUrl:r.files&&r.files.regular;if(!fontsLoaded.has(i)){var o=this.getCssFromFont(r,e);if(fontsLoaded.add(i),!o)continue;var a=document.createElement("style");a.className="builder-custom-font",a.setAttribute("data-builder-custom-font",i),a.innerHTML=o,document.head.appendChild(a);}}},t.prototype.getCss=function(e){var t,n=null===(t=this.useContent)||void 0===t?void 0:t.id,r=(null==e?void 0:e.cssCode)||"";return n&&(r=r.replace(/&/g,".builder-component-"+n)),r+this.getFontCss(e)},Object.defineProperty(t.prototype,"data",{get:function(){var e,t=__assign$1(__assign$1(__assign$1({},this.props.content&&(null===(e=this.props.content.data)||void 0===e?void 0:e.state)),this.props.data),this.state.state);return Object.assign(this.rootState,t),t},enumerable:!0,configurable:!0}),t.prototype.componentDidUpdate=function(e){var t=this;this.props.data&&e.data!==this.props.data&&this.state.update((function(e){Object.assign(e,t.props.data);})),Builder.isEditing&&this.props.content&&e.content!==this.props.content&&this.onContentLoaded(this.props.content.data,this.props.content);},t.prototype.checkStyles=function(e){if(this.styleRef){var t=this.getCss(e);this.styleRef.innerHTML!==t&&(this.styleRef.innerHTML=t);}},t.prototype.reload=function(){this.setState({key:this.state.key+1});},Object.defineProperty(t.prototype,"content",{get:function(){var e=this.props.content;return e&&e.content&&(e=__assign$1(__assign$1({},e),{data:e.content})),e},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"useContent",{get:function(){return this.content||this.state.context.builderContent},enumerable:!0,configurable:!0}),t.prototype.render=function(){var e,t=this,n=this.content,r=Builder.isBrowser&&this.props.data&&size$1(this.props.data)&&hashSum$1(this.props.data),i=Builder.isEditing?this.name:this.props.entry;i&&!Builder.isEditing&&r&&r.length<300&&(i+=":"+r);var o=this.props.dataOnly?react.Fragment:"div",a=null===(e=this.useContent)||void 0===e?void 0:e.id;return react.createElement(o,{className:"builder-component "+(a?"builder-component-"+a:""),"data-name":this.name,"data-source":"Rendered by Builder.io on "+(new Date).toUTCString(),key:this.state.key,ref:function(e){return t.ref=e}},react.createElement(BuilderMetaContext.Consumer,null,(function(e){return react.createElement(BuilderMetaContext.Provider,{value:"boolean"==typeof t.props.ampMode?__assign$1(__assign$1({},e),{ampMode:t.props.ampMode}):e},react.createElement(BuilderAsyncRequestsContext.Consumer,null,(function(e){var r;return t._asyncRequests=e&&e.requests,t._errors=e&&e.errors,t._logs=e&&e.logs,react.createElement(BuilderContent,{isStatic:t.props.isStatic||Builder.isStatic,key:(null===(r=t.props.content)||void 0===r?void 0:r.id)||("content"in t.props?"null-content-prop":"no-content-prop"),builder:t.builder,ref:function(e){return t.contentRef=e},contentLoaded:function(e,n){return t.onContentLoaded(e,n)},options:__assign$1(__assign$1(__assign$1(__assign$1({key:i,entry:t.props.entry},n&&{initialContent:[n]}),!n&&"content"in t.props&&{initialContent:[]}),t.props.url&&{url:t.props.url}),t.props.options),inline:t.props.inlineContent||!Builder.isEditing&&"content"in t.props,contentError:t.props.contentError,modelName:t.name||"page"},(function(e,n,r){var i;return t.props.dataOnly?null:(r&&r.id&&(t.state.context.builderContent=r),Builder.isBrowser&&Builder.nextTick((function(){t.checkStyles(e);})),e?react.createElement("div",{"data-builder-component":t.name,"data-builder-content-id":r.id,"data-builder-variation-id":r.testVariationId||r.variationId||r.id},t.getCss(e)&&react.createElement("style",{ref:function(e){return t.styleRef=e},className:"builder-custom-styles",dangerouslySetInnerHTML:{__html:t.getCss(e)}}),react.createElement(BuilderStoreContext.Provider,{value:__assign$1(__assign$1({},t.state),{rootState:t.rootState,state:t.data,content:r,renderLink:t.props.renderLink})},react.createElement(BuilderBlocks,{key:String(!!(null===(i=null==e?void 0:e.blocks)||void 0===i?void 0:i.length)),emailMode:t.props.emailMode,fieldName:"blocks",blocks:e.blocks}))):n?react.createElement("div",{"data-builder-component":t.name,className:"builder-loading"},t.props.children):react.createElement("div",{"data-builder-component":t.name,className:"builder-no-content"}))}))})))})))},t.prototype.evalExpression=function(e){var t=this,n=this.data;return e.replace(/{{([^}]+)}}/g,(function(e,r){return tryEval(r,n,t._errors)}))},t.prototype.throttledHandleRequest=function(e,t){return this.handleRequest(e,t)},t.prototype.handleRequest=function(e,t){return __awaiter$1(this,void 0,void 0,(function(){var n,r,i,o,a=this;return __generator$1(this,(function(s){return Builder.isIframe&&fetchCache[t]?(this.updateState((function(n){n[e]=fetchCache[t];})),[2,fetchCache[t]]):(n=function(){return __awaiter$1(a,void 0,void 0,(function(){var n,r,i;return __generator$1(this,(function(o){switch(o.label){case 0:n=Date.now(),Builder.isBrowser||console.time("Fetch "+t),o.label=1;case 1:return o.trys.push([1,4,5,6]),[4,fetch$1$1(t)];case 2:return[4,o.sent().json()];case 3:return r=o.sent(),[3,6];case 4:return i=o.sent(),this._errors&&this._errors.push(i),this._logs&&this._logs.push("Fetch to "+t+" errored in "+(Date.now()-n)+"ms"),[2];case 5:return Builder.isBrowser||(console.timeEnd("Fetch "+t),this._logs&&this._logs.push("Fetched "+t+" in "+(Date.now()-n)+"ms")),[7];case 6:return r&&(Builder.isIframe&&(fetchCache[t]=r),this.updateState((function(t){t[e]=r;}))),[2,r]}}))}))},(r=this._asyncRequests&&this._asyncRequests.find((function(e){return isRequestInfo(e)&&e.url===t})))?((i=r.promise).then((function(t){t&&a.updateState((function(n){n[e]=t;}));})),[2,i]):(o=n(),Builder.nextTick((function(){a._asyncRequests&&a._asyncRequests.push(o);})),[2,o]))}))}))},t.prototype.unsubscribe=function(){this.subscriptions&&(this.subscriptions.unsubscribe(),this.subscriptions=new Subscription);},t.prototype.handleBuilderRequest=function(e,t){var n=this,r=tryEval(t,this.data,this._errors);this.subscriptions&&this.unsubscribe(),r&&this.subscriptions.add(this.builder.queueGetContent(r.model,r).subscribe((function(t){t&&n.updateState((function(n){n[e]=t;}));})));},__decorate$1([debounceNextTick,__metadata$1("design:type",Function),__metadata$1("design:paramtypes",[]),__metadata$1("design:returntype",void 0)],t.prototype,"notifyStateChange",null),__decorate$1([Throttle(100,{leading:!0,trailing:!0}),__metadata$1("design:type",Function),__metadata$1("design:paramtypes",[String,String]),__metadata$1("design:returntype",void 0)],t.prototype,"throttledHandleRequest",null),t}(react.Component);function BuilderBlock$1(e){return e.type="react",Builder.Component(e)}function withBuilder(e,t){return BuilderBlock$1(t)(e),e}var withChildren=function(e){var t=react.forwardRef((function(t,n){var r=t.children||t.builderBlock&&t.builderBlock.children&&t.builderBlock.children.map((function(e){return react.createElement(BuilderBlock,{key:e.id,block:e})}));return react.createElement(e,__assign$1({},t,{ref:n}),r)}));return t.builderOptions={canHaveChildren:!0},t},iconUrl="https://firebasestorage.googleapis.com/v0/b/builder-3b0a2.appspot.com/o/images%2Fbaseline-text_fields-24px%20(1).svg?alt=media&token=12177b73-0ee3-42ca-98c6-0dd003de1929",TextComponent=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.textRef=null,t}return __extends$1(t,e),t.prototype.componentDidUpdate=function(e){this.allowTextEdit&&(!this.textRef||"true"===this.textRef.contentEditable&&this.textRef===document.activeElement||this.props.text!==e.text&&(this.textRef.innerHTML=this.props.text));},t.prototype.componentDidMount=function(){this.textRef&&(this.textRef.innerHTML=this.props.text);},Object.defineProperty(t.prototype,"allowTextEdit",{get:function(){return Builder.isBrowser&&Builder.isEditing&&location.search.includes("builder.allowTextEdit=true")&&!(this.props.builderBlock&&this.props.builderBlock.bindings&&(this.props.builderBlock.bindings["component.options.text"]||this.props.builderBlock.bindings["options.text"]||this.props.builderBlock.bindings.text))},enumerable:!0,configurable:!0}),t.prototype.render=function(){var e=this,t=this.allowTextEdit,n={outline:"none","& p:first-of-type, & .builder-paragraph:first-of-type":{margin:0},"& > p, & .builder-paragraph":{color:"inherit",lineHeight:"inherit",letterSpacing:"inherit",fontWeight:"inherit",fontSize:"inherit",textAlign:"inherit",fontFamily:"inherit"}};return jsx(BuilderStoreContext.Consumer,null,(function(r){var i;return(null===(i=r.content.meta)||void 0===i?void 0:i.rtlMode)&&(n.direction="rtl"),jsx(react.Fragment,null,jsx("span",__assign$1({ref:function(t){e.textRef=t;},contentEditable:t||void 0,onInput:function(n){var r;t&&(null===(r=window.parent)||void 0===r||r.postMessage({type:"builder.textEdited",data:{id:e.props.builderBlock&&e.props.builderBlock.id,value:n.currentTarget.innerHTML}},"*"));},onKeyDown:function(n){t&&e.textRef&&27===n.which&&document.activeElement===e.textRef&&e.textRef.blur();},onFocus:function(n){var r;t&&(null===(r=window.parent)||void 0===r||r.postMessage({type:"builder.textFocused",data:{id:e.props.builderBlock&&e.props.builderBlock.id}},"*"));},onBlur:function(n){var r;t&&(null===(r=window.parent)||void 0===r||r.postMessage({type:"builder.textBlurred",data:{id:e.props.builderBlock&&e.props.builderBlock.id}},"*"));},css:n,className:"builder-text"},!t&&{dangerouslySetInnerHTML:{__html:e.props.text||e.props.content||""}})))}))},t}(react.Component),Text=withBuilder(TextComponent,{name:"Text",static:!0,image:iconUrl,inputs:[{name:"text",type:"html",required:!0,autoFocus:!0,defaultValue:"Enter some text..."}],defaultStyles:{lineHeight:"normal",height:"auto",textAlign:"center"}}),FragmentComponent=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return __extends$1(t,e),t.prototype.render=function(){return this.props.builderBlock&&this.props.builderBlock.children&&this.props.builderBlock.children.map((function(e,t){return react.createElement(BuilderBlock,{block:e,key:e.id,index:t})}))},t}(react.Component),Fragment$$1=withBuilder(FragmentComponent,{name:"Core:Fragment",canHaveChildren:!0,noWrap:!0,static:!0,hideFromInsertMenu:!0}),DEFAULT_ASPECT_RATIO=.7004048582995948,defaultBlocks=[{"@type":"@builder.io/sdk:Element",responsiveStyles:{large:{display:"flex",flexDirection:"column",alignItems:"stretch",flexShrink:"0",position:"relative",marginTop:"30px",textAlign:"center",lineHeight:"normal",height:"auto",minHeight:"20px",minWidth:"20px",overflow:"hidden"}},component:{name:"Image",options:{image:"https://builder.io/api/v1/image/assets%2Fpwgjf0RoYWbdnJSbpBAjXNRMe9F2%2Ffb27a7c790324294af8be1c35fe30f4d",backgroundPosition:"center",backgroundSize:"cover",aspectRatio:DEFAULT_ASPECT_RATIO}}},{"@type":"@builder.io/sdk:Element",responsiveStyles:{large:{display:"flex",flexDirection:"column",alignItems:"stretch",flexShrink:"0",position:"relative",marginTop:"30px",textAlign:"center",lineHeight:"normal",height:"auto"}},component:{name:"Text",options:{text:"<p>Enter some text...</p>"}}}],ColumnsComponent=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return __extends$1(t,e),Object.defineProperty(t.prototype,"columns",{get:function(){return this.props.columns||[]},enumerable:!0,configurable:!0}),Object.defineProperty(t.prototype,"gutterSize",{get:function(){return"number"==typeof this.props.space?this.props.space||0:20},enumerable:!0,configurable:!0}),t.prototype.getWidth=function(e){return this.columns[e]&&this.columns[e].width||100/this.columns.length},t.prototype.getColumnWidth=function(e){var t=this.columns,n=this.gutterSize*(t.length-1)/t.length;return"calc("+this.getWidth(e)+"% - "+n+"px)"},t.prototype.render=function(){var e,t=this,n=this.columns,r=this.gutterSize;return jsx(react.Fragment,null,jsx("div",{className:"builder-columns",css:__assign$1({display:"flex"},"never"!==this.props.stackColumnsAt&&(e={},e["@media (max-width: "+("tablet"!==this.props.stackColumnsAt?639:999)+"px)"]={flexDirection:this.props.reverseColumnsWhenStacked?"column-reverse":"column",alignItems:"stretch"},e))},n.map((function(e,n){var i,o,a=e.link?Link:"div";return jsx(react.Fragment,{key:n},jsx(a,__assign$1({className:"builder-column"},e.link?{href:e.link}:null,{css:__assign$1((i={display:"flex",flexDirection:"column",alignItems:"stretch",lineHeight:"normal"},i["& > .builder-blocks"]={flexGrow:1},i.width=t.getColumnWidth(n),i.marginLeft=0===n?0:r,i),"never"!==t.props.stackColumnsAt&&(o={},o["@media (max-width: "+("tablet"!==t.props.stackColumnsAt?639:999)+"px)"]={width:"100%",marginLeft:0},o))}),jsx(BuilderBlocks,{key:n,child:!0,parentElementId:t.props.builderBlock&&t.props.builderBlock.id,blocks:e.blocks,dataPath:"component.options.columns."+n+".blocks"})))}))))},t}(react.Component),Columns=withBuilder(ColumnsComponent,{name:"Columns",static:!0,inputs:[{name:"columns",type:"array",subFields:[{name:"blocks",type:"array",hideFromUI:!0,defaultValue:defaultBlocks},{name:"width",type:"number",hideFromUI:!0,helperText:"Width %, e.g. set to 50 to fill half of the space"},{name:"link",type:"url",helperText:"Optionally set a url that clicking this column will link to"}],defaultValue:[{blocks:defaultBlocks},{blocks:defaultBlocks}],onChange:function(e){function t(){n.forEach((function(e){e.delete("width");}));}var n=e.get("columns");Array.isArray(n)&&(!n.find((function(e){return e.get("width")}))||(n.find((function(e){return!e.get("width")}))||100!==n.reduce((function(e,t){return e+t.get("width")}),0))&&t());}},{name:"space",type:"number",defaultValue:20,helperText:"Size of gap between columns",advanced:!0},{name:"stackColumnsAt",type:"string",defaultValue:"tablet",helperText:"Convert horizontal columns to vertical at what device size",enum:["tablet","mobile","never"],advanced:!0},{name:"reverseColumnsWhenStacked",type:"boolean",defaultValue:!1,helperText:"When stacking columns for mobile devices, reverse the ordering",advanced:!0}]}),EmbedComponent=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.elementRef=null,t.scriptsInserted=new Set,t.scriptsRun=new Set,t}return __extends$1(t,e),t.prototype.componentDidUpdate=function(e){this.props.content!==e.content&&this.findAndRunScripts();},t.prototype.componentDidMount=function(){this.findAndRunScripts();},t.prototype.findAndRunScripts=function(){if(this.elementRef&&"undefined"!=typeof window)for(var e=this.elementRef.getElementsByTagName("script"),t=0;t<e.length;t++){var n=e[t];if(n.src){if(this.scriptsInserted.has(n.src))continue;this.scriptsInserted.add(n.src);var r=document.createElement("script");r.async=!0,r.src=n.src,document.head.appendChild(r);}else{if(this.scriptsRun.has(n.innerText))continue;this.scriptsRun.add(n.innerText);try{new Function(n.innerText)();}catch(e){console.warn("Builder custom code component error:",e);}}}},Object.defineProperty(t.prototype,"content",{get:function(){return Builder.isServer?(this.props.content||"").replace(/<script[\s\S]*?<\/script>/g,""):this.props.content},enumerable:!0,configurable:!0}),t.prototype.render=function(){var e=this;return react.createElement("div",{ref:function(t){return e.elementRef=t},className:"builder-embed",dangerouslySetInnerHTML:{__html:this.content}})},t}(react.Component),Embed=withBuilder(EmbedComponent,{name:"Embed",static:!0,inputs:[{name:"url",type:"url",required:!0,defaultValue:"",helperText:"e.g. enter a youtube url, google map, etc",onChange:function(e){var t=e.get("url");if(t){e.set("content","Loading...");return fetch("https://iframe.ly/api/iframely?url="+t+"&api_key=ae0e60e78201a3f2b0de4b").then((function(e){return e.json()})).then((function(n){e.get("url")===t&&(n.html?e.set("content",n.html):e.set("content","Invalid url, please try another"));})).catch((function(t){e.set("content","There was an error embedding this URL, please try again or another URL");}))}e.delete("content");}},{name:"content",type:"html",defaultValue:'<div style="padding: 20px; text-align: center">(Choose an embed URL)<div>',hideFromUI:!0}]}),globalReplaceNodes={}||null,isShopify=Builder.isBrowser&&"Shopify"in window;if(Builder.isBrowser&&globalReplaceNodes)try{Array.from(document.querySelectorAll(isShopify?".builder-custom-code":".builder-custom-code.replace-nodes")).forEach((function(e){var t=e.parentElement,n=t&&t.getAttribute("builder-id");n&&(globalReplaceNodes[n]=globalReplaceNodes[n]||[],globalReplaceNodes[n].push(e));}));}catch(e){console.error("Builder replace nodes error:",e);}var CustomCodeComponent=function(e){function t(t){var n,r=e.call(this,t)||this;r.elementRef=null,r.originalRef=null,r.scriptsInserted=new Set,r.scriptsRun=new Set,r.firstLoad=!0;var i=null===(n=r.props.builderBlock)||void 0===n?void 0:n.id;if(r.replaceNodes=Boolean(Builder.isBrowser&&(t.replaceNodes||isShopify)&&i&&(null==globalReplaceNodes?void 0:globalReplaceNodes[i])),r.replaceNodes&&Builder.isBrowser&&r.firstLoad&&r.props.builderBlock)if(i&&(null==globalReplaceNodes?void 0:globalReplaceNodes[i])){var o=globalReplaceNodes[i].shift()||null;r.originalRef=o,0===globalReplaceNodes[i].length&&delete globalReplaceNodes[i];}else{var a=document.querySelectorAll("."+r.props.builderBlock.id+" .builder-custom-code");if(1===a.length){var s=a[0];r.originalRef=s,r.originalRef.remove();}}return r}return __extends$1(t,e),Object.defineProperty(t.prototype,"noReactRender",{get:function(){var e;return Boolean(isShopify&&(null===(e=this.props.code)||void 0===e?void 0:e.match(/{[{%]/g)))},enumerable:!0,configurable:!0}),t.prototype.componentDidUpdate=function(e){this.props.code!==e.code&&this.findAndRunScripts();},t.prototype.componentDidMount=function(){this.firstLoad=!1,this.findAndRunScripts(),Builder.isBrowser&&this.replaceNodes&&this.originalRef&&this.elementRef&&this.elementRef.appendChild(this.originalRef);},t.prototype.findAndRunScripts=function(){if(this.elementRef&&"undefined"!=typeof window)for(var e=this.elementRef.getElementsByTagName("script"),t=0;t<e.length;t++){var n=e[t];if(n.src){if(this.scriptsInserted.has(n.src))continue;this.scriptsInserted.add(n.src);var r=document.createElement("script");r.async=!0,r.src=n.src,document.head.appendChild(r);}else{if(this.scriptsRun.has(n.innerText))continue;try{this.scriptsRun.add(n.innerText),new Function(n.innerText)();}catch(e){console.warn("Builder custom code component error:",e);}}}},Object.defineProperty(t.prototype,"code",{get:function(){return Builder.isServer&&this.props.scriptsClientOnly?(this.props.code||"").replace(/<script\b[^<]*(?:(?!<\/script>)<[^<]*)*<\/script>/gi,""):this.props.code},enumerable:!0,configurable:!0}),t.prototype.render=function(){var e=this;return react.createElement("div",__assign$1({ref:function(t){return e.elementRef=t},className:"builder-custom-code"+(this.props.replaceNodes?" replace-nodes":"")},!this.replaceNodes&&!this.noReactRender&&{dangerouslySetInnerHTML:{__html:this.code}}))},t}(react.Component),CustomCode=withBuilder(CustomCodeComponent,{name:"Custom Code",static:!0,inputs:[{name:"code",type:"html",required:!0,defaultValue:"<p>Hello there, I am custom HTML code!</p>",code:!0},__assign$1({name:"replaceNodes",type:"boolean",helperText:"Preserve server rendered dom nodes",advanced:!0},isShopify&&{defaultValue:!0}),{name:"scriptsClientOnly",type:"boolean",defaultValue:!1,helperText:"Only print and run scripts on the client. Important when scripts influence DOM that could be replaced when client loads",advanced:!0}]});function removeProtocol(e){return e.replace(/http(s)?:/,"")}function getShopifyImageUrl(e,t){if(!e||!(null==e?void 0:e.match(/cdn\.shopify\.com/))||!t)return e;if("master"===t)return removeProtocol(e);var n=e.match(/(_\d+x(\d+)?)?(\.(jpg|jpeg|gif|png|bmp|bitmap|tiff|tif)(\?v=\d+)?)/i);if(n){var r=e.split(n[0]),i=n[3],o=t.match("x")?t:t+"x";return removeProtocol(r[0]+"_"+o+i)}return null}var DEFAULT_ASPECT_RATIO$1=.7041;function updateQueryParam(e,t,n){void 0===e&&(e="");var r=new RegExp("([?&])"+t+"=.*?(&|$)","i"),i=-1!==e.indexOf("?")?"&":"?";return e.match(r)?e.replace(r,"$1"+t+"="+encodeURIComponent(n)+"$2"):e+i+t+"="+encodeURIComponent(n)}function getSrcSet(e){if(!e)return e;var t=[100,200,400,800,1200,1600,2e3];if(e.match(/builder\.io/)){var n=e,r=Number(e.split("?width=")[1]);return isNaN(r)||(n=n+" "+r+"w"),t.filter((function(e){return e!==r})).map((function(t){return updateQueryParam(e,"width",t)+" "+t+"w"})).concat([n]).join(", ")}return e.match(/cdn\.shopify\.com/)?t.map((function(t){return[getShopifyImageUrl(e,t+"x"+t),t]})).filter((function(e){return!!e[0]})).map((function(e){return e[0]+" "+e[1]+"w"})).concat([e]).join(", "):e}var getSizes=function(e,t){var n,r,i,o,a,s,l,u,d="";if(e){var p=e.split(","),c=p.length;d=p.map((function(e,t){return c===t+1?e.replace(/\([\s\S]*?\)/g,"").trim():e})).join(", ");}else if(t&&t.responsiveStyles){var m=[],f=!1,h=/^\d+/;if(null===(i=null===(r=null===(n=t.responsiveStyles)||void 0===n?void 0:n.small)||void 0===r?void 0:r.width)||void 0===i?void 0:i.match(h)){f=!0;var g="(max-width: 639px)"+" "+t.responsiveStyles.small.width.replace("%","vw");m.push(g);}if(null===(s=null===(a=null===(o=t.responsiveStyles)||void 0===o?void 0:o.medium)||void 0===a?void 0:a.width)||void 0===s?void 0:s.match(h)){f=!0;g="(max-width: 999px)"+" "+t.responsiveStyles.medium.width.replace("%","vw");m.push(g);}if(null===(u=null===(l=t.responsiveStyles)||void 0===l?void 0:l.large)||void 0===u?void 0:u.width){var v=t.responsiveStyles.large.width.replace("%","vw");m.push(v);}else f&&m.push("100vw");m.length&&(d=m.join(", "));}return d},ImageComponent=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.state={imageLoaded:!t.useLazyLoading,load:!t.useLazyLoading},t.pictureRef=null,t.scrollListener=null,t}return __extends$1(t,e),Object.defineProperty(t.prototype,"useLazyLoading",{get:function(){return(!Builder.isBrowser||!location.search.includes("builder.lazyLoadImages=false"))&&(!(!Builder.isBrowser||!location.href.includes("builder.lazyLoadImages=true"))||this.props.lazy)},enumerable:!0,configurable:!0}),t.prototype.componentWillUnmount=function(){Builder.isBrowser&&this.scrollListener&&(window.removeEventListener("scroll",this.scrollListener),this.scrollListener=null);},t.prototype.componentDidMount=function(){var e=this;if(this.props.lazy&&Builder.isBrowser){var t=throttle$1((function(n){if(e.pictureRef){var r=e.pictureRef.getBoundingClientRect(),i=window.innerHeight/2;r.top<window.innerHeight+i&&(e.setState(__assign$1(__assign$1({},e.state),{load:!0})),window.removeEventListener("scroll",t),e.scrollListener=null);}}),400,{leading:!1,trailing:!0});this.scrollListener=t,window.addEventListener("scroll",t,{capture:!0,passive:!0}),t();}},t.prototype.getSrcSet=function(){var e=this.props.image;if(e&&(e.match(/builder\.io/)||e.match(/cdn\.shopify\.com/)))return getSrcSet(e)},t.prototype.render=function(){var e=this,t=this.props,n=t.aspectRatio,r=t.lazy,i=this.props.builderBlock&&this.props.builderBlock.children,o=this.props.srcset,a=getSizes(this.props.sizes,this.props.builderBlock),s=this.props.image;return o&&s&&s.includes("builder.io/api/v1/image")?o.includes(s.split("?")[0])||(console.debug("Removed given srcset"),o=this.getSrcSet()):s&&!o&&(o=this.getSrcSet()),jsx(BuilderMetaContext.Consumer,null,(function(t){var s,l=t.ampMode,u=l?"amp-img":"img",d=(!r||e.state.load||l)&&jsx(u,__assign$1({},l?{layout:"responsive",height:e.props.height||(n?Math.round(1e3*n):void 0),width:e.props.width||(n?Math.round(1e3/n):void 0)}:null,{alt:e.props.altText,key:Builder.isEditing&&"string"==typeof e.props.image&&e.props.image.split("?")[0]||void 0,role:e.props.altText?void 0:"presentation",css:__assign$1(__assign$1({opacity:l?1:e.useLazyLoading&&!e.state.imageLoaded?0:1,transition:"opacity 0.2s ease-in-out",objectFit:e.props.backgroundSize||"cover",objectPosition:e.props.backgroundPosition||"center"},n&&!l&&{position:"absolute",height:"100%",width:"100%",left:0,top:0}),l&&(s={},s["& img"]={objectFit:e.props.backgroundSize,objectPosition:e.props.backgroundPosition},s)),className:"builder-image"+(e.props.className?" "+e.props.className:""),src:e.props.image},!l&&{onLoad:function(){return e.setState({imageLoaded:!0})}},{srcSet:o,sizes:!l&&a?a:void 0}));return jsx(react.Fragment,null,l?d:jsx("picture",{ref:function(t){return e.pictureRef=t}},o&&o.match(/builder\.io/)&&jsx("source",{srcSet:o.replace(/\?/g,"?format=webp&"),type:"image/webp"}),d),n&&!l?jsx("div",{className:"builder-image-sizer",css:{width:"100%",paddingTop:100*n+"%",pointerEvents:"none",fontSize:0}}," "):null,i&&i.length?jsx("div",{css:{display:"flex",flexDirection:"column",alignItems:"stretch",position:"absolute",top:0,left:0,width:"100%",height:"100%"}},i.map((function(e,t){return jsx(BuilderBlock,{key:e.id,block:e})}))):null)}))},t}(react.Component),Image=withBuilder(ImageComponent,{name:"Image",static:!0,image:"https://firebasestorage.googleapis.com/v0/b/builder-3b0a2.appspot.com/o/images%2Fbaseline-insert_photo-24px.svg?alt=media&token=4e5d0ef4-f5e8-4e57-b3a9-38d63a9b9dc4",defaultStyles:{position:"relative",minHeight:"20px",minWidth:"20px",overflow:"hidden"},canHaveChildren:!0,inputs:[{name:"image",type:"file",allowedFileTypes:["jpeg","jpg","png","svg"],required:!0,defaultValue:"https://cdn.builder.io/api/v1/image/assets%2Fpwgjf0RoYWbdnJSbpBAjXNRMe9F2%2Ffb27a7c790324294af8be1c35fe30f4d",onChange:function(e){e.delete("srcset");var t,n,r=e.get("image"),i=e.get("aspectRatio");if(r&&(!i||.7041===i))return(t=r,void 0===n&&(n=6e4),new Promise((function(e,r){var i=document.createElement("img"),o=!1;i.onload=function(){o=!0,e(i);},i.addEventListener("error",(function(e){console.warn("Image load failed",e.error),r(e.error);})),i.src=t,setTimeout((function(){o||r(new Error("Image load timed out"));}),n);}))).then((function(t){var n,i=e.get("aspectRatio");e.get("image")!==r||i&&.7041!==i||t.width&&t.height&&(e.set("aspectRatio",(n=t.height/t.width,Math.round(1e3*n)/1e3)),e.set("height",t.height),e.set("width",t.width));}))}},{name:"backgroundSize",type:"text",defaultValue:"cover",enum:[{label:"contain",value:"contain",helperText:"The image should never get cropped"},{label:"cover",value:"cover",helperText:"The image should fill it's box, cropping when needed"}]},{name:"backgroundPosition",type:"text",defaultValue:"center",enum:["center","top","left","right","bottom","top left","top right","bottom left","bottom right"]},{name:"altText",type:"string",helperText:"Text to display when the user has images off"},{name:"height",type:"number",hideFromUI:!0},{name:"width",type:"number",hideFromUI:!0},{name:"sizes",type:"string",hideFromUI:!0},{name:"srcset",type:"string",hideFromUI:!0},{name:"lazy",type:"boolean",defaultValue:!0,hideFromUI:!0},{name:"aspectRatio",type:"number",helperText:"This is the ratio of height/width, e.g. set to 1.5 for a 300px wide and 200px tall photo. Set to 0 to not force the image to maintain it's aspect ratio",advanced:!0,defaultValue:DEFAULT_ASPECT_RATIO$1}]}),DEFAULT_ASPECT_RATIO$2=.7004048582995948,VideoComponent=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.video=null,t.containerRef=null,t.scrollListener=null,t.state={load:!t.lazyLoad},t}return __extends$1(t,e),Object.defineProperty(t.prototype,"lazyLoad",{get:function(){return!1!==this.props.lazyLoad},enumerable:!0,configurable:!0}),t.prototype.updateVideo=function(){this.video&&(this.video.setAttribute("muted",String(this.props.muted)),this.video.setAttribute("playsinline",String(this.props.playsInline)),this.video.setAttribute("autoplay",String(this.props.autoPlay)));},t.prototype.componentDidUpdate=function(){this.updateVideo();},t.prototype.componentDidMount=function(){var e=this;if(this.updateVideo(),this.lazyLoad&&Builder.isBrowser){var t=throttle$1((function(n){if(e.containerRef){var r=e.containerRef.getBoundingClientRect(),i=window.innerHeight/2;r.top<window.innerHeight+i&&(e.setState((function(e){return __assign$1(__assign$1({},e),{load:!0})})),window.removeEventListener("scroll",t),e.scrollListener=null);}}),400,{leading:!1,trailing:!0});this.scrollListener=t,window.addEventListener("scroll",t,{capture:!0,passive:!0}),t();}},t.prototype.componentWillUnmount=function(){Builder.isBrowser&&this.scrollListener&&(window.removeEventListener("scroll",this.scrollListener),this.scrollListener=null);},t.prototype.render=function(){var e=this,t=this.props,n=t.aspectRatio,r=t.children;return jsx("div",{ref:function(t){return e.containerRef=t},css:{position:"relative"}},jsx("video",{key:this.props.video||"no-src",poster:this.props.posterImage,ref:function(t){return e.video=t},autoPlay:this.props.autoPlay,muted:this.props.muted,controls:this.props.controls,loop:this.props.loop,className:"builder-video",css:__assign$1({width:"100%",height:"100%",objectFit:this.props.fit,objectPosition:this.props.position,borderRadius:1},n?{position:"absolute"}:null)},(!this.lazyLoad||this.state.load)&&jsx("source",{type:"video/mp4",src:this.props.video})),n?jsx("div",{css:{width:"100%",paddingTop:100*n+"%",pointerEvents:"none",fontSize:0}}):null,r&&jsx("div",{css:{display:"flex",flexDirection:"column",alignItems:"stretch",position:"absolute",top:0,left:0,width:"100%",height:"100%"}},r))},t}(react.Component),Video=Builder.registerComponent(withChildren(VideoComponent),{name:"Video",canHaveChildren:!0,image:"https://firebasestorage.googleapis.com/v0/b/builder-3b0a2.appspot.com/o/images%2Fbaseline-videocam-24px%20(1).svg?alt=media&token=49a84e4a-b20e-4977-a650-047f986874bb",inputs:[{name:"video",type:"file",allowedFileTypes:["mp4"],defaultValue:"https://firebasestorage.googleapis.com/v0/b/builder-3b0a2.appspot.com/o/assets%2FKQlEmWDxA0coC3PK6UvkrjwkIGI2%2F28cb070609f546cdbe5efa20e931aa4b?alt=media&token=912e9551-7a7c-4dfb-86b6-3da1537d1a7f",required:!0,onChange:function(e){var t,n,r=e.get("image"),i=e.get("aspectRatio");if(r&&(!i||.7004048582995948===i))return(t=r,void 0===n&&(n=6e4),new Promise((function(e,r){var i=document.createElement("img"),o=!1;i.onload=function(){o=!0,e(i);},i.addEventListener("error",(function(e){console.warn("Image load failed",e.error),r(e.error);})),i.src=t,setTimeout((function(){o||r(new Error("Image load timed out"));}),n);}))).then((function(t){var n,i=e.get("aspectRatio");e.get("image")!==r||i&&.7004048582995948!==i||t.width&&t.height&&e.set("aspectRatio",(n=t.height/t.width,Math.round(1e3*n)/1e3));}))}},{name:"posterImage",type:"file",allowedFileTypes:["jpeg","png"],helperText:"Image to show before the video plays"},{name:"autoPlay",type:"boolean",defaultValue:!0},{name:"controls",type:"boolean",defaultValue:!1},{name:"muted",type:"boolean",defaultValue:!0},{name:"loop",type:"boolean",defaultValue:!0},{name:"playsInline",type:"boolean",defaultValue:!0},{name:"fit",type:"text",defaultValue:"cover",enum:["contain","cover","fill","auto"]},{name:"position",type:"text",defaultValue:"center",enum:["center","top","left","right","bottom","top left","top right","bottom left","bottom right"]},{name:"height",type:"number",advanced:!0},{name:"width",type:"number",advanced:!0},{name:"aspectRatio",type:"number",advanced:!0,defaultValue:DEFAULT_ASPECT_RATIO$2},{name:"lazyLoad",type:"boolean",helperText:'Load this video "lazily" - as in only when a user scrolls near the video. Recommended for optmized performance and bandwidth consumption',defaultValue:!0,advanced:!0}]}),size$1$1=function(e){return Object.keys(e).length},isShopify$1=Builder.isBrowser&&"Shopify"in window,refs={};if(Builder.isBrowser)try{Array.from(document.querySelectorAll("[builder-static-symbol]")).forEach((function(e){var t=e.getAttribute("builder-static-symbol");t&&(refs[t]=e);}));}catch(e){console.error("Builder replace nodes error:",e);}var SymbolComponent=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.ref=null,t.staticRef=null,t}return __extends$1(t,e),Object.defineProperty(t.prototype,"placeholder",{get:function(){return jsx("div",{css:{padding:10}},"Symbols let you reuse dynamic elements across your content. Please choose a model and entry for this symbol.")},enumerable:!0,configurable:!0}),t.prototype.componentDidMount=function(){var e,t,n;this.useStatic&&this.staticRef&&refs[null===(e=this.props.builderBlock)||void 0===e?void 0:e.id]&&(null===(t=this.staticRef.parentNode)||void 0===t||t.replaceChild(refs[null===(n=this.props.builderBlock)||void 0===n?void 0:n.id],this.staticRef));},Object.defineProperty(t.prototype,"useStatic",{get:function(){var e;return Boolean(Builder.isBrowser&&refs[null===(e=this.props.builderBlock)||void 0===e?void 0:e.id]&&!(Builder.isEditing||Builder.isPreviewing))},enumerable:!0,configurable:!0}),t.prototype.render=function(){var e=this;if(this.useStatic)return jsx("div",{ref:function(t){return e.staticRef=t}});var t=this.props.symbol,n=!1;t||(n=!0);var r=this.props.dataOnly?NoWrap:this.props.builderBlock&&this.props.builderBlock.tagName||"div",i=t||{},o=i.model,a=i.entry,s=i.data,l=i.content,u=i.inline,d=(null==t?void 0:t.dynamic)||this.props.dynamic;o&&(a||d)||u||(n=!0);var p=d?void 0:[o,a].join(":"),c=Builder.isEditing?null:s&&size$1$1(s)&&hashSum$1(s);p&&c&&c.length<300&&(p+=":"+c);var m=this.props.attributes||{};return jsx(BuilderStoreContext.Consumer,{key:(o||"no model")+":"+(a||"no entry")},(function(i){var u,d,c,f,h,g,v;return jsx(r,__assign$1({"data-model":o},m,{className:(m.class||m.className||"")+" builder-symbol"+((null==t?void 0:t.inline)?" builder-inline-symbol":"")+((null==t?void 0:t.dynamic)||e.props.dynamic?" builder-dynamic-symbol":"")}),n?e.placeholder:jsx(BuilderPage,__assign$1({ref:function(t){return e.ref=t},context:__assign$1({},i.context),modelName:o,entry:a,data:__assign$1(__assign$1(__assign$1({},s),!!e.props.inheritState&&i.state),null===(g=null===(h=null===(f=null===(c=null===(d=null===(u=e.props.builderBlock)||void 0===u?void 0:u.component)||void 0===d?void 0:d.options)||void 0===c?void 0:c.symbol)||void 0===f?void 0:f.content)||void 0===h?void 0:h.data)||void 0===g?void 0:g.state),renderLink:i.renderLink,inlineContent:null==t?void 0:t.inline},l&&{content:l},{options:{key:p},hydrate:null===(v=i.state)||void 0===v?void 0:v._hydrate,builderBlock:e.props.builderBlock,dataOnly:e.props.dataOnly}),e.props.children))}))},t}(react.Component),Symbol$1=withBuilder(SymbolComponent,{name:"Symbol",noWrap:!0,static:!0,inputs:[{name:"symbol",type:"uiSymbol"},{name:"dataOnly",helperText:"Make this a data symbol that doesn't display any UI",type:"boolean",defaultValue:!1,advanced:!0,hideFromUI:!0},{name:"inheritState",helperText:"Inherit the parent component state and data",type:"boolean",defaultValue:isShopify$1,advanced:!0,hideFromUI:!0},{name:"renderToLiquid",helperText:"Render this symbols contents to liquid. Turn off to fetch with javascript and use custom targeting",type:"boolean",defaultValue:isShopify$1,advanced:!0,hideFromUI:!0}]}),ButtonComponent=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return __extends$1(t,e),t.prototype.render=function(){var e=this.props.link?Link:"span";return react.createElement(e,__assign$1({href:this.props.link,target:this.props.openLinkInNewTab?"_blank":void 0},this.props.attributes),this.props.text)},t}(react.Component),Button=withBuilder(ButtonComponent,{name:"Core:Button",image:"https://cdn.builder.io/api/v1/image/assets%2FIsxPKMo2gPRRKeakUztj1D6uqed2%2F81a15681c3e74df09677dfc57a615b13",defaultStyles:{appearance:"none",paddingTop:"15px",paddingBottom:"15px",paddingLeft:"25px",paddingRight:"25px",backgroundColor:"#3898EC",color:"white",borderRadius:"4px",textAlign:"center",cursor:"pointer"},inputs:[{name:"text",type:"text",defaultValue:"Click me!"},{name:"link",type:"url"},{name:"openLinkInNewTab",type:"boolean",defaultValue:!1,friendlyName:"Open link in new tab"}],static:!0,noWrap:!0}),SectionComponent=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return __extends$1(t,e),t.prototype.render=function(){return jsx("div",{css:{width:"100%",alignSelf:"stretch",flexGrow:1,boxSizing:"border-box",maxWidth:this.props.maxWidth,display:"flex",flexDirection:"column",alignItems:"stretch",marginLeft:"auto",marginRight:"auto"}},this.props.builderBlock&&this.props.builderBlock.children&&this.props.builderBlock.children.map((function(e,t){return jsx(BuilderBlock,{key:e.id,block:e})})))},t}(react.Component),Section=withBuilder(SectionComponent,{name:"Core:Section",static:!0,image:"https://cdn.builder.io/api/v1/image/assets%2FIsxPKMo2gPRRKeakUztj1D6uqed2%2F682efef23ace49afac61748dd305c70a",inputs:[{name:"maxWidth",type:"number",defaultValue:1200}],defaultStyles:{paddingLeft:"20px",paddingRight:"20px",paddingTop:"50px",paddingBottom:"50px",marginTop:"0px",width:"100vw",marginLeft:"calc(50% - 50vw)"},canHaveChildren:!0,defaultChildren:[{"@type":"@builder.io/sdk:Element",responsiveStyles:{large:{textAlign:"center"}},component:{name:"Text",options:{text:"<p><b>I am a section! My content keeps from getting too wide, so that it's easy to read even on big screens.</b></p><p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur</p>"}}}]}),StateProviderComponent=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return __extends$1(t,e),t.prototype.render=function(){var e=this;return react.createElement(BuilderStoreContext.Consumer,null,(function(t){return react.createElement(BuilderStoreContext.Provider,{value:__assign$1(__assign$1({},t),{state:__assign$1(__assign$1({},t.state),e.props.state),context:__assign$1(__assign$1({},t.context),e.props.context)})},e.props.builderBlock&&e.props.builderBlock.children&&e.props.builderBlock.children.map((function(e,t){return react.createElement(BuilderBlock,{block:e,key:e.id,index:t,child:!0})})),e.props.children)}))},t}(react.Component),StateProvider=withBuilder(StateProviderComponent,{name:"Builder:StateProvider",canHaveChildren:!0,static:!0,noWrap:!0,hideFromInsertMenu:!0}),prefetched=new Set;function searchToObject$1(e){var t=(e.search||"").substring(1).split("&"),n={};for(var r in t)if(t[r]&&"string"==typeof t[r]){var i=t[r].split("=");n[decodeURIComponent(i[0])]=decodeURIComponent(i[1]);}return n}var RouterComponent=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.builder=builder,t.routed=!1,t.preloadQueue=0,t.onPopState=function(e){t.updateLocationState();},t.onMouseOverOrTouchStart=function(e){if(!(t.preloadQueue>4)&&!1!==t.props.preloadOnHover){var n=t.findHrefTarget(e);if(n){var r=n.getAttribute("href");if(r){if(!t.isRelative(r)){var i=t.convertToRelative(r);if(!i)return;r=i;}if(!r.startsWith("#")&&!prefetched.has(r)){prefetched.add(r);var o=t.parseUrl(r);t.preloadQueue++;var a=builder.getUserAttributes();a.urlPath=o.pathname,a.queryString=o.search;var s=builder.get(t.model,{userAttributes:a,key:t.model+":"+o.pathname+o.search}).subscribe((function(){t.preloadQueue--,s.unsubscribe();}));}}}}},t.onClick=function(e){return __awaiter$1(t,void 0,void 0,(function(){var t,n,r,i;return __generator$1(this,(function(o){if(!1===this.props.handleRouting)return[2];if(0!==e.button||e.ctrlKey||e.defaultPrevented||e.metaKey)return[2];if(!(t=this.findHrefTarget(e)))return[2];if(t.target&&"_client"!==t.target)return[2];if(!(n=t.getAttribute("href")))return[2];if(this.props.onRoute&&(r={url:n,anchorNode:t,preventDefault:function(){this.defaultPrevented=!0;},defaultPrevented:!1},this.props.onRoute(r),r.defaultPrevented))return[2];if(!this.isRelative(n)){if(!(i=this.convertToRelative(n)))return[2];n=i;}return n.startsWith("#")||(e.preventDefault(),this.route(n)),[2]}))}))},t.privateState=null,t}return __extends$1(t,e),t.prototype.route=function(e){return this.routed=!0,window.history&&window.history.pushState?(history.pushState(null,"",e),this.updateLocationState(),!0):(location.href=e,!1)},t.prototype.updateLocationState=function(){this.privateState&&this.privateState.update((function(e){e.location=__assign$1(__assign$1({},e.location),{pathname:location.pathname,search:location.search,path:location.pathname.split("/").slice(1),query:searchToObject$1(location)});}));},Object.defineProperty(t.prototype,"model",{get:function(){return this.props.model||"page"},enumerable:!0,configurable:!0}),t.prototype.componentDidMount=function(){"undefined"!=typeof document&&(document.addEventListener("click",this.onClick),window.addEventListener("popstate",this.onPopState),document.addEventListener("mouseover",this.onMouseOverOrTouchStart),document.addEventListener("touchstart",this.onMouseOverOrTouchStart));},t.prototype.componentWillUnmount=function(){"undefined"!=typeof document&&(document.removeEventListener("click",this.onClick),document.removeEventListener("mouseover",this.onMouseOverOrTouchStart),window.removeEventListener("popstate",this.onPopState),document.removeEventListener("touchstart",this.onMouseOverOrTouchStart));},t.prototype.render=function(){var e=this,t=this.model;return jsx(BuilderStoreContext.Consumer,null,(function(n){e.privateState=n;var r=n.state&&n.state.location&&n.state.location.pathname+n.state.location.search;return jsx("div",{className:"builder-router","data-model":t},jsx("style",null,"\n                @keyframes builderLoadingSpinner {\n                  0% {\n                    transform: rotate(0deg);\n                  }\n                  100% {\n                    transform: rotate(360deg);\n                  }\n                }\n                /* TODO: overridable tag */\n                .builder-page-loading {\n                  -webkit-animation: builderLoadingSpinner 1s infinite linear;\n                  animation: builderLoadingSpinner 1s infinite linear;\n                  -webkit-transform: translateZ(0);\n                  transform: translateZ(0);\n                  border-radius: 50%;\n                  width: 36px;\n                  height: 36px;\n                  margin: 6px auto;\n                  position: relative;\n                  border: 1px solid transparent;\n                  border-left: 1px solid #808284;\n                }\n              "),jsx(BuilderPage,{key:r,data:e.props.data,content:e.routed?void 0:e.props.content,modelName:t,options:{key:Builder.isEditing?void 0:e.model+":"+r}},e.props.children||jsx("div",{css:{display:"flex"}},jsx("div",{css:{margin:"40vh auto"},className:"builder-page-loading"}))))}))},t.prototype.findHrefTarget=function(e){for(var t=e.target;t;){if(t instanceof HTMLAnchorElement&&t.getAttribute("href"))return t;if(t===e.currentTarget)break;t=t.parentElement;}return null},t.prototype.isRelative=function(e){return!e.match(/^(\/\/|https?:\/\/)/i)},t.prototype.parseUrl=function(e){var t=document.createElement("a");return t.href=e,t},t.prototype.convertToRelative=function(e){var t=this.parseUrl(location.href),n=this.parseUrl(e);if(t.host===n.host){var r=n.pathname+(n.search?n.search:"");return r.startsWith("#")?null:r||"/"}return null},t}(react.Component),Router=withBuilder(RouterComponent,{name:"Core:Router",hideFromInsertMenu:!0,inputs:[{name:"model",type:"string",defaultValue:"page",advanced:!0},{name:"handleRouting",type:"boolean",defaultValue:!0,advanced:!0},{name:"preloadOnHover",type:"boolean",defaultValue:!0,advanced:!0},{name:"onRoute",type:"function",advanced:!0}]}),get=function(e,t,n){var r=String.prototype.split.call(t,/[,[\].]+?/).filter(Boolean).reduce((function(e,t){return null!=e?e[t]:e}),e);return void 0===r||r===e?n:r},FormComponent=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.ref=null,t.state={state:"unsubmitted",responseData:null,formErrorMessage:""},t}return __extends$1(t,e),Object.defineProperty(t.prototype,"submissionState",{get:function(){return Builder.isEditing&&this.props.previewState||this.state.state},enumerable:!0,configurable:!0}),t.prototype.render=function(){var e=this;return(jsx(BuilderStoreContext.Consumer,null,(function(t){return jsx(BuilderStoreContext.Provider,{value:__assign$1(__assign$1({},t),{state:__assign$1(__assign$1({},t.state),{formErrorMessage:e.state.formErrorMessage})})},jsx("form",__assign$1({validate:e.props.validate,ref:function(t){return e.ref=t},action:!e.props.sendWithJs&&e.props.action,method:e.props.method,name:e.props.name,onSubmit:function(t){var n,r=e.props.sendWithJs||"email"===e.props.sendSubmissionsTo;if("zapier"===e.props.sendSubmissionsTo)t.preventDefault();else if(r){if(!e.props.action&&"email"!==e.props.sendSubmissionsTo)return void t.preventDefault();t.preventDefault();var i=t.currentTarget,o=e.props.customHeaders||{},a=void 0,s=new FormData(i),l=Array.from(t.currentTarget.querySelectorAll("input,select,textarea")).filter((function(e){return!!e.name})).map((function(e){var t,n=e.name;if(e instanceof HTMLInputElement)if("radio"===e.type){if(e.checked)return{key:n,value:t=e.name}}else if("checkbox"===e.type)t=e.checked;else if("number"===e.type||"range"===e.type){var r=e.valueAsNumber;isNaN(r)||(t=r);}else t="file"===e.type?e.files:e.value;else t=e.value;return{key:n,value:t}})),u=e.props.contentType;if("email"===e.props.sendSubmissionsTo&&(u="multipart/form-data"),Array.from(l).forEach((function(e){var t=e.value;(t instanceof File||Array.isArray(t)&&t[0]instanceof File||t instanceof FileList)&&(u="multipart/form-data");})),"application/json"!==u)a=s;else{var d={};Array.from(l).forEach((function(e){var t=e.value,n=e.key;set(d,n,t);})),a=JSON.stringify(d);}u&&"multipart/form-data"!==u&&(r&&(null===(n=e.props.action)||void 0===n?void 0:n.includes("zapier.com"))||(o["content-type"]=u));var p=new CustomEvent("presubmit",{detail:{body:a}});if(e.ref&&(e.ref.dispatchEvent(p),p.defaultPrevented))return;e.setState(__assign$1(__assign$1({},e.state),{state:"sending"}));var c=("dev"===builder.env?"http://localhost:5000":"https://builder.io")+"/api/v1/form-submit?apiKey="+builder.apiKey+"&to="+btoa(e.props.sendSubmissionsToEmail||"")+"&name="+encodeURIComponent(e.props.name||"");fetch("email"===e.props.sendSubmissionsTo?c:e.props.action,{body:a,headers:o,method:e.props.method||"post"}).then((function(t){return __awaiter$1(e,void 0,void 0,(function(){var e,n,r,i,o;return __generator$1(this,(function(a){switch(a.label){case 0:return(n=t.headers.get("content-type"))&&-1!==n.indexOf("application/json")?[4,t.json()]:[3,2];case 1:return e=a.sent(),[3,4];case 2:return[4,t.text()];case 3:e=a.sent(),a.label=4;case 4:if(!t.ok&&this.props.errorMessagePath&&(r=get(e,this.props.errorMessagePath))&&("string"!=typeof r&&(r=JSON.stringify(r)),this.setState(__assign$1(__assign$1({},this.state),{formErrorMessage:r}))),this.setState(__assign$1(__assign$1({},this.state),{responseData:e,state:t.ok?"success":"error"})),t.ok){if(i=new CustomEvent("submit:success",{detail:{res:t,body:e}}),this.ref){if(this.ref.dispatchEvent(i),i.defaultPrevented)return[2];!1!==this.props.resetFormOnSubmit&&this.ref.reset();}this.props.successUrl&&(this.ref?(o=new CustomEvent("route",{detail:{url:this.props.successUrl}}),this.ref.dispatchEvent(o),o.defaultPrevented||(location.href=this.props.successUrl)):location.href=this.props.successUrl);}return[2]}}))}))}),(function(t){var n=new CustomEvent("submit:error",{detail:{error:t}});e.ref&&(e.ref.dispatchEvent(n),n.defaultPrevented)||e.setState(__assign$1(__assign$1({},e.state),{responseData:t,state:"error"}));}));}}},e.props.attributes),e.props.builderBlock&&e.props.builderBlock.children&&e.props.builderBlock.children.map((function(e,t){return jsx(BuilderBlock,{key:e.id,block:e})})),"error"===e.submissionState&&jsx(BuilderBlocks,{dataPath:"errorMessage",blocks:e.props.errorMessage}),"sending"===e.submissionState&&jsx(BuilderBlocks,{dataPath:"sendingMessage",blocks:e.props.sendingMessage}),"error"===e.submissionState&&e.state.responseData&&jsx("pre",{className:"builder-form-error-text",css:{padding:10,color:"red",textAlign:"center"}},JSON.stringify(e.state.responseData,null,2)),"success"===e.submissionState&&jsx(BuilderBlocks,{dataPath:"successMessage",blocks:e.props.successMessage})))})))},t}(react.Component),Form=withBuilder(FormComponent,{name:"Form:Form",defaults:{responsiveStyles:{large:{marginTop:"15px",paddingBottom:"15px"}}},image:"https://cdn.builder.io/api/v1/image/assets%2FIsxPKMo2gPRRKeakUztj1D6uqed2%2Fef36d2a846134910b64b88e6d18c5ca5",inputs:[{name:"sendSubmissionsTo",type:"string",enum:[{label:"Send to email",value:"email",helperText:"Send form submissions to the email address of your choosing"},{label:"Custom",value:"custom",helperText:"Handle where the form requests go manually with a little code, e.g. to your own custom backend"}],defaultValue:"email"},{name:"sendSubmissionsToEmail",type:"string",required:!0,defaultValue:"your@email.com",showIf:'options.get("sendSubmissionsTo") === "email"'},{name:"sendWithJs",type:"boolean",helperText:"Set to false to use basic html form action",defaultValue:!0,showIf:'options.get("sendSubmissionsTo") === "custom"'},{name:"name",type:"string",defaultValue:"My form"},{name:"action",type:"string",helperText:"URL to send the form data to",showIf:'options.get("sendSubmissionsTo") === "custom"'},{name:"contentType",type:"string",defaultValue:"application/json",advanced:!0,enum:["application/json","multipart/form-data","application/x-www-form-urlencoded"],showIf:'options.get("sendSubmissionsTo") === "custom" && options.get("sendWithJs") === true'},{name:"method",type:"string",showIf:'options.get("sendSubmissionsTo") === "custom"',advanced:!0},{name:"previewState",type:"string",enum:["unsubmitted","sending","success","error"],defaultValue:"unsubmitted",helperText:'Choose a state to edit, e.g. choose "success" to show what users see on success and edit the message',showIf:'options.get("sendSubmissionsTo") !== "zapier" && options.get("sendWithJs") === true'},{name:"successUrl",type:"url",helperText:"Optional URL to redirect the user to on form submission success",showIf:'options.get("sendSubmissionsTo") !== "zapier" && options.get("sendWithJs") === true'},{name:"resetFormOnSubmit",type:"boolean",showIf:function(e){return"custom"===e.get("sendSubmissionsTo")&&!0===e.get("sendWithJs")},advanced:!0},{name:"successMessage",type:"uiBlocks",hideFromUI:!0,defaultValue:[{"@type":"@builder.io/sdk:Element",responsiveStyles:{large:{marginTop:"10px"}},component:{name:"Text",options:{text:"<span>Thanks!</span>"}}}]},{name:"validate",type:"boolean",defaultValue:!0,advanced:!0},{name:"errorMessagePath",type:"text",advanced:!0,helperText:'Path to where to get the error message from in a JSON response to display to the user, e.g. "error.message" for a response like { "error": { "message": "this username is taken" }}'},{name:"errorMessage",type:"uiBlocks",hideFromUI:!0,defaultValue:[{"@type":"@builder.io/sdk:Element",responsiveStyles:{large:{marginTop:"10px"}},bindings:{"component.options.text":"state.formErrorMessage || block.component.options.text"},component:{name:"Text",options:{text:"<span>Form submission error :( Please check your answers and try again</span>"}}}]},{name:"sendingMessage",type:"uiBlocks",hideFromUI:!0,defaultValue:[{"@type":"@builder.io/sdk:Element",responsiveStyles:{large:{marginTop:"10px"}},component:{name:"Text",options:{text:"<span>Sending...</span>"}}}]},__assign$1(__assign$1({name:"customHeaders",type:"map"},{valueType:{type:"string"}}),{advanced:!0,showIf:'options.get("sendSubmissionsTo") === "custom" && options.get("sendWithJs") === true'})],noWrap:!0,canHaveChildren:!0,defaultChildren:[{"@type":"@builder.io/sdk:Element",responsiveStyles:{large:{marginTop:"10px"}},component:{name:"Text",options:{text:"<span>Enter your name</span>"}}},{"@type":"@builder.io/sdk:Element",responsiveStyles:{large:{marginTop:"10px"}},component:{name:"Form:Input",options:{name:"name",placeholder:"Jane Doe"}}},{"@type":"@builder.io/sdk:Element",responsiveStyles:{large:{marginTop:"10px"}},component:{name:"Text",options:{text:"<span>Enter your email</span>"}}},{"@type":"@builder.io/sdk:Element",responsiveStyles:{large:{marginTop:"10px"}},component:{name:"Form:Input",options:{name:"email",placeholder:"jane@doe.com"}}},{"@type":"@builder.io/sdk:Element",responsiveStyles:{large:{marginTop:"10px"}},component:{name:"Form:SubmitButton",options:{text:"Submit"}}}]}),FormInputComponent=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return __extends$1(t,e),t.prototype.render=function(){return react.createElement("input",__assign$1({key:Builder.isEditing&&this.props.defaultValue?this.props.defaultValue:"default-key",placeholder:this.props.placeholder,type:this.props.type,name:this.props.name,value:this.props.value,defaultValue:this.props.defaultValue,required:this.props.required},this.props.attributes))},t}(react.Component),FormInput=withBuilder(FormInputComponent,{name:"Form:Input",image:"https://cdn.builder.io/api/v1/image/assets%2FIsxPKMo2gPRRKeakUztj1D6uqed2%2Fad6f37889d9e40bbbbc72cdb5875d6ca",inputs:[{name:"type",type:"text",enum:["text","number","email","url","checkbox","radio","range","date","datetime-local","search","tel","time","file","month","week","password","color","hidden"],defaultValue:"text"},{name:"name",type:"string",required:!0,helperText:'Every input in a form needs a unique name describing what it takes, e.g. "email"'},{name:"placeholder",type:"string",defaultValue:"Hello there",helperText:"Text to display when there is no value"},{name:"defaultValue",type:"string"},{name:"value",type:"string",advanced:!0},{name:"required",type:"boolean",helperText:"Is this input required to be filled out to submit a form",defaultValue:!1}],noWrap:!0,static:!0,defaultStyles:{paddingTop:"10px",paddingBottom:"10px",paddingLeft:"10px",paddingRight:"10px",borderRadius:"3px",borderWidth:"1px",borderStyle:"solid",borderColor:"#ccc"}}),FormSubmitButtonComponent=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return __extends$1(t,e),t.prototype.render=function(){return react.createElement("button",__assign$1({type:"submit"},this.props.attributes),this.props.text)},t}(react.Component),FormSubmitButton=withBuilder(FormSubmitButtonComponent,{name:"Form:SubmitButton",image:"https://cdn.builder.io/api/v1/image/assets%2FIsxPKMo2gPRRKeakUztj1D6uqed2%2Fdf2820ffed1f4349a94c40b3221f5b98",defaultStyles:{appearance:"none",paddingTop:"15px",paddingBottom:"15px",paddingLeft:"25px",paddingRight:"25px",backgroundColor:"#3898EC",color:"white",borderRadius:"4px",cursor:"pointer"},inputs:[{name:"text",type:"text",defaultValue:"Click me"}],static:!0,noWrap:!0}),LabelComponent=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return __extends$1(t,e),t.prototype.render=function(){return react.createElement("label",__assign$1({htmlFor:this.props.for},this.props.attributes),this.props.text&&react.createElement("span",{className:"builder-label-text",dangerouslySetInnerHTML:{__html:this.props.text}}),this.props.builderBlock&&this.props.builderBlock.children&&this.props.builderBlock.children.map((function(e){return react.createElement(BuilderBlock,{key:e.id,block:e})})))},t}(react.Component),Label=withBuilder(LabelComponent,{name:"Form:Label",image:"https://cdn.builder.io/api/v1/image/assets%2FIsxPKMo2gPRRKeakUztj1D6uqed2%2F9322342f04b545fb9a8091cd801dfb5b",inputs:[{name:"text",type:"html",richText:!0,defaultValue:"Label"},{name:"for",type:"text",helperText:"The name of the input this label is for",advanced:!0}],noWrap:!0,static:!0,canHaveChildren:!0}),FormSelectComponent=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return __extends$1(t,e),t.prototype.render=function(){var e=this.props.options;return react.createElement("select",__assign$1({value:this.props.value,key:Builder.isEditing&&this.props.defaultValue?this.props.defaultValue:"default-key",defaultValue:this.props.defaultValue,name:this.props.name},this.props.attributes),e&&e.map((function(e){return react.createElement("option",{value:e.value},e.name||e.value)})))},t}(react.Component),FormSelect=withBuilder(FormSelectComponent,{name:"Form:Select",image:"https://cdn.builder.io/api/v1/image/assets%2FIsxPKMo2gPRRKeakUztj1D6uqed2%2F83acca093fb24aaf94dee136e9a4b045",defaultStyles:{alignSelf:"flex-start"},inputs:[{name:"options",type:"list",required:!0,subFields:[{name:"value",type:"text",required:!0},{name:"name",type:"text"}],defaultValue:[{value:"option 1"},{value:"option 2"}]},{name:"name",type:"string",required:!0,helperText:'Every select in a form needs a unique name describing what it gets, e.g. "email"'},{name:"defaultValue",type:"string"},{name:"value",type:"string",advanced:!0},{name:"required",type:"boolean",defaultValue:!1}],static:!0,noWrap:!0}),TextAreaComponent=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return __extends$1(t,e),t.prototype.render=function(){return react.createElement("textarea",__assign$1({placeholder:this.props.placeholder,name:this.props.name,value:this.props.value,defaultValue:this.props.defaultValue},this.props.attributes))},t}(react.Component),TextArea=withBuilder(TextAreaComponent,{name:"Form:TextArea",image:"https://cdn.builder.io/api/v1/image/assets%2FIsxPKMo2gPRRKeakUztj1D6uqed2%2Ff74a2f3de58c4c3e939204e5b6b8f6c3",inputs:[{advanced:!0,name:"value",type:"string"},{name:"name",type:"string",required:!0,helperText:'Every input in a form needs a unique name describing what it gets, e.g. "email"'},{name:"defaultValue",type:"string"},{name:"placeholder",type:"string",defaultValue:"Hello there"},{name:"required",type:"boolean",defaultValue:!1}],defaultStyles:{paddingTop:"10px",paddingBottom:"10px",paddingLeft:"10px",paddingRight:"10px",borderRadius:"3px",borderWidth:"1px",borderStyle:"solid",borderColor:"#ccc"},static:!0,noWrap:!0}),ImgComponent=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return __extends$1(t,e),t.prototype.render=function(){var e=this.props.attributes||{};return react.createElement("img",__assign$1({},this.props.attributes,{src:this.props.image||e.src}))},t}(react.Component),Img=withBuilder(ImgComponent,{name:"Raw:Img",hideFromInsertMenu:!0,image:"https://firebasestorage.googleapis.com/v0/b/builder-3b0a2.appspot.com/o/images%2Fbaseline-insert_photo-24px.svg?alt=media&token=4e5d0ef4-f5e8-4e57-b3a9-38d63a9b9dc4",inputs:[{name:"image",type:"file",allowedFileTypes:["jpeg","jpg","png","svg"],required:!0}],noWrap:!0,static:!0}),RawText=function(e){var t=e.attributes||{};return react_4("span",{className:(null==t?void 0:t.class)||(null==t?void 0:t.className),dangerouslySetInnerHTML:{__html:e.text||""}})};Builder.registerComponent(RawText,{name:"Builder:RawText",hideFromInsertMenu:!0,inputs:[{name:"text",type:"longText",required:!0}]}),Builder.isReact=!0;

    /*
    object-assign
    (c) Sindre Sorhus
    @license MIT
    */
    /* eslint-disable no-unused-vars */
    var getOwnPropertySymbols$1 = Object.getOwnPropertySymbols;
    var hasOwnProperty$2 = Object.prototype.hasOwnProperty;
    var propIsEnumerable$1 = Object.prototype.propertyIsEnumerable;

    function toObject$1(val) {
    	if (val === null || val === undefined) {
    		throw new TypeError('Object.assign cannot be called with null or undefined');
    	}

    	return Object(val);
    }

    function shouldUseNative$1() {
    	try {
    		if (!Object.assign) {
    			return false;
    		}

    		// Detect buggy property enumeration order in older V8 versions.

    		// https://bugs.chromium.org/p/v8/issues/detail?id=4118
    		var test1 = new String('abc');  // eslint-disable-line no-new-wrappers
    		test1[5] = 'de';
    		if (Object.getOwnPropertyNames(test1)[0] === '5') {
    			return false;
    		}

    		// https://bugs.chromium.org/p/v8/issues/detail?id=3056
    		var test2 = {};
    		for (var i = 0; i < 10; i++) {
    			test2['_' + String.fromCharCode(i)] = i;
    		}
    		var order2 = Object.getOwnPropertyNames(test2).map(function (n) {
    			return test2[n];
    		});
    		if (order2.join('') !== '0123456789') {
    			return false;
    		}

    		// https://bugs.chromium.org/p/v8/issues/detail?id=3056
    		var test3 = {};
    		'abcdefghijklmnopqrst'.split('').forEach(function (letter) {
    			test3[letter] = letter;
    		});
    		if (Object.keys(Object.assign({}, test3)).join('') !==
    				'abcdefghijklmnopqrst') {
    			return false;
    		}

    		return true;
    	} catch (err) {
    		// We don't expect any of the above to throw, but better to be safe.
    		return false;
    	}
    }

    var objectAssign$1 = shouldUseNative$1() ? Object.assign : function (target, source) {
    	var from;
    	var to = toObject$1(target);
    	var symbols;

    	for (var s = 1; s < arguments.length; s++) {
    		from = Object(arguments[s]);

    		for (var key in from) {
    			if (hasOwnProperty$2.call(from, key)) {
    				to[key] = from[key];
    			}
    		}

    		if (getOwnPropertySymbols$1) {
    			symbols = getOwnPropertySymbols$1(from);
    			for (var i = 0; i < symbols.length; i++) {
    				if (propIsEnumerable$1.call(from, symbols[i])) {
    					to[symbols[i]] = from[symbols[i]];
    				}
    			}
    		}
    	}

    	return to;
    };

    var n$1="function"===typeof Symbol&&Symbol.for,p$1=n$1?Symbol.for("react.element"):60103,q$1=n$1?Symbol.for("react.portal"):60106,r$1=n$1?Symbol.for("react.fragment"):60107,t$1=n$1?Symbol.for("react.strict_mode"):60108,u$2=n$1?Symbol.for("react.profiler"):60114,v$1=n$1?Symbol.for("react.provider"):60109,w$2=n$1?Symbol.for("react.context"):60110,x$1=n$1?Symbol.for("react.forward_ref"):60112,y$1=n$1?Symbol.for("react.suspense"):60113;var z$1=n$1?Symbol.for("react.memo"):60115,aa$1=n$1?Symbol.for("react.lazy"):60116;var A$1="function"===typeof Symbol&&Symbol.iterator;
    function B$2(a){for(var b="https://reactjs.org/docs/error-decoder.html?invariant="+a,c=1;c<arguments.length;c++)b+="&args[]="+encodeURIComponent(arguments[c]);return"Minified React error #"+a+"; visit "+b+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}var C$1={isMounted:function(){return!1},enqueueForceUpdate:function(){},enqueueReplaceState:function(){},enqueueSetState:function(){}},D$2={};
    function E$2(a,b,c){this.props=a;this.context=b;this.refs=D$2;this.updater=c||C$1;}E$2.prototype.isReactComponent={};E$2.prototype.setState=function(a,b){if("object"!==typeof a&&"function"!==typeof a&&null!=a)throw Error(B$2(85));this.updater.enqueueSetState(this,a,b,"setState");};E$2.prototype.forceUpdate=function(a){this.updater.enqueueForceUpdate(this,a,"forceUpdate");};function F$2(){}F$2.prototype=E$2.prototype;function G$2(a,b,c){this.props=a;this.context=b;this.refs=D$2;this.updater=c||C$1;}var H$1=G$2.prototype=new F$2;
    H$1.constructor=G$2;objectAssign$1(H$1,E$2.prototype);H$1.isPureReactComponent=!0;var I$2={current:null},J$2={current:null},K$2=Object.prototype.hasOwnProperty,L$2={key:!0,ref:!0,__self:!0,__source:!0};
    function M$2(a,b,c){var e,d={},g=null,l=null;if(null!=b)for(e in void 0!==b.ref&&(l=b.ref),void 0!==b.key&&(g=""+b.key),b)K$2.call(b,e)&&!L$2.hasOwnProperty(e)&&(d[e]=b[e]);var f=arguments.length-2;if(1===f)d.children=c;else if(1<f){for(var k=Array(f),m=0;m<f;m++)k[m]=arguments[m+2];d.children=k;}if(a&&a.defaultProps)for(e in f=a.defaultProps,f)void 0===d[e]&&(d[e]=f[e]);return{$$typeof:p$1,type:a,key:g,ref:l,props:d,_owner:J$2.current}}
    function ba$2(a,b){return{$$typeof:p$1,type:a.type,key:b,ref:a.ref,props:a.props,_owner:a._owner}}function N$2(a){return"object"===typeof a&&null!==a&&a.$$typeof===p$1}function escape$1(a){var b={"=":"=0",":":"=2"};return"$"+(""+a).replace(/[=:]/g,function(a){return b[a]})}var O$2=/\/+/g,P$2=[];function Q$2(a,b,c,e){if(P$2.length){var d=P$2.pop();d.result=a;d.keyPrefix=b;d.func=c;d.context=e;d.count=0;return d}return{result:a,keyPrefix:b,func:c,context:e,count:0}}
    function R$2(a){a.result=null;a.keyPrefix=null;a.func=null;a.context=null;a.count=0;10>P$2.length&&P$2.push(a);}
    function S$2(a,b,c,e){var d=typeof a;if("undefined"===d||"boolean"===d)a=null;var g=!1;if(null===a)g=!0;else switch(d){case "string":case "number":g=!0;break;case "object":switch(a.$$typeof){case p$1:case q$1:g=!0;}}if(g)return c(e,a,""===b?"."+T$2(a,0):b),1;g=0;b=""===b?".":b+":";if(Array.isArray(a))for(var l=0;l<a.length;l++){d=a[l];var f=b+T$2(d,l);g+=S$2(d,f,c,e);}else if(null===a||"object"!==typeof a?f=null:(f=A$1&&a[A$1]||a["@@iterator"],f="function"===typeof f?f:null),"function"===typeof f)for(a=f.call(a),l=
    0;!(d=a.next()).done;)d=d.value,f=b+T$2(d,l++),g+=S$2(d,f,c,e);else if("object"===d)throw c=""+a,Error(B$2(31,"[object Object]"===c?"object with keys {"+Object.keys(a).join(", ")+"}":c,""));return g}function U$2(a,b,c){return null==a?0:S$2(a,"",b,c)}function T$2(a,b){return"object"===typeof a&&null!==a&&null!=a.key?escape$1(a.key):b.toString(36)}function ca$2(a,b){a.func.call(a.context,b,a.count++);}
    function da$2(a,b,c){var e=a.result,d=a.keyPrefix;a=a.func.call(a.context,b,a.count++);Array.isArray(a)?V$2(a,e,c,function(a){return a}):null!=a&&(N$2(a)&&(a=ba$2(a,d+(!a.key||b&&b.key===a.key?"":(""+a.key).replace(O$2,"$&/")+"/")+c)),e.push(a));}function V$2(a,b,c,e,d){var g="";null!=c&&(g=(""+c).replace(O$2,"$&/")+"/");b=Q$2(b,g,e,d);U$2(a,da$2,b);R$2(b);}function W$2(){var a=I$2.current;if(null===a)throw Error(B$2(321));return a}
    var X$2={Children:{map:function(a,b,c){if(null==a)return a;var e=[];V$2(a,e,null,b,c);return e},forEach:function(a,b,c){if(null==a)return a;b=Q$2(null,null,b,c);U$2(a,ca$2,b);R$2(b);},count:function(a){return U$2(a,function(){return null},null)},toArray:function(a){var b=[];V$2(a,b,null,function(a){return a});return b},only:function(a){if(!N$2(a))throw Error(B$2(143));return a}},createRef:function(){return{current:null}},Component:E$2,PureComponent:G$2,createContext:function(a,b){void 0===b&&(b=null);a={$$typeof:w$2,_calculateChangedBits:b,
    _currentValue:a,_currentValue2:a,_threadCount:0,Provider:null,Consumer:null};a.Provider={$$typeof:v$1,_context:a};return a.Consumer=a},forwardRef:function(a){return{$$typeof:x$1,render:a}},lazy:function(a){return{$$typeof:aa$1,_ctor:a,_status:-1,_result:null}},memo:function(a,b){return{$$typeof:z$1,type:a,compare:void 0===b?null:b}},useCallback:function(a,b){return W$2().useCallback(a,b)},useContext:function(a,b){return W$2().useContext(a,b)},useEffect:function(a,b){return W$2().useEffect(a,b)},useImperativeHandle:function(a,
    b,c){return W$2().useImperativeHandle(a,b,c)},useDebugValue:function(){},useLayoutEffect:function(a,b){return W$2().useLayoutEffect(a,b)},useMemo:function(a,b){return W$2().useMemo(a,b)},useReducer:function(a,b,c){return W$2().useReducer(a,b,c)},useRef:function(a){return W$2().useRef(a)},useState:function(a){return W$2().useState(a)},Fragment:r$1,Profiler:u$2,StrictMode:t$1,Suspense:y$1,createElement:M$2,cloneElement:function(a,b,c){if(null===a||void 0===a)throw Error(B$2(267,a));var e=objectAssign$1({},a.props),d=a.key,g=a.ref,l=a._owner;
    if(null!=b){void 0!==b.ref&&(g=b.ref,l=J$2.current);void 0!==b.key&&(d=""+b.key);if(a.type&&a.type.defaultProps)var f=a.type.defaultProps;for(k in b)K$2.call(b,k)&&!L$2.hasOwnProperty(k)&&(e[k]=void 0===b[k]&&void 0!==f?f[k]:b[k]);}var k=arguments.length-2;if(1===k)e.children=c;else if(1<k){f=Array(k);for(var m=0;m<k;m++)f[m]=arguments[m+2];e.children=f;}return{$$typeof:p$1,type:a.type,key:d,ref:g,props:e,_owner:l}},createFactory:function(a){var b=M$2.bind(null,a);b.type=a;return b},isValidElement:N$2,version:"16.12.0",
    __SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED:{ReactCurrentDispatcher:I$2,ReactCurrentBatchConfig:{suspense:null},ReactCurrentOwner:J$2,IsSomeRendererActing:{current:!1},assign:objectAssign$1}},Y$2={default:X$2},Z$2=Y$2&&X$2||Y$2;var react_production_min$1=Z$2.default||Z$2;

    var react$1 = createCommonjsModule(function (module) {

    {
      module.exports = react_production_min$1;
    }
    });
    var react_1$1 = react$1.cloneElement;
    var react_2$1 = react$1.createContext;
    var react_3$1 = react$1.Component;
    var react_4$1 = react$1.createElement;
    var react_5$1 = react$1.forwardRef;
    var react_6$1 = react$1.Fragment;

    var BG_START_TAG = 'bg-image-start';
    var BG_END_TAG = 'bg-image-end';
    var sizes$1 = {
        xsmall: {
            min: 0,
            default: 0,
            max: 0,
        },
        small: {
            min: 0,
            default: 321,
            max: 639,
        },
        medium: {
            min: 640,
            default: 641,
            max: 999,
        },
        large: {
            min: 1000,
            default: 1001,
            max: 1200,
        },
        getWidthForSize: function (size) {
            return this[size].default;
        },
        getSizeForWidth: function (width) {
            for (var _i = 0, sizeNames_1 = sizeNames$1; _i < sizeNames_1.length; _i++) {
                var size = sizeNames_1[_i];
                var value = this[size];
                if (width <= value.max) {
                    return size;
                }
            }
            return 'large';
        },
    };
    var sizeNames$1 = ['xsmall', 'small', 'medium', 'large'];
    var camelCaseToKebabCase$2 = function (str) {
        return str ? str.replace(/([A-Z])/g, function (g) { return "-" + g[0].toLowerCase(); }) : '';
    };
    var cssCase$1 = function (property) {
        if (!property) {
            return property;
        }
        var str = camelCaseToKebabCase$2(property);
        if (property[0] === property[0].toUpperCase()) {
            str = '-' + str;
        }
        return str;
    };
    function mapToCss$1(map, spaces, important) {
        if (spaces === void 0) { spaces = 2; }
        if (important === void 0) { important = false; }
        return Object.keys(map).reduce(function (memo, key) {
            var value = map[key];
            if (typeof value !== 'string') {
                return memo;
            }
            return (memo +
                (value && value.trim()
                    ? "\n" + ' '.repeat(spaces) + cssCase$1(key) + ": " + (value + (important ? ' !important' : '')) + ";"
                    : ''));
        }, '');
    }
    var Block = /** @class */ (function (_super) {
        __extends(Block, _super);
        function Block() {
            var _this = _super !== null && _super.apply(this, arguments) || this;
            _this.outerTable = null;
            return _this;
        }
        Block.prototype.getAlign = function (size) {
            var _a;
            var block = this.props.builderBlock;
            var sizeStyles = ((_a = block.responsiveStyles) === null || _a === void 0 ? void 0 : _a[size]) || {};
            var align = sizeStyles.marginRight === 'auto' && sizeStyles.marginLeft === 'auto'
                ? 'center'
                : sizeStyles.marginLeft === 'auto'
                    ? 'right'
                    : 'left';
            return align;
        };
        Block.prototype.getVAlign = function (size) {
            var block = this.props.builderBlock;
            var sizeStyles = block.responsiveStyles[size] || {};
            var vAlign = sizeStyles.marginBottom === 'auto' && sizeStyles.marginTop === 'auto'
                ? 'middle'
                : sizeStyles.marginTop === 'auto'
                    ? 'bottom'
                    : 'top';
            return vAlign;
        };
        Block.prototype.getOuterStyles = function (size) {
            var block = this.props.builderBlock;
            var sizeStyles = block.responsiveStyles[size] || {};
            var outerDisplay = sizeStyles.display;
            var outerVerticalAlign = sizeStyles.verticalAlign;
            var outerStyles = {
                width: '100%',
                border: '0',
                display: outerDisplay,
                verticalAlign: outerVerticalAlign,
            };
            return outerStyles;
        };
        Block.prototype.getMidStyles = function (size) {
            var block = this.props.builderBlock;
            var sizeStyles = block.responsiveStyles[size] || {};
            var align = this.getAlign(size);
            var vAlign = this.getVAlign(size);
            var midStyles = {
                paddingTop: sizeStyles.marginTop,
                paddingRight: sizeStyles.marginRight,
                paddingBottom: sizeStyles.marginBottom,
                paddingLeft: sizeStyles.marginLeft,
                verticalAlign: vAlign,
                width: (align === 'left' && sizeStyles.marginRight !== 'auto' && '100%') || undefined,
            };
            return midStyles;
        };
        Block.prototype.getInnerStyles = function (size) {
            var block = this.props.builderBlock;
            var align = this.getAlign(size);
            var sizeStyles = block.responsiveStyles[size] || {};
            var innerStyles = __assign(__assign(__assign({ verticalAlign: 'top' }, sizeStyles), { marginTop: undefined, marginBottom: undefined, marginLeft: undefined, marginRight: undefined, width: (align === 'left' && sizeStyles.marginRight !== 'auto' && '100%') || undefined, display: undefined }), this.props.innerStyleOverrides);
            return innerStyles;
        };
        Block.prototype.getInnerTableStyles = function (size) {
            var block = this.props.builderBlock;
            var sizeStyles = block.responsiveStyles[size] || {};
            var hasPxWidth = sizeStyles.width && sizeStyles.width.trim().endsWith('px');
            var align = this.getAlign(size);
            return {
                // TODO: hasPercent use that also
                width: hasPxWidth
                    ? sizeStyles.width
                    : (align === 'left' && sizeStyles.marginRight !== 'auto' && '100%') || undefined,
            };
        };
        Block.prototype.getLeftTdStyle = function (size) {
            var align = this.getAlign(size);
            return {
                // width: align === 'center' ? '45%' : '90%',
                display: align === 'right' || align === 'center' ? undefined : 'none',
            };
        };
        Block.prototype.getRightTdStyle = function (size) {
            var align = this.getAlign(size);
            return {
                // width: align === 'center' ? '45%' : '90%',
                display: align === 'left' || align === 'center' ? undefined : 'none',
            };
        };
        Object.defineProperty(Block.prototype, "css", {
            get: function () {
                var css = '';
                var block = this.props.builderBlock;
                if (!block) {
                    return '';
                }
                var reversedNames = sizeNames$1.slice().reverse();
                if (block.responsiveStyles) {
                    for (var _i = 0, reversedNames_1 = reversedNames; _i < reversedNames_1.length; _i++) {
                        var size = reversedNames_1[_i];
                        if (size !== 'large' &&
                            size !== 'xsmall' &&
                            block.responsiveStyles[size] &&
                            Object.keys(block.responsiveStyles[size]).length) {
                            // TODO: use emotion
                            css += "\n@media only screen and (max-width: " + sizes$1[size].max + "px) {\n  ." + block.id + " { " + mapToCss$1(this.getOuterStyles(size), 4, true) + " }\n  ." + block.id + "-inner { " + mapToCss$1(this.getInnerTableStyles(size), 4, true) + " }\n  ." + block.id + "-subject { " + mapToCss$1(this.getInnerStyles(size), 4, true) + " }\n  ." + block.id + "-middle { " + mapToCss$1(this.getMidStyles(size), 4, true) + " }\n}";
                        }
                    }
                }
                return css;
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(Block.prototype, "bgImageUrl", {
            get: function () {
                var backgroundImage = this.props.builderBlock.responsiveStyles.large.backgroundImage;
                return backgroundImage && backgroundImage.replace(/.*?url\(['"]?(.*?)['"]?\).*?/, '$1');
            },
            enumerable: true,
            configurable: true
        });
        Block.prototype.render = function () {
            var _this = this;
            var block = this.props.builderBlock;
            var align = this.getAlign('large');
            var vAlign = this.getVAlign('large');
            var midStyles = this.getMidStyles('large');
            var attributes = this.props.attributes || {};
            var hasLink = attributes.href;
            var InnerTag = hasLink ? 'a' : 'span';
            var innerStyles = this.getInnerStyles('large');
            var bgImageUrl = this.bgImageUrl;
            var pxHeight = innerStyles.height && innerStyles.height.includes('px') && parseFloat(innerStyles.height);
            // TODO: only double wrap if hasMargin
            return (react$1.createElement(react$1.Fragment, null,
                react$1.createElement("style", { className: "builder-style" }, this.css),
                react$1.createElement("table", { role: "presentation", ref: function (ref) { return (_this.outerTable = ref); }, cellPadding: "0", cellSpacing: "0", "builder-id": attributes['builder-id'], className: attributes.class || attributes.className, style: this.getOuterStyles('large') },
                    react$1.createElement("tbody", { style: { width: '100%' } },
                        react$1.createElement("tr", null,
                            react$1.createElement("td", null),
                            react$1.createElement("td", __assign({}, { align: align, vAlign: vAlign }, { style: midStyles, className: block.id + "-middle" }),
                                react$1.createElement(InnerTag, __assign({}, (hasLink
                                    ? {
                                        href: attributes.href,
                                        target: '_blank',
                                        style: {
                                            textDecoration: 'none',
                                            // TODO: outlook this not always working
                                            color: 'inherit',
                                        },
                                    }
                                    : null)),
                                    react$1.createElement("table", __assign({ role: "presentation", cellPadding: "0", cellSpacing: "0", className: block.id + "-inner", style: __assign(__assign({}, this.getInnerTableStyles('large')), { height: '100%' }) }, {
                                        border: '0',
                                    }),
                                        react$1.createElement("tbody", { style: { width: '100%' } },
                                            react$1.createElement("tr", null,
                                                react$1.createElement("td", __assign({ className: "builder-block-subject " + this.props.builderBlock.id + "-subject", style: innerStyles }, (typeof pxHeight === 'number' &&
                                                    !isNaN(pxHeight) && {
                                                    height: pxHeight,
                                                })),
                                                    bgImageUrl && (react$1.createElement(BG_START_TAG, { url: this.bgImageUrl, color: innerStyles.backgroundColor, height: innerStyles.height })),
                                                    this.props.children,
                                                    bgImageUrl && react$1.createElement(BG_END_TAG, null))))))),
                            react$1.createElement("td", null))))));
        };
        return Block;
    }(react$1.Component));

    // TODO: acceptsChildren option?
    var Box = /** @class */ (function (_super) {
        __extends(Box, _super);
        function Box() {
            return _super !== null && _super.apply(this, arguments) || this;
        }
        Box.prototype.render = function () {
            return (react$1.createElement(Block, { attributes: this.props.attributes, builderBlock: this.props.builderBlock, innerStyleOverrides: { verticalAlign: this.props.verticalAlignContent } },
                react$1.createElement(BuilderBlocks, { blocks: this.props.children, dataPath: "children", emailMode: true })));
        };
        Box = __decorate([
            BuilderBlock$1({
                name: 'Email:Box',
                inputs: [
                    {
                        name: 'children',
                        type: 'uiBlocks',
                        defaultValue: [],
                        // showNoBlocks: false
                        hideFromUI: true,
                    },
                    {
                        name: 'verticalAlignContent',
                        type: 'string',
                        enum: ['top', 'bottom', 'middle'],
                        defaultValue: 'top',
                    },
                ],
                defaultStyles: {
                    height: '200px',
                },
            })
        ], Box);
        return Box;
    }(react$1.Component));

    var defaultBlocks$1 = [
        {
            '@type': '@builder.io/sdk:Element',
            responsiveStyles: {
                large: {
                    marginTop: '20px',
                    minWidth: '20px',
                    overflow: 'hidden',
                    fontSize: '0px',
                },
            },
            component: {
                name: 'Email:Image',
                options: {
                    image: 'https://builder.io/api/v1/image/assets%2Fpwgjf0RoYWbdnJSbpBAjXNRMe9F2%2Ffb27a7c790324294af8be1c35fe30f4d',
                },
            },
        },
        {
            '@type': '@builder.io/sdk:Element',
            responsiveStyles: {
                large: {
                    marginTop: '20px',
                    textAlign: 'center',
                },
            },
            component: {
                name: 'Email:Text',
                options: {
                    text: '<span>Enter some text...</span>',
                },
            },
        },
    ];
    var Columns$1 = /** @class */ (function (_super) {
        __extends(Columns$$1, _super);
        function Columns$$1() {
            return _super !== null && _super.apply(this, arguments) || this;
        }
        Columns$$1.prototype.render = function () {
            var _this = this;
            return (react$1.createElement(Block, { attributes: this.props.attributes, builderBlock: this.props.builderBlock },
                this.props.stackColumnsAt && this.props.stackColumnsAt !== 'never' && (react$1.createElement("style", null, "\n          @media only screen and (max-width:" + (this.props.stackColumnsAt === 'mobile' ? 639 : 999) + "px) {\n            ." + this.props.builderBlock.id + "-separator-td {\n              display: none !important;\n            }\n\n            ." + this.props.builderBlock.id + "-subject-td {\n              display: block !important;\n              width: 100% !important;\n            }\n          }\n        ")),
                react$1.createElement("table", { style: { width: '100%' }, cellPadding: "0", cellSpacing: "0" },
                    react$1.createElement("tbody", null,
                        react$1.createElement("tr", null, this.props.columns.map(function (col, index) { return (
                        // TODO: width
                        react$1.createElement(react$1.Fragment, { key: index },
                            index !== 0 && (react$1.createElement("td", { className: _this.props.builderBlock.id + "-separator-td", style: {
                                    width: _this.props.space,
                                    minWidth: _this.props.space,
                                } })),
                            react$1.createElement("td", { className: _this.props.builderBlock.id + "-subject-td", style: {
                                    width: col.width,
                                    verticalAlign: _this.props.verticalAlignContent || 'top',
                                } },
                                react$1.createElement(BuilderBlocks, { blocks: col.blocks, dataPath: "columns." + index + ".blocks", emailMode: true })))); }))))));
        };
        Columns$$1 = __decorate([
            BuilderBlock$1({
                name: 'Email:Columns',
                inputs: [
                    {
                        name: 'columns',
                        type: 'array',
                        subFields: [
                            {
                                name: 'blocks',
                                type: 'uiBlocks',
                                hideFromUI: true,
                                defaultValue: defaultBlocks$1,
                            },
                            {
                                name: 'width',
                                type: 'string',
                                // defaultValue: 'auto',
                                // advanced: true,
                                helperText: 'Width, e.g. set to "100px" to always be 100 pixels wide, or "50%" to always fill 50% of the entire space',
                            },
                            {
                                name: 'verticalAlignContent',
                                type: 'string',
                                enum: ['top', 'bottom', 'middle'],
                                defaultValue: 'top',
                            },
                        ],
                        defaultValue: [
                            { blocks: defaultBlocks$1, width: '50%' },
                            { blocks: defaultBlocks$1, width: '50%' },
                        ],
                        onChange: function (options) {
                            var columns = options.get('columns');
                            var colsWithoutPx = columns.filter(function (col) {
                                var width = col.get('width') || '';
                                return !width.includes('px');
                            });
                            function round(num) {
                                return Math.round(num * 1000) / 1000;
                            }
                            function clearWidths() {
                                colsWithoutPx.forEach(function (col) {
                                    // TODO: round
                                    col.set('width', round(100 / colsWithoutPx.length) + '%');
                                });
                            }
                            if (Array.isArray(columns)) {
                                var containsColumnWithWidth = !!colsWithoutPx.find(function (col) { return col.get('width'); });
                                if (containsColumnWithWidth) {
                                    var containsColumnWithoutWidth = !!colsWithoutPx.find(function (col) { return !col.get('width'); });
                                    if (containsColumnWithoutWidth) {
                                        clearWidths();
                                    }
                                    else {
                                        var sumWidths = colsWithoutPx.reduce(function (memo, col) {
                                            return memo + col.get('width');
                                        }, 0);
                                        var widthsDontAddUp = sumWidths !== 100;
                                        if (widthsDontAddUp) {
                                            clearWidths();
                                        }
                                    }
                                }
                            }
                        },
                    },
                    {
                        name: 'space',
                        friendlyName: 'Gap size',
                        type: 'number',
                        defaultValue: 20,
                        helperText: 'Size of gap between columns',
                    },
                    {
                        name: 'stackColumnsAt',
                        type: 'string',
                        defaultValue: 'mobile',
                        helperText: 'Convert horizontal columns to vertical at what device size',
                        enum: ['tablet', 'mobile', 'never'],
                    },
                ],
            })
        ], Columns$$1);
        return Columns$$1;
    }(react$1.Component));

    var CustomCode$1 = /** @class */ (function (_super) {
        __extends(CustomCode$$1, _super);
        function CustomCode$$1() {
            return _super !== null && _super.apply(this, arguments) || this;
        }
        CustomCode$$1.prototype.render = function () {
            return (react$1.createElement(Block, { attributes: this.props.attributes, builderBlock: this.props.builderBlock },
                react$1.createElement("span", { dangerouslySetInnerHTML: { __html: this.props.code } })));
        };
        CustomCode$$1 = __decorate([
            BuilderBlock$1({
                name: 'Email:CustomCode',
                inputs: [
                    {
                        name: 'code',
                        type: 'html',
                        required: true,
                        defaultValue: 'I am custom html',
                    },
                ],
            })
        ], CustomCode$$1);
        return CustomCode$$1;
    }(react$1.Component));

    function getStyles(block) {
        // TODO: responsive
        var styles = block && block.responsiveStyles && block.responsiveStyles.large;
        return styles;
    }

    function updateQueryParam$1(uri, key, value) {
        if (uri === void 0) { uri = ''; }
        var re = new RegExp('([?&])' + key + '=.*?(&|$)', 'i');
        var separator = uri.indexOf('?') !== -1 ? '&' : '?';
        if (uri.match(re)) {
            return uri.replace(re, '$1' + key + '=' + encodeURIComponent(value) + '$2');
        }
        return uri + separator + key + '=' + encodeURIComponent(value);
    }
    var DEFAULT_ASPECT_RATIO$3 = 0.7041;
    var Image$1 = /** @class */ (function (_super) {
        __extends(Image$$1, _super);
        function Image$$1() {
            return _super !== null && _super.apply(this, arguments) || this;
        }
        Image$$1.prototype.getSrcSet = function () {
            var url = this.props.image;
            if (!url) {
                return url;
            }
            var sizes = [100, 200, 400, 800, 1200, 1600, 2000];
            return sizes
                .map(function (size) { return updateQueryParam$1(url, 'width', String(size)) + " " + size + "w"; })
                .concat([url])
                .join(', ');
        };
        Image$$1.prototype.render = function () {
            var allStyles = getStyles(this.props.builderBlock) || {};
            var srcset = this.props.srcset;
            var image = this.props.image;
            if (srcset && image && image.includes('/api/v1/image')) {
                if (!srcset.includes(image.split('?')[0])) {
                    console.debug('Removed given srcset');
                    srcset = this.getSrcSet();
                }
            }
            else if (image) {
                srcset = this.getSrcSet();
            }
            return (react$1.createElement(Block, { attributes: this.props.attributes, builderBlock: this.props.builderBlock },
                react$1.createElement("img", { key: Builder.isEditing
                        ? (typeof this.props.image === 'string' && this.props.image.split('?')[0]) ||
                            undefined
                        : undefined, alt: this.props.altText, height: this.props.height, width: this.props.width, role: !this.props.altText ? 'presentation' : undefined, style: {
                        height: allStyles.height || 'auto',
                        // maxWidth: '100%',
                        width: '100%',
                    }, className: "builder-image", src: this.props.image, sizes: this.props.sizes, srcSet: srcset })));
        };
        Image$$1 = __decorate([
            BuilderBlock$1({
                name: 'Email:Image',
                image: 'https://firebasestorage.googleapis.com/v0/b/builder-3b0a2.appspot.com/o/images%2Fbaseline-insert_photo-24px.svg?alt=media&token=4e5d0ef4-f5e8-4e57-b3a9-38d63a9b9dc4',
                defaultStyles: {
                    minHeight: '20px',
                    minWidth: '20px',
                    overflow: 'hidden',
                    fontSize: '0px',
                    textAlign: 'center',
                },
                inputs: [
                    {
                        name: 'image',
                        type: 'file',
                        // TODO: gif!
                        allowedFileTypes: ['jpeg', 'jpg', 'png', 'svg'],
                        required: true,
                        // TODO: something better
                        defaultValue: 'https://builder.io/api/v1/image/assets%2Fpwgjf0RoYWbdnJSbpBAjXNRMe9F2%2Ffb27a7c790324294af8be1c35fe30f4d',
                        onChange: function (options) {
                            var DEFAULT_ASPECT_RATIO = 0.7041;
                            function loadImage(url, timeout) {
                                if (timeout === void 0) { timeout = 60000; }
                                return new Promise(function (resolve, reject) {
                                    var img = document.createElement('img');
                                    var loaded = false;
                                    img.onload = function () {
                                        loaded = true;
                                        resolve(img);
                                    };
                                    img.addEventListener('error', function (event) {
                                        console.warn('Image load failed', event.error);
                                        reject(event.error);
                                    });
                                    img.src = url;
                                    setTimeout(function () {
                                        if (!loaded) {
                                            reject(new Error('Image load timed out'));
                                        }
                                    }, timeout);
                                });
                            }
                            // // TODO
                            var value = options.get('image');
                            var aspectRatio = options.get('aspectRatio');
                            if (value && (!aspectRatio || aspectRatio === DEFAULT_ASPECT_RATIO)) {
                                return loadImage(value).then(function (img) {
                                    var possiblyUpdatedAspectRatio = options.get('aspectRatio');
                                    if (options.get('image') === value &&
                                        (!possiblyUpdatedAspectRatio || possiblyUpdatedAspectRatio === DEFAULT_ASPECT_RATIO)) {
                                        if (img.width && img.height) {
                                            // options.set('aspectRatio', round(img.height / img.width));
                                            options.set('height', img.height);
                                            options.set('width', img.width);
                                        }
                                    }
                                });
                            }
                        },
                    },
                    {
                        name: 'altText',
                        type: 'string',
                        helperText: 'Text to display when the user has images off',
                    },
                    {
                        name: 'height',
                        type: 'number',
                        hideFromUI: true,
                    },
                    {
                        name: 'width',
                        type: 'number',
                        hideFromUI: true,
                    },
                    {
                        name: 'aspectRatio',
                        type: 'number',
                        helperText: "This is the ratio of height/width, e.g. set to 1.5 for a 300px wide and 200px tall photo. Set to 0 to not force the image to maintain it's aspect ratio",
                        advanced: true,
                        defaultValue: DEFAULT_ASPECT_RATIO$3,
                    },
                ],
            })
        ], Image$$1);
        return Image$$1;
    }(react$1.Component));

    var Text$1 = /** @class */ (function (_super) {
        __extends(Text$$1, _super);
        function Text$$1() {
            return _super !== null && _super.apply(this, arguments) || this;
        }
        Text$$1.prototype.render = function () {
            return (react$1.createElement(Block, { attributes: this.props.attributes, builderBlock: this.props.builderBlock },
                react$1.createElement("span", { dangerouslySetInnerHTML: { __html: this.props.text } })));
        };
        Text$$1 = __decorate([
            BuilderBlock$1({
                name: 'Email:Text',
                inputs: [
                    {
                        name: 'text',
                        type: 'html',
                        required: true,
                        defaultValue: '<span>Enter some text...</span>',
                    },
                ],
                defaultStyles: {
                    lineHeight: 'normal',
                    height: 'auto',
                    textAlign: 'center',
                },
            })
        ], Text$$1);
        return Text$$1;
    }(react$1.Component));

    // TODO: acceptsChildren option?
    var Section$1 = /** @class */ (function (_super) {
        __extends(Section$$1, _super);
        function Section$$1() {
            return _super !== null && _super.apply(this, arguments) || this;
        }
        Section$$1.prototype.render = function () {
            return (react$1.createElement(Block, { attributes: this.props.attributes, builderBlock: this.props.builderBlock, innerStyleOverrides: { verticalAlign: this.props.verticalAlignContent } },
                react$1.createElement("table", __assign({ cellPadding: "0", cellSpacing: "0" }, {
                    width: '100%',
                    border: '0',
                }),
                    react$1.createElement("tbody", null,
                        react$1.createElement("tr", null,
                            react$1.createElement("td", null),
                            react$1.createElement("td", __assign({}, { align: 'center', width: this.props.maxWidth }, { style: { maxWidth: '100%' } }),
                                react$1.createElement("div", { style: { margin: 'auto', maxWidth: this.props.maxWidth } },
                                    react$1.createElement(BuilderBlocks, { blocks: this.props.children, dataPath: "children", emailMode: true }))),
                            react$1.createElement("td", null))))));
        };
        Section$$1 = __decorate([
            BuilderBlock$1({
                name: 'Email:Section',
                inputs: [
                    {
                        name: 'children',
                        type: 'uiBlocks',
                        defaultValue: [
                            {
                                '@type': '@builder.io/sdk:Element',
                                responsiveStyles: {
                                    large: {
                                        // marginTop: '20px',
                                        textAlign: 'center',
                                    },
                                },
                                component: {
                                    name: 'Email:Text',
                                    options: {
                                        text: "<span>I am a section! My content keeps from getting too wide, so that it's easy to read even on big screens. Lorem ipsum dolor kismet etc etc :)</span>",
                                    },
                                },
                            },
                        ],
                        // showNoBlocks: false
                        hideFromUI: true,
                    },
                    {
                        name: 'maxWidth',
                        type: 'number',
                        defaultValue: 800,
                    },
                    {
                        name: 'verticalAlignContent',
                        type: 'string',
                        enum: ['top', 'bottom', 'middle'],
                        defaultValue: 'top',
                    },
                ],
                defaultStyles: {
                    // height: '200px',
                    paddingLeft: '20px',
                    paddingRight: '20px',
                    paddingTop: '50px',
                    paddingBottom: '50px',
                    marginTop: '0px',
                },
            })
        ], Section$$1);
        return Section$$1;
    }(react$1.Component));

    var resetStyles = "\n/* Based on The MailChimp Reset INLINE: Yes. */\n\n/* Client-specific Styles */\n/* Force Outlook to provide a \"view in browser\" menu link. */\n#outlook a {\n    padding:0;\n}\n\na {\n    text-decoration: none;\n    color: inherit;\n}\n\nbody {\n    width:100% !important;\n    -webkit-text-size-adjust:100%;\n    -ms-text-size-adjust:100%;\n    margin:0;\n    padding:0;\n}\n\n/* Prevent Webkit and Windows Mobile platforms from changing default font sizes.*/\n/* Force Hotmail to display emails at full width */\n.ExternalClass {\n    width:100%;\n}\n.ExternalClass,\n.ExternalClass p,\n.ExternalClass span,\n.ExternalClass font,\n.ExternalClass td,\n.ExternalClass div {\n    line-height: 100%;\n}\n\n/* Forces Hotmail to display normal line spacing.  More on that: http://www.emailonacid.com/forum/viewthread/43/ */\n#backgroundTable {\n    margin:0;\n    padding:0;\n    width:100% !important;\n    line-height: 100% !important;\n}\n\n/* End reset */\n\n/* Some sensible defaults for images Bring inline: Yes. */\nimg {\n    outline:none;\n    text-decoration:none;\n    -ms-interpolation-mode: bicubic;\n}\n\na img {\n    border:none;\n}\n\n.image_fix {\n    display:block;\n}\n\n/* Yahoo paragraph fix Bring inline: Yes. */\np {\n    /* margin: 1em 0;*/\n    margin: 0;\n}\n\n/* Hotmail header color reset Bring inline: Yes. */\nh1, h2, h3, h4, h5, h6 {\n    color: black !important;\n}\n\nh1 a, h2 a, h3 a, h4 a, h5 a, h6 a {\n    color: blue !important;\n}\n\n/* Preferably not the same color as the normal header link color.  There is limited support for psuedo classes in email clients, this was added just for good measure. */\nh1 a:active,\nh2 a:active,\nh3 a:active,\nh4 a:active,\nh5 a:active,\nh6 a:active {\n    color: red !important;\n}\n\n/* Preferably not the same color as the normal header link color. There is limited support for psuedo classes in email clients, this was added just for good measure. */\nh1 a:visited,\nh2 a:visited,\nh3 a:visited,\nh4 a:visited,\nh5 a:visited,\nh6 a:visited {\n    color: purple !important;\n}\n\n/* Outlook 07, 10 Padding issue fix Bring inline: No.*/\ntable td {\n    border-collapse: collapse;\n}\n\n/* Remove spacing around Outlook 07, 10 tables Bring inline: Yes */\ntable {\n    border-collapse:collapse; mso-table-lspace:0pt; mso-table-rspace:0pt;\n}\n\n/* Styling your links has become much simpler with the new Yahoo.  In fact, it falls in line with the main credo of styling in email and make sure to bring your styles inline.  Your link colors will be uniform across clients when brought inline. Bring inline: Yes. */\na {\n    color: orange;\n}\n\n\n/***************************************************\n ****************************************************\n MOBILE TARGETING\n ****************************************************\n ***************************************************/\n @media only screen and (max-device-width: 480px) {\n     /* Part one of controlling phone number linking for mobile. */\n a[href^=\"tel\"], a[href^=\"sms\"] {\n     text-decoration: none;\n     color: blue; /* or whatever your want */\n     pointer-events: none;\n     cursor: default;\n }\n\n .mobile_link a[href^=\"tel\"], .mobile_link a[href^=\"sms\"] {\n     text-decoration: default;\n     color: orange !important;\n     pointer-events: auto;\n     cursor: default;\n }\n\n }\n\n /* More Specific Targeting */\n\n @media only screen and (min-device-width: 768px) and (max-device-width: 1024px) {\n /* You guessed it, ipad (tablets, smaller screens, etc) */\n     /* repeating for the ipad */\n     a[href^=\"tel\"], a[href^=\"sms\"] {\n                 text-decoration: none;\n                 color: blue; /* or whatever your want */\n                 pointer-events: none;\n                 cursor: default;\n             }\n\n .mobile_link a[href^=\"tel\"], .mobile_link a[href^=\"sms\"] {\n             text-decoration: default;\n             color: orange !important;\n             pointer-events: auto;\n             cursor: default;\n         }\n }\n\n @media only screen and (-webkit-min-device-pixel-ratio: 2) {\n /* iPhone 4g styles in here */\n }\n\n /* Android targeting */\n @media only screen and (-webkit-device-pixel-ratio:.75){\n /* CSS for low density (ldpi) Android layouts in here */\n }\n @media only screen and (-webkit-device-pixel-ratio:1){\n /* CSS for medium density (mdpi) Android layouts in here */\n }\n @media only screen and (-webkit-device-pixel-ratio:1.5){\n /* CSS for high density (hdpi) Android layouts in here */\n }\n /* end Android targeting */\n\n";

    var Email = /** @class */ (function (_super) {
        __extends(Email, _super);
        function Email() {
            return _super !== null && _super.apply(this, arguments) || this;
        }
        Email.prototype.render = function () {
            return (react$1.createElement(react$1.Fragment, null,
                react$1.createElement("html", null,
                    react$1.createElement("head", null,
                        react$1.createElement("meta", { "http-equiv": "Content-Type", content: "text/html; charset=utf-8" }),
                        react$1.createElement("meta", { name: "viewport", content: "width=device-width, initial-scale=1.0" }),
                        react$1.createElement("title", null, this.props.title),
                        react$1.createElement("style", { type: "text/css" }, resetStyles)),
                    react$1.createElement("body", null, this.props.children))));
        };
        Email = __decorate([
            BuilderBlock$1({
                name: 'Email:Email',
                inputs: [
                    {
                        name: 'title',
                        type: 'text',
                        required: true,
                        defaultValue: 'Email title',
                    },
                ],
            })
        ], Email);
        return Email;
    }(react$1.Component));

    var EmailPreview = /** @class */ (function (_super) {
        __extends(EmailPreview, _super);
        function EmailPreview() {
            return _super !== null && _super.apply(this, arguments) || this;
        }
        EmailPreview.prototype.render = function () {
            return (react$1.createElement("div", null,
                react$1.createElement("style", { type: "text/css" }, resetStyles),
                this.props.children));
        };
        return EmailPreview;
    }(react$1.Component));

    var EmailPreviewComponent = /** @class */ (function (_super) {
        __extends(EmailPreviewComponent, _super);
        function EmailPreviewComponent() {
            return _super !== null && _super.apply(this, arguments) || this;
        }
        EmailPreviewComponent.prototype.render = function () {
            return (react$1.createElement(EmailPreview, null,
                react$1.createElement(BuilderPage, __assign({ emailMode: true }, this.props))));
        };
        return EmailPreviewComponent;
    }(react$1.Component));

    exports.Box = Box;
    exports.Columns = Columns$1;
    exports.CustomCode = CustomCode$1;
    exports.Image = Image$1;
    exports.Text = Text$1;
    exports.Section = Section$1;
    exports.Email = Email;
    exports.EmailPreview = EmailPreview;
    exports.EmailPreviewComponent = EmailPreviewComponent;

    return exports;

}({}));
//# sourceMappingURL=builder-email.browser.js.map
